"""
# Terraform CDK AWS Provider

This repo builds and publishes the Terraform AWS Provider bindings for [cdktf](https://cdk.tf).

Current build targets are:

* [npm](https://cdk.tf)
* [Pypi](https://cdk.tf)

## Versioning

This project is explicitly not tracking the Terraform AWS Provider version 1:1. In fact, it always tracks `latest` of `~> 2.0` with every release. If there scenarios where you explicitly have to pin your provider version, you can do so by generating the [provider constructs manually](https://cdk.tf).

These are the upstream dependencies:

* [Terraform CDK](https://cdk.tf)
* [Terraform AWS Provider](https://cdk.tf/provider/aws-native)
* [Terraform Engine](https://cdk.tf/terraform)

If there are breaking changes (backward incompatible) in any of the above, the major version of this project will be bumped. While the Terraform Engine and the Terraform AWS Provider are relatively stable, the Terraform CDK is in an early stage. Therefore, it's likely that there will be breaking changes.

## Features / Issues / Bugs

Please report bugs and issues to the [terraform cdk](https://cdk.tf) project:

* [Create bug report](https://cdk.tf/bug)
* [Create feature request](https://cdk.tf/feature)

## Contributing

## projen

This is mostly based on [projen](https://github.com/eladb/projen), which takes care of generating the entire repository.

## cdktf-provider-project based on projen

There's a custom [project builder](https://github.com/skorfmann/cdktf-provider-project) which encapsulate the common settings for all `cdktf` providers.

## provider version

The provider version can be adjusted in [./.projenrc.js](./.projenrc.js).
"""
import abc
import builtins
import datetime
import enum
import typing

import jsii
import jsii.compat
import publication

from ._jsii import *

import cdktf
import constructs


class AccessanalyzerAnalyzer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AccessanalyzerAnalyzer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        analyzer_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param analyzer_name: 
        :param tags: 
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AccessanalyzerAnalyzerConfig(
            analyzer_name=analyzer_name,
            tags=tags,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AccessanalyzerAnalyzer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="analyzerName")
    def analyzer_name(self) -> str:
        return jsii.get(self, "analyzerName")

    @analyzer_name.setter
    def analyzer_name(self, value: str) -> None:
        jsii.set(self, "analyzerName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AccessanalyzerAnalyzerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "analyzer_name": "analyzerName",
        "tags": "tags",
        "type": "type",
    },
)
class AccessanalyzerAnalyzerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        analyzer_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param analyzer_name: 
        :param tags: 
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "analyzer_name": analyzer_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def analyzer_name(self) -> str:
        return self._values.get("analyzer_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AccessanalyzerAnalyzerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AcmCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AcmCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate_authority_arn: typing.Optional[str] = None,
        certificate_body: typing.Optional[str] = None,
        certificate_chain: typing.Optional[str] = None,
        domain_name: typing.Optional[str] = None,
        options: typing.Optional[typing.List["AcmCertificateOptions"]] = None,
        private_key: typing.Optional[str] = None,
        subject_alternative_names: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        validation_method: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_authority_arn: 
        :param certificate_body: 
        :param certificate_chain: 
        :param domain_name: 
        :param options: options block.
        :param private_key: 
        :param subject_alternative_names: 
        :param tags: 
        :param validation_method: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AcmCertificateConfig(
            certificate_authority_arn=certificate_authority_arn,
            certificate_body=certificate_body,
            certificate_chain=certificate_chain,
            domain_name=domain_name,
            options=options,
            private_key=private_key,
            subject_alternative_names=subject_alternative_names,
            tags=tags,
            validation_method=validation_method,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AcmCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="domainValidationOptions")
    def domain_validation_options(
        self, index: str
    ) -> "AcmCertificateDomainValidationOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "domainValidationOptions", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="validationEmails")
    def validation_emails(self) -> typing.List[str]:
        return jsii.get(self, "validationEmails")

    @builtins.property
    @jsii.member(jsii_name="certificateAuthorityArn")
    def certificate_authority_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateAuthorityArn")

    @certificate_authority_arn.setter
    def certificate_authority_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateAuthorityArn", value)

    @builtins.property
    @jsii.member(jsii_name="certificateBody")
    def certificate_body(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateBody")

    @certificate_body.setter
    def certificate_body(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateBody", value)

    @builtins.property
    @jsii.member(jsii_name="certificateChain")
    def certificate_chain(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateChain")

    @certificate_chain.setter
    def certificate_chain(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateChain", value)

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> typing.Optional[str]:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="options")
    def options(self) -> typing.Optional[typing.List["AcmCertificateOptions"]]:
        return jsii.get(self, "options")

    @options.setter
    def options(
        self, value: typing.Optional[typing.List["AcmCertificateOptions"]]
    ) -> None:
        jsii.set(self, "options", value)

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> typing.Optional[str]:
        return jsii.get(self, "privateKey")

    @private_key.setter
    def private_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateKey", value)

    @builtins.property
    @jsii.member(jsii_name="subjectAlternativeNames")
    def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subjectAlternativeNames")

    @subject_alternative_names.setter
    def subject_alternative_names(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "subjectAlternativeNames", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="validationMethod")
    def validation_method(self) -> typing.Optional[str]:
        return jsii.get(self, "validationMethod")

    @validation_method.setter
    def validation_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "validationMethod", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_authority_arn": "certificateAuthorityArn",
        "certificate_body": "certificateBody",
        "certificate_chain": "certificateChain",
        "domain_name": "domainName",
        "options": "options",
        "private_key": "privateKey",
        "subject_alternative_names": "subjectAlternativeNames",
        "tags": "tags",
        "validation_method": "validationMethod",
    },
)
class AcmCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_authority_arn: typing.Optional[str] = None,
        certificate_body: typing.Optional[str] = None,
        certificate_chain: typing.Optional[str] = None,
        domain_name: typing.Optional[str] = None,
        options: typing.Optional[typing.List["AcmCertificateOptions"]] = None,
        private_key: typing.Optional[str] = None,
        subject_alternative_names: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        validation_method: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_authority_arn: 
        :param certificate_body: 
        :param certificate_chain: 
        :param domain_name: 
        :param options: options block.
        :param private_key: 
        :param subject_alternative_names: 
        :param tags: 
        :param validation_method: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_authority_arn is not None:
            self._values["certificate_authority_arn"] = certificate_authority_arn
        if certificate_body is not None:
            self._values["certificate_body"] = certificate_body
        if certificate_chain is not None:
            self._values["certificate_chain"] = certificate_chain
        if domain_name is not None:
            self._values["domain_name"] = domain_name
        if options is not None:
            self._values["options"] = options
        if private_key is not None:
            self._values["private_key"] = private_key
        if subject_alternative_names is not None:
            self._values["subject_alternative_names"] = subject_alternative_names
        if tags is not None:
            self._values["tags"] = tags
        if validation_method is not None:
            self._values["validation_method"] = validation_method

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate_authority_arn(self) -> typing.Optional[str]:
        return self._values.get("certificate_authority_arn")

    @builtins.property
    def certificate_body(self) -> typing.Optional[str]:
        return self._values.get("certificate_body")

    @builtins.property
    def certificate_chain(self) -> typing.Optional[str]:
        return self._values.get("certificate_chain")

    @builtins.property
    def domain_name(self) -> typing.Optional[str]:
        return self._values.get("domain_name")

    @builtins.property
    def options(self) -> typing.Optional[typing.List["AcmCertificateOptions"]]:
        """options block."""
        return self._values.get("options")

    @builtins.property
    def private_key(self) -> typing.Optional[str]:
        return self._values.get("private_key")

    @builtins.property
    def subject_alternative_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subject_alternative_names")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def validation_method(self) -> typing.Optional[str]:
        return self._values.get("validation_method")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AcmCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AcmCertificateDomainValidationOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AcmCertificateDomainValidationOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            AcmCertificateDomainValidationOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @builtins.property
    @jsii.member(jsii_name="resourceRecordName")
    def resource_record_name(self) -> str:
        return jsii.get(self, "resourceRecordName")

    @builtins.property
    @jsii.member(jsii_name="resourceRecordType")
    def resource_record_type(self) -> str:
        return jsii.get(self, "resourceRecordType")

    @builtins.property
    @jsii.member(jsii_name="resourceRecordValue")
    def resource_record_value(self) -> str:
        return jsii.get(self, "resourceRecordValue")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmCertificateOptions",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_transparency_logging_preference": "certificateTransparencyLoggingPreference"
    },
)
class AcmCertificateOptions:
    def __init__(
        self,
        *,
        certificate_transparency_logging_preference: typing.Optional[str] = None,
    ) -> None:
        """
        :param certificate_transparency_logging_preference: 
        """
        self._values = {}
        if certificate_transparency_logging_preference is not None:
            self._values[
                "certificate_transparency_logging_preference"
            ] = certificate_transparency_logging_preference

    @builtins.property
    def certificate_transparency_logging_preference(self) -> typing.Optional[str]:
        return self._values.get("certificate_transparency_logging_preference")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AcmCertificateOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AcmCertificateValidation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AcmCertificateValidation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate_arn: str,
        timeouts: typing.Optional["AcmCertificateValidationTimeouts"] = None,
        validation_record_fqdns: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_arn: 
        :param timeouts: timeouts block.
        :param validation_record_fqdns: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AcmCertificateValidationConfig(
            certificate_arn=certificate_arn,
            timeouts=timeouts,
            validation_record_fqdns=validation_record_fqdns,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AcmCertificateValidation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> str:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: str) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AcmCertificateValidationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["AcmCertificateValidationTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="validationRecordFqdns")
    def validation_record_fqdns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "validationRecordFqdns")

    @validation_record_fqdns.setter
    def validation_record_fqdns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "validationRecordFqdns", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmCertificateValidationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_arn": "certificateArn",
        "timeouts": "timeouts",
        "validation_record_fqdns": "validationRecordFqdns",
    },
)
class AcmCertificateValidationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_arn: str,
        timeouts: typing.Optional["AcmCertificateValidationTimeouts"] = None,
        validation_record_fqdns: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_arn: 
        :param timeouts: timeouts block.
        :param validation_record_fqdns: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AcmCertificateValidationTimeouts(**timeouts)
        self._values = {
            "certificate_arn": certificate_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if validation_record_fqdns is not None:
            self._values["validation_record_fqdns"] = validation_record_fqdns

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate_arn(self) -> str:
        return self._values.get("certificate_arn")

    @builtins.property
    def timeouts(self) -> typing.Optional["AcmCertificateValidationTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def validation_record_fqdns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("validation_record_fqdns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AcmCertificateValidationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmCertificateValidationTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class AcmCertificateValidationTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AcmCertificateValidationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AcmpcaCertificateAuthority(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AcmpcaCertificateAuthority",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate_authority_configuration: typing.List[
            "AcmpcaCertificateAuthorityCertificateAuthorityConfiguration"
        ],
        enabled: typing.Optional[bool] = None,
        permanent_deletion_time_in_days: typing.Optional[jsii.Number] = None,
        revocation_configuration: typing.Optional[
            typing.List["AcmpcaCertificateAuthorityRevocationConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AcmpcaCertificateAuthorityTimeouts"] = None,
        type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_authority_configuration: certificate_authority_configuration block.
        :param enabled: 
        :param permanent_deletion_time_in_days: 
        :param revocation_configuration: revocation_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AcmpcaCertificateAuthorityConfig(
            certificate_authority_configuration=certificate_authority_configuration,
            enabled=enabled,
            permanent_deletion_time_in_days=permanent_deletion_time_in_days,
            revocation_configuration=revocation_configuration,
            tags=tags,
            timeouts=timeouts,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AcmpcaCertificateAuthority, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> str:
        return jsii.get(self, "certificate")

    @builtins.property
    @jsii.member(jsii_name="certificateChain")
    def certificate_chain(self) -> str:
        return jsii.get(self, "certificateChain")

    @builtins.property
    @jsii.member(jsii_name="certificateSigningRequest")
    def certificate_signing_request(self) -> str:
        return jsii.get(self, "certificateSigningRequest")

    @builtins.property
    @jsii.member(jsii_name="notAfter")
    def not_after(self) -> str:
        return jsii.get(self, "notAfter")

    @builtins.property
    @jsii.member(jsii_name="notBefore")
    def not_before(self) -> str:
        return jsii.get(self, "notBefore")

    @builtins.property
    @jsii.member(jsii_name="serial")
    def serial(self) -> str:
        return jsii.get(self, "serial")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="certificateAuthorityConfiguration")
    def certificate_authority_configuration(
        self,
    ) -> typing.List["AcmpcaCertificateAuthorityCertificateAuthorityConfiguration"]:
        return jsii.get(self, "certificateAuthorityConfiguration")

    @certificate_authority_configuration.setter
    def certificate_authority_configuration(
        self,
        value: typing.List[
            "AcmpcaCertificateAuthorityCertificateAuthorityConfiguration"
        ],
    ) -> None:
        jsii.set(self, "certificateAuthorityConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="permanentDeletionTimeInDays")
    def permanent_deletion_time_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "permanentDeletionTimeInDays")

    @permanent_deletion_time_in_days.setter
    def permanent_deletion_time_in_days(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "permanentDeletionTimeInDays", value)

    @builtins.property
    @jsii.member(jsii_name="revocationConfiguration")
    def revocation_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AcmpcaCertificateAuthorityRevocationConfiguration"]
    ]:
        return jsii.get(self, "revocationConfiguration")

    @revocation_configuration.setter
    def revocation_configuration(
        self,
        value: typing.Optional[
            typing.List["AcmpcaCertificateAuthorityRevocationConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "revocationConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AcmpcaCertificateAuthorityTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["AcmpcaCertificateAuthorityTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmpcaCertificateAuthorityCertificateAuthorityConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "key_algorithm": "keyAlgorithm",
        "signing_algorithm": "signingAlgorithm",
        "subject": "subject",
    },
)
class AcmpcaCertificateAuthorityCertificateAuthorityConfiguration:
    def __init__(
        self,
        *,
        key_algorithm: str,
        signing_algorithm: str,
        subject: typing.List[
            "AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject"
        ],
    ) -> None:
        """
        :param key_algorithm: 
        :param signing_algorithm: 
        :param subject: subject block.
        """
        self._values = {
            "key_algorithm": key_algorithm,
            "signing_algorithm": signing_algorithm,
            "subject": subject,
        }

    @builtins.property
    def key_algorithm(self) -> str:
        return self._values.get("key_algorithm")

    @builtins.property
    def signing_algorithm(self) -> str:
        return self._values.get("signing_algorithm")

    @builtins.property
    def subject(
        self,
    ) -> typing.List[
        "AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject"
    ]:
        """subject block."""
        return self._values.get("subject")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AcmpcaCertificateAuthorityCertificateAuthorityConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject",
    jsii_struct_bases=[],
    name_mapping={
        "common_name": "commonName",
        "country": "country",
        "distinguished_name_qualifier": "distinguishedNameQualifier",
        "generation_qualifier": "generationQualifier",
        "given_name": "givenName",
        "initials": "initials",
        "locality": "locality",
        "organization": "organization",
        "organizational_unit": "organizationalUnit",
        "pseudonym": "pseudonym",
        "state": "state",
        "surname": "surname",
        "title": "title",
    },
)
class AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject:
    def __init__(
        self,
        *,
        common_name: typing.Optional[str] = None,
        country: typing.Optional[str] = None,
        distinguished_name_qualifier: typing.Optional[str] = None,
        generation_qualifier: typing.Optional[str] = None,
        given_name: typing.Optional[str] = None,
        initials: typing.Optional[str] = None,
        locality: typing.Optional[str] = None,
        organization: typing.Optional[str] = None,
        organizational_unit: typing.Optional[str] = None,
        pseudonym: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        surname: typing.Optional[str] = None,
        title: typing.Optional[str] = None,
    ) -> None:
        """
        :param common_name: 
        :param country: 
        :param distinguished_name_qualifier: 
        :param generation_qualifier: 
        :param given_name: 
        :param initials: 
        :param locality: 
        :param organization: 
        :param organizational_unit: 
        :param pseudonym: 
        :param state: 
        :param surname: 
        :param title: 
        """
        self._values = {}
        if common_name is not None:
            self._values["common_name"] = common_name
        if country is not None:
            self._values["country"] = country
        if distinguished_name_qualifier is not None:
            self._values["distinguished_name_qualifier"] = distinguished_name_qualifier
        if generation_qualifier is not None:
            self._values["generation_qualifier"] = generation_qualifier
        if given_name is not None:
            self._values["given_name"] = given_name
        if initials is not None:
            self._values["initials"] = initials
        if locality is not None:
            self._values["locality"] = locality
        if organization is not None:
            self._values["organization"] = organization
        if organizational_unit is not None:
            self._values["organizational_unit"] = organizational_unit
        if pseudonym is not None:
            self._values["pseudonym"] = pseudonym
        if state is not None:
            self._values["state"] = state
        if surname is not None:
            self._values["surname"] = surname
        if title is not None:
            self._values["title"] = title

    @builtins.property
    def common_name(self) -> typing.Optional[str]:
        return self._values.get("common_name")

    @builtins.property
    def country(self) -> typing.Optional[str]:
        return self._values.get("country")

    @builtins.property
    def distinguished_name_qualifier(self) -> typing.Optional[str]:
        return self._values.get("distinguished_name_qualifier")

    @builtins.property
    def generation_qualifier(self) -> typing.Optional[str]:
        return self._values.get("generation_qualifier")

    @builtins.property
    def given_name(self) -> typing.Optional[str]:
        return self._values.get("given_name")

    @builtins.property
    def initials(self) -> typing.Optional[str]:
        return self._values.get("initials")

    @builtins.property
    def locality(self) -> typing.Optional[str]:
        return self._values.get("locality")

    @builtins.property
    def organization(self) -> typing.Optional[str]:
        return self._values.get("organization")

    @builtins.property
    def organizational_unit(self) -> typing.Optional[str]:
        return self._values.get("organizational_unit")

    @builtins.property
    def pseudonym(self) -> typing.Optional[str]:
        return self._values.get("pseudonym")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def surname(self) -> typing.Optional[str]:
        return self._values.get("surname")

    @builtins.property
    def title(self) -> typing.Optional[str]:
        return self._values.get("title")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmpcaCertificateAuthorityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_authority_configuration": "certificateAuthorityConfiguration",
        "enabled": "enabled",
        "permanent_deletion_time_in_days": "permanentDeletionTimeInDays",
        "revocation_configuration": "revocationConfiguration",
        "tags": "tags",
        "timeouts": "timeouts",
        "type": "type",
    },
)
class AcmpcaCertificateAuthorityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_authority_configuration: typing.List[
            "AcmpcaCertificateAuthorityCertificateAuthorityConfiguration"
        ],
        enabled: typing.Optional[bool] = None,
        permanent_deletion_time_in_days: typing.Optional[jsii.Number] = None,
        revocation_configuration: typing.Optional[
            typing.List["AcmpcaCertificateAuthorityRevocationConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AcmpcaCertificateAuthorityTimeouts"] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_authority_configuration: certificate_authority_configuration block.
        :param enabled: 
        :param permanent_deletion_time_in_days: 
        :param revocation_configuration: revocation_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AcmpcaCertificateAuthorityTimeouts(**timeouts)
        self._values = {
            "certificate_authority_configuration": certificate_authority_configuration,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if permanent_deletion_time_in_days is not None:
            self._values[
                "permanent_deletion_time_in_days"
            ] = permanent_deletion_time_in_days
        if revocation_configuration is not None:
            self._values["revocation_configuration"] = revocation_configuration
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate_authority_configuration(
        self,
    ) -> typing.List["AcmpcaCertificateAuthorityCertificateAuthorityConfiguration"]:
        """certificate_authority_configuration block."""
        return self._values.get("certificate_authority_configuration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def permanent_deletion_time_in_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("permanent_deletion_time_in_days")

    @builtins.property
    def revocation_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AcmpcaCertificateAuthorityRevocationConfiguration"]
    ]:
        """revocation_configuration block."""
        return self._values.get("revocation_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["AcmpcaCertificateAuthorityTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AcmpcaCertificateAuthorityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmpcaCertificateAuthorityRevocationConfiguration",
    jsii_struct_bases=[],
    name_mapping={"crl_configuration": "crlConfiguration"},
)
class AcmpcaCertificateAuthorityRevocationConfiguration:
    def __init__(
        self,
        *,
        crl_configuration: typing.Optional[
            typing.List[
                "AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration"
            ]
        ] = None,
    ) -> None:
        """
        :param crl_configuration: crl_configuration block.
        """
        self._values = {}
        if crl_configuration is not None:
            self._values["crl_configuration"] = crl_configuration

    @builtins.property
    def crl_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration"]
    ]:
        """crl_configuration block."""
        return self._values.get("crl_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AcmpcaCertificateAuthorityRevocationConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "expiration_in_days": "expirationInDays",
        "custom_cname": "customCname",
        "enabled": "enabled",
        "s3_bucket_name": "s3BucketName",
    },
)
class AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration:
    def __init__(
        self,
        *,
        expiration_in_days: jsii.Number,
        custom_cname: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        s3_bucket_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param expiration_in_days: 
        :param custom_cname: 
        :param enabled: 
        :param s3_bucket_name: 
        """
        self._values = {
            "expiration_in_days": expiration_in_days,
        }
        if custom_cname is not None:
            self._values["custom_cname"] = custom_cname
        if enabled is not None:
            self._values["enabled"] = enabled
        if s3_bucket_name is not None:
            self._values["s3_bucket_name"] = s3_bucket_name

    @builtins.property
    def expiration_in_days(self) -> jsii.Number:
        return self._values.get("expiration_in_days")

    @builtins.property
    def custom_cname(self) -> typing.Optional[str]:
        return self._values.get("custom_cname")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def s3_bucket_name(self) -> typing.Optional[str]:
        return self._values.get("s3_bucket_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AcmpcaCertificateAuthorityTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class AcmpcaCertificateAuthorityTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AcmpcaCertificateAuthorityTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Alb(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Alb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        access_logs: typing.Optional[typing.List["AlbAccessLogs"]] = None,
        drop_invalid_header_fields: typing.Optional[bool] = None,
        enable_cross_zone_load_balancing: typing.Optional[bool] = None,
        enable_deletion_protection: typing.Optional[bool] = None,
        enable_http2: typing.Optional[bool] = None,
        idle_timeout: typing.Optional[jsii.Number] = None,
        internal: typing.Optional[bool] = None,
        ip_address_type: typing.Optional[str] = None,
        load_balancer_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        subnet_mapping: typing.Optional[typing.List["AlbSubnetMapping"]] = None,
        subnets: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AlbTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param access_logs: access_logs block.
        :param drop_invalid_header_fields: 
        :param enable_cross_zone_load_balancing: 
        :param enable_deletion_protection: 
        :param enable_http2: 
        :param idle_timeout: 
        :param internal: 
        :param ip_address_type: 
        :param load_balancer_type: 
        :param name: 
        :param name_prefix: 
        :param security_groups: 
        :param subnet_mapping: subnet_mapping block.
        :param subnets: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AlbConfig(
            access_logs=access_logs,
            drop_invalid_header_fields=drop_invalid_header_fields,
            enable_cross_zone_load_balancing=enable_cross_zone_load_balancing,
            enable_deletion_protection=enable_deletion_protection,
            enable_http2=enable_http2,
            idle_timeout=idle_timeout,
            internal=internal,
            ip_address_type=ip_address_type,
            load_balancer_type=load_balancer_type,
            name=name,
            name_prefix=name_prefix,
            security_groups=security_groups,
            subnet_mapping=subnet_mapping,
            subnets=subnets,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Alb, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @builtins.property
    @jsii.member(jsii_name="accessLogs")
    def access_logs(self) -> typing.Optional[typing.List["AlbAccessLogs"]]:
        return jsii.get(self, "accessLogs")

    @access_logs.setter
    def access_logs(self, value: typing.Optional[typing.List["AlbAccessLogs"]]) -> None:
        jsii.set(self, "accessLogs", value)

    @builtins.property
    @jsii.member(jsii_name="dropInvalidHeaderFields")
    def drop_invalid_header_fields(self) -> typing.Optional[bool]:
        return jsii.get(self, "dropInvalidHeaderFields")

    @drop_invalid_header_fields.setter
    def drop_invalid_header_fields(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "dropInvalidHeaderFields", value)

    @builtins.property
    @jsii.member(jsii_name="enableCrossZoneLoadBalancing")
    def enable_cross_zone_load_balancing(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableCrossZoneLoadBalancing")

    @enable_cross_zone_load_balancing.setter
    def enable_cross_zone_load_balancing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableCrossZoneLoadBalancing", value)

    @builtins.property
    @jsii.member(jsii_name="enableDeletionProtection")
    def enable_deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableDeletionProtection")

    @enable_deletion_protection.setter
    def enable_deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableDeletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="enableHttp2")
    def enable_http2(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableHttp2")

    @enable_http2.setter
    def enable_http2(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableHttp2", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeout")

    @idle_timeout.setter
    def idle_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="internal")
    def internal(self) -> typing.Optional[bool]:
        return jsii.get(self, "internal")

    @internal.setter
    def internal(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "internal", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddressType")
    def ip_address_type(self) -> typing.Optional[str]:
        return jsii.get(self, "ipAddressType")

    @ip_address_type.setter
    def ip_address_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipAddressType", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerType")
    def load_balancer_type(self) -> typing.Optional[str]:
        return jsii.get(self, "loadBalancerType")

    @load_balancer_type.setter
    def load_balancer_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "loadBalancerType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="subnetMapping")
    def subnet_mapping(self) -> typing.Optional[typing.List["AlbSubnetMapping"]]:
        return jsii.get(self, "subnetMapping")

    @subnet_mapping.setter
    def subnet_mapping(
        self, value: typing.Optional[typing.List["AlbSubnetMapping"]]
    ) -> None:
        jsii.set(self, "subnetMapping", value)

    @builtins.property
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnets")

    @subnets.setter
    def subnets(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnets", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AlbTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["AlbTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbAccessLogs",
    jsii_struct_bases=[],
    name_mapping={"bucket": "bucket", "enabled": "enabled", "prefix": "prefix"},
)
class AlbAccessLogs:
    def __init__(
        self,
        *,
        bucket: str,
        enabled: typing.Optional[bool] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket: 
        :param enabled: 
        :param prefix: 
        """
        self._values = {
            "bucket": bucket,
        }
        if enabled is not None:
            self._values["enabled"] = enabled
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbAccessLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_logs": "accessLogs",
        "drop_invalid_header_fields": "dropInvalidHeaderFields",
        "enable_cross_zone_load_balancing": "enableCrossZoneLoadBalancing",
        "enable_deletion_protection": "enableDeletionProtection",
        "enable_http2": "enableHttp2",
        "idle_timeout": "idleTimeout",
        "internal": "internal",
        "ip_address_type": "ipAddressType",
        "load_balancer_type": "loadBalancerType",
        "name": "name",
        "name_prefix": "namePrefix",
        "security_groups": "securityGroups",
        "subnet_mapping": "subnetMapping",
        "subnets": "subnets",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AlbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_logs: typing.Optional[typing.List["AlbAccessLogs"]] = None,
        drop_invalid_header_fields: typing.Optional[bool] = None,
        enable_cross_zone_load_balancing: typing.Optional[bool] = None,
        enable_deletion_protection: typing.Optional[bool] = None,
        enable_http2: typing.Optional[bool] = None,
        idle_timeout: typing.Optional[jsii.Number] = None,
        internal: typing.Optional[bool] = None,
        ip_address_type: typing.Optional[str] = None,
        load_balancer_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        subnet_mapping: typing.Optional[typing.List["AlbSubnetMapping"]] = None,
        subnets: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AlbTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_logs: access_logs block.
        :param drop_invalid_header_fields: 
        :param enable_cross_zone_load_balancing: 
        :param enable_deletion_protection: 
        :param enable_http2: 
        :param idle_timeout: 
        :param internal: 
        :param ip_address_type: 
        :param load_balancer_type: 
        :param name: 
        :param name_prefix: 
        :param security_groups: 
        :param subnet_mapping: subnet_mapping block.
        :param subnets: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AlbTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_logs is not None:
            self._values["access_logs"] = access_logs
        if drop_invalid_header_fields is not None:
            self._values["drop_invalid_header_fields"] = drop_invalid_header_fields
        if enable_cross_zone_load_balancing is not None:
            self._values[
                "enable_cross_zone_load_balancing"
            ] = enable_cross_zone_load_balancing
        if enable_deletion_protection is not None:
            self._values["enable_deletion_protection"] = enable_deletion_protection
        if enable_http2 is not None:
            self._values["enable_http2"] = enable_http2
        if idle_timeout is not None:
            self._values["idle_timeout"] = idle_timeout
        if internal is not None:
            self._values["internal"] = internal
        if ip_address_type is not None:
            self._values["ip_address_type"] = ip_address_type
        if load_balancer_type is not None:
            self._values["load_balancer_type"] = load_balancer_type
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if subnet_mapping is not None:
            self._values["subnet_mapping"] = subnet_mapping
        if subnets is not None:
            self._values["subnets"] = subnets
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def access_logs(self) -> typing.Optional[typing.List["AlbAccessLogs"]]:
        """access_logs block."""
        return self._values.get("access_logs")

    @builtins.property
    def drop_invalid_header_fields(self) -> typing.Optional[bool]:
        return self._values.get("drop_invalid_header_fields")

    @builtins.property
    def enable_cross_zone_load_balancing(self) -> typing.Optional[bool]:
        return self._values.get("enable_cross_zone_load_balancing")

    @builtins.property
    def enable_deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("enable_deletion_protection")

    @builtins.property
    def enable_http2(self) -> typing.Optional[bool]:
        return self._values.get("enable_http2")

    @builtins.property
    def idle_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("idle_timeout")

    @builtins.property
    def internal(self) -> typing.Optional[bool]:
        return self._values.get("internal")

    @builtins.property
    def ip_address_type(self) -> typing.Optional[str]:
        return self._values.get("ip_address_type")

    @builtins.property
    def load_balancer_type(self) -> typing.Optional[str]:
        return self._values.get("load_balancer_type")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def subnet_mapping(self) -> typing.Optional[typing.List["AlbSubnetMapping"]]:
        """subnet_mapping block."""
        return self._values.get("subnet_mapping")

    @builtins.property
    def subnets(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnets")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["AlbTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbListener(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListener",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_action: typing.List["AlbListenerDefaultAction"],
        load_balancer_arn: str,
        port: jsii.Number,
        certificate_arn: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        ssl_policy: typing.Optional[str] = None,
        timeouts: typing.Optional["AlbListenerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_action: default_action block.
        :param load_balancer_arn: 
        :param port: 
        :param certificate_arn: 
        :param protocol: 
        :param ssl_policy: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AlbListenerConfig(
            default_action=default_action,
            load_balancer_arn=load_balancer_arn,
            port=port,
            certificate_arn=certificate_arn,
            protocol=protocol,
            ssl_policy=ssl_policy,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AlbListener, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultAction")
    def default_action(self) -> typing.List["AlbListenerDefaultAction"]:
        return jsii.get(self, "defaultAction")

    @default_action.setter
    def default_action(self, value: typing.List["AlbListenerDefaultAction"]) -> None:
        jsii.set(self, "defaultAction", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerArn")
    def load_balancer_arn(self) -> str:
        return jsii.get(self, "loadBalancerArn")

    @load_balancer_arn.setter
    def load_balancer_arn(self, value: str) -> None:
        jsii.set(self, "loadBalancerArn", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> typing.Optional[str]:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="sslPolicy")
    def ssl_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "sslPolicy")

    @ssl_policy.setter
    def ssl_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sslPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AlbListenerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["AlbListenerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class AlbListenerCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate_arn: str,
        listener_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_arn: 
        :param listener_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AlbListenerCertificateConfig(
            certificate_arn=certificate_arn,
            listener_arn=listener_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AlbListenerCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> str:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: str) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="listenerArn")
    def listener_arn(self) -> str:
        return jsii.get(self, "listenerArn")

    @listener_arn.setter
    def listener_arn(self, value: str) -> None:
        jsii.set(self, "listenerArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_arn": "certificateArn",
        "listener_arn": "listenerArn",
    },
)
class AlbListenerCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_arn: str,
        listener_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_arn: 
        :param listener_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "certificate_arn": certificate_arn,
            "listener_arn": listener_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate_arn(self) -> str:
        return self._values.get("certificate_arn")

    @builtins.property
    def listener_arn(self) -> str:
        return self._values.get("listener_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_action": "defaultAction",
        "load_balancer_arn": "loadBalancerArn",
        "port": "port",
        "certificate_arn": "certificateArn",
        "protocol": "protocol",
        "ssl_policy": "sslPolicy",
        "timeouts": "timeouts",
    },
)
class AlbListenerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_action: typing.List["AlbListenerDefaultAction"],
        load_balancer_arn: str,
        port: jsii.Number,
        certificate_arn: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        ssl_policy: typing.Optional[str] = None,
        timeouts: typing.Optional["AlbListenerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_action: default_action block.
        :param load_balancer_arn: 
        :param port: 
        :param certificate_arn: 
        :param protocol: 
        :param ssl_policy: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AlbListenerTimeouts(**timeouts)
        self._values = {
            "default_action": default_action,
            "load_balancer_arn": load_balancer_arn,
            "port": port,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_arn is not None:
            self._values["certificate_arn"] = certificate_arn
        if protocol is not None:
            self._values["protocol"] = protocol
        if ssl_policy is not None:
            self._values["ssl_policy"] = ssl_policy
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_action(self) -> typing.List["AlbListenerDefaultAction"]:
        """default_action block."""
        return self._values.get("default_action")

    @builtins.property
    def load_balancer_arn(self) -> str:
        return self._values.get("load_balancer_arn")

    @builtins.property
    def port(self) -> jsii.Number:
        return self._values.get("port")

    @builtins.property
    def certificate_arn(self) -> typing.Optional[str]:
        return self._values.get("certificate_arn")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def ssl_policy(self) -> typing.Optional[str]:
        return self._values.get("ssl_policy")

    @builtins.property
    def timeouts(self) -> typing.Optional["AlbListenerTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultAction",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "authenticate_cognito": "authenticateCognito",
        "authenticate_oidc": "authenticateOidc",
        "fixed_response": "fixedResponse",
        "forward": "forward",
        "order": "order",
        "redirect": "redirect",
        "target_group_arn": "targetGroupArn",
    },
)
class AlbListenerDefaultAction:
    def __init__(
        self,
        *,
        type: str,
        authenticate_cognito: typing.Optional[
            typing.List["AlbListenerDefaultActionAuthenticateCognito"]
        ] = None,
        authenticate_oidc: typing.Optional[
            typing.List["AlbListenerDefaultActionAuthenticateOidc"]
        ] = None,
        fixed_response: typing.Optional[
            typing.List["AlbListenerDefaultActionFixedResponse"]
        ] = None,
        forward: typing.Optional[typing.List["AlbListenerDefaultActionForward"]] = None,
        order: typing.Optional[jsii.Number] = None,
        redirect: typing.Optional[
            typing.List["AlbListenerDefaultActionRedirect"]
        ] = None,
        target_group_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param authenticate_cognito: authenticate_cognito block.
        :param authenticate_oidc: authenticate_oidc block.
        :param fixed_response: fixed_response block.
        :param forward: forward block.
        :param order: 
        :param redirect: redirect block.
        :param target_group_arn: 
        """
        self._values = {
            "type": type,
        }
        if authenticate_cognito is not None:
            self._values["authenticate_cognito"] = authenticate_cognito
        if authenticate_oidc is not None:
            self._values["authenticate_oidc"] = authenticate_oidc
        if fixed_response is not None:
            self._values["fixed_response"] = fixed_response
        if forward is not None:
            self._values["forward"] = forward
        if order is not None:
            self._values["order"] = order
        if redirect is not None:
            self._values["redirect"] = redirect
        if target_group_arn is not None:
            self._values["target_group_arn"] = target_group_arn

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def authenticate_cognito(
        self,
    ) -> typing.Optional[typing.List["AlbListenerDefaultActionAuthenticateCognito"]]:
        """authenticate_cognito block."""
        return self._values.get("authenticate_cognito")

    @builtins.property
    def authenticate_oidc(
        self,
    ) -> typing.Optional[typing.List["AlbListenerDefaultActionAuthenticateOidc"]]:
        """authenticate_oidc block."""
        return self._values.get("authenticate_oidc")

    @builtins.property
    def fixed_response(
        self,
    ) -> typing.Optional[typing.List["AlbListenerDefaultActionFixedResponse"]]:
        """fixed_response block."""
        return self._values.get("fixed_response")

    @builtins.property
    def forward(
        self,
    ) -> typing.Optional[typing.List["AlbListenerDefaultActionForward"]]:
        """forward block."""
        return self._values.get("forward")

    @builtins.property
    def order(self) -> typing.Optional[jsii.Number]:
        return self._values.get("order")

    @builtins.property
    def redirect(
        self,
    ) -> typing.Optional[typing.List["AlbListenerDefaultActionRedirect"]]:
        """redirect block."""
        return self._values.get("redirect")

    @builtins.property
    def target_group_arn(self) -> typing.Optional[str]:
        return self._values.get("target_group_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultActionAuthenticateCognito",
    jsii_struct_bases=[],
    name_mapping={
        "user_pool_arn": "userPoolArn",
        "user_pool_client_id": "userPoolClientId",
        "user_pool_domain": "userPoolDomain",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class AlbListenerDefaultActionAuthenticateCognito:
    def __init__(
        self,
        *,
        user_pool_arn: str,
        user_pool_client_id: str,
        user_pool_domain: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param user_pool_arn: 
        :param user_pool_client_id: 
        :param user_pool_domain: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "user_pool_arn": user_pool_arn,
            "user_pool_client_id": user_pool_client_id,
            "user_pool_domain": user_pool_domain,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def user_pool_arn(self) -> str:
        return self._values.get("user_pool_arn")

    @builtins.property
    def user_pool_client_id(self) -> str:
        return self._values.get("user_pool_client_id")

    @builtins.property
    def user_pool_domain(self) -> str:
        return self._values.get("user_pool_domain")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultActionAuthenticateCognito(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultActionAuthenticateOidc",
    jsii_struct_bases=[],
    name_mapping={
        "authorization_endpoint": "authorizationEndpoint",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "issuer": "issuer",
        "token_endpoint": "tokenEndpoint",
        "user_info_endpoint": "userInfoEndpoint",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class AlbListenerDefaultActionAuthenticateOidc:
    def __init__(
        self,
        *,
        authorization_endpoint: str,
        client_id: str,
        client_secret: str,
        issuer: str,
        token_endpoint: str,
        user_info_endpoint: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param authorization_endpoint: 
        :param client_id: 
        :param client_secret: 
        :param issuer: 
        :param token_endpoint: 
        :param user_info_endpoint: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "authorization_endpoint": authorization_endpoint,
            "client_id": client_id,
            "client_secret": client_secret,
            "issuer": issuer,
            "token_endpoint": token_endpoint,
            "user_info_endpoint": user_info_endpoint,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def authorization_endpoint(self) -> str:
        return self._values.get("authorization_endpoint")

    @builtins.property
    def client_id(self) -> str:
        return self._values.get("client_id")

    @builtins.property
    def client_secret(self) -> str:
        return self._values.get("client_secret")

    @builtins.property
    def issuer(self) -> str:
        return self._values.get("issuer")

    @builtins.property
    def token_endpoint(self) -> str:
        return self._values.get("token_endpoint")

    @builtins.property
    def user_info_endpoint(self) -> str:
        return self._values.get("user_info_endpoint")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultActionAuthenticateOidc(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultActionFixedResponse",
    jsii_struct_bases=[],
    name_mapping={
        "content_type": "contentType",
        "message_body": "messageBody",
        "status_code": "statusCode",
    },
)
class AlbListenerDefaultActionFixedResponse:
    def __init__(
        self,
        *,
        content_type: str,
        message_body: typing.Optional[str] = None,
        status_code: typing.Optional[str] = None,
    ) -> None:
        """
        :param content_type: 
        :param message_body: 
        :param status_code: 
        """
        self._values = {
            "content_type": content_type,
        }
        if message_body is not None:
            self._values["message_body"] = message_body
        if status_code is not None:
            self._values["status_code"] = status_code

    @builtins.property
    def content_type(self) -> str:
        return self._values.get("content_type")

    @builtins.property
    def message_body(self) -> typing.Optional[str]:
        return self._values.get("message_body")

    @builtins.property
    def status_code(self) -> typing.Optional[str]:
        return self._values.get("status_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultActionFixedResponse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultActionForward",
    jsii_struct_bases=[],
    name_mapping={"target_group": "targetGroup", "stickiness": "stickiness"},
)
class AlbListenerDefaultActionForward:
    def __init__(
        self,
        *,
        target_group: typing.List["AlbListenerDefaultActionForwardTargetGroup"],
        stickiness: typing.Optional[
            typing.List["AlbListenerDefaultActionForwardStickiness"]
        ] = None,
    ) -> None:
        """
        :param target_group: target_group block.
        :param stickiness: stickiness block.
        """
        self._values = {
            "target_group": target_group,
        }
        if stickiness is not None:
            self._values["stickiness"] = stickiness

    @builtins.property
    def target_group(self) -> typing.List["AlbListenerDefaultActionForwardTargetGroup"]:
        """target_group block."""
        return self._values.get("target_group")

    @builtins.property
    def stickiness(
        self,
    ) -> typing.Optional[typing.List["AlbListenerDefaultActionForwardStickiness"]]:
        """stickiness block."""
        return self._values.get("stickiness")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultActionForward(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultActionForwardStickiness",
    jsii_struct_bases=[],
    name_mapping={"duration": "duration", "enabled": "enabled"},
)
class AlbListenerDefaultActionForwardStickiness:
    def __init__(
        self, *, duration: jsii.Number, enabled: typing.Optional[bool] = None
    ) -> None:
        """
        :param duration: 
        :param enabled: 
        """
        self._values = {
            "duration": duration,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def duration(self) -> jsii.Number:
        return self._values.get("duration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultActionForwardStickiness(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultActionForwardTargetGroup",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "weight": "weight"},
)
class AlbListenerDefaultActionForwardTargetGroup:
    def __init__(
        self, *, arn: str, weight: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param arn: 
        :param weight: 
        """
        self._values = {
            "arn": arn,
        }
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultActionForwardTargetGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerDefaultActionRedirect",
    jsii_struct_bases=[],
    name_mapping={
        "status_code": "statusCode",
        "host": "host",
        "path": "path",
        "port": "port",
        "protocol": "protocol",
        "query": "query",
    },
)
class AlbListenerDefaultActionRedirect:
    def __init__(
        self,
        *,
        status_code: str,
        host: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        port: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        query: typing.Optional[str] = None,
    ) -> None:
        """
        :param status_code: 
        :param host: 
        :param path: 
        :param port: 
        :param protocol: 
        :param query: 
        """
        self._values = {
            "status_code": status_code,
        }
        if host is not None:
            self._values["host"] = host
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if query is not None:
            self._values["query"] = query

    @builtins.property
    def status_code(self) -> str:
        return self._values.get("status_code")

    @builtins.property
    def host(self) -> typing.Optional[str]:
        return self._values.get("host")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def port(self) -> typing.Optional[str]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def query(self) -> typing.Optional[str]:
        return self._values.get("query")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerDefaultActionRedirect(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbListenerRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        action: typing.List["AlbListenerRuleAction"],
        condition: typing.List["AlbListenerRuleCondition"],
        listener_arn: str,
        priority: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param action: action block.
        :param condition: condition block.
        :param listener_arn: 
        :param priority: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AlbListenerRuleConfig(
            action=action,
            condition=condition,
            listener_arn=listener_arn,
            priority=priority,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AlbListenerRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="action")
    def action(self) -> typing.List["AlbListenerRuleAction"]:
        return jsii.get(self, "action")

    @action.setter
    def action(self, value: typing.List["AlbListenerRuleAction"]) -> None:
        jsii.set(self, "action", value)

    @builtins.property
    @jsii.member(jsii_name="condition")
    def condition(self) -> typing.List["AlbListenerRuleCondition"]:
        return jsii.get(self, "condition")

    @condition.setter
    def condition(self, value: typing.List["AlbListenerRuleCondition"]) -> None:
        jsii.set(self, "condition", value)

    @builtins.property
    @jsii.member(jsii_name="listenerArn")
    def listener_arn(self) -> str:
        return jsii.get(self, "listenerArn")

    @listener_arn.setter
    def listener_arn(self, value: str) -> None:
        jsii.set(self, "listenerArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "priority")

    @priority.setter
    def priority(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "priority", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleAction",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "authenticate_cognito": "authenticateCognito",
        "authenticate_oidc": "authenticateOidc",
        "fixed_response": "fixedResponse",
        "forward": "forward",
        "order": "order",
        "redirect": "redirect",
        "target_group_arn": "targetGroupArn",
    },
)
class AlbListenerRuleAction:
    def __init__(
        self,
        *,
        type: str,
        authenticate_cognito: typing.Optional[
            typing.List["AlbListenerRuleActionAuthenticateCognito"]
        ] = None,
        authenticate_oidc: typing.Optional[
            typing.List["AlbListenerRuleActionAuthenticateOidc"]
        ] = None,
        fixed_response: typing.Optional[
            typing.List["AlbListenerRuleActionFixedResponse"]
        ] = None,
        forward: typing.Optional[typing.List["AlbListenerRuleActionForward"]] = None,
        order: typing.Optional[jsii.Number] = None,
        redirect: typing.Optional[typing.List["AlbListenerRuleActionRedirect"]] = None,
        target_group_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param authenticate_cognito: authenticate_cognito block.
        :param authenticate_oidc: authenticate_oidc block.
        :param fixed_response: fixed_response block.
        :param forward: forward block.
        :param order: 
        :param redirect: redirect block.
        :param target_group_arn: 
        """
        self._values = {
            "type": type,
        }
        if authenticate_cognito is not None:
            self._values["authenticate_cognito"] = authenticate_cognito
        if authenticate_oidc is not None:
            self._values["authenticate_oidc"] = authenticate_oidc
        if fixed_response is not None:
            self._values["fixed_response"] = fixed_response
        if forward is not None:
            self._values["forward"] = forward
        if order is not None:
            self._values["order"] = order
        if redirect is not None:
            self._values["redirect"] = redirect
        if target_group_arn is not None:
            self._values["target_group_arn"] = target_group_arn

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def authenticate_cognito(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleActionAuthenticateCognito"]]:
        """authenticate_cognito block."""
        return self._values.get("authenticate_cognito")

    @builtins.property
    def authenticate_oidc(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleActionAuthenticateOidc"]]:
        """authenticate_oidc block."""
        return self._values.get("authenticate_oidc")

    @builtins.property
    def fixed_response(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleActionFixedResponse"]]:
        """fixed_response block."""
        return self._values.get("fixed_response")

    @builtins.property
    def forward(self) -> typing.Optional[typing.List["AlbListenerRuleActionForward"]]:
        """forward block."""
        return self._values.get("forward")

    @builtins.property
    def order(self) -> typing.Optional[jsii.Number]:
        return self._values.get("order")

    @builtins.property
    def redirect(self) -> typing.Optional[typing.List["AlbListenerRuleActionRedirect"]]:
        """redirect block."""
        return self._values.get("redirect")

    @builtins.property
    def target_group_arn(self) -> typing.Optional[str]:
        return self._values.get("target_group_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleActionAuthenticateCognito",
    jsii_struct_bases=[],
    name_mapping={
        "user_pool_arn": "userPoolArn",
        "user_pool_client_id": "userPoolClientId",
        "user_pool_domain": "userPoolDomain",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class AlbListenerRuleActionAuthenticateCognito:
    def __init__(
        self,
        *,
        user_pool_arn: str,
        user_pool_client_id: str,
        user_pool_domain: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param user_pool_arn: 
        :param user_pool_client_id: 
        :param user_pool_domain: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "user_pool_arn": user_pool_arn,
            "user_pool_client_id": user_pool_client_id,
            "user_pool_domain": user_pool_domain,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def user_pool_arn(self) -> str:
        return self._values.get("user_pool_arn")

    @builtins.property
    def user_pool_client_id(self) -> str:
        return self._values.get("user_pool_client_id")

    @builtins.property
    def user_pool_domain(self) -> str:
        return self._values.get("user_pool_domain")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleActionAuthenticateCognito(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleActionAuthenticateOidc",
    jsii_struct_bases=[],
    name_mapping={
        "authorization_endpoint": "authorizationEndpoint",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "issuer": "issuer",
        "token_endpoint": "tokenEndpoint",
        "user_info_endpoint": "userInfoEndpoint",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class AlbListenerRuleActionAuthenticateOidc:
    def __init__(
        self,
        *,
        authorization_endpoint: str,
        client_id: str,
        client_secret: str,
        issuer: str,
        token_endpoint: str,
        user_info_endpoint: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param authorization_endpoint: 
        :param client_id: 
        :param client_secret: 
        :param issuer: 
        :param token_endpoint: 
        :param user_info_endpoint: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "authorization_endpoint": authorization_endpoint,
            "client_id": client_id,
            "client_secret": client_secret,
            "issuer": issuer,
            "token_endpoint": token_endpoint,
            "user_info_endpoint": user_info_endpoint,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def authorization_endpoint(self) -> str:
        return self._values.get("authorization_endpoint")

    @builtins.property
    def client_id(self) -> str:
        return self._values.get("client_id")

    @builtins.property
    def client_secret(self) -> str:
        return self._values.get("client_secret")

    @builtins.property
    def issuer(self) -> str:
        return self._values.get("issuer")

    @builtins.property
    def token_endpoint(self) -> str:
        return self._values.get("token_endpoint")

    @builtins.property
    def user_info_endpoint(self) -> str:
        return self._values.get("user_info_endpoint")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleActionAuthenticateOidc(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleActionFixedResponse",
    jsii_struct_bases=[],
    name_mapping={
        "content_type": "contentType",
        "message_body": "messageBody",
        "status_code": "statusCode",
    },
)
class AlbListenerRuleActionFixedResponse:
    def __init__(
        self,
        *,
        content_type: str,
        message_body: typing.Optional[str] = None,
        status_code: typing.Optional[str] = None,
    ) -> None:
        """
        :param content_type: 
        :param message_body: 
        :param status_code: 
        """
        self._values = {
            "content_type": content_type,
        }
        if message_body is not None:
            self._values["message_body"] = message_body
        if status_code is not None:
            self._values["status_code"] = status_code

    @builtins.property
    def content_type(self) -> str:
        return self._values.get("content_type")

    @builtins.property
    def message_body(self) -> typing.Optional[str]:
        return self._values.get("message_body")

    @builtins.property
    def status_code(self) -> typing.Optional[str]:
        return self._values.get("status_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleActionFixedResponse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleActionForward",
    jsii_struct_bases=[],
    name_mapping={"target_group": "targetGroup", "stickiness": "stickiness"},
)
class AlbListenerRuleActionForward:
    def __init__(
        self,
        *,
        target_group: typing.List["AlbListenerRuleActionForwardTargetGroup"],
        stickiness: typing.Optional[
            typing.List["AlbListenerRuleActionForwardStickiness"]
        ] = None,
    ) -> None:
        """
        :param target_group: target_group block.
        :param stickiness: stickiness block.
        """
        self._values = {
            "target_group": target_group,
        }
        if stickiness is not None:
            self._values["stickiness"] = stickiness

    @builtins.property
    def target_group(self) -> typing.List["AlbListenerRuleActionForwardTargetGroup"]:
        """target_group block."""
        return self._values.get("target_group")

    @builtins.property
    def stickiness(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleActionForwardStickiness"]]:
        """stickiness block."""
        return self._values.get("stickiness")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleActionForward(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleActionForwardStickiness",
    jsii_struct_bases=[],
    name_mapping={"duration": "duration", "enabled": "enabled"},
)
class AlbListenerRuleActionForwardStickiness:
    def __init__(
        self, *, duration: jsii.Number, enabled: typing.Optional[bool] = None
    ) -> None:
        """
        :param duration: 
        :param enabled: 
        """
        self._values = {
            "duration": duration,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def duration(self) -> jsii.Number:
        return self._values.get("duration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleActionForwardStickiness(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleActionForwardTargetGroup",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "weight": "weight"},
)
class AlbListenerRuleActionForwardTargetGroup:
    def __init__(
        self, *, arn: str, weight: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param arn: 
        :param weight: 
        """
        self._values = {
            "arn": arn,
        }
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleActionForwardTargetGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleActionRedirect",
    jsii_struct_bases=[],
    name_mapping={
        "status_code": "statusCode",
        "host": "host",
        "path": "path",
        "port": "port",
        "protocol": "protocol",
        "query": "query",
    },
)
class AlbListenerRuleActionRedirect:
    def __init__(
        self,
        *,
        status_code: str,
        host: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        port: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        query: typing.Optional[str] = None,
    ) -> None:
        """
        :param status_code: 
        :param host: 
        :param path: 
        :param port: 
        :param protocol: 
        :param query: 
        """
        self._values = {
            "status_code": status_code,
        }
        if host is not None:
            self._values["host"] = host
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if query is not None:
            self._values["query"] = query

    @builtins.property
    def status_code(self) -> str:
        return self._values.get("status_code")

    @builtins.property
    def host(self) -> typing.Optional[str]:
        return self._values.get("host")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def port(self) -> typing.Optional[str]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def query(self) -> typing.Optional[str]:
        return self._values.get("query")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleActionRedirect(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleCondition",
    jsii_struct_bases=[],
    name_mapping={
        "field": "field",
        "host_header": "hostHeader",
        "http_header": "httpHeader",
        "http_request_method": "httpRequestMethod",
        "path_pattern": "pathPattern",
        "query_string": "queryString",
        "source_ip": "sourceIp",
        "values": "values",
    },
)
class AlbListenerRuleCondition:
    def __init__(
        self,
        *,
        field: typing.Optional[str] = None,
        host_header: typing.Optional[
            typing.List["AlbListenerRuleConditionHostHeader"]
        ] = None,
        http_header: typing.Optional[
            typing.List["AlbListenerRuleConditionHttpHeader"]
        ] = None,
        http_request_method: typing.Optional[
            typing.List["AlbListenerRuleConditionHttpRequestMethod"]
        ] = None,
        path_pattern: typing.Optional[
            typing.List["AlbListenerRuleConditionPathPattern"]
        ] = None,
        query_string: typing.Optional[
            typing.List["AlbListenerRuleConditionQueryString"]
        ] = None,
        source_ip: typing.Optional[
            typing.List["AlbListenerRuleConditionSourceIp"]
        ] = None,
        values: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param field: 
        :param host_header: host_header block.
        :param http_header: http_header block.
        :param http_request_method: http_request_method block.
        :param path_pattern: path_pattern block.
        :param query_string: query_string block.
        :param source_ip: source_ip block.
        :param values: 
        """
        self._values = {}
        if field is not None:
            self._values["field"] = field
        if host_header is not None:
            self._values["host_header"] = host_header
        if http_header is not None:
            self._values["http_header"] = http_header
        if http_request_method is not None:
            self._values["http_request_method"] = http_request_method
        if path_pattern is not None:
            self._values["path_pattern"] = path_pattern
        if query_string is not None:
            self._values["query_string"] = query_string
        if source_ip is not None:
            self._values["source_ip"] = source_ip
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def field(self) -> typing.Optional[str]:
        return self._values.get("field")

    @builtins.property
    def host_header(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleConditionHostHeader"]]:
        """host_header block."""
        return self._values.get("host_header")

    @builtins.property
    def http_header(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleConditionHttpHeader"]]:
        """http_header block."""
        return self._values.get("http_header")

    @builtins.property
    def http_request_method(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleConditionHttpRequestMethod"]]:
        """http_request_method block."""
        return self._values.get("http_request_method")

    @builtins.property
    def path_pattern(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleConditionPathPattern"]]:
        """path_pattern block."""
        return self._values.get("path_pattern")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleConditionQueryString"]]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def source_ip(
        self,
    ) -> typing.Optional[typing.List["AlbListenerRuleConditionSourceIp"]]:
        """source_ip block."""
        return self._values.get("source_ip")

    @builtins.property
    def values(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleCondition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleConditionHostHeader",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class AlbListenerRuleConditionHostHeader:
    def __init__(self, *, values: typing.Optional[typing.List[str]] = None) -> None:
        """
        :param values: 
        """
        self._values = {}
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def values(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleConditionHostHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleConditionHttpHeader",
    jsii_struct_bases=[],
    name_mapping={"http_header_name": "httpHeaderName", "values": "values"},
)
class AlbListenerRuleConditionHttpHeader:
    def __init__(self, *, http_header_name: str, values: typing.List[str]) -> None:
        """
        :param http_header_name: 
        :param values: 
        """
        self._values = {
            "http_header_name": http_header_name,
            "values": values,
        }

    @builtins.property
    def http_header_name(self) -> str:
        return self._values.get("http_header_name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleConditionHttpHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleConditionHttpRequestMethod",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class AlbListenerRuleConditionHttpRequestMethod:
    def __init__(self, *, values: typing.List[str]) -> None:
        """
        :param values: 
        """
        self._values = {
            "values": values,
        }

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleConditionHttpRequestMethod(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleConditionPathPattern",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class AlbListenerRuleConditionPathPattern:
    def __init__(self, *, values: typing.Optional[typing.List[str]] = None) -> None:
        """
        :param values: 
        """
        self._values = {}
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def values(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleConditionPathPattern(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleConditionQueryString",
    jsii_struct_bases=[],
    name_mapping={"value": "value", "key": "key"},
)
class AlbListenerRuleConditionQueryString:
    def __init__(self, *, value: str, key: typing.Optional[str] = None) -> None:
        """
        :param value: 
        :param key: 
        """
        self._values = {
            "value": value,
        }
        if key is not None:
            self._values["key"] = key

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def key(self) -> typing.Optional[str]:
        return self._values.get("key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleConditionQueryString(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleConditionSourceIp",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class AlbListenerRuleConditionSourceIp:
    def __init__(self, *, values: typing.List[str]) -> None:
        """
        :param values: 
        """
        self._values = {
            "values": values,
        }

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleConditionSourceIp(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "action": "action",
        "condition": "condition",
        "listener_arn": "listenerArn",
        "priority": "priority",
    },
)
class AlbListenerRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        action: typing.List["AlbListenerRuleAction"],
        condition: typing.List["AlbListenerRuleCondition"],
        listener_arn: str,
        priority: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param action: action block.
        :param condition: condition block.
        :param listener_arn: 
        :param priority: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "action": action,
            "condition": condition,
            "listener_arn": listener_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if priority is not None:
            self._values["priority"] = priority

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def action(self) -> typing.List["AlbListenerRuleAction"]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def condition(self) -> typing.List["AlbListenerRuleCondition"]:
        """condition block."""
        return self._values.get("condition")

    @builtins.property
    def listener_arn(self) -> str:
        return self._values.get("listener_arn")

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        return self._values.get("priority")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbListenerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class AlbListenerTimeouts:
    def __init__(self, *, read: typing.Optional[str] = None) -> None:
        """
        :param read: 
        """
        self._values = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[str]:
        return self._values.get("read")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbListenerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbSubnetMapping",
    jsii_struct_bases=[],
    name_mapping={"subnet_id": "subnetId", "allocation_id": "allocationId"},
)
class AlbSubnetMapping:
    def __init__(
        self, *, subnet_id: str, allocation_id: typing.Optional[str] = None
    ) -> None:
        """
        :param subnet_id: 
        :param allocation_id: 
        """
        self._values = {
            "subnet_id": subnet_id,
        }
        if allocation_id is not None:
            self._values["allocation_id"] = allocation_id

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    @builtins.property
    def allocation_id(self) -> typing.Optional[str]:
        return self._values.get("allocation_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbSubnetMapping(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AlbTargetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AlbTargetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        deregistration_delay: typing.Optional[jsii.Number] = None,
        health_check: typing.Optional[typing.List["AlbTargetGroupHealthCheck"]] = None,
        lambda_multi_value_headers_enabled: typing.Optional[bool] = None,
        load_balancing_algorithm_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[str] = None,
        proxy_protocol_v2: typing.Optional[bool] = None,
        slow_start: typing.Optional[jsii.Number] = None,
        stickiness: typing.Optional[typing.List["AlbTargetGroupStickiness"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_type: typing.Optional[str] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param deregistration_delay: 
        :param health_check: health_check block.
        :param lambda_multi_value_headers_enabled: 
        :param load_balancing_algorithm_type: 
        :param name: 
        :param name_prefix: 
        :param port: 
        :param protocol: 
        :param proxy_protocol_v2: 
        :param slow_start: 
        :param stickiness: stickiness block.
        :param tags: 
        :param target_type: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AlbTargetGroupConfig(
            deregistration_delay=deregistration_delay,
            health_check=health_check,
            lambda_multi_value_headers_enabled=lambda_multi_value_headers_enabled,
            load_balancing_algorithm_type=load_balancing_algorithm_type,
            name=name,
            name_prefix=name_prefix,
            port=port,
            protocol=protocol,
            proxy_protocol_v2=proxy_protocol_v2,
            slow_start=slow_start,
            stickiness=stickiness,
            tags=tags,
            target_type=target_type,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AlbTargetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="deregistrationDelay")
    def deregistration_delay(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "deregistrationDelay")

    @deregistration_delay.setter
    def deregistration_delay(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "deregistrationDelay", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheck")
    def health_check(self) -> typing.Optional[typing.List["AlbTargetGroupHealthCheck"]]:
        return jsii.get(self, "healthCheck")

    @health_check.setter
    def health_check(
        self, value: typing.Optional[typing.List["AlbTargetGroupHealthCheck"]]
    ) -> None:
        jsii.set(self, "healthCheck", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaMultiValueHeadersEnabled")
    def lambda_multi_value_headers_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "lambdaMultiValueHeadersEnabled")

    @lambda_multi_value_headers_enabled.setter
    def lambda_multi_value_headers_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "lambdaMultiValueHeadersEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancingAlgorithmType")
    def load_balancing_algorithm_type(self) -> typing.Optional[str]:
        return jsii.get(self, "loadBalancingAlgorithmType")

    @load_balancing_algorithm_type.setter
    def load_balancing_algorithm_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "loadBalancingAlgorithmType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> typing.Optional[str]:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="proxyProtocolV2")
    def proxy_protocol_v2(self) -> typing.Optional[bool]:
        return jsii.get(self, "proxyProtocolV2")

    @proxy_protocol_v2.setter
    def proxy_protocol_v2(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "proxyProtocolV2", value)

    @builtins.property
    @jsii.member(jsii_name="slowStart")
    def slow_start(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "slowStart")

    @slow_start.setter
    def slow_start(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "slowStart", value)

    @builtins.property
    @jsii.member(jsii_name="stickiness")
    def stickiness(self) -> typing.Optional[typing.List["AlbTargetGroupStickiness"]]:
        return jsii.get(self, "stickiness")

    @stickiness.setter
    def stickiness(
        self, value: typing.Optional[typing.List["AlbTargetGroupStickiness"]]
    ) -> None:
        jsii.set(self, "stickiness", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="targetType")
    def target_type(self) -> typing.Optional[str]:
        return jsii.get(self, "targetType")

    @target_type.setter
    def target_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "targetType", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


class AlbTargetGroupAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AlbTargetGroupAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        target_group_arn: str,
        target_id: str,
        availability_zone: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param target_group_arn: 
        :param target_id: 
        :param availability_zone: 
        :param port: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AlbTargetGroupAttachmentConfig(
            target_group_arn=target_group_arn,
            target_id=target_id,
            availability_zone=availability_zone,
            port=port,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AlbTargetGroupAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="targetGroupArn")
    def target_group_arn(self) -> str:
        return jsii.get(self, "targetGroupArn")

    @target_group_arn.setter
    def target_group_arn(self, value: str) -> None:
        jsii.set(self, "targetGroupArn", value)

    @builtins.property
    @jsii.member(jsii_name="targetId")
    def target_id(self) -> str:
        return jsii.get(self, "targetId")

    @target_id.setter
    def target_id(self, value: str) -> None:
        jsii.set(self, "targetId", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbTargetGroupAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "target_group_arn": "targetGroupArn",
        "target_id": "targetId",
        "availability_zone": "availabilityZone",
        "port": "port",
    },
)
class AlbTargetGroupAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        target_group_arn: str,
        target_id: str,
        availability_zone: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param target_group_arn: 
        :param target_id: 
        :param availability_zone: 
        :param port: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "target_group_arn": target_group_arn,
            "target_id": target_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def target_group_arn(self) -> str:
        return self._values.get("target_group_arn")

    @builtins.property
    def target_id(self) -> str:
        return self._values.get("target_id")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTargetGroupAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "deregistration_delay": "deregistrationDelay",
        "health_check": "healthCheck",
        "lambda_multi_value_headers_enabled": "lambdaMultiValueHeadersEnabled",
        "load_balancing_algorithm_type": "loadBalancingAlgorithmType",
        "name": "name",
        "name_prefix": "namePrefix",
        "port": "port",
        "protocol": "protocol",
        "proxy_protocol_v2": "proxyProtocolV2",
        "slow_start": "slowStart",
        "stickiness": "stickiness",
        "tags": "tags",
        "target_type": "targetType",
        "vpc_id": "vpcId",
    },
)
class AlbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        deregistration_delay: typing.Optional[jsii.Number] = None,
        health_check: typing.Optional[typing.List["AlbTargetGroupHealthCheck"]] = None,
        lambda_multi_value_headers_enabled: typing.Optional[bool] = None,
        load_balancing_algorithm_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[str] = None,
        proxy_protocol_v2: typing.Optional[bool] = None,
        slow_start: typing.Optional[jsii.Number] = None,
        stickiness: typing.Optional[typing.List["AlbTargetGroupStickiness"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_type: typing.Optional[str] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param deregistration_delay: 
        :param health_check: health_check block.
        :param lambda_multi_value_headers_enabled: 
        :param load_balancing_algorithm_type: 
        :param name: 
        :param name_prefix: 
        :param port: 
        :param protocol: 
        :param proxy_protocol_v2: 
        :param slow_start: 
        :param stickiness: stickiness block.
        :param tags: 
        :param target_type: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deregistration_delay is not None:
            self._values["deregistration_delay"] = deregistration_delay
        if health_check is not None:
            self._values["health_check"] = health_check
        if lambda_multi_value_headers_enabled is not None:
            self._values[
                "lambda_multi_value_headers_enabled"
            ] = lambda_multi_value_headers_enabled
        if load_balancing_algorithm_type is not None:
            self._values[
                "load_balancing_algorithm_type"
            ] = load_balancing_algorithm_type
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if proxy_protocol_v2 is not None:
            self._values["proxy_protocol_v2"] = proxy_protocol_v2
        if slow_start is not None:
            self._values["slow_start"] = slow_start
        if stickiness is not None:
            self._values["stickiness"] = stickiness
        if tags is not None:
            self._values["tags"] = tags
        if target_type is not None:
            self._values["target_type"] = target_type
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def deregistration_delay(self) -> typing.Optional[jsii.Number]:
        return self._values.get("deregistration_delay")

    @builtins.property
    def health_check(self) -> typing.Optional[typing.List["AlbTargetGroupHealthCheck"]]:
        """health_check block."""
        return self._values.get("health_check")

    @builtins.property
    def lambda_multi_value_headers_enabled(self) -> typing.Optional[bool]:
        return self._values.get("lambda_multi_value_headers_enabled")

    @builtins.property
    def load_balancing_algorithm_type(self) -> typing.Optional[str]:
        return self._values.get("load_balancing_algorithm_type")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def proxy_protocol_v2(self) -> typing.Optional[bool]:
        return self._values.get("proxy_protocol_v2")

    @builtins.property
    def slow_start(self) -> typing.Optional[jsii.Number]:
        return self._values.get("slow_start")

    @builtins.property
    def stickiness(self) -> typing.Optional[typing.List["AlbTargetGroupStickiness"]]:
        """stickiness block."""
        return self._values.get("stickiness")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target_type(self) -> typing.Optional[str]:
        return self._values.get("target_type")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbTargetGroupHealthCheck",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "healthy_threshold": "healthyThreshold",
        "interval": "interval",
        "matcher": "matcher",
        "path": "path",
        "port": "port",
        "protocol": "protocol",
        "timeout": "timeout",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class AlbTargetGroupHealthCheck:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        interval: typing.Optional[jsii.Number] = None,
        matcher: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        port: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        timeout: typing.Optional[jsii.Number] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param enabled: 
        :param healthy_threshold: 
        :param interval: 
        :param matcher: 
        :param path: 
        :param port: 
        :param protocol: 
        :param timeout: 
        :param unhealthy_threshold: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if interval is not None:
            self._values["interval"] = interval
        if matcher is not None:
            self._values["matcher"] = matcher
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if timeout is not None:
            self._values["timeout"] = timeout
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("healthy_threshold")

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("interval")

    @builtins.property
    def matcher(self) -> typing.Optional[str]:
        return self._values.get("matcher")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def port(self) -> typing.Optional[str]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout")

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("unhealthy_threshold")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTargetGroupHealthCheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbTargetGroupStickiness",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "cookie_duration": "cookieDuration",
        "enabled": "enabled",
    },
)
class AlbTargetGroupStickiness:
    def __init__(
        self,
        *,
        type: str,
        cookie_duration: typing.Optional[jsii.Number] = None,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param type: 
        :param cookie_duration: 
        :param enabled: 
        """
        self._values = {
            "type": type,
        }
        if cookie_duration is not None:
            self._values["cookie_duration"] = cookie_duration
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def cookie_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cookie_duration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTargetGroupStickiness(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AlbTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AlbTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AlbTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ami(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ami",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        architecture: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        ebs_block_device: typing.Optional[typing.List["AmiEbsBlockDevice"]] = None,
        ena_support: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["AmiEphemeralBlockDevice"]
        ] = None,
        image_location: typing.Optional[str] = None,
        kernel_id: typing.Optional[str] = None,
        ramdisk_id: typing.Optional[str] = None,
        root_device_name: typing.Optional[str] = None,
        sriov_net_support: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AmiTimeouts"] = None,
        virtualization_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param architecture: 
        :param description: 
        :param ebs_block_device: ebs_block_device block.
        :param ena_support: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param image_location: 
        :param kernel_id: 
        :param ramdisk_id: 
        :param root_device_name: 
        :param sriov_net_support: 
        :param tags: 
        :param timeouts: timeouts block.
        :param virtualization_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AmiConfig(
            name=name,
            architecture=architecture,
            description=description,
            ebs_block_device=ebs_block_device,
            ena_support=ena_support,
            ephemeral_block_device=ephemeral_block_device,
            image_location=image_location,
            kernel_id=kernel_id,
            ramdisk_id=ramdisk_id,
            root_device_name=root_device_name,
            sriov_net_support=sriov_net_support,
            tags=tags,
            timeouts=timeouts,
            virtualization_type=virtualization_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ami, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="manageEbsSnapshots")
    def manage_ebs_snapshots(self) -> bool:
        return jsii.get(self, "manageEbsSnapshots")

    @builtins.property
    @jsii.member(jsii_name="rootSnapshotId")
    def root_snapshot_id(self) -> str:
        return jsii.get(self, "rootSnapshotId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="architecture")
    def architecture(self) -> typing.Optional[str]:
        return jsii.get(self, "architecture")

    @architecture.setter
    def architecture(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "architecture", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(self) -> typing.Optional[typing.List["AmiEbsBlockDevice"]]:
        return jsii.get(self, "ebsBlockDevice")

    @ebs_block_device.setter
    def ebs_block_device(
        self, value: typing.Optional[typing.List["AmiEbsBlockDevice"]]
    ) -> None:
        jsii.set(self, "ebsBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="enaSupport")
    def ena_support(self) -> typing.Optional[bool]:
        return jsii.get(self, "enaSupport")

    @ena_support.setter
    def ena_support(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enaSupport", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiEphemeralBlockDevice"]]:
        return jsii.get(self, "ephemeralBlockDevice")

    @ephemeral_block_device.setter
    def ephemeral_block_device(
        self, value: typing.Optional[typing.List["AmiEphemeralBlockDevice"]]
    ) -> None:
        jsii.set(self, "ephemeralBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="imageLocation")
    def image_location(self) -> typing.Optional[str]:
        return jsii.get(self, "imageLocation")

    @image_location.setter
    def image_location(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "imageLocation", value)

    @builtins.property
    @jsii.member(jsii_name="kernelId")
    def kernel_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kernelId")

    @kernel_id.setter
    def kernel_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kernelId", value)

    @builtins.property
    @jsii.member(jsii_name="ramdiskId")
    def ramdisk_id(self) -> typing.Optional[str]:
        return jsii.get(self, "ramdiskId")

    @ramdisk_id.setter
    def ramdisk_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ramdiskId", value)

    @builtins.property
    @jsii.member(jsii_name="rootDeviceName")
    def root_device_name(self) -> typing.Optional[str]:
        return jsii.get(self, "rootDeviceName")

    @root_device_name.setter
    def root_device_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rootDeviceName", value)

    @builtins.property
    @jsii.member(jsii_name="sriovNetSupport")
    def sriov_net_support(self) -> typing.Optional[str]:
        return jsii.get(self, "sriovNetSupport")

    @sriov_net_support.setter
    def sriov_net_support(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sriovNetSupport", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AmiTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["AmiTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="virtualizationType")
    def virtualization_type(self) -> typing.Optional[str]:
        return jsii.get(self, "virtualizationType")

    @virtualization_type.setter
    def virtualization_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "virtualizationType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "architecture": "architecture",
        "description": "description",
        "ebs_block_device": "ebsBlockDevice",
        "ena_support": "enaSupport",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "image_location": "imageLocation",
        "kernel_id": "kernelId",
        "ramdisk_id": "ramdiskId",
        "root_device_name": "rootDeviceName",
        "sriov_net_support": "sriovNetSupport",
        "tags": "tags",
        "timeouts": "timeouts",
        "virtualization_type": "virtualizationType",
    },
)
class AmiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        architecture: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        ebs_block_device: typing.Optional[typing.List["AmiEbsBlockDevice"]] = None,
        ena_support: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["AmiEphemeralBlockDevice"]
        ] = None,
        image_location: typing.Optional[str] = None,
        kernel_id: typing.Optional[str] = None,
        ramdisk_id: typing.Optional[str] = None,
        root_device_name: typing.Optional[str] = None,
        sriov_net_support: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AmiTimeouts"] = None,
        virtualization_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param architecture: 
        :param description: 
        :param ebs_block_device: ebs_block_device block.
        :param ena_support: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param image_location: 
        :param kernel_id: 
        :param ramdisk_id: 
        :param root_device_name: 
        :param sriov_net_support: 
        :param tags: 
        :param timeouts: timeouts block.
        :param virtualization_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AmiTimeouts(**timeouts)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if architecture is not None:
            self._values["architecture"] = architecture
        if description is not None:
            self._values["description"] = description
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if ena_support is not None:
            self._values["ena_support"] = ena_support
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if image_location is not None:
            self._values["image_location"] = image_location
        if kernel_id is not None:
            self._values["kernel_id"] = kernel_id
        if ramdisk_id is not None:
            self._values["ramdisk_id"] = ramdisk_id
        if root_device_name is not None:
            self._values["root_device_name"] = root_device_name
        if sriov_net_support is not None:
            self._values["sriov_net_support"] = sriov_net_support
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if virtualization_type is not None:
            self._values["virtualization_type"] = virtualization_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def architecture(self) -> typing.Optional[str]:
        return self._values.get("architecture")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def ebs_block_device(self) -> typing.Optional[typing.List["AmiEbsBlockDevice"]]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def ena_support(self) -> typing.Optional[bool]:
        return self._values.get("ena_support")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiEphemeralBlockDevice"]]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def image_location(self) -> typing.Optional[str]:
        return self._values.get("image_location")

    @builtins.property
    def kernel_id(self) -> typing.Optional[str]:
        return self._values.get("kernel_id")

    @builtins.property
    def ramdisk_id(self) -> typing.Optional[str]:
        return self._values.get("ramdisk_id")

    @builtins.property
    def root_device_name(self) -> typing.Optional[str]:
        return self._values.get("root_device_name")

    @builtins.property
    def sriov_net_support(self) -> typing.Optional[str]:
        return self._values.get("sriov_net_support")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["AmiTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def virtualization_type(self) -> typing.Optional[str]:
        return self._values.get("virtualization_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AmiCopy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AmiCopy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        source_ami_id: str,
        source_ami_region: str,
        description: typing.Optional[str] = None,
        ebs_block_device: typing.Optional[typing.List["AmiCopyEbsBlockDevice"]] = None,
        encrypted: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["AmiCopyEphemeralBlockDevice"]
        ] = None,
        kms_key_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AmiCopyTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param source_ami_id: 
        :param source_ami_region: 
        :param description: 
        :param ebs_block_device: ebs_block_device block.
        :param encrypted: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param kms_key_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AmiCopyConfig(
            name=name,
            source_ami_id=source_ami_id,
            source_ami_region=source_ami_region,
            description=description,
            ebs_block_device=ebs_block_device,
            encrypted=encrypted,
            ephemeral_block_device=ephemeral_block_device,
            kms_key_id=kms_key_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AmiCopy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="architecture")
    def architecture(self) -> str:
        return jsii.get(self, "architecture")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="enaSupport")
    def ena_support(self) -> bool:
        return jsii.get(self, "enaSupport")

    @builtins.property
    @jsii.member(jsii_name="imageLocation")
    def image_location(self) -> str:
        return jsii.get(self, "imageLocation")

    @builtins.property
    @jsii.member(jsii_name="kernelId")
    def kernel_id(self) -> str:
        return jsii.get(self, "kernelId")

    @builtins.property
    @jsii.member(jsii_name="manageEbsSnapshots")
    def manage_ebs_snapshots(self) -> bool:
        return jsii.get(self, "manageEbsSnapshots")

    @builtins.property
    @jsii.member(jsii_name="ramdiskId")
    def ramdisk_id(self) -> str:
        return jsii.get(self, "ramdiskId")

    @builtins.property
    @jsii.member(jsii_name="rootDeviceName")
    def root_device_name(self) -> str:
        return jsii.get(self, "rootDeviceName")

    @builtins.property
    @jsii.member(jsii_name="rootSnapshotId")
    def root_snapshot_id(self) -> str:
        return jsii.get(self, "rootSnapshotId")

    @builtins.property
    @jsii.member(jsii_name="sriovNetSupport")
    def sriov_net_support(self) -> str:
        return jsii.get(self, "sriovNetSupport")

    @builtins.property
    @jsii.member(jsii_name="virtualizationType")
    def virtualization_type(self) -> str:
        return jsii.get(self, "virtualizationType")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="sourceAmiId")
    def source_ami_id(self) -> str:
        return jsii.get(self, "sourceAmiId")

    @source_ami_id.setter
    def source_ami_id(self, value: str) -> None:
        jsii.set(self, "sourceAmiId", value)

    @builtins.property
    @jsii.member(jsii_name="sourceAmiRegion")
    def source_ami_region(self) -> str:
        return jsii.get(self, "sourceAmiRegion")

    @source_ami_region.setter
    def source_ami_region(self, value: str) -> None:
        jsii.set(self, "sourceAmiRegion", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(self) -> typing.Optional[typing.List["AmiCopyEbsBlockDevice"]]:
        return jsii.get(self, "ebsBlockDevice")

    @ebs_block_device.setter
    def ebs_block_device(
        self, value: typing.Optional[typing.List["AmiCopyEbsBlockDevice"]]
    ) -> None:
        jsii.set(self, "ebsBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiCopyEphemeralBlockDevice"]]:
        return jsii.get(self, "ephemeralBlockDevice")

    @ephemeral_block_device.setter
    def ephemeral_block_device(
        self, value: typing.Optional[typing.List["AmiCopyEphemeralBlockDevice"]]
    ) -> None:
        jsii.set(self, "ephemeralBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AmiCopyTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["AmiCopyTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiCopyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "source_ami_id": "sourceAmiId",
        "source_ami_region": "sourceAmiRegion",
        "description": "description",
        "ebs_block_device": "ebsBlockDevice",
        "encrypted": "encrypted",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "kms_key_id": "kmsKeyId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AmiCopyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        source_ami_id: str,
        source_ami_region: str,
        description: typing.Optional[str] = None,
        ebs_block_device: typing.Optional[typing.List["AmiCopyEbsBlockDevice"]] = None,
        encrypted: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["AmiCopyEphemeralBlockDevice"]
        ] = None,
        kms_key_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AmiCopyTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param source_ami_id: 
        :param source_ami_region: 
        :param description: 
        :param ebs_block_device: ebs_block_device block.
        :param encrypted: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param kms_key_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AmiCopyTimeouts(**timeouts)
        self._values = {
            "name": name,
            "source_ami_id": source_ami_id,
            "source_ami_region": source_ami_region,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def source_ami_id(self) -> str:
        return self._values.get("source_ami_id")

    @builtins.property
    def source_ami_region(self) -> str:
        return self._values.get("source_ami_region")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def ebs_block_device(self) -> typing.Optional[typing.List["AmiCopyEbsBlockDevice"]]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiCopyEphemeralBlockDevice"]]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["AmiCopyTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiCopyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiCopyEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={},
)
class AmiCopyEbsBlockDevice:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiCopyEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiCopyEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={},
)
class AmiCopyEphemeralBlockDevice:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiCopyEphemeralBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiCopyTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AmiCopyTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiCopyTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "snapshot_id": "snapshotId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class AmiEbsBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param snapshot_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {
            "device_name": device_name,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={"device_name": "deviceName", "virtual_name": "virtualName"},
)
class AmiEphemeralBlockDevice:
    def __init__(self, *, device_name: str, virtual_name: str) -> None:
        """
        :param device_name: 
        :param virtual_name: 
        """
        self._values = {
            "device_name": device_name,
            "virtual_name": virtual_name,
        }

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def virtual_name(self) -> str:
        return self._values.get("virtual_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiEphemeralBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AmiFromInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AmiFromInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        source_instance_id: str,
        description: typing.Optional[str] = None,
        ebs_block_device: typing.Optional[
            typing.List["AmiFromInstanceEbsBlockDevice"]
        ] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["AmiFromInstanceEphemeralBlockDevice"]
        ] = None,
        snapshot_without_reboot: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AmiFromInstanceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param source_instance_id: 
        :param description: 
        :param ebs_block_device: ebs_block_device block.
        :param ephemeral_block_device: ephemeral_block_device block.
        :param snapshot_without_reboot: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AmiFromInstanceConfig(
            name=name,
            source_instance_id=source_instance_id,
            description=description,
            ebs_block_device=ebs_block_device,
            ephemeral_block_device=ephemeral_block_device,
            snapshot_without_reboot=snapshot_without_reboot,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AmiFromInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="architecture")
    def architecture(self) -> str:
        return jsii.get(self, "architecture")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="enaSupport")
    def ena_support(self) -> bool:
        return jsii.get(self, "enaSupport")

    @builtins.property
    @jsii.member(jsii_name="imageLocation")
    def image_location(self) -> str:
        return jsii.get(self, "imageLocation")

    @builtins.property
    @jsii.member(jsii_name="kernelId")
    def kernel_id(self) -> str:
        return jsii.get(self, "kernelId")

    @builtins.property
    @jsii.member(jsii_name="manageEbsSnapshots")
    def manage_ebs_snapshots(self) -> bool:
        return jsii.get(self, "manageEbsSnapshots")

    @builtins.property
    @jsii.member(jsii_name="ramdiskId")
    def ramdisk_id(self) -> str:
        return jsii.get(self, "ramdiskId")

    @builtins.property
    @jsii.member(jsii_name="rootDeviceName")
    def root_device_name(self) -> str:
        return jsii.get(self, "rootDeviceName")

    @builtins.property
    @jsii.member(jsii_name="rootSnapshotId")
    def root_snapshot_id(self) -> str:
        return jsii.get(self, "rootSnapshotId")

    @builtins.property
    @jsii.member(jsii_name="sriovNetSupport")
    def sriov_net_support(self) -> str:
        return jsii.get(self, "sriovNetSupport")

    @builtins.property
    @jsii.member(jsii_name="virtualizationType")
    def virtualization_type(self) -> str:
        return jsii.get(self, "virtualizationType")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="sourceInstanceId")
    def source_instance_id(self) -> str:
        return jsii.get(self, "sourceInstanceId")

    @source_instance_id.setter
    def source_instance_id(self, value: str) -> None:
        jsii.set(self, "sourceInstanceId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiFromInstanceEbsBlockDevice"]]:
        return jsii.get(self, "ebsBlockDevice")

    @ebs_block_device.setter
    def ebs_block_device(
        self, value: typing.Optional[typing.List["AmiFromInstanceEbsBlockDevice"]]
    ) -> None:
        jsii.set(self, "ebsBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiFromInstanceEphemeralBlockDevice"]]:
        return jsii.get(self, "ephemeralBlockDevice")

    @ephemeral_block_device.setter
    def ephemeral_block_device(
        self, value: typing.Optional[typing.List["AmiFromInstanceEphemeralBlockDevice"]]
    ) -> None:
        jsii.set(self, "ephemeralBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotWithoutReboot")
    def snapshot_without_reboot(self) -> typing.Optional[bool]:
        return jsii.get(self, "snapshotWithoutReboot")

    @snapshot_without_reboot.setter
    def snapshot_without_reboot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "snapshotWithoutReboot", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AmiFromInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["AmiFromInstanceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiFromInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "source_instance_id": "sourceInstanceId",
        "description": "description",
        "ebs_block_device": "ebsBlockDevice",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "snapshot_without_reboot": "snapshotWithoutReboot",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class AmiFromInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        source_instance_id: str,
        description: typing.Optional[str] = None,
        ebs_block_device: typing.Optional[
            typing.List["AmiFromInstanceEbsBlockDevice"]
        ] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["AmiFromInstanceEphemeralBlockDevice"]
        ] = None,
        snapshot_without_reboot: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["AmiFromInstanceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param source_instance_id: 
        :param description: 
        :param ebs_block_device: ebs_block_device block.
        :param ephemeral_block_device: ephemeral_block_device block.
        :param snapshot_without_reboot: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AmiFromInstanceTimeouts(**timeouts)
        self._values = {
            "name": name,
            "source_instance_id": source_instance_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if snapshot_without_reboot is not None:
            self._values["snapshot_without_reboot"] = snapshot_without_reboot
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def source_instance_id(self) -> str:
        return self._values.get("source_instance_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiFromInstanceEbsBlockDevice"]]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["AmiFromInstanceEphemeralBlockDevice"]]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def snapshot_without_reboot(self) -> typing.Optional[bool]:
        return self._values.get("snapshot_without_reboot")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["AmiFromInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiFromInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiFromInstanceEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={},
)
class AmiFromInstanceEbsBlockDevice:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiFromInstanceEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiFromInstanceEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={},
)
class AmiFromInstanceEphemeralBlockDevice:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiFromInstanceEphemeralBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiFromInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AmiFromInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiFromInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AmiLaunchPermission(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AmiLaunchPermission",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_id: str,
        image_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_id: 
        :param image_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AmiLaunchPermissionConfig(
            account_id=account_id,
            image_id=image_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AmiLaunchPermission, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: str) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> str:
        return jsii.get(self, "imageId")

    @image_id.setter
    def image_id(self, value: str) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiLaunchPermissionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_id": "accountId",
        "image_id": "imageId",
    },
)
class AmiLaunchPermissionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_id: str,
        image_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_id: 
        :param image_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "account_id": account_id,
            "image_id": image_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_id(self) -> str:
        return self._values.get("account_id")

    @builtins.property
    def image_id(self) -> str:
        return self._values.get("image_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiLaunchPermissionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AmiTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class AmiTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AmiTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cloudwatch_role_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cloudwatch_role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayAccountConfig(
            cloudwatch_role_arn=cloudwatch_role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="throttleSettings")
    def throttle_settings(self, index: str) -> "ApiGatewayAccountThrottleSettings":
        """
        :param index: -
        """
        return jsii.invoke(self, "throttleSettings", [index])

    @builtins.property
    @jsii.member(jsii_name="cloudwatchRoleArn")
    def cloudwatch_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "cloudwatchRoleArn")

    @cloudwatch_role_arn.setter
    def cloudwatch_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cloudwatchRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloudwatch_role_arn": "cloudwatchRoleArn",
    },
)
class ApiGatewayAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloudwatch_role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloudwatch_role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloudwatch_role_arn is not None:
            self._values["cloudwatch_role_arn"] = cloudwatch_role_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cloudwatch_role_arn(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayAccountThrottleSettings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayAccountThrottleSettings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            ApiGatewayAccountThrottleSettings,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="burstLimit")
    def burst_limit(self) -> jsii.Number:
        return jsii.get(self, "burstLimit")

    @builtins.property
    @jsii.member(jsii_name="rateLimit")
    def rate_limit(self) -> jsii.Number:
        return jsii.get(self, "rateLimit")


class ApiGatewayApiKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayApiKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        stage_key: typing.Optional[typing.List["ApiGatewayApiKeyStageKey"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        value: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param enabled: 
        :param stage_key: stage_key block.
        :param tags: 
        :param value: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayApiKeyConfig(
            name=name,
            description=description,
            enabled=enabled,
            stage_key=stage_key,
            tags=tags,
            value=value,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayApiKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedDate")
    def last_updated_date(self) -> str:
        return jsii.get(self, "lastUpdatedDate")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="stageKey")
    def stage_key(self) -> typing.Optional[typing.List["ApiGatewayApiKeyStageKey"]]:
        return jsii.get(self, "stageKey")

    @stage_key.setter
    def stage_key(
        self, value: typing.Optional[typing.List["ApiGatewayApiKeyStageKey"]]
    ) -> None:
        jsii.set(self, "stageKey", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> typing.Optional[str]:
        return jsii.get(self, "value")

    @value.setter
    def value(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "value", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayApiKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "enabled": "enabled",
        "stage_key": "stageKey",
        "tags": "tags",
        "value": "value",
    },
)
class ApiGatewayApiKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        stage_key: typing.Optional[typing.List["ApiGatewayApiKeyStageKey"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        value: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param enabled: 
        :param stage_key: stage_key block.
        :param tags: 
        :param value: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if enabled is not None:
            self._values["enabled"] = enabled
        if stage_key is not None:
            self._values["stage_key"] = stage_key
        if tags is not None:
            self._values["tags"] = tags
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def stage_key(self) -> typing.Optional[typing.List["ApiGatewayApiKeyStageKey"]]:
        """stage_key block."""
        return self._values.get("stage_key")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def value(self) -> typing.Optional[str]:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayApiKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayApiKeyStageKey",
    jsii_struct_bases=[],
    name_mapping={"rest_api_id": "restApiId", "stage_name": "stageName"},
)
class ApiGatewayApiKeyStageKey:
    def __init__(self, *, rest_api_id: str, stage_name: str) -> None:
        """
        :param rest_api_id: 
        :param stage_name: 
        """
        self._values = {
            "rest_api_id": rest_api_id,
            "stage_name": stage_name,
        }

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def stage_name(self) -> str:
        return self._values.get("stage_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayApiKeyStageKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayAuthorizer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayAuthorizer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        rest_api_id: str,
        authorizer_credentials: typing.Optional[str] = None,
        authorizer_result_ttl_in_seconds: typing.Optional[jsii.Number] = None,
        authorizer_uri: typing.Optional[str] = None,
        identity_source: typing.Optional[str] = None,
        identity_validation_expression: typing.Optional[str] = None,
        provider_arns: typing.Optional[typing.List[str]] = None,
        type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param rest_api_id: 
        :param authorizer_credentials: 
        :param authorizer_result_ttl_in_seconds: 
        :param authorizer_uri: 
        :param identity_source: 
        :param identity_validation_expression: 
        :param provider_arns: 
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayAuthorizerConfig(
            name=name,
            rest_api_id=rest_api_id,
            authorizer_credentials=authorizer_credentials,
            authorizer_result_ttl_in_seconds=authorizer_result_ttl_in_seconds,
            authorizer_uri=authorizer_uri,
            identity_source=identity_source,
            identity_validation_expression=identity_validation_expression,
            provider_arns=provider_arns,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayAuthorizer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerCredentials")
    def authorizer_credentials(self) -> typing.Optional[str]:
        return jsii.get(self, "authorizerCredentials")

    @authorizer_credentials.setter
    def authorizer_credentials(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authorizerCredentials", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerResultTtlInSeconds")
    def authorizer_result_ttl_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "authorizerResultTtlInSeconds")

    @authorizer_result_ttl_in_seconds.setter
    def authorizer_result_ttl_in_seconds(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "authorizerResultTtlInSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerUri")
    def authorizer_uri(self) -> typing.Optional[str]:
        return jsii.get(self, "authorizerUri")

    @authorizer_uri.setter
    def authorizer_uri(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authorizerUri", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identitySource")
    def identity_source(self) -> typing.Optional[str]:
        return jsii.get(self, "identitySource")

    @identity_source.setter
    def identity_source(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identitySource", value)

    @builtins.property
    @jsii.member(jsii_name="identityValidationExpression")
    def identity_validation_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "identityValidationExpression")

    @identity_validation_expression.setter
    def identity_validation_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identityValidationExpression", value)

    @builtins.property
    @jsii.member(jsii_name="providerArns")
    def provider_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "providerArns")

    @provider_arns.setter
    def provider_arns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "providerArns", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayAuthorizerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "rest_api_id": "restApiId",
        "authorizer_credentials": "authorizerCredentials",
        "authorizer_result_ttl_in_seconds": "authorizerResultTtlInSeconds",
        "authorizer_uri": "authorizerUri",
        "identity_source": "identitySource",
        "identity_validation_expression": "identityValidationExpression",
        "provider_arns": "providerArns",
        "type": "type",
    },
)
class ApiGatewayAuthorizerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        rest_api_id: str,
        authorizer_credentials: typing.Optional[str] = None,
        authorizer_result_ttl_in_seconds: typing.Optional[jsii.Number] = None,
        authorizer_uri: typing.Optional[str] = None,
        identity_source: typing.Optional[str] = None,
        identity_validation_expression: typing.Optional[str] = None,
        provider_arns: typing.Optional[typing.List[str]] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param rest_api_id: 
        :param authorizer_credentials: 
        :param authorizer_result_ttl_in_seconds: 
        :param authorizer_uri: 
        :param identity_source: 
        :param identity_validation_expression: 
        :param provider_arns: 
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authorizer_credentials is not None:
            self._values["authorizer_credentials"] = authorizer_credentials
        if authorizer_result_ttl_in_seconds is not None:
            self._values[
                "authorizer_result_ttl_in_seconds"
            ] = authorizer_result_ttl_in_seconds
        if authorizer_uri is not None:
            self._values["authorizer_uri"] = authorizer_uri
        if identity_source is not None:
            self._values["identity_source"] = identity_source
        if identity_validation_expression is not None:
            self._values[
                "identity_validation_expression"
            ] = identity_validation_expression
        if provider_arns is not None:
            self._values["provider_arns"] = provider_arns
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def authorizer_credentials(self) -> typing.Optional[str]:
        return self._values.get("authorizer_credentials")

    @builtins.property
    def authorizer_result_ttl_in_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("authorizer_result_ttl_in_seconds")

    @builtins.property
    def authorizer_uri(self) -> typing.Optional[str]:
        return self._values.get("authorizer_uri")

    @builtins.property
    def identity_source(self) -> typing.Optional[str]:
        return self._values.get("identity_source")

    @builtins.property
    def identity_validation_expression(self) -> typing.Optional[str]:
        return self._values.get("identity_validation_expression")

    @builtins.property
    def provider_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("provider_arns")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayAuthorizerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayBasePathMapping(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayBasePathMapping",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        domain_name: str,
        base_path: typing.Optional[str] = None,
        stage_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param domain_name: 
        :param base_path: 
        :param stage_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayBasePathMappingConfig(
            api_id=api_id,
            domain_name=domain_name,
            base_path=base_path,
            stage_name=stage_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayBasePathMapping, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="basePath")
    def base_path(self) -> typing.Optional[str]:
        return jsii.get(self, "basePath")

    @base_path.setter
    def base_path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "basePath", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="stageName")
    def stage_name(self) -> typing.Optional[str]:
        return jsii.get(self, "stageName")

    @stage_name.setter
    def stage_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "stageName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayBasePathMappingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "domain_name": "domainName",
        "base_path": "basePath",
        "stage_name": "stageName",
    },
)
class ApiGatewayBasePathMappingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        domain_name: str,
        base_path: typing.Optional[str] = None,
        stage_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param domain_name: 
        :param base_path: 
        :param stage_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "domain_name": domain_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if base_path is not None:
            self._values["base_path"] = base_path
        if stage_name is not None:
            self._values["stage_name"] = stage_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def base_path(self) -> typing.Optional[str]:
        return self._values.get("base_path")

    @builtins.property
    def stage_name(self) -> typing.Optional[str]:
        return self._values.get("stage_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayBasePathMappingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayClientCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayClientCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayClientCertificateConfig(
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayClientCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="expirationDate")
    def expiration_date(self) -> str:
        return jsii.get(self, "expirationDate")

    @builtins.property
    @jsii.member(jsii_name="pemEncodedCertificate")
    def pem_encoded_certificate(self) -> str:
        return jsii.get(self, "pemEncodedCertificate")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayClientCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "tags": "tags",
    },
)
class ApiGatewayClientCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayClientCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayDeployment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDeployment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        rest_api_id: str,
        description: typing.Optional[str] = None,
        stage_description: typing.Optional[str] = None,
        stage_name: typing.Optional[str] = None,
        triggers: typing.Optional[typing.Mapping[str, str]] = None,
        variables: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param rest_api_id: 
        :param description: 
        :param stage_description: 
        :param stage_name: 
        :param triggers: 
        :param variables: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayDeploymentConfig(
            rest_api_id=rest_api_id,
            description=description,
            stage_description=stage_description,
            stage_name=stage_name,
            triggers=triggers,
            variables=variables,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayDeployment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="executionArn")
    def execution_arn(self) -> str:
        return jsii.get(self, "executionArn")

    @builtins.property
    @jsii.member(jsii_name="invokeUrl")
    def invoke_url(self) -> str:
        return jsii.get(self, "invokeUrl")

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="stageDescription")
    def stage_description(self) -> typing.Optional[str]:
        return jsii.get(self, "stageDescription")

    @stage_description.setter
    def stage_description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "stageDescription", value)

    @builtins.property
    @jsii.member(jsii_name="stageName")
    def stage_name(self) -> typing.Optional[str]:
        return jsii.get(self, "stageName")

    @stage_name.setter
    def stage_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "stageName", value)

    @builtins.property
    @jsii.member(jsii_name="triggers")
    def triggers(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "triggers", value)

    @builtins.property
    @jsii.member(jsii_name="variables")
    def variables(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "variables")

    @variables.setter
    def variables(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "variables", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDeploymentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "rest_api_id": "restApiId",
        "description": "description",
        "stage_description": "stageDescription",
        "stage_name": "stageName",
        "triggers": "triggers",
        "variables": "variables",
    },
)
class ApiGatewayDeploymentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        rest_api_id: str,
        description: typing.Optional[str] = None,
        stage_description: typing.Optional[str] = None,
        stage_name: typing.Optional[str] = None,
        triggers: typing.Optional[typing.Mapping[str, str]] = None,
        variables: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param rest_api_id: 
        :param description: 
        :param stage_description: 
        :param stage_name: 
        :param triggers: 
        :param variables: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if stage_description is not None:
            self._values["stage_description"] = stage_description
        if stage_name is not None:
            self._values["stage_name"] = stage_name
        if triggers is not None:
            self._values["triggers"] = triggers
        if variables is not None:
            self._values["variables"] = variables

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def stage_description(self) -> typing.Optional[str]:
        return self._values.get("stage_description")

    @builtins.property
    def stage_name(self) -> typing.Optional[str]:
        return self._values.get("stage_name")

    @builtins.property
    def triggers(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("triggers")

    @builtins.property
    def variables(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("variables")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayDeploymentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayDocumentationPart(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDocumentationPart",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        location: typing.List["ApiGatewayDocumentationPartLocation"],
        properties: str,
        rest_api_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param location: location block.
        :param properties: 
        :param rest_api_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayDocumentationPartConfig(
            location=location,
            properties=properties,
            rest_api_id=rest_api_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayDocumentationPart, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="location")
    def location(self) -> typing.List["ApiGatewayDocumentationPartLocation"]:
        return jsii.get(self, "location")

    @location.setter
    def location(
        self, value: typing.List["ApiGatewayDocumentationPartLocation"]
    ) -> None:
        jsii.set(self, "location", value)

    @builtins.property
    @jsii.member(jsii_name="properties")
    def properties(self) -> str:
        return jsii.get(self, "properties")

    @properties.setter
    def properties(self, value: str) -> None:
        jsii.set(self, "properties", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDocumentationPartConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "location": "location",
        "properties": "properties",
        "rest_api_id": "restApiId",
    },
)
class ApiGatewayDocumentationPartConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        location: typing.List["ApiGatewayDocumentationPartLocation"],
        properties: str,
        rest_api_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param location: location block.
        :param properties: 
        :param rest_api_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "location": location,
            "properties": properties,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def location(self) -> typing.List["ApiGatewayDocumentationPartLocation"]:
        """location block."""
        return self._values.get("location")

    @builtins.property
    def properties(self) -> str:
        return self._values.get("properties")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayDocumentationPartConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDocumentationPartLocation",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "method": "method",
        "name": "name",
        "path": "path",
        "status_code": "statusCode",
    },
)
class ApiGatewayDocumentationPartLocation:
    def __init__(
        self,
        *,
        type: str,
        method: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        status_code: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param method: 
        :param name: 
        :param path: 
        :param status_code: 
        """
        self._values = {
            "type": type,
        }
        if method is not None:
            self._values["method"] = method
        if name is not None:
            self._values["name"] = name
        if path is not None:
            self._values["path"] = path
        if status_code is not None:
            self._values["status_code"] = status_code

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def method(self) -> typing.Optional[str]:
        return self._values.get("method")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def status_code(self) -> typing.Optional[str]:
        return self._values.get("status_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayDocumentationPartLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayDocumentationVersion(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDocumentationVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        rest_api_id: str,
        version: str,
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param rest_api_id: 
        :param version: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayDocumentationVersionConfig(
            rest_api_id=rest_api_id,
            version=version,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayDocumentationVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: str) -> None:
        jsii.set(self, "version", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDocumentationVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "rest_api_id": "restApiId",
        "version": "version",
        "description": "description",
    },
)
class ApiGatewayDocumentationVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        rest_api_id: str,
        version: str,
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param rest_api_id: 
        :param version: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "rest_api_id": rest_api_id,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def version(self) -> str:
        return self._values.get("version")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayDocumentationVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayDomainName(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDomainName",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: str,
        certificate_arn: typing.Optional[str] = None,
        certificate_body: typing.Optional[str] = None,
        certificate_chain: typing.Optional[str] = None,
        certificate_name: typing.Optional[str] = None,
        certificate_private_key: typing.Optional[str] = None,
        endpoint_configuration: typing.Optional[
            typing.List["ApiGatewayDomainNameEndpointConfiguration"]
        ] = None,
        regional_certificate_arn: typing.Optional[str] = None,
        regional_certificate_name: typing.Optional[str] = None,
        security_policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param certificate_arn: 
        :param certificate_body: 
        :param certificate_chain: 
        :param certificate_name: 
        :param certificate_private_key: 
        :param endpoint_configuration: endpoint_configuration block.
        :param regional_certificate_arn: 
        :param regional_certificate_name: 
        :param security_policy: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayDomainNameConfig(
            domain_name=domain_name,
            certificate_arn=certificate_arn,
            certificate_body=certificate_body,
            certificate_chain=certificate_chain,
            certificate_name=certificate_name,
            certificate_private_key=certificate_private_key,
            endpoint_configuration=endpoint_configuration,
            regional_certificate_arn=regional_certificate_arn,
            regional_certificate_name=regional_certificate_name,
            security_policy=security_policy,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayDomainName, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="certificateUploadDate")
    def certificate_upload_date(self) -> str:
        return jsii.get(self, "certificateUploadDate")

    @builtins.property
    @jsii.member(jsii_name="cloudfrontDomainName")
    def cloudfront_domain_name(self) -> str:
        return jsii.get(self, "cloudfrontDomainName")

    @builtins.property
    @jsii.member(jsii_name="cloudfrontZoneId")
    def cloudfront_zone_id(self) -> str:
        return jsii.get(self, "cloudfrontZoneId")

    @builtins.property
    @jsii.member(jsii_name="regionalDomainName")
    def regional_domain_name(self) -> str:
        return jsii.get(self, "regionalDomainName")

    @builtins.property
    @jsii.member(jsii_name="regionalZoneId")
    def regional_zone_id(self) -> str:
        return jsii.get(self, "regionalZoneId")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="certificateBody")
    def certificate_body(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateBody")

    @certificate_body.setter
    def certificate_body(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateBody", value)

    @builtins.property
    @jsii.member(jsii_name="certificateChain")
    def certificate_chain(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateChain")

    @certificate_chain.setter
    def certificate_chain(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateChain", value)

    @builtins.property
    @jsii.member(jsii_name="certificateName")
    def certificate_name(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateName")

    @certificate_name.setter
    def certificate_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateName", value)

    @builtins.property
    @jsii.member(jsii_name="certificatePrivateKey")
    def certificate_private_key(self) -> typing.Optional[str]:
        return jsii.get(self, "certificatePrivateKey")

    @certificate_private_key.setter
    def certificate_private_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificatePrivateKey", value)

    @builtins.property
    @jsii.member(jsii_name="endpointConfiguration")
    def endpoint_configuration(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayDomainNameEndpointConfiguration"]]:
        return jsii.get(self, "endpointConfiguration")

    @endpoint_configuration.setter
    def endpoint_configuration(
        self,
        value: typing.Optional[
            typing.List["ApiGatewayDomainNameEndpointConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "endpointConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="regionalCertificateArn")
    def regional_certificate_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "regionalCertificateArn")

    @regional_certificate_arn.setter
    def regional_certificate_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "regionalCertificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="regionalCertificateName")
    def regional_certificate_name(self) -> typing.Optional[str]:
        return jsii.get(self, "regionalCertificateName")

    @regional_certificate_name.setter
    def regional_certificate_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "regionalCertificateName", value)

    @builtins.property
    @jsii.member(jsii_name="securityPolicy")
    def security_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "securityPolicy")

    @security_policy.setter
    def security_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "securityPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDomainNameConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
        "certificate_arn": "certificateArn",
        "certificate_body": "certificateBody",
        "certificate_chain": "certificateChain",
        "certificate_name": "certificateName",
        "certificate_private_key": "certificatePrivateKey",
        "endpoint_configuration": "endpointConfiguration",
        "regional_certificate_arn": "regionalCertificateArn",
        "regional_certificate_name": "regionalCertificateName",
        "security_policy": "securityPolicy",
        "tags": "tags",
    },
)
class ApiGatewayDomainNameConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: str,
        certificate_arn: typing.Optional[str] = None,
        certificate_body: typing.Optional[str] = None,
        certificate_chain: typing.Optional[str] = None,
        certificate_name: typing.Optional[str] = None,
        certificate_private_key: typing.Optional[str] = None,
        endpoint_configuration: typing.Optional[
            typing.List["ApiGatewayDomainNameEndpointConfiguration"]
        ] = None,
        regional_certificate_arn: typing.Optional[str] = None,
        regional_certificate_name: typing.Optional[str] = None,
        security_policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        :param certificate_arn: 
        :param certificate_body: 
        :param certificate_chain: 
        :param certificate_name: 
        :param certificate_private_key: 
        :param endpoint_configuration: endpoint_configuration block.
        :param regional_certificate_arn: 
        :param regional_certificate_name: 
        :param security_policy: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain_name": domain_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_arn is not None:
            self._values["certificate_arn"] = certificate_arn
        if certificate_body is not None:
            self._values["certificate_body"] = certificate_body
        if certificate_chain is not None:
            self._values["certificate_chain"] = certificate_chain
        if certificate_name is not None:
            self._values["certificate_name"] = certificate_name
        if certificate_private_key is not None:
            self._values["certificate_private_key"] = certificate_private_key
        if endpoint_configuration is not None:
            self._values["endpoint_configuration"] = endpoint_configuration
        if regional_certificate_arn is not None:
            self._values["regional_certificate_arn"] = regional_certificate_arn
        if regional_certificate_name is not None:
            self._values["regional_certificate_name"] = regional_certificate_name
        if security_policy is not None:
            self._values["security_policy"] = security_policy
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def certificate_arn(self) -> typing.Optional[str]:
        return self._values.get("certificate_arn")

    @builtins.property
    def certificate_body(self) -> typing.Optional[str]:
        return self._values.get("certificate_body")

    @builtins.property
    def certificate_chain(self) -> typing.Optional[str]:
        return self._values.get("certificate_chain")

    @builtins.property
    def certificate_name(self) -> typing.Optional[str]:
        return self._values.get("certificate_name")

    @builtins.property
    def certificate_private_key(self) -> typing.Optional[str]:
        return self._values.get("certificate_private_key")

    @builtins.property
    def endpoint_configuration(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayDomainNameEndpointConfiguration"]]:
        """endpoint_configuration block."""
        return self._values.get("endpoint_configuration")

    @builtins.property
    def regional_certificate_arn(self) -> typing.Optional[str]:
        return self._values.get("regional_certificate_arn")

    @builtins.property
    def regional_certificate_name(self) -> typing.Optional[str]:
        return self._values.get("regional_certificate_name")

    @builtins.property
    def security_policy(self) -> typing.Optional[str]:
        return self._values.get("security_policy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayDomainNameConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayDomainNameEndpointConfiguration",
    jsii_struct_bases=[],
    name_mapping={"types": "types"},
)
class ApiGatewayDomainNameEndpointConfiguration:
    def __init__(self, *, types: typing.List[str]) -> None:
        """
        :param types: 
        """
        self._values = {
            "types": types,
        }

    @builtins.property
    def types(self) -> typing.List[str]:
        return self._values.get("types")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayDomainNameEndpointConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayGatewayResponse(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayGatewayResponse",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        response_type: str,
        rest_api_id: str,
        response_parameters: typing.Optional[typing.Mapping[str, str]] = None,
        response_templates: typing.Optional[typing.Mapping[str, str]] = None,
        status_code: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param response_type: 
        :param rest_api_id: 
        :param response_parameters: 
        :param response_templates: 
        :param status_code: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayGatewayResponseConfig(
            response_type=response_type,
            rest_api_id=rest_api_id,
            response_parameters=response_parameters,
            response_templates=response_templates,
            status_code=status_code,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayGatewayResponse, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="responseType")
    def response_type(self) -> str:
        return jsii.get(self, "responseType")

    @response_type.setter
    def response_type(self, value: str) -> None:
        jsii.set(self, "responseType", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="responseParameters")
    def response_parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "responseParameters")

    @response_parameters.setter
    def response_parameters(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "responseParameters", value)

    @builtins.property
    @jsii.member(jsii_name="responseTemplates")
    def response_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "responseTemplates")

    @response_templates.setter
    def response_templates(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "responseTemplates", value)

    @builtins.property
    @jsii.member(jsii_name="statusCode")
    def status_code(self) -> typing.Optional[str]:
        return jsii.get(self, "statusCode")

    @status_code.setter
    def status_code(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "statusCode", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayGatewayResponseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "response_type": "responseType",
        "rest_api_id": "restApiId",
        "response_parameters": "responseParameters",
        "response_templates": "responseTemplates",
        "status_code": "statusCode",
    },
)
class ApiGatewayGatewayResponseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        response_type: str,
        rest_api_id: str,
        response_parameters: typing.Optional[typing.Mapping[str, str]] = None,
        response_templates: typing.Optional[typing.Mapping[str, str]] = None,
        status_code: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param response_type: 
        :param rest_api_id: 
        :param response_parameters: 
        :param response_templates: 
        :param status_code: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "response_type": response_type,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if response_parameters is not None:
            self._values["response_parameters"] = response_parameters
        if response_templates is not None:
            self._values["response_templates"] = response_templates
        if status_code is not None:
            self._values["status_code"] = status_code

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def response_type(self) -> str:
        return self._values.get("response_type")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def response_parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("response_parameters")

    @builtins.property
    def response_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("response_templates")

    @builtins.property
    def status_code(self) -> typing.Optional[str]:
        return self._values.get("status_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayGatewayResponseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayIntegration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayIntegration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        type: str,
        cache_key_parameters: typing.Optional[typing.List[str]] = None,
        cache_namespace: typing.Optional[str] = None,
        connection_id: typing.Optional[str] = None,
        connection_type: typing.Optional[str] = None,
        content_handling: typing.Optional[str] = None,
        credentials: typing.Optional[str] = None,
        integration_http_method: typing.Optional[str] = None,
        passthrough_behavior: typing.Optional[str] = None,
        request_parameters: typing.Optional[typing.Mapping[str, str]] = None,
        request_parameters_in_json: typing.Optional[str] = None,
        request_templates: typing.Optional[typing.Mapping[str, str]] = None,
        timeout_milliseconds: typing.Optional[jsii.Number] = None,
        uri: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param type: 
        :param cache_key_parameters: 
        :param cache_namespace: 
        :param connection_id: 
        :param connection_type: 
        :param content_handling: 
        :param credentials: 
        :param integration_http_method: 
        :param passthrough_behavior: 
        :param request_parameters: 
        :param request_parameters_in_json: 
        :param request_templates: 
        :param timeout_milliseconds: 
        :param uri: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayIntegrationConfig(
            http_method=http_method,
            resource_id=resource_id,
            rest_api_id=rest_api_id,
            type=type,
            cache_key_parameters=cache_key_parameters,
            cache_namespace=cache_namespace,
            connection_id=connection_id,
            connection_type=connection_type,
            content_handling=content_handling,
            credentials=credentials,
            integration_http_method=integration_http_method,
            passthrough_behavior=passthrough_behavior,
            request_parameters=request_parameters,
            request_parameters_in_json=request_parameters_in_json,
            request_templates=request_templates,
            timeout_milliseconds=timeout_milliseconds,
            uri=uri,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayIntegration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="httpMethod")
    def http_method(self) -> str:
        return jsii.get(self, "httpMethod")

    @http_method.setter
    def http_method(self, value: str) -> None:
        jsii.set(self, "httpMethod", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="cacheKeyParameters")
    def cache_key_parameters(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "cacheKeyParameters")

    @cache_key_parameters.setter
    def cache_key_parameters(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "cacheKeyParameters", value)

    @builtins.property
    @jsii.member(jsii_name="cacheNamespace")
    def cache_namespace(self) -> typing.Optional[str]:
        return jsii.get(self, "cacheNamespace")

    @cache_namespace.setter
    def cache_namespace(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cacheNamespace", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> typing.Optional[str]:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="connectionType")
    def connection_type(self) -> typing.Optional[str]:
        return jsii.get(self, "connectionType")

    @connection_type.setter
    def connection_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "connectionType", value)

    @builtins.property
    @jsii.member(jsii_name="contentHandling")
    def content_handling(self) -> typing.Optional[str]:
        return jsii.get(self, "contentHandling")

    @content_handling.setter
    def content_handling(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentHandling", value)

    @builtins.property
    @jsii.member(jsii_name="credentials")
    def credentials(self) -> typing.Optional[str]:
        return jsii.get(self, "credentials")

    @credentials.setter
    def credentials(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "credentials", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="integrationHttpMethod")
    def integration_http_method(self) -> typing.Optional[str]:
        return jsii.get(self, "integrationHttpMethod")

    @integration_http_method.setter
    def integration_http_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "integrationHttpMethod", value)

    @builtins.property
    @jsii.member(jsii_name="passthroughBehavior")
    def passthrough_behavior(self) -> typing.Optional[str]:
        return jsii.get(self, "passthroughBehavior")

    @passthrough_behavior.setter
    def passthrough_behavior(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "passthroughBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="requestParameters")
    def request_parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "requestParameters")

    @request_parameters.setter
    def request_parameters(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "requestParameters", value)

    @builtins.property
    @jsii.member(jsii_name="requestParametersInJson")
    def request_parameters_in_json(self) -> typing.Optional[str]:
        return jsii.get(self, "requestParametersInJson")

    @request_parameters_in_json.setter
    def request_parameters_in_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "requestParametersInJson", value)

    @builtins.property
    @jsii.member(jsii_name="requestTemplates")
    def request_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "requestTemplates")

    @request_templates.setter
    def request_templates(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "requestTemplates", value)

    @builtins.property
    @jsii.member(jsii_name="timeoutMilliseconds")
    def timeout_milliseconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "timeoutMilliseconds")

    @timeout_milliseconds.setter
    def timeout_milliseconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "timeoutMilliseconds", value)

    @builtins.property
    @jsii.member(jsii_name="uri")
    def uri(self) -> typing.Optional[str]:
        return jsii.get(self, "uri")

    @uri.setter
    def uri(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "uri", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayIntegrationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "http_method": "httpMethod",
        "resource_id": "resourceId",
        "rest_api_id": "restApiId",
        "type": "type",
        "cache_key_parameters": "cacheKeyParameters",
        "cache_namespace": "cacheNamespace",
        "connection_id": "connectionId",
        "connection_type": "connectionType",
        "content_handling": "contentHandling",
        "credentials": "credentials",
        "integration_http_method": "integrationHttpMethod",
        "passthrough_behavior": "passthroughBehavior",
        "request_parameters": "requestParameters",
        "request_parameters_in_json": "requestParametersInJson",
        "request_templates": "requestTemplates",
        "timeout_milliseconds": "timeoutMilliseconds",
        "uri": "uri",
    },
)
class ApiGatewayIntegrationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        type: str,
        cache_key_parameters: typing.Optional[typing.List[str]] = None,
        cache_namespace: typing.Optional[str] = None,
        connection_id: typing.Optional[str] = None,
        connection_type: typing.Optional[str] = None,
        content_handling: typing.Optional[str] = None,
        credentials: typing.Optional[str] = None,
        integration_http_method: typing.Optional[str] = None,
        passthrough_behavior: typing.Optional[str] = None,
        request_parameters: typing.Optional[typing.Mapping[str, str]] = None,
        request_parameters_in_json: typing.Optional[str] = None,
        request_templates: typing.Optional[typing.Mapping[str, str]] = None,
        timeout_milliseconds: typing.Optional[jsii.Number] = None,
        uri: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param type: 
        :param cache_key_parameters: 
        :param cache_namespace: 
        :param connection_id: 
        :param connection_type: 
        :param content_handling: 
        :param credentials: 
        :param integration_http_method: 
        :param passthrough_behavior: 
        :param request_parameters: 
        :param request_parameters_in_json: 
        :param request_templates: 
        :param timeout_milliseconds: 
        :param uri: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "http_method": http_method,
            "resource_id": resource_id,
            "rest_api_id": rest_api_id,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cache_key_parameters is not None:
            self._values["cache_key_parameters"] = cache_key_parameters
        if cache_namespace is not None:
            self._values["cache_namespace"] = cache_namespace
        if connection_id is not None:
            self._values["connection_id"] = connection_id
        if connection_type is not None:
            self._values["connection_type"] = connection_type
        if content_handling is not None:
            self._values["content_handling"] = content_handling
        if credentials is not None:
            self._values["credentials"] = credentials
        if integration_http_method is not None:
            self._values["integration_http_method"] = integration_http_method
        if passthrough_behavior is not None:
            self._values["passthrough_behavior"] = passthrough_behavior
        if request_parameters is not None:
            self._values["request_parameters"] = request_parameters
        if request_parameters_in_json is not None:
            self._values["request_parameters_in_json"] = request_parameters_in_json
        if request_templates is not None:
            self._values["request_templates"] = request_templates
        if timeout_milliseconds is not None:
            self._values["timeout_milliseconds"] = timeout_milliseconds
        if uri is not None:
            self._values["uri"] = uri

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def http_method(self) -> str:
        return self._values.get("http_method")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def cache_key_parameters(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cache_key_parameters")

    @builtins.property
    def cache_namespace(self) -> typing.Optional[str]:
        return self._values.get("cache_namespace")

    @builtins.property
    def connection_id(self) -> typing.Optional[str]:
        return self._values.get("connection_id")

    @builtins.property
    def connection_type(self) -> typing.Optional[str]:
        return self._values.get("connection_type")

    @builtins.property
    def content_handling(self) -> typing.Optional[str]:
        return self._values.get("content_handling")

    @builtins.property
    def credentials(self) -> typing.Optional[str]:
        return self._values.get("credentials")

    @builtins.property
    def integration_http_method(self) -> typing.Optional[str]:
        return self._values.get("integration_http_method")

    @builtins.property
    def passthrough_behavior(self) -> typing.Optional[str]:
        return self._values.get("passthrough_behavior")

    @builtins.property
    def request_parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("request_parameters")

    @builtins.property
    def request_parameters_in_json(self) -> typing.Optional[str]:
        return self._values.get("request_parameters_in_json")

    @builtins.property
    def request_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("request_templates")

    @builtins.property
    def timeout_milliseconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout_milliseconds")

    @builtins.property
    def uri(self) -> typing.Optional[str]:
        return self._values.get("uri")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayIntegrationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayIntegrationResponse(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayIntegrationResponse",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        status_code: str,
        content_handling: typing.Optional[str] = None,
        response_parameters: typing.Optional[typing.Mapping[str, str]] = None,
        response_parameters_in_json: typing.Optional[str] = None,
        response_templates: typing.Optional[typing.Mapping[str, str]] = None,
        selection_pattern: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param status_code: 
        :param content_handling: 
        :param response_parameters: 
        :param response_parameters_in_json: 
        :param response_templates: 
        :param selection_pattern: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayIntegrationResponseConfig(
            http_method=http_method,
            resource_id=resource_id,
            rest_api_id=rest_api_id,
            status_code=status_code,
            content_handling=content_handling,
            response_parameters=response_parameters,
            response_parameters_in_json=response_parameters_in_json,
            response_templates=response_templates,
            selection_pattern=selection_pattern,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayIntegrationResponse, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="httpMethod")
    def http_method(self) -> str:
        return jsii.get(self, "httpMethod")

    @http_method.setter
    def http_method(self, value: str) -> None:
        jsii.set(self, "httpMethod", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="statusCode")
    def status_code(self) -> str:
        return jsii.get(self, "statusCode")

    @status_code.setter
    def status_code(self, value: str) -> None:
        jsii.set(self, "statusCode", value)

    @builtins.property
    @jsii.member(jsii_name="contentHandling")
    def content_handling(self) -> typing.Optional[str]:
        return jsii.get(self, "contentHandling")

    @content_handling.setter
    def content_handling(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentHandling", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="responseParameters")
    def response_parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "responseParameters")

    @response_parameters.setter
    def response_parameters(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "responseParameters", value)

    @builtins.property
    @jsii.member(jsii_name="responseParametersInJson")
    def response_parameters_in_json(self) -> typing.Optional[str]:
        return jsii.get(self, "responseParametersInJson")

    @response_parameters_in_json.setter
    def response_parameters_in_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "responseParametersInJson", value)

    @builtins.property
    @jsii.member(jsii_name="responseTemplates")
    def response_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "responseTemplates")

    @response_templates.setter
    def response_templates(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "responseTemplates", value)

    @builtins.property
    @jsii.member(jsii_name="selectionPattern")
    def selection_pattern(self) -> typing.Optional[str]:
        return jsii.get(self, "selectionPattern")

    @selection_pattern.setter
    def selection_pattern(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "selectionPattern", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayIntegrationResponseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "http_method": "httpMethod",
        "resource_id": "resourceId",
        "rest_api_id": "restApiId",
        "status_code": "statusCode",
        "content_handling": "contentHandling",
        "response_parameters": "responseParameters",
        "response_parameters_in_json": "responseParametersInJson",
        "response_templates": "responseTemplates",
        "selection_pattern": "selectionPattern",
    },
)
class ApiGatewayIntegrationResponseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        status_code: str,
        content_handling: typing.Optional[str] = None,
        response_parameters: typing.Optional[typing.Mapping[str, str]] = None,
        response_parameters_in_json: typing.Optional[str] = None,
        response_templates: typing.Optional[typing.Mapping[str, str]] = None,
        selection_pattern: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param status_code: 
        :param content_handling: 
        :param response_parameters: 
        :param response_parameters_in_json: 
        :param response_templates: 
        :param selection_pattern: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "http_method": http_method,
            "resource_id": resource_id,
            "rest_api_id": rest_api_id,
            "status_code": status_code,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if content_handling is not None:
            self._values["content_handling"] = content_handling
        if response_parameters is not None:
            self._values["response_parameters"] = response_parameters
        if response_parameters_in_json is not None:
            self._values["response_parameters_in_json"] = response_parameters_in_json
        if response_templates is not None:
            self._values["response_templates"] = response_templates
        if selection_pattern is not None:
            self._values["selection_pattern"] = selection_pattern

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def http_method(self) -> str:
        return self._values.get("http_method")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def status_code(self) -> str:
        return self._values.get("status_code")

    @builtins.property
    def content_handling(self) -> typing.Optional[str]:
        return self._values.get("content_handling")

    @builtins.property
    def response_parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("response_parameters")

    @builtins.property
    def response_parameters_in_json(self) -> typing.Optional[str]:
        return self._values.get("response_parameters_in_json")

    @builtins.property
    def response_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("response_templates")

    @builtins.property
    def selection_pattern(self) -> typing.Optional[str]:
        return self._values.get("selection_pattern")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayIntegrationResponseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayMethod(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayMethod",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        authorization: str,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        api_key_required: typing.Optional[bool] = None,
        authorization_scopes: typing.Optional[typing.List[str]] = None,
        authorizer_id: typing.Optional[str] = None,
        request_models: typing.Optional[typing.Mapping[str, str]] = None,
        request_parameters: typing.Optional[typing.Mapping[str, bool]] = None,
        request_parameters_in_json: typing.Optional[str] = None,
        request_validator_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param authorization: 
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param api_key_required: 
        :param authorization_scopes: 
        :param authorizer_id: 
        :param request_models: 
        :param request_parameters: 
        :param request_parameters_in_json: 
        :param request_validator_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayMethodConfig(
            authorization=authorization,
            http_method=http_method,
            resource_id=resource_id,
            rest_api_id=rest_api_id,
            api_key_required=api_key_required,
            authorization_scopes=authorization_scopes,
            authorizer_id=authorizer_id,
            request_models=request_models,
            request_parameters=request_parameters,
            request_parameters_in_json=request_parameters_in_json,
            request_validator_id=request_validator_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayMethod, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="authorization")
    def authorization(self) -> str:
        return jsii.get(self, "authorization")

    @authorization.setter
    def authorization(self, value: str) -> None:
        jsii.set(self, "authorization", value)

    @builtins.property
    @jsii.member(jsii_name="httpMethod")
    def http_method(self) -> str:
        return jsii.get(self, "httpMethod")

    @http_method.setter
    def http_method(self, value: str) -> None:
        jsii.set(self, "httpMethod", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="apiKeyRequired")
    def api_key_required(self) -> typing.Optional[bool]:
        return jsii.get(self, "apiKeyRequired")

    @api_key_required.setter
    def api_key_required(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "apiKeyRequired", value)

    @builtins.property
    @jsii.member(jsii_name="authorizationScopes")
    def authorization_scopes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "authorizationScopes")

    @authorization_scopes.setter
    def authorization_scopes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "authorizationScopes", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerId")
    def authorizer_id(self) -> typing.Optional[str]:
        return jsii.get(self, "authorizerId")

    @authorizer_id.setter
    def authorizer_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authorizerId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="requestModels")
    def request_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "requestModels")

    @request_models.setter
    def request_models(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "requestModels", value)

    @builtins.property
    @jsii.member(jsii_name="requestParameters")
    def request_parameters(self) -> typing.Optional[typing.Mapping[str, bool]]:
        return jsii.get(self, "requestParameters")

    @request_parameters.setter
    def request_parameters(
        self, value: typing.Optional[typing.Mapping[str, bool]]
    ) -> None:
        jsii.set(self, "requestParameters", value)

    @builtins.property
    @jsii.member(jsii_name="requestParametersInJson")
    def request_parameters_in_json(self) -> typing.Optional[str]:
        return jsii.get(self, "requestParametersInJson")

    @request_parameters_in_json.setter
    def request_parameters_in_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "requestParametersInJson", value)

    @builtins.property
    @jsii.member(jsii_name="requestValidatorId")
    def request_validator_id(self) -> typing.Optional[str]:
        return jsii.get(self, "requestValidatorId")

    @request_validator_id.setter
    def request_validator_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "requestValidatorId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayMethodConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "authorization": "authorization",
        "http_method": "httpMethod",
        "resource_id": "resourceId",
        "rest_api_id": "restApiId",
        "api_key_required": "apiKeyRequired",
        "authorization_scopes": "authorizationScopes",
        "authorizer_id": "authorizerId",
        "request_models": "requestModels",
        "request_parameters": "requestParameters",
        "request_parameters_in_json": "requestParametersInJson",
        "request_validator_id": "requestValidatorId",
    },
)
class ApiGatewayMethodConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        authorization: str,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        api_key_required: typing.Optional[bool] = None,
        authorization_scopes: typing.Optional[typing.List[str]] = None,
        authorizer_id: typing.Optional[str] = None,
        request_models: typing.Optional[typing.Mapping[str, str]] = None,
        request_parameters: typing.Optional[typing.Mapping[str, bool]] = None,
        request_parameters_in_json: typing.Optional[str] = None,
        request_validator_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param authorization: 
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param api_key_required: 
        :param authorization_scopes: 
        :param authorizer_id: 
        :param request_models: 
        :param request_parameters: 
        :param request_parameters_in_json: 
        :param request_validator_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "authorization": authorization,
            "http_method": http_method,
            "resource_id": resource_id,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if api_key_required is not None:
            self._values["api_key_required"] = api_key_required
        if authorization_scopes is not None:
            self._values["authorization_scopes"] = authorization_scopes
        if authorizer_id is not None:
            self._values["authorizer_id"] = authorizer_id
        if request_models is not None:
            self._values["request_models"] = request_models
        if request_parameters is not None:
            self._values["request_parameters"] = request_parameters
        if request_parameters_in_json is not None:
            self._values["request_parameters_in_json"] = request_parameters_in_json
        if request_validator_id is not None:
            self._values["request_validator_id"] = request_validator_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def authorization(self) -> str:
        return self._values.get("authorization")

    @builtins.property
    def http_method(self) -> str:
        return self._values.get("http_method")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def api_key_required(self) -> typing.Optional[bool]:
        return self._values.get("api_key_required")

    @builtins.property
    def authorization_scopes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("authorization_scopes")

    @builtins.property
    def authorizer_id(self) -> typing.Optional[str]:
        return self._values.get("authorizer_id")

    @builtins.property
    def request_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("request_models")

    @builtins.property
    def request_parameters(self) -> typing.Optional[typing.Mapping[str, bool]]:
        return self._values.get("request_parameters")

    @builtins.property
    def request_parameters_in_json(self) -> typing.Optional[str]:
        return self._values.get("request_parameters_in_json")

    @builtins.property
    def request_validator_id(self) -> typing.Optional[str]:
        return self._values.get("request_validator_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayMethodConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayMethodResponse(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayMethodResponse",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        status_code: str,
        response_models: typing.Optional[typing.Mapping[str, str]] = None,
        response_parameters: typing.Optional[typing.Mapping[str, bool]] = None,
        response_parameters_in_json: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param status_code: 
        :param response_models: 
        :param response_parameters: 
        :param response_parameters_in_json: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayMethodResponseConfig(
            http_method=http_method,
            resource_id=resource_id,
            rest_api_id=rest_api_id,
            status_code=status_code,
            response_models=response_models,
            response_parameters=response_parameters,
            response_parameters_in_json=response_parameters_in_json,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayMethodResponse, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="httpMethod")
    def http_method(self) -> str:
        return jsii.get(self, "httpMethod")

    @http_method.setter
    def http_method(self, value: str) -> None:
        jsii.set(self, "httpMethod", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="statusCode")
    def status_code(self) -> str:
        return jsii.get(self, "statusCode")

    @status_code.setter
    def status_code(self, value: str) -> None:
        jsii.set(self, "statusCode", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="responseModels")
    def response_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "responseModels")

    @response_models.setter
    def response_models(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "responseModels", value)

    @builtins.property
    @jsii.member(jsii_name="responseParameters")
    def response_parameters(self) -> typing.Optional[typing.Mapping[str, bool]]:
        return jsii.get(self, "responseParameters")

    @response_parameters.setter
    def response_parameters(
        self, value: typing.Optional[typing.Mapping[str, bool]]
    ) -> None:
        jsii.set(self, "responseParameters", value)

    @builtins.property
    @jsii.member(jsii_name="responseParametersInJson")
    def response_parameters_in_json(self) -> typing.Optional[str]:
        return jsii.get(self, "responseParametersInJson")

    @response_parameters_in_json.setter
    def response_parameters_in_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "responseParametersInJson", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayMethodResponseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "http_method": "httpMethod",
        "resource_id": "resourceId",
        "rest_api_id": "restApiId",
        "status_code": "statusCode",
        "response_models": "responseModels",
        "response_parameters": "responseParameters",
        "response_parameters_in_json": "responseParametersInJson",
    },
)
class ApiGatewayMethodResponseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        http_method: str,
        resource_id: str,
        rest_api_id: str,
        status_code: str,
        response_models: typing.Optional[typing.Mapping[str, str]] = None,
        response_parameters: typing.Optional[typing.Mapping[str, bool]] = None,
        response_parameters_in_json: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param http_method: 
        :param resource_id: 
        :param rest_api_id: 
        :param status_code: 
        :param response_models: 
        :param response_parameters: 
        :param response_parameters_in_json: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "http_method": http_method,
            "resource_id": resource_id,
            "rest_api_id": rest_api_id,
            "status_code": status_code,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if response_models is not None:
            self._values["response_models"] = response_models
        if response_parameters is not None:
            self._values["response_parameters"] = response_parameters
        if response_parameters_in_json is not None:
            self._values["response_parameters_in_json"] = response_parameters_in_json

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def http_method(self) -> str:
        return self._values.get("http_method")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def status_code(self) -> str:
        return self._values.get("status_code")

    @builtins.property
    def response_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("response_models")

    @builtins.property
    def response_parameters(self) -> typing.Optional[typing.Mapping[str, bool]]:
        return self._values.get("response_parameters")

    @builtins.property
    def response_parameters_in_json(self) -> typing.Optional[str]:
        return self._values.get("response_parameters_in_json")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayMethodResponseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayMethodSettings(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayMethodSettings",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        method_path: str,
        rest_api_id: str,
        settings: typing.List["ApiGatewayMethodSettingsSettings"],
        stage_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param method_path: 
        :param rest_api_id: 
        :param settings: settings block.
        :param stage_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayMethodSettingsConfig(
            method_path=method_path,
            rest_api_id=rest_api_id,
            settings=settings,
            stage_name=stage_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayMethodSettings, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="methodPath")
    def method_path(self) -> str:
        return jsii.get(self, "methodPath")

    @method_path.setter
    def method_path(self, value: str) -> None:
        jsii.set(self, "methodPath", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="settings")
    def settings(self) -> typing.List["ApiGatewayMethodSettingsSettings"]:
        return jsii.get(self, "settings")

    @settings.setter
    def settings(self, value: typing.List["ApiGatewayMethodSettingsSettings"]) -> None:
        jsii.set(self, "settings", value)

    @builtins.property
    @jsii.member(jsii_name="stageName")
    def stage_name(self) -> str:
        return jsii.get(self, "stageName")

    @stage_name.setter
    def stage_name(self, value: str) -> None:
        jsii.set(self, "stageName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayMethodSettingsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "method_path": "methodPath",
        "rest_api_id": "restApiId",
        "settings": "settings",
        "stage_name": "stageName",
    },
)
class ApiGatewayMethodSettingsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        method_path: str,
        rest_api_id: str,
        settings: typing.List["ApiGatewayMethodSettingsSettings"],
        stage_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param method_path: 
        :param rest_api_id: 
        :param settings: settings block.
        :param stage_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "method_path": method_path,
            "rest_api_id": rest_api_id,
            "settings": settings,
            "stage_name": stage_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def method_path(self) -> str:
        return self._values.get("method_path")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def settings(self) -> typing.List["ApiGatewayMethodSettingsSettings"]:
        """settings block."""
        return self._values.get("settings")

    @builtins.property
    def stage_name(self) -> str:
        return self._values.get("stage_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayMethodSettingsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayMethodSettingsSettings",
    jsii_struct_bases=[],
    name_mapping={
        "cache_data_encrypted": "cacheDataEncrypted",
        "cache_ttl_in_seconds": "cacheTtlInSeconds",
        "caching_enabled": "cachingEnabled",
        "data_trace_enabled": "dataTraceEnabled",
        "logging_level": "loggingLevel",
        "metrics_enabled": "metricsEnabled",
        "require_authorization_for_cache_control": "requireAuthorizationForCacheControl",
        "throttling_burst_limit": "throttlingBurstLimit",
        "throttling_rate_limit": "throttlingRateLimit",
        "unauthorized_cache_control_header_strategy": "unauthorizedCacheControlHeaderStrategy",
    },
)
class ApiGatewayMethodSettingsSettings:
    def __init__(
        self,
        *,
        cache_data_encrypted: typing.Optional[bool] = None,
        cache_ttl_in_seconds: typing.Optional[jsii.Number] = None,
        caching_enabled: typing.Optional[bool] = None,
        data_trace_enabled: typing.Optional[bool] = None,
        logging_level: typing.Optional[str] = None,
        metrics_enabled: typing.Optional[bool] = None,
        require_authorization_for_cache_control: typing.Optional[bool] = None,
        throttling_burst_limit: typing.Optional[jsii.Number] = None,
        throttling_rate_limit: typing.Optional[jsii.Number] = None,
        unauthorized_cache_control_header_strategy: typing.Optional[str] = None,
    ) -> None:
        """
        :param cache_data_encrypted: 
        :param cache_ttl_in_seconds: 
        :param caching_enabled: 
        :param data_trace_enabled: 
        :param logging_level: 
        :param metrics_enabled: 
        :param require_authorization_for_cache_control: 
        :param throttling_burst_limit: 
        :param throttling_rate_limit: 
        :param unauthorized_cache_control_header_strategy: 
        """
        self._values = {}
        if cache_data_encrypted is not None:
            self._values["cache_data_encrypted"] = cache_data_encrypted
        if cache_ttl_in_seconds is not None:
            self._values["cache_ttl_in_seconds"] = cache_ttl_in_seconds
        if caching_enabled is not None:
            self._values["caching_enabled"] = caching_enabled
        if data_trace_enabled is not None:
            self._values["data_trace_enabled"] = data_trace_enabled
        if logging_level is not None:
            self._values["logging_level"] = logging_level
        if metrics_enabled is not None:
            self._values["metrics_enabled"] = metrics_enabled
        if require_authorization_for_cache_control is not None:
            self._values[
                "require_authorization_for_cache_control"
            ] = require_authorization_for_cache_control
        if throttling_burst_limit is not None:
            self._values["throttling_burst_limit"] = throttling_burst_limit
        if throttling_rate_limit is not None:
            self._values["throttling_rate_limit"] = throttling_rate_limit
        if unauthorized_cache_control_header_strategy is not None:
            self._values[
                "unauthorized_cache_control_header_strategy"
            ] = unauthorized_cache_control_header_strategy

    @builtins.property
    def cache_data_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("cache_data_encrypted")

    @builtins.property
    def cache_ttl_in_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cache_ttl_in_seconds")

    @builtins.property
    def caching_enabled(self) -> typing.Optional[bool]:
        return self._values.get("caching_enabled")

    @builtins.property
    def data_trace_enabled(self) -> typing.Optional[bool]:
        return self._values.get("data_trace_enabled")

    @builtins.property
    def logging_level(self) -> typing.Optional[str]:
        return self._values.get("logging_level")

    @builtins.property
    def metrics_enabled(self) -> typing.Optional[bool]:
        return self._values.get("metrics_enabled")

    @builtins.property
    def require_authorization_for_cache_control(self) -> typing.Optional[bool]:
        return self._values.get("require_authorization_for_cache_control")

    @builtins.property
    def throttling_burst_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("throttling_burst_limit")

    @builtins.property
    def throttling_rate_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("throttling_rate_limit")

    @builtins.property
    def unauthorized_cache_control_header_strategy(self) -> typing.Optional[str]:
        return self._values.get("unauthorized_cache_control_header_strategy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayMethodSettingsSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayModel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayModel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        content_type: str,
        name: str,
        rest_api_id: str,
        description: typing.Optional[str] = None,
        schema: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param content_type: 
        :param name: 
        :param rest_api_id: 
        :param description: 
        :param schema: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayModelConfig(
            content_type=content_type,
            name=name,
            rest_api_id=rest_api_id,
            description=description,
            schema=schema,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayModel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> str:
        return jsii.get(self, "contentType")

    @content_type.setter
    def content_type(self, value: str) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="schema")
    def schema(self) -> typing.Optional[str]:
        return jsii.get(self, "schema")

    @schema.setter
    def schema(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "schema", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayModelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "content_type": "contentType",
        "name": "name",
        "rest_api_id": "restApiId",
        "description": "description",
        "schema": "schema",
    },
)
class ApiGatewayModelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        content_type: str,
        name: str,
        rest_api_id: str,
        description: typing.Optional[str] = None,
        schema: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param content_type: 
        :param name: 
        :param rest_api_id: 
        :param description: 
        :param schema: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "content_type": content_type,
            "name": name,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if schema is not None:
            self._values["schema"] = schema

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def content_type(self) -> str:
        return self._values.get("content_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def schema(self) -> typing.Optional[str]:
        return self._values.get("schema")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayModelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayRequestValidator(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayRequestValidator",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        rest_api_id: str,
        validate_request_body: typing.Optional[bool] = None,
        validate_request_parameters: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param rest_api_id: 
        :param validate_request_body: 
        :param validate_request_parameters: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayRequestValidatorConfig(
            name=name,
            rest_api_id=rest_api_id,
            validate_request_body=validate_request_body,
            validate_request_parameters=validate_request_parameters,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayRequestValidator, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="validateRequestBody")
    def validate_request_body(self) -> typing.Optional[bool]:
        return jsii.get(self, "validateRequestBody")

    @validate_request_body.setter
    def validate_request_body(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "validateRequestBody", value)

    @builtins.property
    @jsii.member(jsii_name="validateRequestParameters")
    def validate_request_parameters(self) -> typing.Optional[bool]:
        return jsii.get(self, "validateRequestParameters")

    @validate_request_parameters.setter
    def validate_request_parameters(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "validateRequestParameters", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayRequestValidatorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "rest_api_id": "restApiId",
        "validate_request_body": "validateRequestBody",
        "validate_request_parameters": "validateRequestParameters",
    },
)
class ApiGatewayRequestValidatorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        rest_api_id: str,
        validate_request_body: typing.Optional[bool] = None,
        validate_request_parameters: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param rest_api_id: 
        :param validate_request_body: 
        :param validate_request_parameters: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if validate_request_body is not None:
            self._values["validate_request_body"] = validate_request_body
        if validate_request_parameters is not None:
            self._values["validate_request_parameters"] = validate_request_parameters

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def validate_request_body(self) -> typing.Optional[bool]:
        return self._values.get("validate_request_body")

    @builtins.property
    def validate_request_parameters(self) -> typing.Optional[bool]:
        return self._values.get("validate_request_parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayRequestValidatorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayResource(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayResource",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        parent_id: str,
        path_part: str,
        rest_api_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param parent_id: 
        :param path_part: 
        :param rest_api_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayResourceConfig(
            parent_id=parent_id,
            path_part=path_part,
            rest_api_id=rest_api_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayResource, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="parentId")
    def parent_id(self) -> str:
        return jsii.get(self, "parentId")

    @parent_id.setter
    def parent_id(self, value: str) -> None:
        jsii.set(self, "parentId", value)

    @builtins.property
    @jsii.member(jsii_name="pathPart")
    def path_part(self) -> str:
        return jsii.get(self, "pathPart")

    @path_part.setter
    def path_part(self, value: str) -> None:
        jsii.set(self, "pathPart", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayResourceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "parent_id": "parentId",
        "path_part": "pathPart",
        "rest_api_id": "restApiId",
    },
)
class ApiGatewayResourceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        parent_id: str,
        path_part: str,
        rest_api_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param parent_id: 
        :param path_part: 
        :param rest_api_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "parent_id": parent_id,
            "path_part": path_part,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def parent_id(self) -> str:
        return self._values.get("parent_id")

    @builtins.property
    def path_part(self) -> str:
        return self._values.get("path_part")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayResourceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayRestApi(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayRestApi",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        api_key_source: typing.Optional[str] = None,
        binary_media_types: typing.Optional[typing.List[str]] = None,
        body: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        endpoint_configuration: typing.Optional[
            typing.List["ApiGatewayRestApiEndpointConfiguration"]
        ] = None,
        minimum_compression_size: typing.Optional[jsii.Number] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param api_key_source: 
        :param binary_media_types: 
        :param body: 
        :param description: 
        :param endpoint_configuration: endpoint_configuration block.
        :param minimum_compression_size: 
        :param policy: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayRestApiConfig(
            name=name,
            api_key_source=api_key_source,
            binary_media_types=binary_media_types,
            body=body,
            description=description,
            endpoint_configuration=endpoint_configuration,
            minimum_compression_size=minimum_compression_size,
            policy=policy,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayRestApi, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="executionArn")
    def execution_arn(self) -> str:
        return jsii.get(self, "executionArn")

    @builtins.property
    @jsii.member(jsii_name="rootResourceId")
    def root_resource_id(self) -> str:
        return jsii.get(self, "rootResourceId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="apiKeySource")
    def api_key_source(self) -> typing.Optional[str]:
        return jsii.get(self, "apiKeySource")

    @api_key_source.setter
    def api_key_source(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "apiKeySource", value)

    @builtins.property
    @jsii.member(jsii_name="binaryMediaTypes")
    def binary_media_types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "binaryMediaTypes")

    @binary_media_types.setter
    def binary_media_types(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "binaryMediaTypes", value)

    @builtins.property
    @jsii.member(jsii_name="body")
    def body(self) -> typing.Optional[str]:
        return jsii.get(self, "body")

    @body.setter
    def body(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "body", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="endpointConfiguration")
    def endpoint_configuration(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayRestApiEndpointConfiguration"]]:
        return jsii.get(self, "endpointConfiguration")

    @endpoint_configuration.setter
    def endpoint_configuration(
        self,
        value: typing.Optional[typing.List["ApiGatewayRestApiEndpointConfiguration"]],
    ) -> None:
        jsii.set(self, "endpointConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="minimumCompressionSize")
    def minimum_compression_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minimumCompressionSize")

    @minimum_compression_size.setter
    def minimum_compression_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minimumCompressionSize", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayRestApiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "api_key_source": "apiKeySource",
        "binary_media_types": "binaryMediaTypes",
        "body": "body",
        "description": "description",
        "endpoint_configuration": "endpointConfiguration",
        "minimum_compression_size": "minimumCompressionSize",
        "policy": "policy",
        "tags": "tags",
    },
)
class ApiGatewayRestApiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        api_key_source: typing.Optional[str] = None,
        binary_media_types: typing.Optional[typing.List[str]] = None,
        body: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        endpoint_configuration: typing.Optional[
            typing.List["ApiGatewayRestApiEndpointConfiguration"]
        ] = None,
        minimum_compression_size: typing.Optional[jsii.Number] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param api_key_source: 
        :param binary_media_types: 
        :param body: 
        :param description: 
        :param endpoint_configuration: endpoint_configuration block.
        :param minimum_compression_size: 
        :param policy: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if api_key_source is not None:
            self._values["api_key_source"] = api_key_source
        if binary_media_types is not None:
            self._values["binary_media_types"] = binary_media_types
        if body is not None:
            self._values["body"] = body
        if description is not None:
            self._values["description"] = description
        if endpoint_configuration is not None:
            self._values["endpoint_configuration"] = endpoint_configuration
        if minimum_compression_size is not None:
            self._values["minimum_compression_size"] = minimum_compression_size
        if policy is not None:
            self._values["policy"] = policy
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def api_key_source(self) -> typing.Optional[str]:
        return self._values.get("api_key_source")

    @builtins.property
    def binary_media_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("binary_media_types")

    @builtins.property
    def body(self) -> typing.Optional[str]:
        return self._values.get("body")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def endpoint_configuration(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayRestApiEndpointConfiguration"]]:
        """endpoint_configuration block."""
        return self._values.get("endpoint_configuration")

    @builtins.property
    def minimum_compression_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("minimum_compression_size")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayRestApiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayRestApiEndpointConfiguration",
    jsii_struct_bases=[],
    name_mapping={"types": "types", "vpc_endpoint_ids": "vpcEndpointIds"},
)
class ApiGatewayRestApiEndpointConfiguration:
    def __init__(
        self,
        *,
        types: typing.List[str],
        vpc_endpoint_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param types: 
        :param vpc_endpoint_ids: 
        """
        self._values = {
            "types": types,
        }
        if vpc_endpoint_ids is not None:
            self._values["vpc_endpoint_ids"] = vpc_endpoint_ids

    @builtins.property
    def types(self) -> typing.List[str]:
        return self._values.get("types")

    @builtins.property
    def vpc_endpoint_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_endpoint_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayRestApiEndpointConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayStage(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayStage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        deployment_id: str,
        rest_api_id: str,
        stage_name: str,
        access_log_settings: typing.Optional[
            typing.List["ApiGatewayStageAccessLogSettings"]
        ] = None,
        cache_cluster_enabled: typing.Optional[bool] = None,
        cache_cluster_size: typing.Optional[str] = None,
        client_certificate_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        documentation_version: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        variables: typing.Optional[typing.Mapping[str, str]] = None,
        xray_tracing_enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param deployment_id: 
        :param rest_api_id: 
        :param stage_name: 
        :param access_log_settings: access_log_settings block.
        :param cache_cluster_enabled: 
        :param cache_cluster_size: 
        :param client_certificate_id: 
        :param description: 
        :param documentation_version: 
        :param tags: 
        :param variables: 
        :param xray_tracing_enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayStageConfig(
            deployment_id=deployment_id,
            rest_api_id=rest_api_id,
            stage_name=stage_name,
            access_log_settings=access_log_settings,
            cache_cluster_enabled=cache_cluster_enabled,
            cache_cluster_size=cache_cluster_size,
            client_certificate_id=client_certificate_id,
            description=description,
            documentation_version=documentation_version,
            tags=tags,
            variables=variables,
            xray_tracing_enabled=xray_tracing_enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayStage, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="executionArn")
    def execution_arn(self) -> str:
        return jsii.get(self, "executionArn")

    @builtins.property
    @jsii.member(jsii_name="invokeUrl")
    def invoke_url(self) -> str:
        return jsii.get(self, "invokeUrl")

    @builtins.property
    @jsii.member(jsii_name="deploymentId")
    def deployment_id(self) -> str:
        return jsii.get(self, "deploymentId")

    @deployment_id.setter
    def deployment_id(self, value: str) -> None:
        jsii.set(self, "deploymentId", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="stageName")
    def stage_name(self) -> str:
        return jsii.get(self, "stageName")

    @stage_name.setter
    def stage_name(self, value: str) -> None:
        jsii.set(self, "stageName", value)

    @builtins.property
    @jsii.member(jsii_name="accessLogSettings")
    def access_log_settings(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayStageAccessLogSettings"]]:
        return jsii.get(self, "accessLogSettings")

    @access_log_settings.setter
    def access_log_settings(
        self, value: typing.Optional[typing.List["ApiGatewayStageAccessLogSettings"]]
    ) -> None:
        jsii.set(self, "accessLogSettings", value)

    @builtins.property
    @jsii.member(jsii_name="cacheClusterEnabled")
    def cache_cluster_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "cacheClusterEnabled")

    @cache_cluster_enabled.setter
    def cache_cluster_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "cacheClusterEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="cacheClusterSize")
    def cache_cluster_size(self) -> typing.Optional[str]:
        return jsii.get(self, "cacheClusterSize")

    @cache_cluster_size.setter
    def cache_cluster_size(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cacheClusterSize", value)

    @builtins.property
    @jsii.member(jsii_name="clientCertificateId")
    def client_certificate_id(self) -> typing.Optional[str]:
        return jsii.get(self, "clientCertificateId")

    @client_certificate_id.setter
    def client_certificate_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clientCertificateId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="documentationVersion")
    def documentation_version(self) -> typing.Optional[str]:
        return jsii.get(self, "documentationVersion")

    @documentation_version.setter
    def documentation_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "documentationVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="variables")
    def variables(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "variables")

    @variables.setter
    def variables(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "variables", value)

    @builtins.property
    @jsii.member(jsii_name="xrayTracingEnabled")
    def xray_tracing_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "xrayTracingEnabled")

    @xray_tracing_enabled.setter
    def xray_tracing_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "xrayTracingEnabled", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayStageAccessLogSettings",
    jsii_struct_bases=[],
    name_mapping={"destination_arn": "destinationArn", "format": "format"},
)
class ApiGatewayStageAccessLogSettings:
    def __init__(self, *, destination_arn: str, format: str) -> None:
        """
        :param destination_arn: 
        :param format: 
        """
        self._values = {
            "destination_arn": destination_arn,
            "format": format,
        }

    @builtins.property
    def destination_arn(self) -> str:
        return self._values.get("destination_arn")

    @builtins.property
    def format(self) -> str:
        return self._values.get("format")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayStageAccessLogSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayStageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "deployment_id": "deploymentId",
        "rest_api_id": "restApiId",
        "stage_name": "stageName",
        "access_log_settings": "accessLogSettings",
        "cache_cluster_enabled": "cacheClusterEnabled",
        "cache_cluster_size": "cacheClusterSize",
        "client_certificate_id": "clientCertificateId",
        "description": "description",
        "documentation_version": "documentationVersion",
        "tags": "tags",
        "variables": "variables",
        "xray_tracing_enabled": "xrayTracingEnabled",
    },
)
class ApiGatewayStageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        deployment_id: str,
        rest_api_id: str,
        stage_name: str,
        access_log_settings: typing.Optional[
            typing.List["ApiGatewayStageAccessLogSettings"]
        ] = None,
        cache_cluster_enabled: typing.Optional[bool] = None,
        cache_cluster_size: typing.Optional[str] = None,
        client_certificate_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        documentation_version: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        variables: typing.Optional[typing.Mapping[str, str]] = None,
        xray_tracing_enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param deployment_id: 
        :param rest_api_id: 
        :param stage_name: 
        :param access_log_settings: access_log_settings block.
        :param cache_cluster_enabled: 
        :param cache_cluster_size: 
        :param client_certificate_id: 
        :param description: 
        :param documentation_version: 
        :param tags: 
        :param variables: 
        :param xray_tracing_enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "deployment_id": deployment_id,
            "rest_api_id": rest_api_id,
            "stage_name": stage_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_log_settings is not None:
            self._values["access_log_settings"] = access_log_settings
        if cache_cluster_enabled is not None:
            self._values["cache_cluster_enabled"] = cache_cluster_enabled
        if cache_cluster_size is not None:
            self._values["cache_cluster_size"] = cache_cluster_size
        if client_certificate_id is not None:
            self._values["client_certificate_id"] = client_certificate_id
        if description is not None:
            self._values["description"] = description
        if documentation_version is not None:
            self._values["documentation_version"] = documentation_version
        if tags is not None:
            self._values["tags"] = tags
        if variables is not None:
            self._values["variables"] = variables
        if xray_tracing_enabled is not None:
            self._values["xray_tracing_enabled"] = xray_tracing_enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def deployment_id(self) -> str:
        return self._values.get("deployment_id")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    @builtins.property
    def stage_name(self) -> str:
        return self._values.get("stage_name")

    @builtins.property
    def access_log_settings(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayStageAccessLogSettings"]]:
        """access_log_settings block."""
        return self._values.get("access_log_settings")

    @builtins.property
    def cache_cluster_enabled(self) -> typing.Optional[bool]:
        return self._values.get("cache_cluster_enabled")

    @builtins.property
    def cache_cluster_size(self) -> typing.Optional[str]:
        return self._values.get("cache_cluster_size")

    @builtins.property
    def client_certificate_id(self) -> typing.Optional[str]:
        return self._values.get("client_certificate_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def documentation_version(self) -> typing.Optional[str]:
        return self._values.get("documentation_version")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def variables(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("variables")

    @builtins.property
    def xray_tracing_enabled(self) -> typing.Optional[bool]:
        return self._values.get("xray_tracing_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayStageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayUsagePlan(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayUsagePlan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        api_stages: typing.Optional[typing.List["ApiGatewayUsagePlanApiStages"]] = None,
        description: typing.Optional[str] = None,
        product_code: typing.Optional[str] = None,
        quota_settings: typing.Optional[
            typing.List["ApiGatewayUsagePlanQuotaSettings"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        throttle_settings: typing.Optional[
            typing.List["ApiGatewayUsagePlanThrottleSettings"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param api_stages: api_stages block.
        :param description: 
        :param product_code: 
        :param quota_settings: quota_settings block.
        :param tags: 
        :param throttle_settings: throttle_settings block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayUsagePlanConfig(
            name=name,
            api_stages=api_stages,
            description=description,
            product_code=product_code,
            quota_settings=quota_settings,
            tags=tags,
            throttle_settings=throttle_settings,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayUsagePlan, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="apiStages")
    def api_stages(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayUsagePlanApiStages"]]:
        return jsii.get(self, "apiStages")

    @api_stages.setter
    def api_stages(
        self, value: typing.Optional[typing.List["ApiGatewayUsagePlanApiStages"]]
    ) -> None:
        jsii.set(self, "apiStages", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="productCode")
    def product_code(self) -> typing.Optional[str]:
        return jsii.get(self, "productCode")

    @product_code.setter
    def product_code(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "productCode", value)

    @builtins.property
    @jsii.member(jsii_name="quotaSettings")
    def quota_settings(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayUsagePlanQuotaSettings"]]:
        return jsii.get(self, "quotaSettings")

    @quota_settings.setter
    def quota_settings(
        self, value: typing.Optional[typing.List["ApiGatewayUsagePlanQuotaSettings"]]
    ) -> None:
        jsii.set(self, "quotaSettings", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="throttleSettings")
    def throttle_settings(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayUsagePlanThrottleSettings"]]:
        return jsii.get(self, "throttleSettings")

    @throttle_settings.setter
    def throttle_settings(
        self, value: typing.Optional[typing.List["ApiGatewayUsagePlanThrottleSettings"]]
    ) -> None:
        jsii.set(self, "throttleSettings", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayUsagePlanApiStages",
    jsii_struct_bases=[],
    name_mapping={"api_id": "apiId", "stage": "stage"},
)
class ApiGatewayUsagePlanApiStages:
    def __init__(self, *, api_id: str, stage: str) -> None:
        """
        :param api_id: 
        :param stage: 
        """
        self._values = {
            "api_id": api_id,
            "stage": stage,
        }

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def stage(self) -> str:
        return self._values.get("stage")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayUsagePlanApiStages(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayUsagePlanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "api_stages": "apiStages",
        "description": "description",
        "product_code": "productCode",
        "quota_settings": "quotaSettings",
        "tags": "tags",
        "throttle_settings": "throttleSettings",
    },
)
class ApiGatewayUsagePlanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        api_stages: typing.Optional[typing.List["ApiGatewayUsagePlanApiStages"]] = None,
        description: typing.Optional[str] = None,
        product_code: typing.Optional[str] = None,
        quota_settings: typing.Optional[
            typing.List["ApiGatewayUsagePlanQuotaSettings"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        throttle_settings: typing.Optional[
            typing.List["ApiGatewayUsagePlanThrottleSettings"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param api_stages: api_stages block.
        :param description: 
        :param product_code: 
        :param quota_settings: quota_settings block.
        :param tags: 
        :param throttle_settings: throttle_settings block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if api_stages is not None:
            self._values["api_stages"] = api_stages
        if description is not None:
            self._values["description"] = description
        if product_code is not None:
            self._values["product_code"] = product_code
        if quota_settings is not None:
            self._values["quota_settings"] = quota_settings
        if tags is not None:
            self._values["tags"] = tags
        if throttle_settings is not None:
            self._values["throttle_settings"] = throttle_settings

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def api_stages(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayUsagePlanApiStages"]]:
        """api_stages block."""
        return self._values.get("api_stages")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def product_code(self) -> typing.Optional[str]:
        return self._values.get("product_code")

    @builtins.property
    def quota_settings(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayUsagePlanQuotaSettings"]]:
        """quota_settings block."""
        return self._values.get("quota_settings")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def throttle_settings(
        self,
    ) -> typing.Optional[typing.List["ApiGatewayUsagePlanThrottleSettings"]]:
        """throttle_settings block."""
        return self._values.get("throttle_settings")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayUsagePlanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayUsagePlanKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayUsagePlanKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        key_id: str,
        key_type: str,
        usage_plan_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_id: 
        :param key_type: 
        :param usage_plan_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayUsagePlanKeyConfig(
            key_id=key_id,
            key_type=key_type,
            usage_plan_id=usage_plan_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayUsagePlanKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")

    @builtins.property
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> str:
        return jsii.get(self, "keyId")

    @key_id.setter
    def key_id(self, value: str) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property
    @jsii.member(jsii_name="keyType")
    def key_type(self) -> str:
        return jsii.get(self, "keyType")

    @key_type.setter
    def key_type(self, value: str) -> None:
        jsii.set(self, "keyType", value)

    @builtins.property
    @jsii.member(jsii_name="usagePlanId")
    def usage_plan_id(self) -> str:
        return jsii.get(self, "usagePlanId")

    @usage_plan_id.setter
    def usage_plan_id(self, value: str) -> None:
        jsii.set(self, "usagePlanId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayUsagePlanKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_id": "keyId",
        "key_type": "keyType",
        "usage_plan_id": "usagePlanId",
    },
)
class ApiGatewayUsagePlanKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_id: str,
        key_type: str,
        usage_plan_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_id: 
        :param key_type: 
        :param usage_plan_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "key_id": key_id,
            "key_type": key_type,
            "usage_plan_id": usage_plan_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def key_id(self) -> str:
        return self._values.get("key_id")

    @builtins.property
    def key_type(self) -> str:
        return self._values.get("key_type")

    @builtins.property
    def usage_plan_id(self) -> str:
        return self._values.get("usage_plan_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayUsagePlanKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayUsagePlanQuotaSettings",
    jsii_struct_bases=[],
    name_mapping={"limit": "limit", "period": "period", "offset": "offset"},
)
class ApiGatewayUsagePlanQuotaSettings:
    def __init__(
        self,
        *,
        limit: jsii.Number,
        period: str,
        offset: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param limit: 
        :param period: 
        :param offset: 
        """
        self._values = {
            "limit": limit,
            "period": period,
        }
        if offset is not None:
            self._values["offset"] = offset

    @builtins.property
    def limit(self) -> jsii.Number:
        return self._values.get("limit")

    @builtins.property
    def period(self) -> str:
        return self._values.get("period")

    @builtins.property
    def offset(self) -> typing.Optional[jsii.Number]:
        return self._values.get("offset")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayUsagePlanQuotaSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayUsagePlanThrottleSettings",
    jsii_struct_bases=[],
    name_mapping={"burst_limit": "burstLimit", "rate_limit": "rateLimit"},
)
class ApiGatewayUsagePlanThrottleSettings:
    def __init__(
        self,
        *,
        burst_limit: typing.Optional[jsii.Number] = None,
        rate_limit: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param burst_limit: 
        :param rate_limit: 
        """
        self._values = {}
        if burst_limit is not None:
            self._values["burst_limit"] = burst_limit
        if rate_limit is not None:
            self._values["rate_limit"] = rate_limit

    @builtins.property
    def burst_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("burst_limit")

    @builtins.property
    def rate_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("rate_limit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayUsagePlanThrottleSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ApiGatewayVpcLink(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayVpcLink",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        target_arns: typing.List[str],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param target_arns: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ApiGatewayVpcLinkConfig(
            name=name,
            target_arns=target_arns,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ApiGatewayVpcLink, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="targetArns")
    def target_arns(self) -> typing.List[str]:
        return jsii.get(self, "targetArns")

    @target_arns.setter
    def target_arns(self, value: typing.List[str]) -> None:
        jsii.set(self, "targetArns", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ApiGatewayVpcLinkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "target_arns": "targetArns",
        "description": "description",
        "tags": "tags",
    },
)
class ApiGatewayVpcLinkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        target_arns: typing.List[str],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param target_arns: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "target_arns": target_arns,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def target_arns(self) -> typing.List[str]:
        return self._values.get("target_arns")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ApiGatewayVpcLinkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2Api(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2Api",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        protocol_type: str,
        api_key_selection_expression: typing.Optional[str] = None,
        cors_configuration: typing.Optional[
            typing.List["Apigatewayv2ApiCorsConfiguration"]
        ] = None,
        credentials_arn: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        route_key: typing.Optional[str] = None,
        route_selection_expression: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target: typing.Optional[str] = None,
        version: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param protocol_type: 
        :param api_key_selection_expression: 
        :param cors_configuration: cors_configuration block.
        :param credentials_arn: 
        :param description: 
        :param route_key: 
        :param route_selection_expression: 
        :param tags: 
        :param target: 
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2ApiConfig(
            name=name,
            protocol_type=protocol_type,
            api_key_selection_expression=api_key_selection_expression,
            cors_configuration=cors_configuration,
            credentials_arn=credentials_arn,
            description=description,
            route_key=route_key,
            route_selection_expression=route_selection_expression,
            tags=tags,
            target=target,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2Api, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiEndpoint")
    def api_endpoint(self) -> str:
        return jsii.get(self, "apiEndpoint")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="executionArn")
    def execution_arn(self) -> str:
        return jsii.get(self, "executionArn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="protocolType")
    def protocol_type(self) -> str:
        return jsii.get(self, "protocolType")

    @protocol_type.setter
    def protocol_type(self, value: str) -> None:
        jsii.set(self, "protocolType", value)

    @builtins.property
    @jsii.member(jsii_name="apiKeySelectionExpression")
    def api_key_selection_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "apiKeySelectionExpression")

    @api_key_selection_expression.setter
    def api_key_selection_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "apiKeySelectionExpression", value)

    @builtins.property
    @jsii.member(jsii_name="corsConfiguration")
    def cors_configuration(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2ApiCorsConfiguration"]]:
        return jsii.get(self, "corsConfiguration")

    @cors_configuration.setter
    def cors_configuration(
        self, value: typing.Optional[typing.List["Apigatewayv2ApiCorsConfiguration"]]
    ) -> None:
        jsii.set(self, "corsConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="credentialsArn")
    def credentials_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "credentialsArn")

    @credentials_arn.setter
    def credentials_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "credentialsArn", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="routeKey")
    def route_key(self) -> typing.Optional[str]:
        return jsii.get(self, "routeKey")

    @route_key.setter
    def route_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "routeKey", value)

    @builtins.property
    @jsii.member(jsii_name="routeSelectionExpression")
    def route_selection_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "routeSelectionExpression")

    @route_selection_expression.setter
    def route_selection_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "routeSelectionExpression", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="target")
    def target(self) -> typing.Optional[str]:
        return jsii.get(self, "target")

    @target.setter
    def target(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "target", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[str]:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2ApiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "protocol_type": "protocolType",
        "api_key_selection_expression": "apiKeySelectionExpression",
        "cors_configuration": "corsConfiguration",
        "credentials_arn": "credentialsArn",
        "description": "description",
        "route_key": "routeKey",
        "route_selection_expression": "routeSelectionExpression",
        "tags": "tags",
        "target": "target",
        "version": "version",
    },
)
class Apigatewayv2ApiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        protocol_type: str,
        api_key_selection_expression: typing.Optional[str] = None,
        cors_configuration: typing.Optional[
            typing.List["Apigatewayv2ApiCorsConfiguration"]
        ] = None,
        credentials_arn: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        route_key: typing.Optional[str] = None,
        route_selection_expression: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target: typing.Optional[str] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param protocol_type: 
        :param api_key_selection_expression: 
        :param cors_configuration: cors_configuration block.
        :param credentials_arn: 
        :param description: 
        :param route_key: 
        :param route_selection_expression: 
        :param tags: 
        :param target: 
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "protocol_type": protocol_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if api_key_selection_expression is not None:
            self._values["api_key_selection_expression"] = api_key_selection_expression
        if cors_configuration is not None:
            self._values["cors_configuration"] = cors_configuration
        if credentials_arn is not None:
            self._values["credentials_arn"] = credentials_arn
        if description is not None:
            self._values["description"] = description
        if route_key is not None:
            self._values["route_key"] = route_key
        if route_selection_expression is not None:
            self._values["route_selection_expression"] = route_selection_expression
        if tags is not None:
            self._values["tags"] = tags
        if target is not None:
            self._values["target"] = target
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def protocol_type(self) -> str:
        return self._values.get("protocol_type")

    @builtins.property
    def api_key_selection_expression(self) -> typing.Optional[str]:
        return self._values.get("api_key_selection_expression")

    @builtins.property
    def cors_configuration(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2ApiCorsConfiguration"]]:
        """cors_configuration block."""
        return self._values.get("cors_configuration")

    @builtins.property
    def credentials_arn(self) -> typing.Optional[str]:
        return self._values.get("credentials_arn")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def route_key(self) -> typing.Optional[str]:
        return self._values.get("route_key")

    @builtins.property
    def route_selection_expression(self) -> typing.Optional[str]:
        return self._values.get("route_selection_expression")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target(self) -> typing.Optional[str]:
        return self._values.get("target")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2ApiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2ApiCorsConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "allow_credentials": "allowCredentials",
        "allow_headers": "allowHeaders",
        "allow_methods": "allowMethods",
        "allow_origins": "allowOrigins",
        "expose_headers": "exposeHeaders",
        "max_age": "maxAge",
    },
)
class Apigatewayv2ApiCorsConfiguration:
    def __init__(
        self,
        *,
        allow_credentials: typing.Optional[bool] = None,
        allow_headers: typing.Optional[typing.List[str]] = None,
        allow_methods: typing.Optional[typing.List[str]] = None,
        allow_origins: typing.Optional[typing.List[str]] = None,
        expose_headers: typing.Optional[typing.List[str]] = None,
        max_age: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param allow_credentials: 
        :param allow_headers: 
        :param allow_methods: 
        :param allow_origins: 
        :param expose_headers: 
        :param max_age: 
        """
        self._values = {}
        if allow_credentials is not None:
            self._values["allow_credentials"] = allow_credentials
        if allow_headers is not None:
            self._values["allow_headers"] = allow_headers
        if allow_methods is not None:
            self._values["allow_methods"] = allow_methods
        if allow_origins is not None:
            self._values["allow_origins"] = allow_origins
        if expose_headers is not None:
            self._values["expose_headers"] = expose_headers
        if max_age is not None:
            self._values["max_age"] = max_age

    @builtins.property
    def allow_credentials(self) -> typing.Optional[bool]:
        return self._values.get("allow_credentials")

    @builtins.property
    def allow_headers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allow_headers")

    @builtins.property
    def allow_methods(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allow_methods")

    @builtins.property
    def allow_origins(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allow_origins")

    @builtins.property
    def expose_headers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("expose_headers")

    @builtins.property
    def max_age(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_age")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2ApiCorsConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2ApiMapping(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2ApiMapping",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        domain_name: str,
        stage: str,
        api_mapping_key: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param domain_name: 
        :param stage: 
        :param api_mapping_key: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2ApiMappingConfig(
            api_id=api_id,
            domain_name=domain_name,
            stage=stage,
            api_mapping_key=api_mapping_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2ApiMapping, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="stage")
    def stage(self) -> str:
        return jsii.get(self, "stage")

    @stage.setter
    def stage(self, value: str) -> None:
        jsii.set(self, "stage", value)

    @builtins.property
    @jsii.member(jsii_name="apiMappingKey")
    def api_mapping_key(self) -> typing.Optional[str]:
        return jsii.get(self, "apiMappingKey")

    @api_mapping_key.setter
    def api_mapping_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "apiMappingKey", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2ApiMappingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "domain_name": "domainName",
        "stage": "stage",
        "api_mapping_key": "apiMappingKey",
    },
)
class Apigatewayv2ApiMappingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        domain_name: str,
        stage: str,
        api_mapping_key: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param domain_name: 
        :param stage: 
        :param api_mapping_key: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "domain_name": domain_name,
            "stage": stage,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if api_mapping_key is not None:
            self._values["api_mapping_key"] = api_mapping_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def stage(self) -> str:
        return self._values.get("stage")

    @builtins.property
    def api_mapping_key(self) -> typing.Optional[str]:
        return self._values.get("api_mapping_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2ApiMappingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2Authorizer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2Authorizer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        authorizer_type: str,
        identity_sources: typing.List[str],
        name: str,
        authorizer_credentials_arn: typing.Optional[str] = None,
        authorizer_uri: typing.Optional[str] = None,
        jwt_configuration: typing.Optional[
            typing.List["Apigatewayv2AuthorizerJwtConfiguration"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param authorizer_type: 
        :param identity_sources: 
        :param name: 
        :param authorizer_credentials_arn: 
        :param authorizer_uri: 
        :param jwt_configuration: jwt_configuration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2AuthorizerConfig(
            api_id=api_id,
            authorizer_type=authorizer_type,
            identity_sources=identity_sources,
            name=name,
            authorizer_credentials_arn=authorizer_credentials_arn,
            authorizer_uri=authorizer_uri,
            jwt_configuration=jwt_configuration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2Authorizer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerType")
    def authorizer_type(self) -> str:
        return jsii.get(self, "authorizerType")

    @authorizer_type.setter
    def authorizer_type(self, value: str) -> None:
        jsii.set(self, "authorizerType", value)

    @builtins.property
    @jsii.member(jsii_name="identitySources")
    def identity_sources(self) -> typing.List[str]:
        return jsii.get(self, "identitySources")

    @identity_sources.setter
    def identity_sources(self, value: typing.List[str]) -> None:
        jsii.set(self, "identitySources", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerCredentialsArn")
    def authorizer_credentials_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "authorizerCredentialsArn")

    @authorizer_credentials_arn.setter
    def authorizer_credentials_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authorizerCredentialsArn", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerUri")
    def authorizer_uri(self) -> typing.Optional[str]:
        return jsii.get(self, "authorizerUri")

    @authorizer_uri.setter
    def authorizer_uri(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authorizerUri", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="jwtConfiguration")
    def jwt_configuration(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2AuthorizerJwtConfiguration"]]:
        return jsii.get(self, "jwtConfiguration")

    @jwt_configuration.setter
    def jwt_configuration(
        self,
        value: typing.Optional[typing.List["Apigatewayv2AuthorizerJwtConfiguration"]],
    ) -> None:
        jsii.set(self, "jwtConfiguration", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2AuthorizerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "authorizer_type": "authorizerType",
        "identity_sources": "identitySources",
        "name": "name",
        "authorizer_credentials_arn": "authorizerCredentialsArn",
        "authorizer_uri": "authorizerUri",
        "jwt_configuration": "jwtConfiguration",
    },
)
class Apigatewayv2AuthorizerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        authorizer_type: str,
        identity_sources: typing.List[str],
        name: str,
        authorizer_credentials_arn: typing.Optional[str] = None,
        authorizer_uri: typing.Optional[str] = None,
        jwt_configuration: typing.Optional[
            typing.List["Apigatewayv2AuthorizerJwtConfiguration"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param authorizer_type: 
        :param identity_sources: 
        :param name: 
        :param authorizer_credentials_arn: 
        :param authorizer_uri: 
        :param jwt_configuration: jwt_configuration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "authorizer_type": authorizer_type,
            "identity_sources": identity_sources,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authorizer_credentials_arn is not None:
            self._values["authorizer_credentials_arn"] = authorizer_credentials_arn
        if authorizer_uri is not None:
            self._values["authorizer_uri"] = authorizer_uri
        if jwt_configuration is not None:
            self._values["jwt_configuration"] = jwt_configuration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def authorizer_type(self) -> str:
        return self._values.get("authorizer_type")

    @builtins.property
    def identity_sources(self) -> typing.List[str]:
        return self._values.get("identity_sources")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def authorizer_credentials_arn(self) -> typing.Optional[str]:
        return self._values.get("authorizer_credentials_arn")

    @builtins.property
    def authorizer_uri(self) -> typing.Optional[str]:
        return self._values.get("authorizer_uri")

    @builtins.property
    def jwt_configuration(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2AuthorizerJwtConfiguration"]]:
        """jwt_configuration block."""
        return self._values.get("jwt_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2AuthorizerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2AuthorizerJwtConfiguration",
    jsii_struct_bases=[],
    name_mapping={"audience": "audience", "issuer": "issuer"},
)
class Apigatewayv2AuthorizerJwtConfiguration:
    def __init__(
        self,
        *,
        audience: typing.Optional[typing.List[str]] = None,
        issuer: typing.Optional[str] = None,
    ) -> None:
        """
        :param audience: 
        :param issuer: 
        """
        self._values = {}
        if audience is not None:
            self._values["audience"] = audience
        if issuer is not None:
            self._values["issuer"] = issuer

    @builtins.property
    def audience(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("audience")

    @builtins.property
    def issuer(self) -> typing.Optional[str]:
        return self._values.get("issuer")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2AuthorizerJwtConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2Deployment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2Deployment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        description: typing.Optional[str] = None,
        triggers: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param description: 
        :param triggers: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2DeploymentConfig(
            api_id=api_id,
            description=description,
            triggers=triggers,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2Deployment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="autoDeployed")
    def auto_deployed(self) -> bool:
        return jsii.get(self, "autoDeployed")

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="triggers")
    def triggers(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "triggers")

    @triggers.setter
    def triggers(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "triggers", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2DeploymentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "description": "description",
        "triggers": "triggers",
    },
)
class Apigatewayv2DeploymentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        description: typing.Optional[str] = None,
        triggers: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param description: 
        :param triggers: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if triggers is not None:
            self._values["triggers"] = triggers

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def triggers(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("triggers")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2DeploymentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2DomainName(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2DomainName",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: str,
        domain_name_configuration: typing.List[
            "Apigatewayv2DomainNameDomainNameConfiguration"
        ],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["Apigatewayv2DomainNameTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param domain_name_configuration: domain_name_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2DomainNameConfig(
            domain_name=domain_name,
            domain_name_configuration=domain_name_configuration,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2DomainName, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiMappingSelectionExpression")
    def api_mapping_selection_expression(self) -> str:
        return jsii.get(self, "apiMappingSelectionExpression")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="domainNameConfiguration")
    def domain_name_configuration(
        self,
    ) -> typing.List["Apigatewayv2DomainNameDomainNameConfiguration"]:
        return jsii.get(self, "domainNameConfiguration")

    @domain_name_configuration.setter
    def domain_name_configuration(
        self, value: typing.List["Apigatewayv2DomainNameDomainNameConfiguration"]
    ) -> None:
        jsii.set(self, "domainNameConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["Apigatewayv2DomainNameTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["Apigatewayv2DomainNameTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2DomainNameConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
        "domain_name_configuration": "domainNameConfiguration",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class Apigatewayv2DomainNameConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: str,
        domain_name_configuration: typing.List[
            "Apigatewayv2DomainNameDomainNameConfiguration"
        ],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["Apigatewayv2DomainNameTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        :param domain_name_configuration: domain_name_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = Apigatewayv2DomainNameTimeouts(**timeouts)
        self._values = {
            "domain_name": domain_name,
            "domain_name_configuration": domain_name_configuration,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def domain_name_configuration(
        self,
    ) -> typing.List["Apigatewayv2DomainNameDomainNameConfiguration"]:
        """domain_name_configuration block."""
        return self._values.get("domain_name_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["Apigatewayv2DomainNameTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2DomainNameConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2DomainNameDomainNameConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "certificate_arn": "certificateArn",
        "endpoint_type": "endpointType",
        "security_policy": "securityPolicy",
    },
)
class Apigatewayv2DomainNameDomainNameConfiguration:
    def __init__(
        self, *, certificate_arn: str, endpoint_type: str, security_policy: str
    ) -> None:
        """
        :param certificate_arn: 
        :param endpoint_type: 
        :param security_policy: 
        """
        self._values = {
            "certificate_arn": certificate_arn,
            "endpoint_type": endpoint_type,
            "security_policy": security_policy,
        }

    @builtins.property
    def certificate_arn(self) -> str:
        return self._values.get("certificate_arn")

    @builtins.property
    def endpoint_type(self) -> str:
        return self._values.get("endpoint_type")

    @builtins.property
    def security_policy(self) -> str:
        return self._values.get("security_policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2DomainNameDomainNameConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2DomainNameTimeouts",
    jsii_struct_bases=[],
    name_mapping={"update": "update"},
)
class Apigatewayv2DomainNameTimeouts:
    def __init__(self, *, update: typing.Optional[str] = None) -> None:
        """
        :param update: 
        """
        self._values = {}
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2DomainNameTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2Integration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2Integration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        integration_type: str,
        connection_id: typing.Optional[str] = None,
        connection_type: typing.Optional[str] = None,
        content_handling_strategy: typing.Optional[str] = None,
        credentials_arn: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        integration_method: typing.Optional[str] = None,
        integration_uri: typing.Optional[str] = None,
        passthrough_behavior: typing.Optional[str] = None,
        payload_format_version: typing.Optional[str] = None,
        request_templates: typing.Optional[typing.Mapping[str, str]] = None,
        template_selection_expression: typing.Optional[str] = None,
        timeout_milliseconds: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param integration_type: 
        :param connection_id: 
        :param connection_type: 
        :param content_handling_strategy: 
        :param credentials_arn: 
        :param description: 
        :param integration_method: 
        :param integration_uri: 
        :param passthrough_behavior: 
        :param payload_format_version: 
        :param request_templates: 
        :param template_selection_expression: 
        :param timeout_milliseconds: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2IntegrationConfig(
            api_id=api_id,
            integration_type=integration_type,
            connection_id=connection_id,
            connection_type=connection_type,
            content_handling_strategy=content_handling_strategy,
            credentials_arn=credentials_arn,
            description=description,
            integration_method=integration_method,
            integration_uri=integration_uri,
            passthrough_behavior=passthrough_behavior,
            payload_format_version=payload_format_version,
            request_templates=request_templates,
            template_selection_expression=template_selection_expression,
            timeout_milliseconds=timeout_milliseconds,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2Integration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="integrationResponseSelectionExpression")
    def integration_response_selection_expression(self) -> str:
        return jsii.get(self, "integrationResponseSelectionExpression")

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="integrationType")
    def integration_type(self) -> str:
        return jsii.get(self, "integrationType")

    @integration_type.setter
    def integration_type(self, value: str) -> None:
        jsii.set(self, "integrationType", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> typing.Optional[str]:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="connectionType")
    def connection_type(self) -> typing.Optional[str]:
        return jsii.get(self, "connectionType")

    @connection_type.setter
    def connection_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "connectionType", value)

    @builtins.property
    @jsii.member(jsii_name="contentHandlingStrategy")
    def content_handling_strategy(self) -> typing.Optional[str]:
        return jsii.get(self, "contentHandlingStrategy")

    @content_handling_strategy.setter
    def content_handling_strategy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentHandlingStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="credentialsArn")
    def credentials_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "credentialsArn")

    @credentials_arn.setter
    def credentials_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "credentialsArn", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="integrationMethod")
    def integration_method(self) -> typing.Optional[str]:
        return jsii.get(self, "integrationMethod")

    @integration_method.setter
    def integration_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "integrationMethod", value)

    @builtins.property
    @jsii.member(jsii_name="integrationUri")
    def integration_uri(self) -> typing.Optional[str]:
        return jsii.get(self, "integrationUri")

    @integration_uri.setter
    def integration_uri(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "integrationUri", value)

    @builtins.property
    @jsii.member(jsii_name="passthroughBehavior")
    def passthrough_behavior(self) -> typing.Optional[str]:
        return jsii.get(self, "passthroughBehavior")

    @passthrough_behavior.setter
    def passthrough_behavior(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "passthroughBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="payloadFormatVersion")
    def payload_format_version(self) -> typing.Optional[str]:
        return jsii.get(self, "payloadFormatVersion")

    @payload_format_version.setter
    def payload_format_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "payloadFormatVersion", value)

    @builtins.property
    @jsii.member(jsii_name="requestTemplates")
    def request_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "requestTemplates")

    @request_templates.setter
    def request_templates(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "requestTemplates", value)

    @builtins.property
    @jsii.member(jsii_name="templateSelectionExpression")
    def template_selection_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "templateSelectionExpression")

    @template_selection_expression.setter
    def template_selection_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "templateSelectionExpression", value)

    @builtins.property
    @jsii.member(jsii_name="timeoutMilliseconds")
    def timeout_milliseconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "timeoutMilliseconds")

    @timeout_milliseconds.setter
    def timeout_milliseconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "timeoutMilliseconds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2IntegrationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "integration_type": "integrationType",
        "connection_id": "connectionId",
        "connection_type": "connectionType",
        "content_handling_strategy": "contentHandlingStrategy",
        "credentials_arn": "credentialsArn",
        "description": "description",
        "integration_method": "integrationMethod",
        "integration_uri": "integrationUri",
        "passthrough_behavior": "passthroughBehavior",
        "payload_format_version": "payloadFormatVersion",
        "request_templates": "requestTemplates",
        "template_selection_expression": "templateSelectionExpression",
        "timeout_milliseconds": "timeoutMilliseconds",
    },
)
class Apigatewayv2IntegrationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        integration_type: str,
        connection_id: typing.Optional[str] = None,
        connection_type: typing.Optional[str] = None,
        content_handling_strategy: typing.Optional[str] = None,
        credentials_arn: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        integration_method: typing.Optional[str] = None,
        integration_uri: typing.Optional[str] = None,
        passthrough_behavior: typing.Optional[str] = None,
        payload_format_version: typing.Optional[str] = None,
        request_templates: typing.Optional[typing.Mapping[str, str]] = None,
        template_selection_expression: typing.Optional[str] = None,
        timeout_milliseconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param integration_type: 
        :param connection_id: 
        :param connection_type: 
        :param content_handling_strategy: 
        :param credentials_arn: 
        :param description: 
        :param integration_method: 
        :param integration_uri: 
        :param passthrough_behavior: 
        :param payload_format_version: 
        :param request_templates: 
        :param template_selection_expression: 
        :param timeout_milliseconds: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "integration_type": integration_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if connection_id is not None:
            self._values["connection_id"] = connection_id
        if connection_type is not None:
            self._values["connection_type"] = connection_type
        if content_handling_strategy is not None:
            self._values["content_handling_strategy"] = content_handling_strategy
        if credentials_arn is not None:
            self._values["credentials_arn"] = credentials_arn
        if description is not None:
            self._values["description"] = description
        if integration_method is not None:
            self._values["integration_method"] = integration_method
        if integration_uri is not None:
            self._values["integration_uri"] = integration_uri
        if passthrough_behavior is not None:
            self._values["passthrough_behavior"] = passthrough_behavior
        if payload_format_version is not None:
            self._values["payload_format_version"] = payload_format_version
        if request_templates is not None:
            self._values["request_templates"] = request_templates
        if template_selection_expression is not None:
            self._values[
                "template_selection_expression"
            ] = template_selection_expression
        if timeout_milliseconds is not None:
            self._values["timeout_milliseconds"] = timeout_milliseconds

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def integration_type(self) -> str:
        return self._values.get("integration_type")

    @builtins.property
    def connection_id(self) -> typing.Optional[str]:
        return self._values.get("connection_id")

    @builtins.property
    def connection_type(self) -> typing.Optional[str]:
        return self._values.get("connection_type")

    @builtins.property
    def content_handling_strategy(self) -> typing.Optional[str]:
        return self._values.get("content_handling_strategy")

    @builtins.property
    def credentials_arn(self) -> typing.Optional[str]:
        return self._values.get("credentials_arn")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def integration_method(self) -> typing.Optional[str]:
        return self._values.get("integration_method")

    @builtins.property
    def integration_uri(self) -> typing.Optional[str]:
        return self._values.get("integration_uri")

    @builtins.property
    def passthrough_behavior(self) -> typing.Optional[str]:
        return self._values.get("passthrough_behavior")

    @builtins.property
    def payload_format_version(self) -> typing.Optional[str]:
        return self._values.get("payload_format_version")

    @builtins.property
    def request_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("request_templates")

    @builtins.property
    def template_selection_expression(self) -> typing.Optional[str]:
        return self._values.get("template_selection_expression")

    @builtins.property
    def timeout_milliseconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout_milliseconds")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2IntegrationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2IntegrationResponse(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2IntegrationResponse",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        integration_id: str,
        integration_response_key: str,
        content_handling_strategy: typing.Optional[str] = None,
        response_templates: typing.Optional[typing.Mapping[str, str]] = None,
        template_selection_expression: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param integration_id: 
        :param integration_response_key: 
        :param content_handling_strategy: 
        :param response_templates: 
        :param template_selection_expression: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2IntegrationResponseConfig(
            api_id=api_id,
            integration_id=integration_id,
            integration_response_key=integration_response_key,
            content_handling_strategy=content_handling_strategy,
            response_templates=response_templates,
            template_selection_expression=template_selection_expression,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2IntegrationResponse, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="integrationId")
    def integration_id(self) -> str:
        return jsii.get(self, "integrationId")

    @integration_id.setter
    def integration_id(self, value: str) -> None:
        jsii.set(self, "integrationId", value)

    @builtins.property
    @jsii.member(jsii_name="integrationResponseKey")
    def integration_response_key(self) -> str:
        return jsii.get(self, "integrationResponseKey")

    @integration_response_key.setter
    def integration_response_key(self, value: str) -> None:
        jsii.set(self, "integrationResponseKey", value)

    @builtins.property
    @jsii.member(jsii_name="contentHandlingStrategy")
    def content_handling_strategy(self) -> typing.Optional[str]:
        return jsii.get(self, "contentHandlingStrategy")

    @content_handling_strategy.setter
    def content_handling_strategy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentHandlingStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="responseTemplates")
    def response_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "responseTemplates")

    @response_templates.setter
    def response_templates(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "responseTemplates", value)

    @builtins.property
    @jsii.member(jsii_name="templateSelectionExpression")
    def template_selection_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "templateSelectionExpression")

    @template_selection_expression.setter
    def template_selection_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "templateSelectionExpression", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2IntegrationResponseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "integration_id": "integrationId",
        "integration_response_key": "integrationResponseKey",
        "content_handling_strategy": "contentHandlingStrategy",
        "response_templates": "responseTemplates",
        "template_selection_expression": "templateSelectionExpression",
    },
)
class Apigatewayv2IntegrationResponseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        integration_id: str,
        integration_response_key: str,
        content_handling_strategy: typing.Optional[str] = None,
        response_templates: typing.Optional[typing.Mapping[str, str]] = None,
        template_selection_expression: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param integration_id: 
        :param integration_response_key: 
        :param content_handling_strategy: 
        :param response_templates: 
        :param template_selection_expression: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "integration_id": integration_id,
            "integration_response_key": integration_response_key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if content_handling_strategy is not None:
            self._values["content_handling_strategy"] = content_handling_strategy
        if response_templates is not None:
            self._values["response_templates"] = response_templates
        if template_selection_expression is not None:
            self._values[
                "template_selection_expression"
            ] = template_selection_expression

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def integration_id(self) -> str:
        return self._values.get("integration_id")

    @builtins.property
    def integration_response_key(self) -> str:
        return self._values.get("integration_response_key")

    @builtins.property
    def content_handling_strategy(self) -> typing.Optional[str]:
        return self._values.get("content_handling_strategy")

    @builtins.property
    def response_templates(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("response_templates")

    @builtins.property
    def template_selection_expression(self) -> typing.Optional[str]:
        return self._values.get("template_selection_expression")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2IntegrationResponseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2Model(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2Model",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        content_type: str,
        name: str,
        schema: str,
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param content_type: 
        :param name: 
        :param schema: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2ModelConfig(
            api_id=api_id,
            content_type=content_type,
            name=name,
            schema=schema,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2Model, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> str:
        return jsii.get(self, "contentType")

    @content_type.setter
    def content_type(self, value: str) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="schema")
    def schema(self) -> str:
        return jsii.get(self, "schema")

    @schema.setter
    def schema(self, value: str) -> None:
        jsii.set(self, "schema", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2ModelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "content_type": "contentType",
        "name": "name",
        "schema": "schema",
        "description": "description",
    },
)
class Apigatewayv2ModelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        content_type: str,
        name: str,
        schema: str,
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param content_type: 
        :param name: 
        :param schema: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "content_type": content_type,
            "name": name,
            "schema": schema,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def content_type(self) -> str:
        return self._values.get("content_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def schema(self) -> str:
        return self._values.get("schema")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2ModelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2Route(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2Route",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        route_key: str,
        api_key_required: typing.Optional[bool] = None,
        authorization_scopes: typing.Optional[typing.List[str]] = None,
        authorization_type: typing.Optional[str] = None,
        authorizer_id: typing.Optional[str] = None,
        model_selection_expression: typing.Optional[str] = None,
        operation_name: typing.Optional[str] = None,
        request_models: typing.Optional[typing.Mapping[str, str]] = None,
        route_response_selection_expression: typing.Optional[str] = None,
        target: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param route_key: 
        :param api_key_required: 
        :param authorization_scopes: 
        :param authorization_type: 
        :param authorizer_id: 
        :param model_selection_expression: 
        :param operation_name: 
        :param request_models: 
        :param route_response_selection_expression: 
        :param target: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2RouteConfig(
            api_id=api_id,
            route_key=route_key,
            api_key_required=api_key_required,
            authorization_scopes=authorization_scopes,
            authorization_type=authorization_type,
            authorizer_id=authorizer_id,
            model_selection_expression=model_selection_expression,
            operation_name=operation_name,
            request_models=request_models,
            route_response_selection_expression=route_response_selection_expression,
            target=target,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2Route, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="routeKey")
    def route_key(self) -> str:
        return jsii.get(self, "routeKey")

    @route_key.setter
    def route_key(self, value: str) -> None:
        jsii.set(self, "routeKey", value)

    @builtins.property
    @jsii.member(jsii_name="apiKeyRequired")
    def api_key_required(self) -> typing.Optional[bool]:
        return jsii.get(self, "apiKeyRequired")

    @api_key_required.setter
    def api_key_required(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "apiKeyRequired", value)

    @builtins.property
    @jsii.member(jsii_name="authorizationScopes")
    def authorization_scopes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "authorizationScopes")

    @authorization_scopes.setter
    def authorization_scopes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "authorizationScopes", value)

    @builtins.property
    @jsii.member(jsii_name="authorizationType")
    def authorization_type(self) -> typing.Optional[str]:
        return jsii.get(self, "authorizationType")

    @authorization_type.setter
    def authorization_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authorizationType", value)

    @builtins.property
    @jsii.member(jsii_name="authorizerId")
    def authorizer_id(self) -> typing.Optional[str]:
        return jsii.get(self, "authorizerId")

    @authorizer_id.setter
    def authorizer_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authorizerId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="modelSelectionExpression")
    def model_selection_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "modelSelectionExpression")

    @model_selection_expression.setter
    def model_selection_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "modelSelectionExpression", value)

    @builtins.property
    @jsii.member(jsii_name="operationName")
    def operation_name(self) -> typing.Optional[str]:
        return jsii.get(self, "operationName")

    @operation_name.setter
    def operation_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "operationName", value)

    @builtins.property
    @jsii.member(jsii_name="requestModels")
    def request_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "requestModels")

    @request_models.setter
    def request_models(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "requestModels", value)

    @builtins.property
    @jsii.member(jsii_name="routeResponseSelectionExpression")
    def route_response_selection_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "routeResponseSelectionExpression")

    @route_response_selection_expression.setter
    def route_response_selection_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "routeResponseSelectionExpression", value)

    @builtins.property
    @jsii.member(jsii_name="target")
    def target(self) -> typing.Optional[str]:
        return jsii.get(self, "target")

    @target.setter
    def target(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "target", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2RouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "route_key": "routeKey",
        "api_key_required": "apiKeyRequired",
        "authorization_scopes": "authorizationScopes",
        "authorization_type": "authorizationType",
        "authorizer_id": "authorizerId",
        "model_selection_expression": "modelSelectionExpression",
        "operation_name": "operationName",
        "request_models": "requestModels",
        "route_response_selection_expression": "routeResponseSelectionExpression",
        "target": "target",
    },
)
class Apigatewayv2RouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        route_key: str,
        api_key_required: typing.Optional[bool] = None,
        authorization_scopes: typing.Optional[typing.List[str]] = None,
        authorization_type: typing.Optional[str] = None,
        authorizer_id: typing.Optional[str] = None,
        model_selection_expression: typing.Optional[str] = None,
        operation_name: typing.Optional[str] = None,
        request_models: typing.Optional[typing.Mapping[str, str]] = None,
        route_response_selection_expression: typing.Optional[str] = None,
        target: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param route_key: 
        :param api_key_required: 
        :param authorization_scopes: 
        :param authorization_type: 
        :param authorizer_id: 
        :param model_selection_expression: 
        :param operation_name: 
        :param request_models: 
        :param route_response_selection_expression: 
        :param target: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "route_key": route_key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if api_key_required is not None:
            self._values["api_key_required"] = api_key_required
        if authorization_scopes is not None:
            self._values["authorization_scopes"] = authorization_scopes
        if authorization_type is not None:
            self._values["authorization_type"] = authorization_type
        if authorizer_id is not None:
            self._values["authorizer_id"] = authorizer_id
        if model_selection_expression is not None:
            self._values["model_selection_expression"] = model_selection_expression
        if operation_name is not None:
            self._values["operation_name"] = operation_name
        if request_models is not None:
            self._values["request_models"] = request_models
        if route_response_selection_expression is not None:
            self._values[
                "route_response_selection_expression"
            ] = route_response_selection_expression
        if target is not None:
            self._values["target"] = target

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def route_key(self) -> str:
        return self._values.get("route_key")

    @builtins.property
    def api_key_required(self) -> typing.Optional[bool]:
        return self._values.get("api_key_required")

    @builtins.property
    def authorization_scopes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("authorization_scopes")

    @builtins.property
    def authorization_type(self) -> typing.Optional[str]:
        return self._values.get("authorization_type")

    @builtins.property
    def authorizer_id(self) -> typing.Optional[str]:
        return self._values.get("authorizer_id")

    @builtins.property
    def model_selection_expression(self) -> typing.Optional[str]:
        return self._values.get("model_selection_expression")

    @builtins.property
    def operation_name(self) -> typing.Optional[str]:
        return self._values.get("operation_name")

    @builtins.property
    def request_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("request_models")

    @builtins.property
    def route_response_selection_expression(self) -> typing.Optional[str]:
        return self._values.get("route_response_selection_expression")

    @builtins.property
    def target(self) -> typing.Optional[str]:
        return self._values.get("target")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2RouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2RouteResponse(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2RouteResponse",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        route_id: str,
        route_response_key: str,
        model_selection_expression: typing.Optional[str] = None,
        response_models: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param route_id: 
        :param route_response_key: 
        :param model_selection_expression: 
        :param response_models: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2RouteResponseConfig(
            api_id=api_id,
            route_id=route_id,
            route_response_key=route_response_key,
            model_selection_expression=model_selection_expression,
            response_models=response_models,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2RouteResponse, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="routeId")
    def route_id(self) -> str:
        return jsii.get(self, "routeId")

    @route_id.setter
    def route_id(self, value: str) -> None:
        jsii.set(self, "routeId", value)

    @builtins.property
    @jsii.member(jsii_name="routeResponseKey")
    def route_response_key(self) -> str:
        return jsii.get(self, "routeResponseKey")

    @route_response_key.setter
    def route_response_key(self, value: str) -> None:
        jsii.set(self, "routeResponseKey", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="modelSelectionExpression")
    def model_selection_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "modelSelectionExpression")

    @model_selection_expression.setter
    def model_selection_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "modelSelectionExpression", value)

    @builtins.property
    @jsii.member(jsii_name="responseModels")
    def response_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "responseModels")

    @response_models.setter
    def response_models(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "responseModels", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2RouteResponseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "route_id": "routeId",
        "route_response_key": "routeResponseKey",
        "model_selection_expression": "modelSelectionExpression",
        "response_models": "responseModels",
    },
)
class Apigatewayv2RouteResponseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        route_id: str,
        route_response_key: str,
        model_selection_expression: typing.Optional[str] = None,
        response_models: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param route_id: 
        :param route_response_key: 
        :param model_selection_expression: 
        :param response_models: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "route_id": route_id,
            "route_response_key": route_response_key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if model_selection_expression is not None:
            self._values["model_selection_expression"] = model_selection_expression
        if response_models is not None:
            self._values["response_models"] = response_models

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def route_id(self) -> str:
        return self._values.get("route_id")

    @builtins.property
    def route_response_key(self) -> str:
        return self._values.get("route_response_key")

    @builtins.property
    def model_selection_expression(self) -> typing.Optional[str]:
        return self._values.get("model_selection_expression")

    @builtins.property
    def response_models(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("response_models")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2RouteResponseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2Stage(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2Stage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        name: str,
        access_log_settings: typing.Optional[
            typing.List["Apigatewayv2StageAccessLogSettings"]
        ] = None,
        auto_deploy: typing.Optional[bool] = None,
        client_certificate_id: typing.Optional[str] = None,
        default_route_settings: typing.Optional[
            typing.List["Apigatewayv2StageDefaultRouteSettings"]
        ] = None,
        deployment_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        route_settings: typing.Optional[
            typing.List["Apigatewayv2StageRouteSettings"]
        ] = None,
        stage_variables: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param name: 
        :param access_log_settings: access_log_settings block.
        :param auto_deploy: 
        :param client_certificate_id: 
        :param default_route_settings: default_route_settings block.
        :param deployment_id: 
        :param description: 
        :param route_settings: route_settings block.
        :param stage_variables: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2StageConfig(
            api_id=api_id,
            name=name,
            access_log_settings=access_log_settings,
            auto_deploy=auto_deploy,
            client_certificate_id=client_certificate_id,
            default_route_settings=default_route_settings,
            deployment_id=deployment_id,
            description=description,
            route_settings=route_settings,
            stage_variables=stage_variables,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2Stage, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="executionArn")
    def execution_arn(self) -> str:
        return jsii.get(self, "executionArn")

    @builtins.property
    @jsii.member(jsii_name="invokeUrl")
    def invoke_url(self) -> str:
        return jsii.get(self, "invokeUrl")

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="accessLogSettings")
    def access_log_settings(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2StageAccessLogSettings"]]:
        return jsii.get(self, "accessLogSettings")

    @access_log_settings.setter
    def access_log_settings(
        self, value: typing.Optional[typing.List["Apigatewayv2StageAccessLogSettings"]]
    ) -> None:
        jsii.set(self, "accessLogSettings", value)

    @builtins.property
    @jsii.member(jsii_name="autoDeploy")
    def auto_deploy(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoDeploy")

    @auto_deploy.setter
    def auto_deploy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoDeploy", value)

    @builtins.property
    @jsii.member(jsii_name="clientCertificateId")
    def client_certificate_id(self) -> typing.Optional[str]:
        return jsii.get(self, "clientCertificateId")

    @client_certificate_id.setter
    def client_certificate_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clientCertificateId", value)

    @builtins.property
    @jsii.member(jsii_name="defaultRouteSettings")
    def default_route_settings(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2StageDefaultRouteSettings"]]:
        return jsii.get(self, "defaultRouteSettings")

    @default_route_settings.setter
    def default_route_settings(
        self,
        value: typing.Optional[typing.List["Apigatewayv2StageDefaultRouteSettings"]],
    ) -> None:
        jsii.set(self, "defaultRouteSettings", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentId")
    def deployment_id(self) -> typing.Optional[str]:
        return jsii.get(self, "deploymentId")

    @deployment_id.setter
    def deployment_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deploymentId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="routeSettings")
    def route_settings(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2StageRouteSettings"]]:
        return jsii.get(self, "routeSettings")

    @route_settings.setter
    def route_settings(
        self, value: typing.Optional[typing.List["Apigatewayv2StageRouteSettings"]]
    ) -> None:
        jsii.set(self, "routeSettings", value)

    @builtins.property
    @jsii.member(jsii_name="stageVariables")
    def stage_variables(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "stageVariables")

    @stage_variables.setter
    def stage_variables(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "stageVariables", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2StageAccessLogSettings",
    jsii_struct_bases=[],
    name_mapping={"destination_arn": "destinationArn", "format": "format"},
)
class Apigatewayv2StageAccessLogSettings:
    def __init__(self, *, destination_arn: str, format: str) -> None:
        """
        :param destination_arn: 
        :param format: 
        """
        self._values = {
            "destination_arn": destination_arn,
            "format": format,
        }

    @builtins.property
    def destination_arn(self) -> str:
        return self._values.get("destination_arn")

    @builtins.property
    def format(self) -> str:
        return self._values.get("format")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2StageAccessLogSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2StageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "name": "name",
        "access_log_settings": "accessLogSettings",
        "auto_deploy": "autoDeploy",
        "client_certificate_id": "clientCertificateId",
        "default_route_settings": "defaultRouteSettings",
        "deployment_id": "deploymentId",
        "description": "description",
        "route_settings": "routeSettings",
        "stage_variables": "stageVariables",
        "tags": "tags",
    },
)
class Apigatewayv2StageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        name: str,
        access_log_settings: typing.Optional[
            typing.List["Apigatewayv2StageAccessLogSettings"]
        ] = None,
        auto_deploy: typing.Optional[bool] = None,
        client_certificate_id: typing.Optional[str] = None,
        default_route_settings: typing.Optional[
            typing.List["Apigatewayv2StageDefaultRouteSettings"]
        ] = None,
        deployment_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        route_settings: typing.Optional[
            typing.List["Apigatewayv2StageRouteSettings"]
        ] = None,
        stage_variables: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param name: 
        :param access_log_settings: access_log_settings block.
        :param auto_deploy: 
        :param client_certificate_id: 
        :param default_route_settings: default_route_settings block.
        :param deployment_id: 
        :param description: 
        :param route_settings: route_settings block.
        :param stage_variables: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_log_settings is not None:
            self._values["access_log_settings"] = access_log_settings
        if auto_deploy is not None:
            self._values["auto_deploy"] = auto_deploy
        if client_certificate_id is not None:
            self._values["client_certificate_id"] = client_certificate_id
        if default_route_settings is not None:
            self._values["default_route_settings"] = default_route_settings
        if deployment_id is not None:
            self._values["deployment_id"] = deployment_id
        if description is not None:
            self._values["description"] = description
        if route_settings is not None:
            self._values["route_settings"] = route_settings
        if stage_variables is not None:
            self._values["stage_variables"] = stage_variables
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def access_log_settings(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2StageAccessLogSettings"]]:
        """access_log_settings block."""
        return self._values.get("access_log_settings")

    @builtins.property
    def auto_deploy(self) -> typing.Optional[bool]:
        return self._values.get("auto_deploy")

    @builtins.property
    def client_certificate_id(self) -> typing.Optional[str]:
        return self._values.get("client_certificate_id")

    @builtins.property
    def default_route_settings(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2StageDefaultRouteSettings"]]:
        """default_route_settings block."""
        return self._values.get("default_route_settings")

    @builtins.property
    def deployment_id(self) -> typing.Optional[str]:
        return self._values.get("deployment_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def route_settings(
        self,
    ) -> typing.Optional[typing.List["Apigatewayv2StageRouteSettings"]]:
        """route_settings block."""
        return self._values.get("route_settings")

    @builtins.property
    def stage_variables(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("stage_variables")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2StageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2StageDefaultRouteSettings",
    jsii_struct_bases=[],
    name_mapping={
        "data_trace_enabled": "dataTraceEnabled",
        "detailed_metrics_enabled": "detailedMetricsEnabled",
        "logging_level": "loggingLevel",
        "throttling_burst_limit": "throttlingBurstLimit",
        "throttling_rate_limit": "throttlingRateLimit",
    },
)
class Apigatewayv2StageDefaultRouteSettings:
    def __init__(
        self,
        *,
        data_trace_enabled: typing.Optional[bool] = None,
        detailed_metrics_enabled: typing.Optional[bool] = None,
        logging_level: typing.Optional[str] = None,
        throttling_burst_limit: typing.Optional[jsii.Number] = None,
        throttling_rate_limit: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param data_trace_enabled: 
        :param detailed_metrics_enabled: 
        :param logging_level: 
        :param throttling_burst_limit: 
        :param throttling_rate_limit: 
        """
        self._values = {}
        if data_trace_enabled is not None:
            self._values["data_trace_enabled"] = data_trace_enabled
        if detailed_metrics_enabled is not None:
            self._values["detailed_metrics_enabled"] = detailed_metrics_enabled
        if logging_level is not None:
            self._values["logging_level"] = logging_level
        if throttling_burst_limit is not None:
            self._values["throttling_burst_limit"] = throttling_burst_limit
        if throttling_rate_limit is not None:
            self._values["throttling_rate_limit"] = throttling_rate_limit

    @builtins.property
    def data_trace_enabled(self) -> typing.Optional[bool]:
        return self._values.get("data_trace_enabled")

    @builtins.property
    def detailed_metrics_enabled(self) -> typing.Optional[bool]:
        return self._values.get("detailed_metrics_enabled")

    @builtins.property
    def logging_level(self) -> typing.Optional[str]:
        return self._values.get("logging_level")

    @builtins.property
    def throttling_burst_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("throttling_burst_limit")

    @builtins.property
    def throttling_rate_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("throttling_rate_limit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2StageDefaultRouteSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2StageRouteSettings",
    jsii_struct_bases=[],
    name_mapping={
        "route_key": "routeKey",
        "data_trace_enabled": "dataTraceEnabled",
        "detailed_metrics_enabled": "detailedMetricsEnabled",
        "logging_level": "loggingLevel",
        "throttling_burst_limit": "throttlingBurstLimit",
        "throttling_rate_limit": "throttlingRateLimit",
    },
)
class Apigatewayv2StageRouteSettings:
    def __init__(
        self,
        *,
        route_key: str,
        data_trace_enabled: typing.Optional[bool] = None,
        detailed_metrics_enabled: typing.Optional[bool] = None,
        logging_level: typing.Optional[str] = None,
        throttling_burst_limit: typing.Optional[jsii.Number] = None,
        throttling_rate_limit: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param route_key: 
        :param data_trace_enabled: 
        :param detailed_metrics_enabled: 
        :param logging_level: 
        :param throttling_burst_limit: 
        :param throttling_rate_limit: 
        """
        self._values = {
            "route_key": route_key,
        }
        if data_trace_enabled is not None:
            self._values["data_trace_enabled"] = data_trace_enabled
        if detailed_metrics_enabled is not None:
            self._values["detailed_metrics_enabled"] = detailed_metrics_enabled
        if logging_level is not None:
            self._values["logging_level"] = logging_level
        if throttling_burst_limit is not None:
            self._values["throttling_burst_limit"] = throttling_burst_limit
        if throttling_rate_limit is not None:
            self._values["throttling_rate_limit"] = throttling_rate_limit

    @builtins.property
    def route_key(self) -> str:
        return self._values.get("route_key")

    @builtins.property
    def data_trace_enabled(self) -> typing.Optional[bool]:
        return self._values.get("data_trace_enabled")

    @builtins.property
    def detailed_metrics_enabled(self) -> typing.Optional[bool]:
        return self._values.get("detailed_metrics_enabled")

    @builtins.property
    def logging_level(self) -> typing.Optional[str]:
        return self._values.get("logging_level")

    @builtins.property
    def throttling_burst_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("throttling_burst_limit")

    @builtins.property
    def throttling_rate_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("throttling_rate_limit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2StageRouteSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Apigatewayv2VpcLink(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2VpcLink",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        security_group_ids: typing.List[str],
        subnet_ids: typing.List[str],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param security_group_ids: 
        :param subnet_ids: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Apigatewayv2VpcLinkConfig(
            name=name,
            security_group_ids=security_group_ids,
            subnet_ids=subnet_ids,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Apigatewayv2VpcLink, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Apigatewayv2VpcLinkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
        "tags": "tags",
    },
)
class Apigatewayv2VpcLinkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        security_group_ids: typing.List[str],
        subnet_ids: typing.List[str],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param security_group_ids: 
        :param subnet_ids: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "security_group_ids": security_group_ids,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def security_group_ids(self) -> typing.List[str]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Apigatewayv2VpcLinkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppCookieStickinessPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppCookieStickinessPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cookie_name: str,
        lb_port: jsii.Number,
        load_balancer: str,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cookie_name: 
        :param lb_port: 
        :param load_balancer: 
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppCookieStickinessPolicyConfig(
            cookie_name=cookie_name,
            lb_port=lb_port,
            load_balancer=load_balancer,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppCookieStickinessPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cookieName")
    def cookie_name(self) -> str:
        return jsii.get(self, "cookieName")

    @cookie_name.setter
    def cookie_name(self, value: str) -> None:
        jsii.set(self, "cookieName", value)

    @builtins.property
    @jsii.member(jsii_name="lbPort")
    def lb_port(self) -> jsii.Number:
        return jsii.get(self, "lbPort")

    @lb_port.setter
    def lb_port(self, value: jsii.Number) -> None:
        jsii.set(self, "lbPort", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancer")
    def load_balancer(self) -> str:
        return jsii.get(self, "loadBalancer")

    @load_balancer.setter
    def load_balancer(self, value: str) -> None:
        jsii.set(self, "loadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppCookieStickinessPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cookie_name": "cookieName",
        "lb_port": "lbPort",
        "load_balancer": "loadBalancer",
        "name": "name",
    },
)
class AppCookieStickinessPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cookie_name: str,
        lb_port: jsii.Number,
        load_balancer: str,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cookie_name: 
        :param lb_port: 
        :param load_balancer: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cookie_name": cookie_name,
            "lb_port": lb_port,
            "load_balancer": load_balancer,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cookie_name(self) -> str:
        return self._values.get("cookie_name")

    @builtins.property
    def lb_port(self) -> jsii.Number:
        return self._values.get("lb_port")

    @builtins.property
    def load_balancer(self) -> str:
        return self._values.get("load_balancer")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppCookieStickinessPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppautoscalingPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        resource_id: str,
        scalable_dimension: str,
        service_namespace: str,
        adjustment_type: typing.Optional[str] = None,
        cooldown: typing.Optional[jsii.Number] = None,
        metric_aggregation_type: typing.Optional[str] = None,
        min_adjustment_magnitude: typing.Optional[jsii.Number] = None,
        policy_type: typing.Optional[str] = None,
        step_adjustment: typing.Optional[
            typing.List["AppautoscalingPolicyStepAdjustment"]
        ] = None,
        step_scaling_policy_configuration: typing.Optional[
            typing.List["AppautoscalingPolicyStepScalingPolicyConfiguration"]
        ] = None,
        target_tracking_scaling_policy_configuration: typing.Optional[
            typing.List["AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_id: 
        :param scalable_dimension: 
        :param service_namespace: 
        :param adjustment_type: 
        :param cooldown: 
        :param metric_aggregation_type: 
        :param min_adjustment_magnitude: 
        :param policy_type: 
        :param step_adjustment: step_adjustment block.
        :param step_scaling_policy_configuration: step_scaling_policy_configuration block.
        :param target_tracking_scaling_policy_configuration: target_tracking_scaling_policy_configuration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppautoscalingPolicyConfig(
            name=name,
            resource_id=resource_id,
            scalable_dimension=scalable_dimension,
            service_namespace=service_namespace,
            adjustment_type=adjustment_type,
            cooldown=cooldown,
            metric_aggregation_type=metric_aggregation_type,
            min_adjustment_magnitude=min_adjustment_magnitude,
            policy_type=policy_type,
            step_adjustment=step_adjustment,
            step_scaling_policy_configuration=step_scaling_policy_configuration,
            target_tracking_scaling_policy_configuration=target_tracking_scaling_policy_configuration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppautoscalingPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="scalableDimension")
    def scalable_dimension(self) -> str:
        return jsii.get(self, "scalableDimension")

    @scalable_dimension.setter
    def scalable_dimension(self, value: str) -> None:
        jsii.set(self, "scalableDimension", value)

    @builtins.property
    @jsii.member(jsii_name="serviceNamespace")
    def service_namespace(self) -> str:
        return jsii.get(self, "serviceNamespace")

    @service_namespace.setter
    def service_namespace(self, value: str) -> None:
        jsii.set(self, "serviceNamespace", value)

    @builtins.property
    @jsii.member(jsii_name="adjustmentType")
    def adjustment_type(self) -> typing.Optional[str]:
        return jsii.get(self, "adjustmentType")

    @adjustment_type.setter
    def adjustment_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "adjustmentType", value)

    @builtins.property
    @jsii.member(jsii_name="cooldown")
    def cooldown(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cooldown")

    @cooldown.setter
    def cooldown(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cooldown", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="metricAggregationType")
    def metric_aggregation_type(self) -> typing.Optional[str]:
        return jsii.get(self, "metricAggregationType")

    @metric_aggregation_type.setter
    def metric_aggregation_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "metricAggregationType", value)

    @builtins.property
    @jsii.member(jsii_name="minAdjustmentMagnitude")
    def min_adjustment_magnitude(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minAdjustmentMagnitude")

    @min_adjustment_magnitude.setter
    def min_adjustment_magnitude(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minAdjustmentMagnitude", value)

    @builtins.property
    @jsii.member(jsii_name="policyType")
    def policy_type(self) -> typing.Optional[str]:
        return jsii.get(self, "policyType")

    @policy_type.setter
    def policy_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policyType", value)

    @builtins.property
    @jsii.member(jsii_name="stepAdjustment")
    def step_adjustment(
        self,
    ) -> typing.Optional[typing.List["AppautoscalingPolicyStepAdjustment"]]:
        return jsii.get(self, "stepAdjustment")

    @step_adjustment.setter
    def step_adjustment(
        self, value: typing.Optional[typing.List["AppautoscalingPolicyStepAdjustment"]]
    ) -> None:
        jsii.set(self, "stepAdjustment", value)

    @builtins.property
    @jsii.member(jsii_name="stepScalingPolicyConfiguration")
    def step_scaling_policy_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AppautoscalingPolicyStepScalingPolicyConfiguration"]
    ]:
        return jsii.get(self, "stepScalingPolicyConfiguration")

    @step_scaling_policy_configuration.setter
    def step_scaling_policy_configuration(
        self,
        value: typing.Optional[
            typing.List["AppautoscalingPolicyStepScalingPolicyConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "stepScalingPolicyConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="targetTrackingScalingPolicyConfiguration")
    def target_tracking_scaling_policy_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration"]
    ]:
        return jsii.get(self, "targetTrackingScalingPolicyConfiguration")

    @target_tracking_scaling_policy_configuration.setter
    def target_tracking_scaling_policy_configuration(
        self,
        value: typing.Optional[
            typing.List["AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "targetTrackingScalingPolicyConfiguration", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_id": "resourceId",
        "scalable_dimension": "scalableDimension",
        "service_namespace": "serviceNamespace",
        "adjustment_type": "adjustmentType",
        "cooldown": "cooldown",
        "metric_aggregation_type": "metricAggregationType",
        "min_adjustment_magnitude": "minAdjustmentMagnitude",
        "policy_type": "policyType",
        "step_adjustment": "stepAdjustment",
        "step_scaling_policy_configuration": "stepScalingPolicyConfiguration",
        "target_tracking_scaling_policy_configuration": "targetTrackingScalingPolicyConfiguration",
    },
)
class AppautoscalingPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        resource_id: str,
        scalable_dimension: str,
        service_namespace: str,
        adjustment_type: typing.Optional[str] = None,
        cooldown: typing.Optional[jsii.Number] = None,
        metric_aggregation_type: typing.Optional[str] = None,
        min_adjustment_magnitude: typing.Optional[jsii.Number] = None,
        policy_type: typing.Optional[str] = None,
        step_adjustment: typing.Optional[
            typing.List["AppautoscalingPolicyStepAdjustment"]
        ] = None,
        step_scaling_policy_configuration: typing.Optional[
            typing.List["AppautoscalingPolicyStepScalingPolicyConfiguration"]
        ] = None,
        target_tracking_scaling_policy_configuration: typing.Optional[
            typing.List["AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_id: 
        :param scalable_dimension: 
        :param service_namespace: 
        :param adjustment_type: 
        :param cooldown: 
        :param metric_aggregation_type: 
        :param min_adjustment_magnitude: 
        :param policy_type: 
        :param step_adjustment: step_adjustment block.
        :param step_scaling_policy_configuration: step_scaling_policy_configuration block.
        :param target_tracking_scaling_policy_configuration: target_tracking_scaling_policy_configuration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "resource_id": resource_id,
            "scalable_dimension": scalable_dimension,
            "service_namespace": service_namespace,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if adjustment_type is not None:
            self._values["adjustment_type"] = adjustment_type
        if cooldown is not None:
            self._values["cooldown"] = cooldown
        if metric_aggregation_type is not None:
            self._values["metric_aggregation_type"] = metric_aggregation_type
        if min_adjustment_magnitude is not None:
            self._values["min_adjustment_magnitude"] = min_adjustment_magnitude
        if policy_type is not None:
            self._values["policy_type"] = policy_type
        if step_adjustment is not None:
            self._values["step_adjustment"] = step_adjustment
        if step_scaling_policy_configuration is not None:
            self._values[
                "step_scaling_policy_configuration"
            ] = step_scaling_policy_configuration
        if target_tracking_scaling_policy_configuration is not None:
            self._values[
                "target_tracking_scaling_policy_configuration"
            ] = target_tracking_scaling_policy_configuration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def scalable_dimension(self) -> str:
        return self._values.get("scalable_dimension")

    @builtins.property
    def service_namespace(self) -> str:
        return self._values.get("service_namespace")

    @builtins.property
    def adjustment_type(self) -> typing.Optional[str]:
        return self._values.get("adjustment_type")

    @builtins.property
    def cooldown(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cooldown")

    @builtins.property
    def metric_aggregation_type(self) -> typing.Optional[str]:
        return self._values.get("metric_aggregation_type")

    @builtins.property
    def min_adjustment_magnitude(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_adjustment_magnitude")

    @builtins.property
    def policy_type(self) -> typing.Optional[str]:
        return self._values.get("policy_type")

    @builtins.property
    def step_adjustment(
        self,
    ) -> typing.Optional[typing.List["AppautoscalingPolicyStepAdjustment"]]:
        """step_adjustment block."""
        return self._values.get("step_adjustment")

    @builtins.property
    def step_scaling_policy_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AppautoscalingPolicyStepScalingPolicyConfiguration"]
    ]:
        """step_scaling_policy_configuration block."""
        return self._values.get("step_scaling_policy_configuration")

    @builtins.property
    def target_tracking_scaling_policy_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration"]
    ]:
        """target_tracking_scaling_policy_configuration block."""
        return self._values.get("target_tracking_scaling_policy_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppautoscalingPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyStepAdjustment",
    jsii_struct_bases=[],
    name_mapping={
        "scaling_adjustment": "scalingAdjustment",
        "metric_interval_lower_bound": "metricIntervalLowerBound",
        "metric_interval_upper_bound": "metricIntervalUpperBound",
    },
)
class AppautoscalingPolicyStepAdjustment:
    def __init__(
        self,
        *,
        scaling_adjustment: jsii.Number,
        metric_interval_lower_bound: typing.Optional[str] = None,
        metric_interval_upper_bound: typing.Optional[str] = None,
    ) -> None:
        """
        :param scaling_adjustment: 
        :param metric_interval_lower_bound: 
        :param metric_interval_upper_bound: 
        """
        self._values = {
            "scaling_adjustment": scaling_adjustment,
        }
        if metric_interval_lower_bound is not None:
            self._values["metric_interval_lower_bound"] = metric_interval_lower_bound
        if metric_interval_upper_bound is not None:
            self._values["metric_interval_upper_bound"] = metric_interval_upper_bound

    @builtins.property
    def scaling_adjustment(self) -> jsii.Number:
        return self._values.get("scaling_adjustment")

    @builtins.property
    def metric_interval_lower_bound(self) -> typing.Optional[str]:
        return self._values.get("metric_interval_lower_bound")

    @builtins.property
    def metric_interval_upper_bound(self) -> typing.Optional[str]:
        return self._values.get("metric_interval_upper_bound")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppautoscalingPolicyStepAdjustment(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyStepScalingPolicyConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "adjustment_type": "adjustmentType",
        "cooldown": "cooldown",
        "metric_aggregation_type": "metricAggregationType",
        "min_adjustment_magnitude": "minAdjustmentMagnitude",
        "step_adjustment": "stepAdjustment",
    },
)
class AppautoscalingPolicyStepScalingPolicyConfiguration:
    def __init__(
        self,
        *,
        adjustment_type: typing.Optional[str] = None,
        cooldown: typing.Optional[jsii.Number] = None,
        metric_aggregation_type: typing.Optional[str] = None,
        min_adjustment_magnitude: typing.Optional[jsii.Number] = None,
        step_adjustment: typing.Optional[
            typing.List[
                "AppautoscalingPolicyStepScalingPolicyConfigurationStepAdjustment"
            ]
        ] = None,
    ) -> None:
        """
        :param adjustment_type: 
        :param cooldown: 
        :param metric_aggregation_type: 
        :param min_adjustment_magnitude: 
        :param step_adjustment: step_adjustment block.
        """
        self._values = {}
        if adjustment_type is not None:
            self._values["adjustment_type"] = adjustment_type
        if cooldown is not None:
            self._values["cooldown"] = cooldown
        if metric_aggregation_type is not None:
            self._values["metric_aggregation_type"] = metric_aggregation_type
        if min_adjustment_magnitude is not None:
            self._values["min_adjustment_magnitude"] = min_adjustment_magnitude
        if step_adjustment is not None:
            self._values["step_adjustment"] = step_adjustment

    @builtins.property
    def adjustment_type(self) -> typing.Optional[str]:
        return self._values.get("adjustment_type")

    @builtins.property
    def cooldown(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cooldown")

    @builtins.property
    def metric_aggregation_type(self) -> typing.Optional[str]:
        return self._values.get("metric_aggregation_type")

    @builtins.property
    def min_adjustment_magnitude(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_adjustment_magnitude")

    @builtins.property
    def step_adjustment(
        self,
    ) -> typing.Optional[
        typing.List["AppautoscalingPolicyStepScalingPolicyConfigurationStepAdjustment"]
    ]:
        """step_adjustment block."""
        return self._values.get("step_adjustment")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppautoscalingPolicyStepScalingPolicyConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyStepScalingPolicyConfigurationStepAdjustment",
    jsii_struct_bases=[],
    name_mapping={
        "scaling_adjustment": "scalingAdjustment",
        "metric_interval_lower_bound": "metricIntervalLowerBound",
        "metric_interval_upper_bound": "metricIntervalUpperBound",
    },
)
class AppautoscalingPolicyStepScalingPolicyConfigurationStepAdjustment:
    def __init__(
        self,
        *,
        scaling_adjustment: jsii.Number,
        metric_interval_lower_bound: typing.Optional[str] = None,
        metric_interval_upper_bound: typing.Optional[str] = None,
    ) -> None:
        """
        :param scaling_adjustment: 
        :param metric_interval_lower_bound: 
        :param metric_interval_upper_bound: 
        """
        self._values = {
            "scaling_adjustment": scaling_adjustment,
        }
        if metric_interval_lower_bound is not None:
            self._values["metric_interval_lower_bound"] = metric_interval_lower_bound
        if metric_interval_upper_bound is not None:
            self._values["metric_interval_upper_bound"] = metric_interval_upper_bound

    @builtins.property
    def scaling_adjustment(self) -> jsii.Number:
        return self._values.get("scaling_adjustment")

    @builtins.property
    def metric_interval_lower_bound(self) -> typing.Optional[str]:
        return self._values.get("metric_interval_lower_bound")

    @builtins.property
    def metric_interval_upper_bound(self) -> typing.Optional[str]:
        return self._values.get("metric_interval_upper_bound")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AppautoscalingPolicyStepScalingPolicyConfigurationStepAdjustment(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "target_value": "targetValue",
        "customized_metric_specification": "customizedMetricSpecification",
        "disable_scale_in": "disableScaleIn",
        "predefined_metric_specification": "predefinedMetricSpecification",
        "scale_in_cooldown": "scaleInCooldown",
        "scale_out_cooldown": "scaleOutCooldown",
    },
)
class AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration:
    def __init__(
        self,
        *,
        target_value: jsii.Number,
        customized_metric_specification: typing.Optional[
            typing.List[
                "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecification"
            ]
        ] = None,
        disable_scale_in: typing.Optional[bool] = None,
        predefined_metric_specification: typing.Optional[
            typing.List[
                "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationPredefinedMetricSpecification"
            ]
        ] = None,
        scale_in_cooldown: typing.Optional[jsii.Number] = None,
        scale_out_cooldown: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param target_value: 
        :param customized_metric_specification: customized_metric_specification block.
        :param disable_scale_in: 
        :param predefined_metric_specification: predefined_metric_specification block.
        :param scale_in_cooldown: 
        :param scale_out_cooldown: 
        """
        self._values = {
            "target_value": target_value,
        }
        if customized_metric_specification is not None:
            self._values[
                "customized_metric_specification"
            ] = customized_metric_specification
        if disable_scale_in is not None:
            self._values["disable_scale_in"] = disable_scale_in
        if predefined_metric_specification is not None:
            self._values[
                "predefined_metric_specification"
            ] = predefined_metric_specification
        if scale_in_cooldown is not None:
            self._values["scale_in_cooldown"] = scale_in_cooldown
        if scale_out_cooldown is not None:
            self._values["scale_out_cooldown"] = scale_out_cooldown

    @builtins.property
    def target_value(self) -> jsii.Number:
        return self._values.get("target_value")

    @builtins.property
    def customized_metric_specification(
        self,
    ) -> typing.Optional[
        typing.List[
            "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecification"
        ]
    ]:
        """customized_metric_specification block."""
        return self._values.get("customized_metric_specification")

    @builtins.property
    def disable_scale_in(self) -> typing.Optional[bool]:
        return self._values.get("disable_scale_in")

    @builtins.property
    def predefined_metric_specification(
        self,
    ) -> typing.Optional[
        typing.List[
            "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationPredefinedMetricSpecification"
        ]
    ]:
        """predefined_metric_specification block."""
        return self._values.get("predefined_metric_specification")

    @builtins.property
    def scale_in_cooldown(self) -> typing.Optional[jsii.Number]:
        return self._values.get("scale_in_cooldown")

    @builtins.property
    def scale_out_cooldown(self) -> typing.Optional[jsii.Number]:
        return self._values.get("scale_out_cooldown")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "namespace": "namespace",
        "statistic": "statistic",
        "dimensions": "dimensions",
        "unit": "unit",
    },
)
class AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecification:
    def __init__(
        self,
        *,
        metric_name: str,
        namespace: str,
        statistic: str,
        dimensions: typing.Optional[
            typing.List[
                "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecificationDimensions"
            ]
        ] = None,
        unit: typing.Optional[str] = None,
    ) -> None:
        """
        :param metric_name: 
        :param namespace: 
        :param statistic: 
        :param dimensions: dimensions block.
        :param unit: 
        """
        self._values = {
            "metric_name": metric_name,
            "namespace": namespace,
            "statistic": statistic,
        }
        if dimensions is not None:
            self._values["dimensions"] = dimensions
        if unit is not None:
            self._values["unit"] = unit

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def namespace(self) -> str:
        return self._values.get("namespace")

    @builtins.property
    def statistic(self) -> str:
        return self._values.get("statistic")

    @builtins.property
    def dimensions(
        self,
    ) -> typing.Optional[
        typing.List[
            "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecificationDimensions"
        ]
    ]:
        """dimensions block."""
        return self._values.get("dimensions")

    @builtins.property
    def unit(self) -> typing.Optional[str]:
        return self._values.get("unit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecification(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecificationDimensions",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecificationDimensions:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecificationDimensions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationPredefinedMetricSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "predefined_metric_type": "predefinedMetricType",
        "resource_label": "resourceLabel",
    },
)
class AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationPredefinedMetricSpecification:
    def __init__(
        self,
        *,
        predefined_metric_type: str,
        resource_label: typing.Optional[str] = None,
    ) -> None:
        """
        :param predefined_metric_type: 
        :param resource_label: 
        """
        self._values = {
            "predefined_metric_type": predefined_metric_type,
        }
        if resource_label is not None:
            self._values["resource_label"] = resource_label

    @builtins.property
    def predefined_metric_type(self) -> str:
        return self._values.get("predefined_metric_type")

    @builtins.property
    def resource_label(self) -> typing.Optional[str]:
        return self._values.get("resource_label")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationPredefinedMetricSpecification(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class AppautoscalingScheduledAction(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingScheduledAction",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        resource_id: str,
        service_namespace: str,
        end_time: typing.Optional[str] = None,
        scalable_dimension: typing.Optional[str] = None,
        scalable_target_action: typing.Optional[
            typing.List["AppautoscalingScheduledActionScalableTargetAction"]
        ] = None,
        schedule: typing.Optional[str] = None,
        start_time: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_id: 
        :param service_namespace: 
        :param end_time: 
        :param scalable_dimension: 
        :param scalable_target_action: scalable_target_action block.
        :param schedule: 
        :param start_time: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppautoscalingScheduledActionConfig(
            name=name,
            resource_id=resource_id,
            service_namespace=service_namespace,
            end_time=end_time,
            scalable_dimension=scalable_dimension,
            scalable_target_action=scalable_target_action,
            schedule=schedule,
            start_time=start_time,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppautoscalingScheduledAction, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="serviceNamespace")
    def service_namespace(self) -> str:
        return jsii.get(self, "serviceNamespace")

    @service_namespace.setter
    def service_namespace(self, value: str) -> None:
        jsii.set(self, "serviceNamespace", value)

    @builtins.property
    @jsii.member(jsii_name="endTime")
    def end_time(self) -> typing.Optional[str]:
        return jsii.get(self, "endTime")

    @end_time.setter
    def end_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endTime", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="scalableDimension")
    def scalable_dimension(self) -> typing.Optional[str]:
        return jsii.get(self, "scalableDimension")

    @scalable_dimension.setter
    def scalable_dimension(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "scalableDimension", value)

    @builtins.property
    @jsii.member(jsii_name="scalableTargetAction")
    def scalable_target_action(
        self,
    ) -> typing.Optional[
        typing.List["AppautoscalingScheduledActionScalableTargetAction"]
    ]:
        return jsii.get(self, "scalableTargetAction")

    @scalable_target_action.setter
    def scalable_target_action(
        self,
        value: typing.Optional[
            typing.List["AppautoscalingScheduledActionScalableTargetAction"]
        ],
    ) -> None:
        jsii.set(self, "scalableTargetAction", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(self) -> typing.Optional[str]:
        return jsii.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "schedule", value)

    @builtins.property
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> typing.Optional[str]:
        return jsii.get(self, "startTime")

    @start_time.setter
    def start_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "startTime", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingScheduledActionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_id": "resourceId",
        "service_namespace": "serviceNamespace",
        "end_time": "endTime",
        "scalable_dimension": "scalableDimension",
        "scalable_target_action": "scalableTargetAction",
        "schedule": "schedule",
        "start_time": "startTime",
    },
)
class AppautoscalingScheduledActionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        resource_id: str,
        service_namespace: str,
        end_time: typing.Optional[str] = None,
        scalable_dimension: typing.Optional[str] = None,
        scalable_target_action: typing.Optional[
            typing.List["AppautoscalingScheduledActionScalableTargetAction"]
        ] = None,
        schedule: typing.Optional[str] = None,
        start_time: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_id: 
        :param service_namespace: 
        :param end_time: 
        :param scalable_dimension: 
        :param scalable_target_action: scalable_target_action block.
        :param schedule: 
        :param start_time: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "resource_id": resource_id,
            "service_namespace": service_namespace,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if end_time is not None:
            self._values["end_time"] = end_time
        if scalable_dimension is not None:
            self._values["scalable_dimension"] = scalable_dimension
        if scalable_target_action is not None:
            self._values["scalable_target_action"] = scalable_target_action
        if schedule is not None:
            self._values["schedule"] = schedule
        if start_time is not None:
            self._values["start_time"] = start_time

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def service_namespace(self) -> str:
        return self._values.get("service_namespace")

    @builtins.property
    def end_time(self) -> typing.Optional[str]:
        return self._values.get("end_time")

    @builtins.property
    def scalable_dimension(self) -> typing.Optional[str]:
        return self._values.get("scalable_dimension")

    @builtins.property
    def scalable_target_action(
        self,
    ) -> typing.Optional[
        typing.List["AppautoscalingScheduledActionScalableTargetAction"]
    ]:
        """scalable_target_action block."""
        return self._values.get("scalable_target_action")

    @builtins.property
    def schedule(self) -> typing.Optional[str]:
        return self._values.get("schedule")

    @builtins.property
    def start_time(self) -> typing.Optional[str]:
        return self._values.get("start_time")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppautoscalingScheduledActionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingScheduledActionScalableTargetAction",
    jsii_struct_bases=[],
    name_mapping={"max_capacity": "maxCapacity", "min_capacity": "minCapacity"},
)
class AppautoscalingScheduledActionScalableTargetAction:
    def __init__(
        self,
        *,
        max_capacity: typing.Optional[jsii.Number] = None,
        min_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param max_capacity: 
        :param min_capacity: 
        """
        self._values = {}
        if max_capacity is not None:
            self._values["max_capacity"] = max_capacity
        if min_capacity is not None:
            self._values["min_capacity"] = min_capacity

    @builtins.property
    def max_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_capacity")

    @builtins.property
    def min_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppautoscalingScheduledActionScalableTargetAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppautoscalingTarget(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingTarget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        max_capacity: jsii.Number,
        min_capacity: jsii.Number,
        resource_id: str,
        scalable_dimension: str,
        service_namespace: str,
        role_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param max_capacity: 
        :param min_capacity: 
        :param resource_id: 
        :param scalable_dimension: 
        :param service_namespace: 
        :param role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppautoscalingTargetConfig(
            max_capacity=max_capacity,
            min_capacity=min_capacity,
            resource_id=resource_id,
            scalable_dimension=scalable_dimension,
            service_namespace=service_namespace,
            role_arn=role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppautoscalingTarget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="maxCapacity")
    def max_capacity(self) -> jsii.Number:
        return jsii.get(self, "maxCapacity")

    @max_capacity.setter
    def max_capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "maxCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="minCapacity")
    def min_capacity(self) -> jsii.Number:
        return jsii.get(self, "minCapacity")

    @min_capacity.setter
    def min_capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "minCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="scalableDimension")
    def scalable_dimension(self) -> str:
        return jsii.get(self, "scalableDimension")

    @scalable_dimension.setter
    def scalable_dimension(self, value: str) -> None:
        jsii.set(self, "scalableDimension", value)

    @builtins.property
    @jsii.member(jsii_name="serviceNamespace")
    def service_namespace(self) -> str:
        return jsii.get(self, "serviceNamespace")

    @service_namespace.setter
    def service_namespace(self, value: str) -> None:
        jsii.set(self, "serviceNamespace", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppautoscalingTargetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "max_capacity": "maxCapacity",
        "min_capacity": "minCapacity",
        "resource_id": "resourceId",
        "scalable_dimension": "scalableDimension",
        "service_namespace": "serviceNamespace",
        "role_arn": "roleArn",
    },
)
class AppautoscalingTargetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        max_capacity: jsii.Number,
        min_capacity: jsii.Number,
        resource_id: str,
        scalable_dimension: str,
        service_namespace: str,
        role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param max_capacity: 
        :param min_capacity: 
        :param resource_id: 
        :param scalable_dimension: 
        :param service_namespace: 
        :param role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "max_capacity": max_capacity,
            "min_capacity": min_capacity,
            "resource_id": resource_id,
            "scalable_dimension": scalable_dimension,
            "service_namespace": service_namespace,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if role_arn is not None:
            self._values["role_arn"] = role_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def max_capacity(self) -> jsii.Number:
        return self._values.get("max_capacity")

    @builtins.property
    def min_capacity(self) -> jsii.Number:
        return self._values.get("min_capacity")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def scalable_dimension(self) -> str:
        return self._values.get("scalable_dimension")

    @builtins.property
    def service_namespace(self) -> str:
        return self._values.get("service_namespace")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppautoscalingTargetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppmeshMesh(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshMesh",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        spec: typing.Optional[typing.List["AppmeshMeshSpec"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param spec: spec block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppmeshMeshConfig(
            name=name,
            spec=spec,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppmeshMesh, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedDate")
    def last_updated_date(self) -> str:
        return jsii.get(self, "lastUpdatedDate")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="spec")
    def spec(self) -> typing.Optional[typing.List["AppmeshMeshSpec"]]:
        return jsii.get(self, "spec")

    @spec.setter
    def spec(self, value: typing.Optional[typing.List["AppmeshMeshSpec"]]) -> None:
        jsii.set(self, "spec", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshMeshConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "spec": "spec",
        "tags": "tags",
    },
)
class AppmeshMeshConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        spec: typing.Optional[typing.List["AppmeshMeshSpec"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param spec: spec block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if spec is not None:
            self._values["spec"] = spec
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def spec(self) -> typing.Optional[typing.List["AppmeshMeshSpec"]]:
        """spec block."""
        return self._values.get("spec")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshMeshConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshMeshSpec",
    jsii_struct_bases=[],
    name_mapping={"egress_filter": "egressFilter"},
)
class AppmeshMeshSpec:
    def __init__(
        self,
        *,
        egress_filter: typing.Optional[
            typing.List["AppmeshMeshSpecEgressFilter"]
        ] = None,
    ) -> None:
        """
        :param egress_filter: egress_filter block.
        """
        self._values = {}
        if egress_filter is not None:
            self._values["egress_filter"] = egress_filter

    @builtins.property
    def egress_filter(
        self,
    ) -> typing.Optional[typing.List["AppmeshMeshSpecEgressFilter"]]:
        """egress_filter block."""
        return self._values.get("egress_filter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshMeshSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshMeshSpecEgressFilter",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class AppmeshMeshSpecEgressFilter:
    def __init__(self, *, type: typing.Optional[str] = None) -> None:
        """
        :param type: 
        """
        self._values = {}
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshMeshSpecEgressFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppmeshRoute(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRoute",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshRouteSpec"],
        virtual_router_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param virtual_router_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppmeshRouteConfig(
            mesh_name=mesh_name,
            name=name,
            spec=spec,
            virtual_router_name=virtual_router_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppmeshRoute, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedDate")
    def last_updated_date(self) -> str:
        return jsii.get(self, "lastUpdatedDate")

    @builtins.property
    @jsii.member(jsii_name="meshName")
    def mesh_name(self) -> str:
        return jsii.get(self, "meshName")

    @mesh_name.setter
    def mesh_name(self, value: str) -> None:
        jsii.set(self, "meshName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="spec")
    def spec(self) -> typing.List["AppmeshRouteSpec"]:
        return jsii.get(self, "spec")

    @spec.setter
    def spec(self, value: typing.List["AppmeshRouteSpec"]) -> None:
        jsii.set(self, "spec", value)

    @builtins.property
    @jsii.member(jsii_name="virtualRouterName")
    def virtual_router_name(self) -> str:
        return jsii.get(self, "virtualRouterName")

    @virtual_router_name.setter
    def virtual_router_name(self, value: str) -> None:
        jsii.set(self, "virtualRouterName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "mesh_name": "meshName",
        "name": "name",
        "spec": "spec",
        "virtual_router_name": "virtualRouterName",
        "tags": "tags",
    },
)
class AppmeshRouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshRouteSpec"],
        virtual_router_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param virtual_router_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "mesh_name": mesh_name,
            "name": name,
            "spec": spec,
            "virtual_router_name": virtual_router_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def mesh_name(self) -> str:
        return self._values.get("mesh_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def spec(self) -> typing.List["AppmeshRouteSpec"]:
        """spec block."""
        return self._values.get("spec")

    @builtins.property
    def virtual_router_name(self) -> str:
        return self._values.get("virtual_router_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpec",
    jsii_struct_bases=[],
    name_mapping={
        "http_route": "httpRoute",
        "priority": "priority",
        "tcp_route": "tcpRoute",
    },
)
class AppmeshRouteSpec:
    def __init__(
        self,
        *,
        http_route: typing.Optional[typing.List["AppmeshRouteSpecHttpRoute"]] = None,
        priority: typing.Optional[jsii.Number] = None,
        tcp_route: typing.Optional[typing.List["AppmeshRouteSpecTcpRoute"]] = None,
    ) -> None:
        """
        :param http_route: http_route block.
        :param priority: 
        :param tcp_route: tcp_route block.
        """
        self._values = {}
        if http_route is not None:
            self._values["http_route"] = http_route
        if priority is not None:
            self._values["priority"] = priority
        if tcp_route is not None:
            self._values["tcp_route"] = tcp_route

    @builtins.property
    def http_route(self) -> typing.Optional[typing.List["AppmeshRouteSpecHttpRoute"]]:
        """http_route block."""
        return self._values.get("http_route")

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        return self._values.get("priority")

    @builtins.property
    def tcp_route(self) -> typing.Optional[typing.List["AppmeshRouteSpecTcpRoute"]]:
        """tcp_route block."""
        return self._values.get("tcp_route")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecHttpRoute",
    jsii_struct_bases=[],
    name_mapping={"action": "action", "match": "match"},
)
class AppmeshRouteSpecHttpRoute:
    def __init__(
        self,
        *,
        action: typing.List["AppmeshRouteSpecHttpRouteAction"],
        match: typing.List["AppmeshRouteSpecHttpRouteMatch"],
    ) -> None:
        """
        :param action: action block.
        :param match: match block.
        """
        self._values = {
            "action": action,
            "match": match,
        }

    @builtins.property
    def action(self) -> typing.List["AppmeshRouteSpecHttpRouteAction"]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def match(self) -> typing.List["AppmeshRouteSpecHttpRouteMatch"]:
        """match block."""
        return self._values.get("match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecHttpRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecHttpRouteAction",
    jsii_struct_bases=[],
    name_mapping={"weighted_target": "weightedTarget"},
)
class AppmeshRouteSpecHttpRouteAction:
    def __init__(
        self,
        *,
        weighted_target: typing.List["AppmeshRouteSpecHttpRouteActionWeightedTarget"],
    ) -> None:
        """
        :param weighted_target: weighted_target block.
        """
        self._values = {
            "weighted_target": weighted_target,
        }

    @builtins.property
    def weighted_target(
        self,
    ) -> typing.List["AppmeshRouteSpecHttpRouteActionWeightedTarget"]:
        """weighted_target block."""
        return self._values.get("weighted_target")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecHttpRouteAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecHttpRouteActionWeightedTarget",
    jsii_struct_bases=[],
    name_mapping={"virtual_node": "virtualNode", "weight": "weight"},
)
class AppmeshRouteSpecHttpRouteActionWeightedTarget:
    def __init__(self, *, virtual_node: str, weight: jsii.Number) -> None:
        """
        :param virtual_node: 
        :param weight: 
        """
        self._values = {
            "virtual_node": virtual_node,
            "weight": weight,
        }

    @builtins.property
    def virtual_node(self) -> str:
        return self._values.get("virtual_node")

    @builtins.property
    def weight(self) -> jsii.Number:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecHttpRouteActionWeightedTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecHttpRouteMatch",
    jsii_struct_bases=[],
    name_mapping={
        "prefix": "prefix",
        "header": "header",
        "method": "method",
        "scheme": "scheme",
    },
)
class AppmeshRouteSpecHttpRouteMatch:
    def __init__(
        self,
        *,
        prefix: str,
        header: typing.Optional[
            typing.List["AppmeshRouteSpecHttpRouteMatchHeader"]
        ] = None,
        method: typing.Optional[str] = None,
        scheme: typing.Optional[str] = None,
    ) -> None:
        """
        :param prefix: 
        :param header: header block.
        :param method: 
        :param scheme: 
        """
        self._values = {
            "prefix": prefix,
        }
        if header is not None:
            self._values["header"] = header
        if method is not None:
            self._values["method"] = method
        if scheme is not None:
            self._values["scheme"] = scheme

    @builtins.property
    def prefix(self) -> str:
        return self._values.get("prefix")

    @builtins.property
    def header(
        self,
    ) -> typing.Optional[typing.List["AppmeshRouteSpecHttpRouteMatchHeader"]]:
        """header block."""
        return self._values.get("header")

    @builtins.property
    def method(self) -> typing.Optional[str]:
        return self._values.get("method")

    @builtins.property
    def scheme(self) -> typing.Optional[str]:
        return self._values.get("scheme")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecHttpRouteMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecHttpRouteMatchHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "invert": "invert", "match": "match"},
)
class AppmeshRouteSpecHttpRouteMatchHeader:
    def __init__(
        self,
        *,
        name: str,
        invert: typing.Optional[bool] = None,
        match: typing.Optional[
            typing.List["AppmeshRouteSpecHttpRouteMatchHeaderMatch"]
        ] = None,
    ) -> None:
        """
        :param name: 
        :param invert: 
        :param match: match block.
        """
        self._values = {
            "name": name,
        }
        if invert is not None:
            self._values["invert"] = invert
        if match is not None:
            self._values["match"] = match

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def invert(self) -> typing.Optional[bool]:
        return self._values.get("invert")

    @builtins.property
    def match(
        self,
    ) -> typing.Optional[typing.List["AppmeshRouteSpecHttpRouteMatchHeaderMatch"]]:
        """match block."""
        return self._values.get("match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecHttpRouteMatchHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecHttpRouteMatchHeaderMatch",
    jsii_struct_bases=[],
    name_mapping={
        "exact": "exact",
        "prefix": "prefix",
        "range": "range",
        "regex": "regex",
        "suffix": "suffix",
    },
)
class AppmeshRouteSpecHttpRouteMatchHeaderMatch:
    def __init__(
        self,
        *,
        exact: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
        range: typing.Optional[
            typing.List["AppmeshRouteSpecHttpRouteMatchHeaderMatchRange"]
        ] = None,
        regex: typing.Optional[str] = None,
        suffix: typing.Optional[str] = None,
    ) -> None:
        """
        :param exact: 
        :param prefix: 
        :param range: range block.
        :param regex: 
        :param suffix: 
        """
        self._values = {}
        if exact is not None:
            self._values["exact"] = exact
        if prefix is not None:
            self._values["prefix"] = prefix
        if range is not None:
            self._values["range"] = range
        if regex is not None:
            self._values["regex"] = regex
        if suffix is not None:
            self._values["suffix"] = suffix

    @builtins.property
    def exact(self) -> typing.Optional[str]:
        return self._values.get("exact")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def range(
        self,
    ) -> typing.Optional[typing.List["AppmeshRouteSpecHttpRouteMatchHeaderMatchRange"]]:
        """range block."""
        return self._values.get("range")

    @builtins.property
    def regex(self) -> typing.Optional[str]:
        return self._values.get("regex")

    @builtins.property
    def suffix(self) -> typing.Optional[str]:
        return self._values.get("suffix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecHttpRouteMatchHeaderMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecHttpRouteMatchHeaderMatchRange",
    jsii_struct_bases=[],
    name_mapping={"end": "end", "start": "start"},
)
class AppmeshRouteSpecHttpRouteMatchHeaderMatchRange:
    def __init__(self, *, end: jsii.Number, start: jsii.Number) -> None:
        """
        :param end: 
        :param start: 
        """
        self._values = {
            "end": end,
            "start": start,
        }

    @builtins.property
    def end(self) -> jsii.Number:
        return self._values.get("end")

    @builtins.property
    def start(self) -> jsii.Number:
        return self._values.get("start")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecHttpRouteMatchHeaderMatchRange(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecTcpRoute",
    jsii_struct_bases=[],
    name_mapping={"action": "action"},
)
class AppmeshRouteSpecTcpRoute:
    def __init__(
        self, *, action: typing.List["AppmeshRouteSpecTcpRouteAction"]
    ) -> None:
        """
        :param action: action block.
        """
        self._values = {
            "action": action,
        }

    @builtins.property
    def action(self) -> typing.List["AppmeshRouteSpecTcpRouteAction"]:
        """action block."""
        return self._values.get("action")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecTcpRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecTcpRouteAction",
    jsii_struct_bases=[],
    name_mapping={"weighted_target": "weightedTarget"},
)
class AppmeshRouteSpecTcpRouteAction:
    def __init__(
        self,
        *,
        weighted_target: typing.List["AppmeshRouteSpecTcpRouteActionWeightedTarget"],
    ) -> None:
        """
        :param weighted_target: weighted_target block.
        """
        self._values = {
            "weighted_target": weighted_target,
        }

    @builtins.property
    def weighted_target(
        self,
    ) -> typing.List["AppmeshRouteSpecTcpRouteActionWeightedTarget"]:
        """weighted_target block."""
        return self._values.get("weighted_target")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecTcpRouteAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshRouteSpecTcpRouteActionWeightedTarget",
    jsii_struct_bases=[],
    name_mapping={"virtual_node": "virtualNode", "weight": "weight"},
)
class AppmeshRouteSpecTcpRouteActionWeightedTarget:
    def __init__(self, *, virtual_node: str, weight: jsii.Number) -> None:
        """
        :param virtual_node: 
        :param weight: 
        """
        self._values = {
            "virtual_node": virtual_node,
            "weight": weight,
        }

    @builtins.property
    def virtual_node(self) -> str:
        return self._values.get("virtual_node")

    @builtins.property
    def weight(self) -> jsii.Number:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshRouteSpecTcpRouteActionWeightedTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppmeshVirtualNode(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNode",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshVirtualNodeSpec"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppmeshVirtualNodeConfig(
            mesh_name=mesh_name,
            name=name,
            spec=spec,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppmeshVirtualNode, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedDate")
    def last_updated_date(self) -> str:
        return jsii.get(self, "lastUpdatedDate")

    @builtins.property
    @jsii.member(jsii_name="meshName")
    def mesh_name(self) -> str:
        return jsii.get(self, "meshName")

    @mesh_name.setter
    def mesh_name(self, value: str) -> None:
        jsii.set(self, "meshName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="spec")
    def spec(self) -> typing.List["AppmeshVirtualNodeSpec"]:
        return jsii.get(self, "spec")

    @spec.setter
    def spec(self, value: typing.List["AppmeshVirtualNodeSpec"]) -> None:
        jsii.set(self, "spec", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "mesh_name": "meshName",
        "name": "name",
        "spec": "spec",
        "tags": "tags",
    },
)
class AppmeshVirtualNodeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshVirtualNodeSpec"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "mesh_name": mesh_name,
            "name": name,
            "spec": spec,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def mesh_name(self) -> str:
        return self._values.get("mesh_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def spec(self) -> typing.List["AppmeshVirtualNodeSpec"]:
        """spec block."""
        return self._values.get("spec")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpec",
    jsii_struct_bases=[],
    name_mapping={
        "backend": "backend",
        "backends": "backends",
        "listener": "listener",
        "logging": "logging",
        "service_discovery": "serviceDiscovery",
    },
)
class AppmeshVirtualNodeSpec:
    def __init__(
        self,
        *,
        backend: typing.Optional[typing.List["AppmeshVirtualNodeSpecBackend"]] = None,
        backends: typing.Optional[typing.List[str]] = None,
        listener: typing.Optional[typing.List["AppmeshVirtualNodeSpecListener"]] = None,
        logging: typing.Optional[typing.List["AppmeshVirtualNodeSpecLogging"]] = None,
        service_discovery: typing.Optional[
            typing.List["AppmeshVirtualNodeSpecServiceDiscovery"]
        ] = None,
    ) -> None:
        """
        :param backend: backend block.
        :param backends: 
        :param listener: listener block.
        :param logging: logging block.
        :param service_discovery: service_discovery block.
        """
        self._values = {}
        if backend is not None:
            self._values["backend"] = backend
        if backends is not None:
            self._values["backends"] = backends
        if listener is not None:
            self._values["listener"] = listener
        if logging is not None:
            self._values["logging"] = logging
        if service_discovery is not None:
            self._values["service_discovery"] = service_discovery

    @builtins.property
    def backend(self) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecBackend"]]:
        """backend block."""
        return self._values.get("backend")

    @builtins.property
    def backends(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("backends")

    @builtins.property
    def listener(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecListener"]]:
        """listener block."""
        return self._values.get("listener")

    @builtins.property
    def logging(self) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecLogging"]]:
        """logging block."""
        return self._values.get("logging")

    @builtins.property
    def service_discovery(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecServiceDiscovery"]]:
        """service_discovery block."""
        return self._values.get("service_discovery")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecBackend",
    jsii_struct_bases=[],
    name_mapping={"virtual_service": "virtualService"},
)
class AppmeshVirtualNodeSpecBackend:
    def __init__(
        self,
        *,
        virtual_service: typing.Optional[
            typing.List["AppmeshVirtualNodeSpecBackendVirtualService"]
        ] = None,
    ) -> None:
        """
        :param virtual_service: virtual_service block.
        """
        self._values = {}
        if virtual_service is not None:
            self._values["virtual_service"] = virtual_service

    @builtins.property
    def virtual_service(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecBackendVirtualService"]]:
        """virtual_service block."""
        return self._values.get("virtual_service")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecBackend(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecBackendVirtualService",
    jsii_struct_bases=[],
    name_mapping={"virtual_service_name": "virtualServiceName"},
)
class AppmeshVirtualNodeSpecBackendVirtualService:
    def __init__(self, *, virtual_service_name: str) -> None:
        """
        :param virtual_service_name: 
        """
        self._values = {
            "virtual_service_name": virtual_service_name,
        }

    @builtins.property
    def virtual_service_name(self) -> str:
        return self._values.get("virtual_service_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecBackendVirtualService(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecListener",
    jsii_struct_bases=[],
    name_mapping={"port_mapping": "portMapping", "health_check": "healthCheck"},
)
class AppmeshVirtualNodeSpecListener:
    def __init__(
        self,
        *,
        port_mapping: typing.List["AppmeshVirtualNodeSpecListenerPortMapping"],
        health_check: typing.Optional[
            typing.List["AppmeshVirtualNodeSpecListenerHealthCheck"]
        ] = None,
    ) -> None:
        """
        :param port_mapping: port_mapping block.
        :param health_check: health_check block.
        """
        self._values = {
            "port_mapping": port_mapping,
        }
        if health_check is not None:
            self._values["health_check"] = health_check

    @builtins.property
    def port_mapping(self) -> typing.List["AppmeshVirtualNodeSpecListenerPortMapping"]:
        """port_mapping block."""
        return self._values.get("port_mapping")

    @builtins.property
    def health_check(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecListenerHealthCheck"]]:
        """health_check block."""
        return self._values.get("health_check")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecListenerHealthCheck",
    jsii_struct_bases=[],
    name_mapping={
        "healthy_threshold": "healthyThreshold",
        "interval_millis": "intervalMillis",
        "protocol": "protocol",
        "timeout_millis": "timeoutMillis",
        "unhealthy_threshold": "unhealthyThreshold",
        "path": "path",
        "port": "port",
    },
)
class AppmeshVirtualNodeSpecListenerHealthCheck:
    def __init__(
        self,
        *,
        healthy_threshold: jsii.Number,
        interval_millis: jsii.Number,
        protocol: str,
        timeout_millis: jsii.Number,
        unhealthy_threshold: jsii.Number,
        path: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param healthy_threshold: 
        :param interval_millis: 
        :param protocol: 
        :param timeout_millis: 
        :param unhealthy_threshold: 
        :param path: 
        :param port: 
        """
        self._values = {
            "healthy_threshold": healthy_threshold,
            "interval_millis": interval_millis,
            "protocol": protocol,
            "timeout_millis": timeout_millis,
            "unhealthy_threshold": unhealthy_threshold,
        }
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def healthy_threshold(self) -> jsii.Number:
        return self._values.get("healthy_threshold")

    @builtins.property
    def interval_millis(self) -> jsii.Number:
        return self._values.get("interval_millis")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def timeout_millis(self) -> jsii.Number:
        return self._values.get("timeout_millis")

    @builtins.property
    def unhealthy_threshold(self) -> jsii.Number:
        return self._values.get("unhealthy_threshold")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecListenerHealthCheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecListenerPortMapping",
    jsii_struct_bases=[],
    name_mapping={"port": "port", "protocol": "protocol"},
)
class AppmeshVirtualNodeSpecListenerPortMapping:
    def __init__(self, *, port: jsii.Number, protocol: str) -> None:
        """
        :param port: 
        :param protocol: 
        """
        self._values = {
            "port": port,
            "protocol": protocol,
        }

    @builtins.property
    def port(self) -> jsii.Number:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecListenerPortMapping(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecLogging",
    jsii_struct_bases=[],
    name_mapping={"access_log": "accessLog"},
)
class AppmeshVirtualNodeSpecLogging:
    def __init__(
        self,
        *,
        access_log: typing.Optional[
            typing.List["AppmeshVirtualNodeSpecLoggingAccessLog"]
        ] = None,
    ) -> None:
        """
        :param access_log: access_log block.
        """
        self._values = {}
        if access_log is not None:
            self._values["access_log"] = access_log

    @builtins.property
    def access_log(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecLoggingAccessLog"]]:
        """access_log block."""
        return self._values.get("access_log")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecLogging(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecLoggingAccessLog",
    jsii_struct_bases=[],
    name_mapping={"file": "file"},
)
class AppmeshVirtualNodeSpecLoggingAccessLog:
    def __init__(
        self,
        *,
        file: typing.Optional[
            typing.List["AppmeshVirtualNodeSpecLoggingAccessLogFile"]
        ] = None,
    ) -> None:
        """
        :param file: file block.
        """
        self._values = {}
        if file is not None:
            self._values["file"] = file

    @builtins.property
    def file(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecLoggingAccessLogFile"]]:
        """file block."""
        return self._values.get("file")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecLoggingAccessLog(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecLoggingAccessLogFile",
    jsii_struct_bases=[],
    name_mapping={"path": "path"},
)
class AppmeshVirtualNodeSpecLoggingAccessLogFile:
    def __init__(self, *, path: str) -> None:
        """
        :param path: 
        """
        self._values = {
            "path": path,
        }

    @builtins.property
    def path(self) -> str:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecLoggingAccessLogFile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecServiceDiscovery",
    jsii_struct_bases=[],
    name_mapping={"aws_cloud_map": "awsCloudMap", "dns": "dns"},
)
class AppmeshVirtualNodeSpecServiceDiscovery:
    def __init__(
        self,
        *,
        aws_cloud_map: typing.Optional[
            typing.List["AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap"]
        ] = None,
        dns: typing.Optional[
            typing.List["AppmeshVirtualNodeSpecServiceDiscoveryDns"]
        ] = None,
    ) -> None:
        """
        :param aws_cloud_map: aws_cloud_map block.
        :param dns: dns block.
        """
        self._values = {}
        if aws_cloud_map is not None:
            self._values["aws_cloud_map"] = aws_cloud_map
        if dns is not None:
            self._values["dns"] = dns

    @builtins.property
    def aws_cloud_map(
        self,
    ) -> typing.Optional[
        typing.List["AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap"]
    ]:
        """aws_cloud_map block."""
        return self._values.get("aws_cloud_map")

    @builtins.property
    def dns(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualNodeSpecServiceDiscoveryDns"]]:
        """dns block."""
        return self._values.get("dns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecServiceDiscovery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap",
    jsii_struct_bases=[],
    name_mapping={
        "namespace_name": "namespaceName",
        "service_name": "serviceName",
        "attributes": "attributes",
    },
)
class AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap:
    def __init__(
        self,
        *,
        namespace_name: str,
        service_name: str,
        attributes: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param namespace_name: 
        :param service_name: 
        :param attributes: 
        """
        self._values = {
            "namespace_name": namespace_name,
            "service_name": service_name,
        }
        if attributes is not None:
            self._values["attributes"] = attributes

    @builtins.property
    def namespace_name(self) -> str:
        return self._values.get("namespace_name")

    @builtins.property
    def service_name(self) -> str:
        return self._values.get("service_name")

    @builtins.property
    def attributes(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("attributes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualNodeSpecServiceDiscoveryDns",
    jsii_struct_bases=[],
    name_mapping={"hostname": "hostname", "service_name": "serviceName"},
)
class AppmeshVirtualNodeSpecServiceDiscoveryDns:
    def __init__(
        self, *, hostname: str, service_name: typing.Optional[str] = None
    ) -> None:
        """
        :param hostname: 
        :param service_name: 
        """
        self._values = {
            "hostname": hostname,
        }
        if service_name is not None:
            self._values["service_name"] = service_name

    @builtins.property
    def hostname(self) -> str:
        return self._values.get("hostname")

    @builtins.property
    def service_name(self) -> typing.Optional[str]:
        return self._values.get("service_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualNodeSpecServiceDiscoveryDns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppmeshVirtualRouter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualRouter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshVirtualRouterSpec"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppmeshVirtualRouterConfig(
            mesh_name=mesh_name,
            name=name,
            spec=spec,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppmeshVirtualRouter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedDate")
    def last_updated_date(self) -> str:
        return jsii.get(self, "lastUpdatedDate")

    @builtins.property
    @jsii.member(jsii_name="meshName")
    def mesh_name(self) -> str:
        return jsii.get(self, "meshName")

    @mesh_name.setter
    def mesh_name(self, value: str) -> None:
        jsii.set(self, "meshName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="spec")
    def spec(self) -> typing.List["AppmeshVirtualRouterSpec"]:
        return jsii.get(self, "spec")

    @spec.setter
    def spec(self, value: typing.List["AppmeshVirtualRouterSpec"]) -> None:
        jsii.set(self, "spec", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualRouterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "mesh_name": "meshName",
        "name": "name",
        "spec": "spec",
        "tags": "tags",
    },
)
class AppmeshVirtualRouterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshVirtualRouterSpec"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "mesh_name": mesh_name,
            "name": name,
            "spec": spec,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def mesh_name(self) -> str:
        return self._values.get("mesh_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def spec(self) -> typing.List["AppmeshVirtualRouterSpec"]:
        """spec block."""
        return self._values.get("spec")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualRouterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualRouterSpec",
    jsii_struct_bases=[],
    name_mapping={"listener": "listener", "service_names": "serviceNames"},
)
class AppmeshVirtualRouterSpec:
    def __init__(
        self,
        *,
        listener: typing.List["AppmeshVirtualRouterSpecListener"],
        service_names: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param listener: listener block.
        :param service_names: 
        """
        self._values = {
            "listener": listener,
        }
        if service_names is not None:
            self._values["service_names"] = service_names

    @builtins.property
    def listener(self) -> typing.List["AppmeshVirtualRouterSpecListener"]:
        """listener block."""
        return self._values.get("listener")

    @builtins.property
    def service_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("service_names")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualRouterSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualRouterSpecListener",
    jsii_struct_bases=[],
    name_mapping={"port_mapping": "portMapping"},
)
class AppmeshVirtualRouterSpecListener:
    def __init__(
        self,
        *,
        port_mapping: typing.List["AppmeshVirtualRouterSpecListenerPortMapping"],
    ) -> None:
        """
        :param port_mapping: port_mapping block.
        """
        self._values = {
            "port_mapping": port_mapping,
        }

    @builtins.property
    def port_mapping(
        self,
    ) -> typing.List["AppmeshVirtualRouterSpecListenerPortMapping"]:
        """port_mapping block."""
        return self._values.get("port_mapping")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualRouterSpecListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualRouterSpecListenerPortMapping",
    jsii_struct_bases=[],
    name_mapping={"port": "port", "protocol": "protocol"},
)
class AppmeshVirtualRouterSpecListenerPortMapping:
    def __init__(self, *, port: jsii.Number, protocol: str) -> None:
        """
        :param port: 
        :param protocol: 
        """
        self._values = {
            "port": port,
            "protocol": protocol,
        }

    @builtins.property
    def port(self) -> jsii.Number:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualRouterSpecListenerPortMapping(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppmeshVirtualService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshVirtualServiceSpec"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppmeshVirtualServiceConfig(
            mesh_name=mesh_name,
            name=name,
            spec=spec,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppmeshVirtualService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedDate")
    def last_updated_date(self) -> str:
        return jsii.get(self, "lastUpdatedDate")

    @builtins.property
    @jsii.member(jsii_name="meshName")
    def mesh_name(self) -> str:
        return jsii.get(self, "meshName")

    @mesh_name.setter
    def mesh_name(self, value: str) -> None:
        jsii.set(self, "meshName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="spec")
    def spec(self) -> typing.List["AppmeshVirtualServiceSpec"]:
        return jsii.get(self, "spec")

    @spec.setter
    def spec(self, value: typing.List["AppmeshVirtualServiceSpec"]) -> None:
        jsii.set(self, "spec", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "mesh_name": "meshName",
        "name": "name",
        "spec": "spec",
        "tags": "tags",
    },
)
class AppmeshVirtualServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        mesh_name: str,
        name: str,
        spec: typing.List["AppmeshVirtualServiceSpec"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param mesh_name: 
        :param name: 
        :param spec: spec block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "mesh_name": mesh_name,
            "name": name,
            "spec": spec,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def mesh_name(self) -> str:
        return self._values.get("mesh_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def spec(self) -> typing.List["AppmeshVirtualServiceSpec"]:
        """spec block."""
        return self._values.get("spec")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualServiceSpec",
    jsii_struct_bases=[],
    name_mapping={"provider": "provider"},
)
class AppmeshVirtualServiceSpec:
    def __init__(
        self,
        *,
        provider: typing.Optional[
            typing.List["AppmeshVirtualServiceSpecProvider"]
        ] = None,
    ) -> None:
        """
        :param provider: provider block.
        """
        self._values = {}
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def provider(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualServiceSpecProvider"]]:
        """provider block."""
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualServiceSpec(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualServiceSpecProvider",
    jsii_struct_bases=[],
    name_mapping={"virtual_node": "virtualNode", "virtual_router": "virtualRouter"},
)
class AppmeshVirtualServiceSpecProvider:
    def __init__(
        self,
        *,
        virtual_node: typing.Optional[
            typing.List["AppmeshVirtualServiceSpecProviderVirtualNode"]
        ] = None,
        virtual_router: typing.Optional[
            typing.List["AppmeshVirtualServiceSpecProviderVirtualRouter"]
        ] = None,
    ) -> None:
        """
        :param virtual_node: virtual_node block.
        :param virtual_router: virtual_router block.
        """
        self._values = {}
        if virtual_node is not None:
            self._values["virtual_node"] = virtual_node
        if virtual_router is not None:
            self._values["virtual_router"] = virtual_router

    @builtins.property
    def virtual_node(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualServiceSpecProviderVirtualNode"]]:
        """virtual_node block."""
        return self._values.get("virtual_node")

    @builtins.property
    def virtual_router(
        self,
    ) -> typing.Optional[typing.List["AppmeshVirtualServiceSpecProviderVirtualRouter"]]:
        """virtual_router block."""
        return self._values.get("virtual_router")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualServiceSpecProvider(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualServiceSpecProviderVirtualNode",
    jsii_struct_bases=[],
    name_mapping={"virtual_node_name": "virtualNodeName"},
)
class AppmeshVirtualServiceSpecProviderVirtualNode:
    def __init__(self, *, virtual_node_name: str) -> None:
        """
        :param virtual_node_name: 
        """
        self._values = {
            "virtual_node_name": virtual_node_name,
        }

    @builtins.property
    def virtual_node_name(self) -> str:
        return self._values.get("virtual_node_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualServiceSpecProviderVirtualNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppmeshVirtualServiceSpecProviderVirtualRouter",
    jsii_struct_bases=[],
    name_mapping={"virtual_router_name": "virtualRouterName"},
)
class AppmeshVirtualServiceSpecProviderVirtualRouter:
    def __init__(self, *, virtual_router_name: str) -> None:
        """
        :param virtual_router_name: 
        """
        self._values = {
            "virtual_router_name": virtual_router_name,
        }

    @builtins.property
    def virtual_router_name(self) -> str:
        return self._values.get("virtual_router_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppmeshVirtualServiceSpecProviderVirtualRouter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppsyncApiKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncApiKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        description: typing.Optional[str] = None,
        expires: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param description: 
        :param expires: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppsyncApiKeyConfig(
            api_id=api_id,
            description=description,
            expires=expires,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppsyncApiKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="key")
    def key(self) -> str:
        return jsii.get(self, "key")

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="expires")
    def expires(self) -> typing.Optional[str]:
        return jsii.get(self, "expires")

    @expires.setter
    def expires(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "expires", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncApiKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "description": "description",
        "expires": "expires",
    },
)
class AppsyncApiKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        description: typing.Optional[str] = None,
        expires: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param description: 
        :param expires: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if expires is not None:
            self._values["expires"] = expires

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def expires(self) -> typing.Optional[str]:
        return self._values.get("expires")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncApiKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppsyncDatasource(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncDatasource",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        name: str,
        type: str,
        description: typing.Optional[str] = None,
        dynamodb_config: typing.Optional[
            typing.List["AppsyncDatasourceDynamodbConfig"]
        ] = None,
        elasticsearch_config: typing.Optional[
            typing.List["AppsyncDatasourceElasticsearchConfig"]
        ] = None,
        http_config: typing.Optional[typing.List["AppsyncDatasourceHttpConfig"]] = None,
        lambda_config: typing.Optional[
            typing.List["AppsyncDatasourceLambdaConfig"]
        ] = None,
        service_role_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param name: 
        :param type: 
        :param description: 
        :param dynamodb_config: dynamodb_config block.
        :param elasticsearch_config: elasticsearch_config block.
        :param http_config: http_config block.
        :param lambda_config: lambda_config block.
        :param service_role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppsyncDatasourceConfig(
            api_id=api_id,
            name=name,
            type=type,
            description=description,
            dynamodb_config=dynamodb_config,
            elasticsearch_config=elasticsearch_config,
            http_config=http_config,
            lambda_config=lambda_config,
            service_role_arn=service_role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppsyncDatasource, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="dynamodbConfig")
    def dynamodb_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceDynamodbConfig"]]:
        return jsii.get(self, "dynamodbConfig")

    @dynamodb_config.setter
    def dynamodb_config(
        self, value: typing.Optional[typing.List["AppsyncDatasourceDynamodbConfig"]]
    ) -> None:
        jsii.set(self, "dynamodbConfig", value)

    @builtins.property
    @jsii.member(jsii_name="elasticsearchConfig")
    def elasticsearch_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceElasticsearchConfig"]]:
        return jsii.get(self, "elasticsearchConfig")

    @elasticsearch_config.setter
    def elasticsearch_config(
        self,
        value: typing.Optional[typing.List["AppsyncDatasourceElasticsearchConfig"]],
    ) -> None:
        jsii.set(self, "elasticsearchConfig", value)

    @builtins.property
    @jsii.member(jsii_name="httpConfig")
    def http_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceHttpConfig"]]:
        return jsii.get(self, "httpConfig")

    @http_config.setter
    def http_config(
        self, value: typing.Optional[typing.List["AppsyncDatasourceHttpConfig"]]
    ) -> None:
        jsii.set(self, "httpConfig", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaConfig")
    def lambda_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceLambdaConfig"]]:
        return jsii.get(self, "lambdaConfig")

    @lambda_config.setter
    def lambda_config(
        self, value: typing.Optional[typing.List["AppsyncDatasourceLambdaConfig"]]
    ) -> None:
        jsii.set(self, "lambdaConfig", value)

    @builtins.property
    @jsii.member(jsii_name="serviceRoleArn")
    def service_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "serviceRoleArn")

    @service_role_arn.setter
    def service_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "serviceRoleArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncDatasourceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "name": "name",
        "type": "type",
        "description": "description",
        "dynamodb_config": "dynamodbConfig",
        "elasticsearch_config": "elasticsearchConfig",
        "http_config": "httpConfig",
        "lambda_config": "lambdaConfig",
        "service_role_arn": "serviceRoleArn",
    },
)
class AppsyncDatasourceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        name: str,
        type: str,
        description: typing.Optional[str] = None,
        dynamodb_config: typing.Optional[
            typing.List["AppsyncDatasourceDynamodbConfig"]
        ] = None,
        elasticsearch_config: typing.Optional[
            typing.List["AppsyncDatasourceElasticsearchConfig"]
        ] = None,
        http_config: typing.Optional[typing.List["AppsyncDatasourceHttpConfig"]] = None,
        lambda_config: typing.Optional[
            typing.List["AppsyncDatasourceLambdaConfig"]
        ] = None,
        service_role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param name: 
        :param type: 
        :param description: 
        :param dynamodb_config: dynamodb_config block.
        :param elasticsearch_config: elasticsearch_config block.
        :param http_config: http_config block.
        :param lambda_config: lambda_config block.
        :param service_role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "name": name,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if dynamodb_config is not None:
            self._values["dynamodb_config"] = dynamodb_config
        if elasticsearch_config is not None:
            self._values["elasticsearch_config"] = elasticsearch_config
        if http_config is not None:
            self._values["http_config"] = http_config
        if lambda_config is not None:
            self._values["lambda_config"] = lambda_config
        if service_role_arn is not None:
            self._values["service_role_arn"] = service_role_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def dynamodb_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceDynamodbConfig"]]:
        """dynamodb_config block."""
        return self._values.get("dynamodb_config")

    @builtins.property
    def elasticsearch_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceElasticsearchConfig"]]:
        """elasticsearch_config block."""
        return self._values.get("elasticsearch_config")

    @builtins.property
    def http_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceHttpConfig"]]:
        """http_config block."""
        return self._values.get("http_config")

    @builtins.property
    def lambda_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncDatasourceLambdaConfig"]]:
        """lambda_config block."""
        return self._values.get("lambda_config")

    @builtins.property
    def service_role_arn(self) -> typing.Optional[str]:
        return self._values.get("service_role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncDatasourceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncDatasourceDynamodbConfig",
    jsii_struct_bases=[],
    name_mapping={
        "table_name": "tableName",
        "region": "region",
        "use_caller_credentials": "useCallerCredentials",
    },
)
class AppsyncDatasourceDynamodbConfig:
    def __init__(
        self,
        *,
        table_name: str,
        region: typing.Optional[str] = None,
        use_caller_credentials: typing.Optional[bool] = None,
    ) -> None:
        """
        :param table_name: 
        :param region: 
        :param use_caller_credentials: 
        """
        self._values = {
            "table_name": table_name,
        }
        if region is not None:
            self._values["region"] = region
        if use_caller_credentials is not None:
            self._values["use_caller_credentials"] = use_caller_credentials

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    @builtins.property
    def use_caller_credentials(self) -> typing.Optional[bool]:
        return self._values.get("use_caller_credentials")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncDatasourceDynamodbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncDatasourceElasticsearchConfig",
    jsii_struct_bases=[],
    name_mapping={"endpoint": "endpoint", "region": "region"},
)
class AppsyncDatasourceElasticsearchConfig:
    def __init__(self, *, endpoint: str, region: typing.Optional[str] = None) -> None:
        """
        :param endpoint: 
        :param region: 
        """
        self._values = {
            "endpoint": endpoint,
        }
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def endpoint(self) -> str:
        return self._values.get("endpoint")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncDatasourceElasticsearchConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncDatasourceHttpConfig",
    jsii_struct_bases=[],
    name_mapping={"endpoint": "endpoint"},
)
class AppsyncDatasourceHttpConfig:
    def __init__(self, *, endpoint: str) -> None:
        """
        :param endpoint: 
        """
        self._values = {
            "endpoint": endpoint,
        }

    @builtins.property
    def endpoint(self) -> str:
        return self._values.get("endpoint")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncDatasourceHttpConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncDatasourceLambdaConfig",
    jsii_struct_bases=[],
    name_mapping={"function_arn": "functionArn"},
)
class AppsyncDatasourceLambdaConfig:
    def __init__(self, *, function_arn: str) -> None:
        """
        :param function_arn: 
        """
        self._values = {
            "function_arn": function_arn,
        }

    @builtins.property
    def function_arn(self) -> str:
        return self._values.get("function_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncDatasourceLambdaConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppsyncFunction(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncFunction",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        data_source: str,
        name: str,
        request_mapping_template: str,
        response_mapping_template: str,
        description: typing.Optional[str] = None,
        function_version: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param data_source: 
        :param name: 
        :param request_mapping_template: 
        :param response_mapping_template: 
        :param description: 
        :param function_version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppsyncFunctionConfig(
            api_id=api_id,
            data_source=data_source,
            name=name,
            request_mapping_template=request_mapping_template,
            response_mapping_template=response_mapping_template,
            description=description,
            function_version=function_version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppsyncFunction, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="functionId")
    def function_id(self) -> str:
        return jsii.get(self, "functionId")

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> str:
        return jsii.get(self, "dataSource")

    @data_source.setter
    def data_source(self, value: str) -> None:
        jsii.set(self, "dataSource", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="requestMappingTemplate")
    def request_mapping_template(self) -> str:
        return jsii.get(self, "requestMappingTemplate")

    @request_mapping_template.setter
    def request_mapping_template(self, value: str) -> None:
        jsii.set(self, "requestMappingTemplate", value)

    @builtins.property
    @jsii.member(jsii_name="responseMappingTemplate")
    def response_mapping_template(self) -> str:
        return jsii.get(self, "responseMappingTemplate")

    @response_mapping_template.setter
    def response_mapping_template(self, value: str) -> None:
        jsii.set(self, "responseMappingTemplate", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="functionVersion")
    def function_version(self) -> typing.Optional[str]:
        return jsii.get(self, "functionVersion")

    @function_version.setter
    def function_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "functionVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncFunctionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "data_source": "dataSource",
        "name": "name",
        "request_mapping_template": "requestMappingTemplate",
        "response_mapping_template": "responseMappingTemplate",
        "description": "description",
        "function_version": "functionVersion",
    },
)
class AppsyncFunctionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        data_source: str,
        name: str,
        request_mapping_template: str,
        response_mapping_template: str,
        description: typing.Optional[str] = None,
        function_version: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param data_source: 
        :param name: 
        :param request_mapping_template: 
        :param response_mapping_template: 
        :param description: 
        :param function_version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "data_source": data_source,
            "name": name,
            "request_mapping_template": request_mapping_template,
            "response_mapping_template": response_mapping_template,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if function_version is not None:
            self._values["function_version"] = function_version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def data_source(self) -> str:
        return self._values.get("data_source")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def request_mapping_template(self) -> str:
        return self._values.get("request_mapping_template")

    @builtins.property
    def response_mapping_template(self) -> str:
        return self._values.get("response_mapping_template")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def function_version(self) -> typing.Optional[str]:
        return self._values.get("function_version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncFunctionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppsyncGraphqlApi(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApi",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        authentication_type: str,
        name: str,
        additional_authentication_provider: typing.Optional[
            typing.List["AppsyncGraphqlApiAdditionalAuthenticationProvider"]
        ] = None,
        log_config: typing.Optional[typing.List["AppsyncGraphqlApiLogConfig"]] = None,
        openid_connect_config: typing.Optional[
            typing.List["AppsyncGraphqlApiOpenidConnectConfig"]
        ] = None,
        schema: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        user_pool_config: typing.Optional[
            typing.List["AppsyncGraphqlApiUserPoolConfig"]
        ] = None,
        xray_enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param authentication_type: 
        :param name: 
        :param additional_authentication_provider: additional_authentication_provider block.
        :param log_config: log_config block.
        :param openid_connect_config: openid_connect_config block.
        :param schema: 
        :param tags: 
        :param user_pool_config: user_pool_config block.
        :param xray_enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppsyncGraphqlApiConfig(
            authentication_type=authentication_type,
            name=name,
            additional_authentication_provider=additional_authentication_provider,
            log_config=log_config,
            openid_connect_config=openid_connect_config,
            schema=schema,
            tags=tags,
            user_pool_config=user_pool_config,
            xray_enabled=xray_enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppsyncGraphqlApi, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="uris")
    def uris(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "uris", [key])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="authenticationType")
    def authentication_type(self) -> str:
        return jsii.get(self, "authenticationType")

    @authentication_type.setter
    def authentication_type(self, value: str) -> None:
        jsii.set(self, "authenticationType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="additionalAuthenticationProvider")
    def additional_authentication_provider(
        self,
    ) -> typing.Optional[
        typing.List["AppsyncGraphqlApiAdditionalAuthenticationProvider"]
    ]:
        return jsii.get(self, "additionalAuthenticationProvider")

    @additional_authentication_provider.setter
    def additional_authentication_provider(
        self,
        value: typing.Optional[
            typing.List["AppsyncGraphqlApiAdditionalAuthenticationProvider"]
        ],
    ) -> None:
        jsii.set(self, "additionalAuthenticationProvider", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="logConfig")
    def log_config(self) -> typing.Optional[typing.List["AppsyncGraphqlApiLogConfig"]]:
        return jsii.get(self, "logConfig")

    @log_config.setter
    def log_config(
        self, value: typing.Optional[typing.List["AppsyncGraphqlApiLogConfig"]]
    ) -> None:
        jsii.set(self, "logConfig", value)

    @builtins.property
    @jsii.member(jsii_name="openidConnectConfig")
    def openid_connect_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncGraphqlApiOpenidConnectConfig"]]:
        return jsii.get(self, "openidConnectConfig")

    @openid_connect_config.setter
    def openid_connect_config(
        self,
        value: typing.Optional[typing.List["AppsyncGraphqlApiOpenidConnectConfig"]],
    ) -> None:
        jsii.set(self, "openidConnectConfig", value)

    @builtins.property
    @jsii.member(jsii_name="schema")
    def schema(self) -> typing.Optional[str]:
        return jsii.get(self, "schema")

    @schema.setter
    def schema(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "schema", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="userPoolConfig")
    def user_pool_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncGraphqlApiUserPoolConfig"]]:
        return jsii.get(self, "userPoolConfig")

    @user_pool_config.setter
    def user_pool_config(
        self, value: typing.Optional[typing.List["AppsyncGraphqlApiUserPoolConfig"]]
    ) -> None:
        jsii.set(self, "userPoolConfig", value)

    @builtins.property
    @jsii.member(jsii_name="xrayEnabled")
    def xray_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "xrayEnabled")

    @xray_enabled.setter
    def xray_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "xrayEnabled", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApiAdditionalAuthenticationProvider",
    jsii_struct_bases=[],
    name_mapping={
        "authentication_type": "authenticationType",
        "openid_connect_config": "openidConnectConfig",
        "user_pool_config": "userPoolConfig",
    },
)
class AppsyncGraphqlApiAdditionalAuthenticationProvider:
    def __init__(
        self,
        *,
        authentication_type: str,
        openid_connect_config: typing.Optional[
            typing.List[
                "AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig"
            ]
        ] = None,
        user_pool_config: typing.Optional[
            typing.List[
                "AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig"
            ]
        ] = None,
    ) -> None:
        """
        :param authentication_type: 
        :param openid_connect_config: openid_connect_config block.
        :param user_pool_config: user_pool_config block.
        """
        self._values = {
            "authentication_type": authentication_type,
        }
        if openid_connect_config is not None:
            self._values["openid_connect_config"] = openid_connect_config
        if user_pool_config is not None:
            self._values["user_pool_config"] = user_pool_config

    @builtins.property
    def authentication_type(self) -> str:
        return self._values.get("authentication_type")

    @builtins.property
    def openid_connect_config(
        self,
    ) -> typing.Optional[
        typing.List[
            "AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig"
        ]
    ]:
        """openid_connect_config block."""
        return self._values.get("openid_connect_config")

    @builtins.property
    def user_pool_config(
        self,
    ) -> typing.Optional[
        typing.List["AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig"]
    ]:
        """user_pool_config block."""
        return self._values.get("user_pool_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncGraphqlApiAdditionalAuthenticationProvider(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig",
    jsii_struct_bases=[],
    name_mapping={
        "issuer": "issuer",
        "auth_ttl": "authTtl",
        "client_id": "clientId",
        "iat_ttl": "iatTtl",
    },
)
class AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig:
    def __init__(
        self,
        *,
        issuer: str,
        auth_ttl: typing.Optional[jsii.Number] = None,
        client_id: typing.Optional[str] = None,
        iat_ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param issuer: 
        :param auth_ttl: 
        :param client_id: 
        :param iat_ttl: 
        """
        self._values = {
            "issuer": issuer,
        }
        if auth_ttl is not None:
            self._values["auth_ttl"] = auth_ttl
        if client_id is not None:
            self._values["client_id"] = client_id
        if iat_ttl is not None:
            self._values["iat_ttl"] = iat_ttl

    @builtins.property
    def issuer(self) -> str:
        return self._values.get("issuer")

    @builtins.property
    def auth_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("auth_ttl")

    @builtins.property
    def client_id(self) -> typing.Optional[str]:
        return self._values.get("client_id")

    @builtins.property
    def iat_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iat_ttl")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig",
    jsii_struct_bases=[],
    name_mapping={
        "user_pool_id": "userPoolId",
        "app_id_client_regex": "appIdClientRegex",
        "aws_region": "awsRegion",
    },
)
class AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig:
    def __init__(
        self,
        *,
        user_pool_id: str,
        app_id_client_regex: typing.Optional[str] = None,
        aws_region: typing.Optional[str] = None,
    ) -> None:
        """
        :param user_pool_id: 
        :param app_id_client_regex: 
        :param aws_region: 
        """
        self._values = {
            "user_pool_id": user_pool_id,
        }
        if app_id_client_regex is not None:
            self._values["app_id_client_regex"] = app_id_client_regex
        if aws_region is not None:
            self._values["aws_region"] = aws_region

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def app_id_client_regex(self) -> typing.Optional[str]:
        return self._values.get("app_id_client_regex")

    @builtins.property
    def aws_region(self) -> typing.Optional[str]:
        return self._values.get("aws_region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "authentication_type": "authenticationType",
        "name": "name",
        "additional_authentication_provider": "additionalAuthenticationProvider",
        "log_config": "logConfig",
        "openid_connect_config": "openidConnectConfig",
        "schema": "schema",
        "tags": "tags",
        "user_pool_config": "userPoolConfig",
        "xray_enabled": "xrayEnabled",
    },
)
class AppsyncGraphqlApiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        authentication_type: str,
        name: str,
        additional_authentication_provider: typing.Optional[
            typing.List["AppsyncGraphqlApiAdditionalAuthenticationProvider"]
        ] = None,
        log_config: typing.Optional[typing.List["AppsyncGraphqlApiLogConfig"]] = None,
        openid_connect_config: typing.Optional[
            typing.List["AppsyncGraphqlApiOpenidConnectConfig"]
        ] = None,
        schema: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        user_pool_config: typing.Optional[
            typing.List["AppsyncGraphqlApiUserPoolConfig"]
        ] = None,
        xray_enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param authentication_type: 
        :param name: 
        :param additional_authentication_provider: additional_authentication_provider block.
        :param log_config: log_config block.
        :param openid_connect_config: openid_connect_config block.
        :param schema: 
        :param tags: 
        :param user_pool_config: user_pool_config block.
        :param xray_enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "authentication_type": authentication_type,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_authentication_provider is not None:
            self._values[
                "additional_authentication_provider"
            ] = additional_authentication_provider
        if log_config is not None:
            self._values["log_config"] = log_config
        if openid_connect_config is not None:
            self._values["openid_connect_config"] = openid_connect_config
        if schema is not None:
            self._values["schema"] = schema
        if tags is not None:
            self._values["tags"] = tags
        if user_pool_config is not None:
            self._values["user_pool_config"] = user_pool_config
        if xray_enabled is not None:
            self._values["xray_enabled"] = xray_enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def authentication_type(self) -> str:
        return self._values.get("authentication_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def additional_authentication_provider(
        self,
    ) -> typing.Optional[
        typing.List["AppsyncGraphqlApiAdditionalAuthenticationProvider"]
    ]:
        """additional_authentication_provider block."""
        return self._values.get("additional_authentication_provider")

    @builtins.property
    def log_config(self) -> typing.Optional[typing.List["AppsyncGraphqlApiLogConfig"]]:
        """log_config block."""
        return self._values.get("log_config")

    @builtins.property
    def openid_connect_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncGraphqlApiOpenidConnectConfig"]]:
        """openid_connect_config block."""
        return self._values.get("openid_connect_config")

    @builtins.property
    def schema(self) -> typing.Optional[str]:
        return self._values.get("schema")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def user_pool_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncGraphqlApiUserPoolConfig"]]:
        """user_pool_config block."""
        return self._values.get("user_pool_config")

    @builtins.property
    def xray_enabled(self) -> typing.Optional[bool]:
        return self._values.get("xray_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncGraphqlApiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApiLogConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_logs_role_arn": "cloudwatchLogsRoleArn",
        "field_log_level": "fieldLogLevel",
        "exclude_verbose_content": "excludeVerboseContent",
    },
)
class AppsyncGraphqlApiLogConfig:
    def __init__(
        self,
        *,
        cloudwatch_logs_role_arn: str,
        field_log_level: str,
        exclude_verbose_content: typing.Optional[bool] = None,
    ) -> None:
        """
        :param cloudwatch_logs_role_arn: 
        :param field_log_level: 
        :param exclude_verbose_content: 
        """
        self._values = {
            "cloudwatch_logs_role_arn": cloudwatch_logs_role_arn,
            "field_log_level": field_log_level,
        }
        if exclude_verbose_content is not None:
            self._values["exclude_verbose_content"] = exclude_verbose_content

    @builtins.property
    def cloudwatch_logs_role_arn(self) -> str:
        return self._values.get("cloudwatch_logs_role_arn")

    @builtins.property
    def field_log_level(self) -> str:
        return self._values.get("field_log_level")

    @builtins.property
    def exclude_verbose_content(self) -> typing.Optional[bool]:
        return self._values.get("exclude_verbose_content")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncGraphqlApiLogConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApiOpenidConnectConfig",
    jsii_struct_bases=[],
    name_mapping={
        "issuer": "issuer",
        "auth_ttl": "authTtl",
        "client_id": "clientId",
        "iat_ttl": "iatTtl",
    },
)
class AppsyncGraphqlApiOpenidConnectConfig:
    def __init__(
        self,
        *,
        issuer: str,
        auth_ttl: typing.Optional[jsii.Number] = None,
        client_id: typing.Optional[str] = None,
        iat_ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param issuer: 
        :param auth_ttl: 
        :param client_id: 
        :param iat_ttl: 
        """
        self._values = {
            "issuer": issuer,
        }
        if auth_ttl is not None:
            self._values["auth_ttl"] = auth_ttl
        if client_id is not None:
            self._values["client_id"] = client_id
        if iat_ttl is not None:
            self._values["iat_ttl"] = iat_ttl

    @builtins.property
    def issuer(self) -> str:
        return self._values.get("issuer")

    @builtins.property
    def auth_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("auth_ttl")

    @builtins.property
    def client_id(self) -> typing.Optional[str]:
        return self._values.get("client_id")

    @builtins.property
    def iat_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iat_ttl")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncGraphqlApiOpenidConnectConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncGraphqlApiUserPoolConfig",
    jsii_struct_bases=[],
    name_mapping={
        "default_action": "defaultAction",
        "user_pool_id": "userPoolId",
        "app_id_client_regex": "appIdClientRegex",
        "aws_region": "awsRegion",
    },
)
class AppsyncGraphqlApiUserPoolConfig:
    def __init__(
        self,
        *,
        default_action: str,
        user_pool_id: str,
        app_id_client_regex: typing.Optional[str] = None,
        aws_region: typing.Optional[str] = None,
    ) -> None:
        """
        :param default_action: 
        :param user_pool_id: 
        :param app_id_client_regex: 
        :param aws_region: 
        """
        self._values = {
            "default_action": default_action,
            "user_pool_id": user_pool_id,
        }
        if app_id_client_regex is not None:
            self._values["app_id_client_regex"] = app_id_client_regex
        if aws_region is not None:
            self._values["aws_region"] = aws_region

    @builtins.property
    def default_action(self) -> str:
        return self._values.get("default_action")

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def app_id_client_regex(self) -> typing.Optional[str]:
        return self._values.get("app_id_client_regex")

    @builtins.property
    def aws_region(self) -> typing.Optional[str]:
        return self._values.get("aws_region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncGraphqlApiUserPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AppsyncResolver(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncResolver",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_id: str,
        field: str,
        request_template: str,
        response_template: str,
        type: str,
        caching_config: typing.Optional[
            typing.List["AppsyncResolverCachingConfig"]
        ] = None,
        data_source: typing.Optional[str] = None,
        kind: typing.Optional[str] = None,
        pipeline_config: typing.Optional[
            typing.List["AppsyncResolverPipelineConfig"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_id: 
        :param field: 
        :param request_template: 
        :param response_template: 
        :param type: 
        :param caching_config: caching_config block.
        :param data_source: 
        :param kind: 
        :param pipeline_config: pipeline_config block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AppsyncResolverConfig(
            api_id=api_id,
            field=field,
            request_template=request_template,
            response_template=response_template,
            type=type,
            caching_config=caching_config,
            data_source=data_source,
            kind=kind,
            pipeline_config=pipeline_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AppsyncResolver, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="apiId")
    def api_id(self) -> str:
        return jsii.get(self, "apiId")

    @api_id.setter
    def api_id(self, value: str) -> None:
        jsii.set(self, "apiId", value)

    @builtins.property
    @jsii.member(jsii_name="field")
    def field(self) -> str:
        return jsii.get(self, "field")

    @field.setter
    def field(self, value: str) -> None:
        jsii.set(self, "field", value)

    @builtins.property
    @jsii.member(jsii_name="requestTemplate")
    def request_template(self) -> str:
        return jsii.get(self, "requestTemplate")

    @request_template.setter
    def request_template(self, value: str) -> None:
        jsii.set(self, "requestTemplate", value)

    @builtins.property
    @jsii.member(jsii_name="responseTemplate")
    def response_template(self) -> str:
        return jsii.get(self, "responseTemplate")

    @response_template.setter
    def response_template(self, value: str) -> None:
        jsii.set(self, "responseTemplate", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="cachingConfig")
    def caching_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncResolverCachingConfig"]]:
        return jsii.get(self, "cachingConfig")

    @caching_config.setter
    def caching_config(
        self, value: typing.Optional[typing.List["AppsyncResolverCachingConfig"]]
    ) -> None:
        jsii.set(self, "cachingConfig", value)

    @builtins.property
    @jsii.member(jsii_name="dataSource")
    def data_source(self) -> typing.Optional[str]:
        return jsii.get(self, "dataSource")

    @data_source.setter
    def data_source(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dataSource", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kind")
    def kind(self) -> typing.Optional[str]:
        return jsii.get(self, "kind")

    @kind.setter
    def kind(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kind", value)

    @builtins.property
    @jsii.member(jsii_name="pipelineConfig")
    def pipeline_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncResolverPipelineConfig"]]:
        return jsii.get(self, "pipelineConfig")

    @pipeline_config.setter
    def pipeline_config(
        self, value: typing.Optional[typing.List["AppsyncResolverPipelineConfig"]]
    ) -> None:
        jsii.set(self, "pipelineConfig", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncResolverCachingConfig",
    jsii_struct_bases=[],
    name_mapping={"caching_keys": "cachingKeys", "ttl": "ttl"},
)
class AppsyncResolverCachingConfig:
    def __init__(
        self,
        *,
        caching_keys: typing.Optional[typing.List[str]] = None,
        ttl: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param caching_keys: 
        :param ttl: 
        """
        self._values = {}
        if caching_keys is not None:
            self._values["caching_keys"] = caching_keys
        if ttl is not None:
            self._values["ttl"] = ttl

    @builtins.property
    def caching_keys(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("caching_keys")

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("ttl")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncResolverCachingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncResolverConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_id": "apiId",
        "field": "field",
        "request_template": "requestTemplate",
        "response_template": "responseTemplate",
        "type": "type",
        "caching_config": "cachingConfig",
        "data_source": "dataSource",
        "kind": "kind",
        "pipeline_config": "pipelineConfig",
    },
)
class AppsyncResolverConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_id: str,
        field: str,
        request_template: str,
        response_template: str,
        type: str,
        caching_config: typing.Optional[
            typing.List["AppsyncResolverCachingConfig"]
        ] = None,
        data_source: typing.Optional[str] = None,
        kind: typing.Optional[str] = None,
        pipeline_config: typing.Optional[
            typing.List["AppsyncResolverPipelineConfig"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_id: 
        :param field: 
        :param request_template: 
        :param response_template: 
        :param type: 
        :param caching_config: caching_config block.
        :param data_source: 
        :param kind: 
        :param pipeline_config: pipeline_config block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_id": api_id,
            "field": field,
            "request_template": request_template,
            "response_template": response_template,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if caching_config is not None:
            self._values["caching_config"] = caching_config
        if data_source is not None:
            self._values["data_source"] = data_source
        if kind is not None:
            self._values["kind"] = kind
        if pipeline_config is not None:
            self._values["pipeline_config"] = pipeline_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_id(self) -> str:
        return self._values.get("api_id")

    @builtins.property
    def field(self) -> str:
        return self._values.get("field")

    @builtins.property
    def request_template(self) -> str:
        return self._values.get("request_template")

    @builtins.property
    def response_template(self) -> str:
        return self._values.get("response_template")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def caching_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncResolverCachingConfig"]]:
        """caching_config block."""
        return self._values.get("caching_config")

    @builtins.property
    def data_source(self) -> typing.Optional[str]:
        return self._values.get("data_source")

    @builtins.property
    def kind(self) -> typing.Optional[str]:
        return self._values.get("kind")

    @builtins.property
    def pipeline_config(
        self,
    ) -> typing.Optional[typing.List["AppsyncResolverPipelineConfig"]]:
        """pipeline_config block."""
        return self._values.get("pipeline_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncResolverConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AppsyncResolverPipelineConfig",
    jsii_struct_bases=[],
    name_mapping={"functions": "functions"},
)
class AppsyncResolverPipelineConfig:
    def __init__(self, *, functions: typing.Optional[typing.List[str]] = None) -> None:
        """
        :param functions: 
        """
        self._values = {}
        if functions is not None:
            self._values["functions"] = functions

    @builtins.property
    def functions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("functions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AppsyncResolverPipelineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AthenaDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        name: str,
        encryption_configuration: typing.Optional[
            typing.List["AthenaDatabaseEncryptionConfiguration"]
        ] = None,
        force_destroy: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param name: 
        :param encryption_configuration: encryption_configuration block.
        :param force_destroy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AthenaDatabaseConfig(
            bucket=bucket,
            name=name,
            encryption_configuration=encryption_configuration,
            force_destroy=force_destroy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AthenaDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="encryptionConfiguration")
    def encryption_configuration(
        self,
    ) -> typing.Optional[typing.List["AthenaDatabaseEncryptionConfiguration"]]:
        return jsii.get(self, "encryptionConfiguration")

    @encryption_configuration.setter
    def encryption_configuration(
        self,
        value: typing.Optional[typing.List["AthenaDatabaseEncryptionConfiguration"]],
    ) -> None:
        jsii.set(self, "encryptionConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "name": "name",
        "encryption_configuration": "encryptionConfiguration",
        "force_destroy": "forceDestroy",
    },
)
class AthenaDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        name: str,
        encryption_configuration: typing.Optional[
            typing.List["AthenaDatabaseEncryptionConfiguration"]
        ] = None,
        force_destroy: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param name: 
        :param encryption_configuration: encryption_configuration block.
        :param force_destroy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if encryption_configuration is not None:
            self._values["encryption_configuration"] = encryption_configuration
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def encryption_configuration(
        self,
    ) -> typing.Optional[typing.List["AthenaDatabaseEncryptionConfiguration"]]:
        """encryption_configuration block."""
        return self._values.get("encryption_configuration")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AthenaDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaDatabaseEncryptionConfiguration",
    jsii_struct_bases=[],
    name_mapping={"encryption_option": "encryptionOption", "kms_key": "kmsKey"},
)
class AthenaDatabaseEncryptionConfiguration:
    def __init__(
        self, *, encryption_option: str, kms_key: typing.Optional[str] = None
    ) -> None:
        """
        :param encryption_option: 
        :param kms_key: 
        """
        self._values = {
            "encryption_option": encryption_option,
        }
        if kms_key is not None:
            self._values["kms_key"] = kms_key

    @builtins.property
    def encryption_option(self) -> str:
        return self._values.get("encryption_option")

    @builtins.property
    def kms_key(self) -> typing.Optional[str]:
        return self._values.get("kms_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AthenaDatabaseEncryptionConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AthenaNamedQuery(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaNamedQuery",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        database: str,
        name: str,
        query: str,
        description: typing.Optional[str] = None,
        workgroup: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param database: 
        :param name: 
        :param query: 
        :param description: 
        :param workgroup: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AthenaNamedQueryConfig(
            database=database,
            name=name,
            query=query,
            description=description,
            workgroup=workgroup,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AthenaNamedQuery, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="database")
    def database(self) -> str:
        return jsii.get(self, "database")

    @database.setter
    def database(self, value: str) -> None:
        jsii.set(self, "database", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> str:
        return jsii.get(self, "query")

    @query.setter
    def query(self, value: str) -> None:
        jsii.set(self, "query", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="workgroup")
    def workgroup(self) -> typing.Optional[str]:
        return jsii.get(self, "workgroup")

    @workgroup.setter
    def workgroup(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "workgroup", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaNamedQueryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database": "database",
        "name": "name",
        "query": "query",
        "description": "description",
        "workgroup": "workgroup",
    },
)
class AthenaNamedQueryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database: str,
        name: str,
        query: str,
        description: typing.Optional[str] = None,
        workgroup: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database: 
        :param name: 
        :param query: 
        :param description: 
        :param workgroup: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "database": database,
            "name": name,
            "query": query,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if workgroup is not None:
            self._values["workgroup"] = workgroup

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def database(self) -> str:
        return self._values.get("database")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def query(self) -> str:
        return self._values.get("query")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def workgroup(self) -> typing.Optional[str]:
        return self._values.get("workgroup")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AthenaNamedQueryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AthenaWorkgroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaWorkgroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        configuration: typing.Optional[
            typing.List["AthenaWorkgroupConfiguration"]
        ] = None,
        description: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param configuration: configuration block.
        :param description: 
        :param force_destroy: 
        :param state: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AthenaWorkgroupConfig(
            name=name,
            configuration=configuration,
            description=description,
            force_destroy=force_destroy,
            state=state,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AthenaWorkgroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="configuration")
    def configuration(
        self,
    ) -> typing.Optional[typing.List["AthenaWorkgroupConfiguration"]]:
        return jsii.get(self, "configuration")

    @configuration.setter
    def configuration(
        self, value: typing.Optional[typing.List["AthenaWorkgroupConfiguration"]]
    ) -> None:
        jsii.set(self, "configuration", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaWorkgroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "configuration": "configuration",
        "description": "description",
        "force_destroy": "forceDestroy",
        "state": "state",
        "tags": "tags",
    },
)
class AthenaWorkgroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        configuration: typing.Optional[
            typing.List["AthenaWorkgroupConfiguration"]
        ] = None,
        description: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param configuration: configuration block.
        :param description: 
        :param force_destroy: 
        :param state: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if configuration is not None:
            self._values["configuration"] = configuration
        if description is not None:
            self._values["description"] = description
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def configuration(
        self,
    ) -> typing.Optional[typing.List["AthenaWorkgroupConfiguration"]]:
        """configuration block."""
        return self._values.get("configuration")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AthenaWorkgroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaWorkgroupConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "bytes_scanned_cutoff_per_query": "bytesScannedCutoffPerQuery",
        "enforce_workgroup_configuration": "enforceWorkgroupConfiguration",
        "publish_cloudwatch_metrics_enabled": "publishCloudwatchMetricsEnabled",
        "result_configuration": "resultConfiguration",
    },
)
class AthenaWorkgroupConfiguration:
    def __init__(
        self,
        *,
        bytes_scanned_cutoff_per_query: typing.Optional[jsii.Number] = None,
        enforce_workgroup_configuration: typing.Optional[bool] = None,
        publish_cloudwatch_metrics_enabled: typing.Optional[bool] = None,
        result_configuration: typing.Optional[
            typing.List["AthenaWorkgroupConfigurationResultConfiguration"]
        ] = None,
    ) -> None:
        """
        :param bytes_scanned_cutoff_per_query: 
        :param enforce_workgroup_configuration: 
        :param publish_cloudwatch_metrics_enabled: 
        :param result_configuration: result_configuration block.
        """
        self._values = {}
        if bytes_scanned_cutoff_per_query is not None:
            self._values[
                "bytes_scanned_cutoff_per_query"
            ] = bytes_scanned_cutoff_per_query
        if enforce_workgroup_configuration is not None:
            self._values[
                "enforce_workgroup_configuration"
            ] = enforce_workgroup_configuration
        if publish_cloudwatch_metrics_enabled is not None:
            self._values[
                "publish_cloudwatch_metrics_enabled"
            ] = publish_cloudwatch_metrics_enabled
        if result_configuration is not None:
            self._values["result_configuration"] = result_configuration

    @builtins.property
    def bytes_scanned_cutoff_per_query(self) -> typing.Optional[jsii.Number]:
        return self._values.get("bytes_scanned_cutoff_per_query")

    @builtins.property
    def enforce_workgroup_configuration(self) -> typing.Optional[bool]:
        return self._values.get("enforce_workgroup_configuration")

    @builtins.property
    def publish_cloudwatch_metrics_enabled(self) -> typing.Optional[bool]:
        return self._values.get("publish_cloudwatch_metrics_enabled")

    @builtins.property
    def result_configuration(
        self,
    ) -> typing.Optional[
        typing.List["AthenaWorkgroupConfigurationResultConfiguration"]
    ]:
        """result_configuration block."""
        return self._values.get("result_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AthenaWorkgroupConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaWorkgroupConfigurationResultConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "encryption_configuration": "encryptionConfiguration",
        "output_location": "outputLocation",
    },
)
class AthenaWorkgroupConfigurationResultConfiguration:
    def __init__(
        self,
        *,
        encryption_configuration: typing.Optional[
            typing.List[
                "AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration"
            ]
        ] = None,
        output_location: typing.Optional[str] = None,
    ) -> None:
        """
        :param encryption_configuration: encryption_configuration block.
        :param output_location: 
        """
        self._values = {}
        if encryption_configuration is not None:
            self._values["encryption_configuration"] = encryption_configuration
        if output_location is not None:
            self._values["output_location"] = output_location

    @builtins.property
    def encryption_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration"
        ]
    ]:
        """encryption_configuration block."""
        return self._values.get("encryption_configuration")

    @builtins.property
    def output_location(self) -> typing.Optional[str]:
        return self._values.get("output_location")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AthenaWorkgroupConfigurationResultConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration",
    jsii_struct_bases=[],
    name_mapping={"encryption_option": "encryptionOption", "kms_key_arn": "kmsKeyArn"},
)
class AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration:
    def __init__(
        self,
        *,
        encryption_option: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param encryption_option: 
        :param kms_key_arn: 
        """
        self._values = {}
        if encryption_option is not None:
            self._values["encryption_option"] = encryption_option
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn

    @builtins.property
    def encryption_option(self) -> typing.Optional[str]:
        return self._values.get("encryption_option")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class AutoscalingAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        autoscaling_group_name: str,
        alb_target_group_arn: typing.Optional[str] = None,
        elb: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param autoscaling_group_name: 
        :param alb_target_group_arn: 
        :param elb: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutoscalingAttachmentConfig(
            autoscaling_group_name=autoscaling_group_name,
            alb_target_group_arn=alb_target_group_arn,
            elb=elb,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutoscalingAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="autoscalingGroupName")
    def autoscaling_group_name(self) -> str:
        return jsii.get(self, "autoscalingGroupName")

    @autoscaling_group_name.setter
    def autoscaling_group_name(self, value: str) -> None:
        jsii.set(self, "autoscalingGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="albTargetGroupArn")
    def alb_target_group_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "albTargetGroupArn")

    @alb_target_group_arn.setter
    def alb_target_group_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "albTargetGroupArn", value)

    @builtins.property
    @jsii.member(jsii_name="elb")
    def elb(self) -> typing.Optional[str]:
        return jsii.get(self, "elb")

    @elb.setter
    def elb(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elb", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "autoscaling_group_name": "autoscalingGroupName",
        "alb_target_group_arn": "albTargetGroupArn",
        "elb": "elb",
    },
)
class AutoscalingAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        autoscaling_group_name: str,
        alb_target_group_arn: typing.Optional[str] = None,
        elb: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param autoscaling_group_name: 
        :param alb_target_group_arn: 
        :param elb: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "autoscaling_group_name": autoscaling_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if alb_target_group_arn is not None:
            self._values["alb_target_group_arn"] = alb_target_group_arn
        if elb is not None:
            self._values["elb"] = elb

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def autoscaling_group_name(self) -> str:
        return self._values.get("autoscaling_group_name")

    @builtins.property
    def alb_target_group_arn(self) -> typing.Optional[str]:
        return self._values.get("alb_target_group_arn")

    @builtins.property
    def elb(self) -> typing.Optional[str]:
        return self._values.get("elb")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutoscalingGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        max_size: jsii.Number,
        min_size: jsii.Number,
        availability_zones: typing.Optional[typing.List[str]] = None,
        default_cooldown: typing.Optional[jsii.Number] = None,
        desired_capacity: typing.Optional[jsii.Number] = None,
        enabled_metrics: typing.Optional[typing.List[str]] = None,
        force_delete: typing.Optional[bool] = None,
        health_check_grace_period: typing.Optional[jsii.Number] = None,
        health_check_type: typing.Optional[str] = None,
        initial_lifecycle_hook: typing.Optional[
            typing.List["AutoscalingGroupInitialLifecycleHook"]
        ] = None,
        launch_configuration: typing.Optional[str] = None,
        launch_template: typing.Optional[
            typing.List["AutoscalingGroupLaunchTemplate"]
        ] = None,
        load_balancers: typing.Optional[typing.List[str]] = None,
        max_instance_lifetime: typing.Optional[jsii.Number] = None,
        metrics_granularity: typing.Optional[str] = None,
        min_elb_capacity: typing.Optional[jsii.Number] = None,
        mixed_instances_policy: typing.Optional[
            typing.List["AutoscalingGroupMixedInstancesPolicy"]
        ] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        placement_group: typing.Optional[str] = None,
        protect_from_scale_in: typing.Optional[bool] = None,
        service_linked_role_arn: typing.Optional[str] = None,
        suspended_processes: typing.Optional[typing.List[str]] = None,
        tag: typing.Optional[typing.List["AutoscalingGroupTag"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_group_arns: typing.Optional[typing.List[str]] = None,
        termination_policies: typing.Optional[typing.List[str]] = None,
        timeouts: typing.Optional["AutoscalingGroupTimeouts"] = None,
        vpc_zone_identifier: typing.Optional[typing.List[str]] = None,
        wait_for_capacity_timeout: typing.Optional[str] = None,
        wait_for_elb_capacity: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param max_size: 
        :param min_size: 
        :param availability_zones: 
        :param default_cooldown: 
        :param desired_capacity: 
        :param enabled_metrics: 
        :param force_delete: 
        :param health_check_grace_period: 
        :param health_check_type: 
        :param initial_lifecycle_hook: initial_lifecycle_hook block.
        :param launch_configuration: 
        :param launch_template: launch_template block.
        :param load_balancers: 
        :param max_instance_lifetime: 
        :param metrics_granularity: 
        :param min_elb_capacity: 
        :param mixed_instances_policy: mixed_instances_policy block.
        :param name: 
        :param name_prefix: 
        :param placement_group: 
        :param protect_from_scale_in: 
        :param service_linked_role_arn: 
        :param suspended_processes: 
        :param tag: tag block.
        :param tags: 
        :param target_group_arns: 
        :param termination_policies: 
        :param timeouts: timeouts block.
        :param vpc_zone_identifier: 
        :param wait_for_capacity_timeout: 
        :param wait_for_elb_capacity: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutoscalingGroupConfig(
            max_size=max_size,
            min_size=min_size,
            availability_zones=availability_zones,
            default_cooldown=default_cooldown,
            desired_capacity=desired_capacity,
            enabled_metrics=enabled_metrics,
            force_delete=force_delete,
            health_check_grace_period=health_check_grace_period,
            health_check_type=health_check_type,
            initial_lifecycle_hook=initial_lifecycle_hook,
            launch_configuration=launch_configuration,
            launch_template=launch_template,
            load_balancers=load_balancers,
            max_instance_lifetime=max_instance_lifetime,
            metrics_granularity=metrics_granularity,
            min_elb_capacity=min_elb_capacity,
            mixed_instances_policy=mixed_instances_policy,
            name=name,
            name_prefix=name_prefix,
            placement_group=placement_group,
            protect_from_scale_in=protect_from_scale_in,
            service_linked_role_arn=service_linked_role_arn,
            suspended_processes=suspended_processes,
            tag=tag,
            tags=tags,
            target_group_arns=target_group_arns,
            termination_policies=termination_policies,
            timeouts=timeouts,
            vpc_zone_identifier=vpc_zone_identifier,
            wait_for_capacity_timeout=wait_for_capacity_timeout,
            wait_for_elb_capacity=wait_for_elb_capacity,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutoscalingGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="maxSize")
    def max_size(self) -> jsii.Number:
        return jsii.get(self, "maxSize")

    @max_size.setter
    def max_size(self, value: jsii.Number) -> None:
        jsii.set(self, "maxSize", value)

    @builtins.property
    @jsii.member(jsii_name="minSize")
    def min_size(self) -> jsii.Number:
        return jsii.get(self, "minSize")

    @min_size.setter
    def min_size(self, value: jsii.Number) -> None:
        jsii.set(self, "minSize", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="defaultCooldown")
    def default_cooldown(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "defaultCooldown")

    @default_cooldown.setter
    def default_cooldown(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "defaultCooldown", value)

    @builtins.property
    @jsii.member(jsii_name="desiredCapacity")
    def desired_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "desiredCapacity")

    @desired_capacity.setter
    def desired_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "desiredCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="enabledMetrics")
    def enabled_metrics(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "enabledMetrics")

    @enabled_metrics.setter
    def enabled_metrics(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "enabledMetrics", value)

    @builtins.property
    @jsii.member(jsii_name="forceDelete")
    def force_delete(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDelete")

    @force_delete.setter
    def force_delete(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDelete", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckGracePeriod")
    def health_check_grace_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "healthCheckGracePeriod")

    @health_check_grace_period.setter
    def health_check_grace_period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "healthCheckGracePeriod", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckType")
    def health_check_type(self) -> typing.Optional[str]:
        return jsii.get(self, "healthCheckType")

    @health_check_type.setter
    def health_check_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "healthCheckType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="initialLifecycleHook")
    def initial_lifecycle_hook(
        self,
    ) -> typing.Optional[typing.List["AutoscalingGroupInitialLifecycleHook"]]:
        return jsii.get(self, "initialLifecycleHook")

    @initial_lifecycle_hook.setter
    def initial_lifecycle_hook(
        self,
        value: typing.Optional[typing.List["AutoscalingGroupInitialLifecycleHook"]],
    ) -> None:
        jsii.set(self, "initialLifecycleHook", value)

    @builtins.property
    @jsii.member(jsii_name="launchConfiguration")
    def launch_configuration(self) -> typing.Optional[str]:
        return jsii.get(self, "launchConfiguration")

    @launch_configuration.setter
    def launch_configuration(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "launchConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="launchTemplate")
    def launch_template(
        self,
    ) -> typing.Optional[typing.List["AutoscalingGroupLaunchTemplate"]]:
        return jsii.get(self, "launchTemplate")

    @launch_template.setter
    def launch_template(
        self, value: typing.Optional[typing.List["AutoscalingGroupLaunchTemplate"]]
    ) -> None:
        jsii.set(self, "launchTemplate", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancers")
    def load_balancers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "loadBalancers")

    @load_balancers.setter
    def load_balancers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "loadBalancers", value)

    @builtins.property
    @jsii.member(jsii_name="maxInstanceLifetime")
    def max_instance_lifetime(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxInstanceLifetime")

    @max_instance_lifetime.setter
    def max_instance_lifetime(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxInstanceLifetime", value)

    @builtins.property
    @jsii.member(jsii_name="metricsGranularity")
    def metrics_granularity(self) -> typing.Optional[str]:
        return jsii.get(self, "metricsGranularity")

    @metrics_granularity.setter
    def metrics_granularity(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "metricsGranularity", value)

    @builtins.property
    @jsii.member(jsii_name="minElbCapacity")
    def min_elb_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minElbCapacity")

    @min_elb_capacity.setter
    def min_elb_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minElbCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="mixedInstancesPolicy")
    def mixed_instances_policy(
        self,
    ) -> typing.Optional[typing.List["AutoscalingGroupMixedInstancesPolicy"]]:
        return jsii.get(self, "mixedInstancesPolicy")

    @mixed_instances_policy.setter
    def mixed_instances_policy(
        self,
        value: typing.Optional[typing.List["AutoscalingGroupMixedInstancesPolicy"]],
    ) -> None:
        jsii.set(self, "mixedInstancesPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="placementGroup")
    def placement_group(self) -> typing.Optional[str]:
        return jsii.get(self, "placementGroup")

    @placement_group.setter
    def placement_group(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "placementGroup", value)

    @builtins.property
    @jsii.member(jsii_name="protectFromScaleIn")
    def protect_from_scale_in(self) -> typing.Optional[bool]:
        return jsii.get(self, "protectFromScaleIn")

    @protect_from_scale_in.setter
    def protect_from_scale_in(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "protectFromScaleIn", value)

    @builtins.property
    @jsii.member(jsii_name="serviceLinkedRoleArn")
    def service_linked_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "serviceLinkedRoleArn")

    @service_linked_role_arn.setter
    def service_linked_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "serviceLinkedRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="suspendedProcesses")
    def suspended_processes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "suspendedProcesses")

    @suspended_processes.setter
    def suspended_processes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "suspendedProcesses", value)

    @builtins.property
    @jsii.member(jsii_name="tag")
    def tag(self) -> typing.Optional[typing.List["AutoscalingGroupTag"]]:
        return jsii.get(self, "tag")

    @tag.setter
    def tag(self, value: typing.Optional[typing.List["AutoscalingGroupTag"]]) -> None:
        jsii.set(self, "tag", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="targetGroupArns")
    def target_group_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "targetGroupArns")

    @target_group_arns.setter
    def target_group_arns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "targetGroupArns", value)

    @builtins.property
    @jsii.member(jsii_name="terminationPolicies")
    def termination_policies(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "terminationPolicies")

    @termination_policies.setter
    def termination_policies(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "terminationPolicies", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["AutoscalingGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["AutoscalingGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcZoneIdentifier")
    def vpc_zone_identifier(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcZoneIdentifier")

    @vpc_zone_identifier.setter
    def vpc_zone_identifier(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcZoneIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="waitForCapacityTimeout")
    def wait_for_capacity_timeout(self) -> typing.Optional[str]:
        return jsii.get(self, "waitForCapacityTimeout")

    @wait_for_capacity_timeout.setter
    def wait_for_capacity_timeout(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "waitForCapacityTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="waitForElbCapacity")
    def wait_for_elb_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "waitForElbCapacity")

    @wait_for_elb_capacity.setter
    def wait_for_elb_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "waitForElbCapacity", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "max_size": "maxSize",
        "min_size": "minSize",
        "availability_zones": "availabilityZones",
        "default_cooldown": "defaultCooldown",
        "desired_capacity": "desiredCapacity",
        "enabled_metrics": "enabledMetrics",
        "force_delete": "forceDelete",
        "health_check_grace_period": "healthCheckGracePeriod",
        "health_check_type": "healthCheckType",
        "initial_lifecycle_hook": "initialLifecycleHook",
        "launch_configuration": "launchConfiguration",
        "launch_template": "launchTemplate",
        "load_balancers": "loadBalancers",
        "max_instance_lifetime": "maxInstanceLifetime",
        "metrics_granularity": "metricsGranularity",
        "min_elb_capacity": "minElbCapacity",
        "mixed_instances_policy": "mixedInstancesPolicy",
        "name": "name",
        "name_prefix": "namePrefix",
        "placement_group": "placementGroup",
        "protect_from_scale_in": "protectFromScaleIn",
        "service_linked_role_arn": "serviceLinkedRoleArn",
        "suspended_processes": "suspendedProcesses",
        "tag": "tag",
        "tags": "tags",
        "target_group_arns": "targetGroupArns",
        "termination_policies": "terminationPolicies",
        "timeouts": "timeouts",
        "vpc_zone_identifier": "vpcZoneIdentifier",
        "wait_for_capacity_timeout": "waitForCapacityTimeout",
        "wait_for_elb_capacity": "waitForElbCapacity",
    },
)
class AutoscalingGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        max_size: jsii.Number,
        min_size: jsii.Number,
        availability_zones: typing.Optional[typing.List[str]] = None,
        default_cooldown: typing.Optional[jsii.Number] = None,
        desired_capacity: typing.Optional[jsii.Number] = None,
        enabled_metrics: typing.Optional[typing.List[str]] = None,
        force_delete: typing.Optional[bool] = None,
        health_check_grace_period: typing.Optional[jsii.Number] = None,
        health_check_type: typing.Optional[str] = None,
        initial_lifecycle_hook: typing.Optional[
            typing.List["AutoscalingGroupInitialLifecycleHook"]
        ] = None,
        launch_configuration: typing.Optional[str] = None,
        launch_template: typing.Optional[
            typing.List["AutoscalingGroupLaunchTemplate"]
        ] = None,
        load_balancers: typing.Optional[typing.List[str]] = None,
        max_instance_lifetime: typing.Optional[jsii.Number] = None,
        metrics_granularity: typing.Optional[str] = None,
        min_elb_capacity: typing.Optional[jsii.Number] = None,
        mixed_instances_policy: typing.Optional[
            typing.List["AutoscalingGroupMixedInstancesPolicy"]
        ] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        placement_group: typing.Optional[str] = None,
        protect_from_scale_in: typing.Optional[bool] = None,
        service_linked_role_arn: typing.Optional[str] = None,
        suspended_processes: typing.Optional[typing.List[str]] = None,
        tag: typing.Optional[typing.List["AutoscalingGroupTag"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_group_arns: typing.Optional[typing.List[str]] = None,
        termination_policies: typing.Optional[typing.List[str]] = None,
        timeouts: typing.Optional["AutoscalingGroupTimeouts"] = None,
        vpc_zone_identifier: typing.Optional[typing.List[str]] = None,
        wait_for_capacity_timeout: typing.Optional[str] = None,
        wait_for_elb_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param max_size: 
        :param min_size: 
        :param availability_zones: 
        :param default_cooldown: 
        :param desired_capacity: 
        :param enabled_metrics: 
        :param force_delete: 
        :param health_check_grace_period: 
        :param health_check_type: 
        :param initial_lifecycle_hook: initial_lifecycle_hook block.
        :param launch_configuration: 
        :param launch_template: launch_template block.
        :param load_balancers: 
        :param max_instance_lifetime: 
        :param metrics_granularity: 
        :param min_elb_capacity: 
        :param mixed_instances_policy: mixed_instances_policy block.
        :param name: 
        :param name_prefix: 
        :param placement_group: 
        :param protect_from_scale_in: 
        :param service_linked_role_arn: 
        :param suspended_processes: 
        :param tag: tag block.
        :param tags: 
        :param target_group_arns: 
        :param termination_policies: 
        :param timeouts: timeouts block.
        :param vpc_zone_identifier: 
        :param wait_for_capacity_timeout: 
        :param wait_for_elb_capacity: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = AutoscalingGroupTimeouts(**timeouts)
        self._values = {
            "max_size": max_size,
            "min_size": min_size,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if default_cooldown is not None:
            self._values["default_cooldown"] = default_cooldown
        if desired_capacity is not None:
            self._values["desired_capacity"] = desired_capacity
        if enabled_metrics is not None:
            self._values["enabled_metrics"] = enabled_metrics
        if force_delete is not None:
            self._values["force_delete"] = force_delete
        if health_check_grace_period is not None:
            self._values["health_check_grace_period"] = health_check_grace_period
        if health_check_type is not None:
            self._values["health_check_type"] = health_check_type
        if initial_lifecycle_hook is not None:
            self._values["initial_lifecycle_hook"] = initial_lifecycle_hook
        if launch_configuration is not None:
            self._values["launch_configuration"] = launch_configuration
        if launch_template is not None:
            self._values["launch_template"] = launch_template
        if load_balancers is not None:
            self._values["load_balancers"] = load_balancers
        if max_instance_lifetime is not None:
            self._values["max_instance_lifetime"] = max_instance_lifetime
        if metrics_granularity is not None:
            self._values["metrics_granularity"] = metrics_granularity
        if min_elb_capacity is not None:
            self._values["min_elb_capacity"] = min_elb_capacity
        if mixed_instances_policy is not None:
            self._values["mixed_instances_policy"] = mixed_instances_policy
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if placement_group is not None:
            self._values["placement_group"] = placement_group
        if protect_from_scale_in is not None:
            self._values["protect_from_scale_in"] = protect_from_scale_in
        if service_linked_role_arn is not None:
            self._values["service_linked_role_arn"] = service_linked_role_arn
        if suspended_processes is not None:
            self._values["suspended_processes"] = suspended_processes
        if tag is not None:
            self._values["tag"] = tag
        if tags is not None:
            self._values["tags"] = tags
        if target_group_arns is not None:
            self._values["target_group_arns"] = target_group_arns
        if termination_policies is not None:
            self._values["termination_policies"] = termination_policies
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_zone_identifier is not None:
            self._values["vpc_zone_identifier"] = vpc_zone_identifier
        if wait_for_capacity_timeout is not None:
            self._values["wait_for_capacity_timeout"] = wait_for_capacity_timeout
        if wait_for_elb_capacity is not None:
            self._values["wait_for_elb_capacity"] = wait_for_elb_capacity

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def max_size(self) -> jsii.Number:
        return self._values.get("max_size")

    @builtins.property
    def min_size(self) -> jsii.Number:
        return self._values.get("min_size")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def default_cooldown(self) -> typing.Optional[jsii.Number]:
        return self._values.get("default_cooldown")

    @builtins.property
    def desired_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("desired_capacity")

    @builtins.property
    def enabled_metrics(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("enabled_metrics")

    @builtins.property
    def force_delete(self) -> typing.Optional[bool]:
        return self._values.get("force_delete")

    @builtins.property
    def health_check_grace_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("health_check_grace_period")

    @builtins.property
    def health_check_type(self) -> typing.Optional[str]:
        return self._values.get("health_check_type")

    @builtins.property
    def initial_lifecycle_hook(
        self,
    ) -> typing.Optional[typing.List["AutoscalingGroupInitialLifecycleHook"]]:
        """initial_lifecycle_hook block."""
        return self._values.get("initial_lifecycle_hook")

    @builtins.property
    def launch_configuration(self) -> typing.Optional[str]:
        return self._values.get("launch_configuration")

    @builtins.property
    def launch_template(
        self,
    ) -> typing.Optional[typing.List["AutoscalingGroupLaunchTemplate"]]:
        """launch_template block."""
        return self._values.get("launch_template")

    @builtins.property
    def load_balancers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("load_balancers")

    @builtins.property
    def max_instance_lifetime(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_instance_lifetime")

    @builtins.property
    def metrics_granularity(self) -> typing.Optional[str]:
        return self._values.get("metrics_granularity")

    @builtins.property
    def min_elb_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_elb_capacity")

    @builtins.property
    def mixed_instances_policy(
        self,
    ) -> typing.Optional[typing.List["AutoscalingGroupMixedInstancesPolicy"]]:
        """mixed_instances_policy block."""
        return self._values.get("mixed_instances_policy")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def placement_group(self) -> typing.Optional[str]:
        return self._values.get("placement_group")

    @builtins.property
    def protect_from_scale_in(self) -> typing.Optional[bool]:
        return self._values.get("protect_from_scale_in")

    @builtins.property
    def service_linked_role_arn(self) -> typing.Optional[str]:
        return self._values.get("service_linked_role_arn")

    @builtins.property
    def suspended_processes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("suspended_processes")

    @builtins.property
    def tag(self) -> typing.Optional[typing.List["AutoscalingGroupTag"]]:
        """tag block."""
        return self._values.get("tag")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target_group_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("target_group_arns")

    @builtins.property
    def termination_policies(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("termination_policies")

    @builtins.property
    def timeouts(self) -> typing.Optional["AutoscalingGroupTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_zone_identifier(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_zone_identifier")

    @builtins.property
    def wait_for_capacity_timeout(self) -> typing.Optional[str]:
        return self._values.get("wait_for_capacity_timeout")

    @builtins.property
    def wait_for_elb_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("wait_for_elb_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupInitialLifecycleHook",
    jsii_struct_bases=[],
    name_mapping={
        "lifecycle_transition": "lifecycleTransition",
        "name": "name",
        "default_result": "defaultResult",
        "heartbeat_timeout": "heartbeatTimeout",
        "notification_metadata": "notificationMetadata",
        "notification_target_arn": "notificationTargetArn",
        "role_arn": "roleArn",
    },
)
class AutoscalingGroupInitialLifecycleHook:
    def __init__(
        self,
        *,
        lifecycle_transition: str,
        name: str,
        default_result: typing.Optional[str] = None,
        heartbeat_timeout: typing.Optional[jsii.Number] = None,
        notification_metadata: typing.Optional[str] = None,
        notification_target_arn: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param lifecycle_transition: 
        :param name: 
        :param default_result: 
        :param heartbeat_timeout: 
        :param notification_metadata: 
        :param notification_target_arn: 
        :param role_arn: 
        """
        self._values = {
            "lifecycle_transition": lifecycle_transition,
            "name": name,
        }
        if default_result is not None:
            self._values["default_result"] = default_result
        if heartbeat_timeout is not None:
            self._values["heartbeat_timeout"] = heartbeat_timeout
        if notification_metadata is not None:
            self._values["notification_metadata"] = notification_metadata
        if notification_target_arn is not None:
            self._values["notification_target_arn"] = notification_target_arn
        if role_arn is not None:
            self._values["role_arn"] = role_arn

    @builtins.property
    def lifecycle_transition(self) -> str:
        return self._values.get("lifecycle_transition")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def default_result(self) -> typing.Optional[str]:
        return self._values.get("default_result")

    @builtins.property
    def heartbeat_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("heartbeat_timeout")

    @builtins.property
    def notification_metadata(self) -> typing.Optional[str]:
        return self._values.get("notification_metadata")

    @builtins.property
    def notification_target_arn(self) -> typing.Optional[str]:
        return self._values.get("notification_target_arn")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingGroupInitialLifecycleHook(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupLaunchTemplate",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "name": "name", "version": "version"},
)
class AutoscalingGroupLaunchTemplate:
    def __init__(
        self,
        *,
        id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param id: 
        :param name: 
        :param version: 
        """
        self._values = {}
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingGroupLaunchTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupMixedInstancesPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "launch_template": "launchTemplate",
        "instances_distribution": "instancesDistribution",
    },
)
class AutoscalingGroupMixedInstancesPolicy:
    def __init__(
        self,
        *,
        launch_template: typing.List[
            "AutoscalingGroupMixedInstancesPolicyLaunchTemplate"
        ],
        instances_distribution: typing.Optional[
            typing.List["AutoscalingGroupMixedInstancesPolicyInstancesDistribution"]
        ] = None,
    ) -> None:
        """
        :param launch_template: launch_template block.
        :param instances_distribution: instances_distribution block.
        """
        self._values = {
            "launch_template": launch_template,
        }
        if instances_distribution is not None:
            self._values["instances_distribution"] = instances_distribution

    @builtins.property
    def launch_template(
        self,
    ) -> typing.List["AutoscalingGroupMixedInstancesPolicyLaunchTemplate"]:
        """launch_template block."""
        return self._values.get("launch_template")

    @builtins.property
    def instances_distribution(
        self,
    ) -> typing.Optional[
        typing.List["AutoscalingGroupMixedInstancesPolicyInstancesDistribution"]
    ]:
        """instances_distribution block."""
        return self._values.get("instances_distribution")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingGroupMixedInstancesPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupMixedInstancesPolicyInstancesDistribution",
    jsii_struct_bases=[],
    name_mapping={
        "on_demand_allocation_strategy": "onDemandAllocationStrategy",
        "on_demand_base_capacity": "onDemandBaseCapacity",
        "on_demand_percentage_above_base_capacity": "onDemandPercentageAboveBaseCapacity",
        "spot_allocation_strategy": "spotAllocationStrategy",
        "spot_instance_pools": "spotInstancePools",
        "spot_max_price": "spotMaxPrice",
    },
)
class AutoscalingGroupMixedInstancesPolicyInstancesDistribution:
    def __init__(
        self,
        *,
        on_demand_allocation_strategy: typing.Optional[str] = None,
        on_demand_base_capacity: typing.Optional[jsii.Number] = None,
        on_demand_percentage_above_base_capacity: typing.Optional[jsii.Number] = None,
        spot_allocation_strategy: typing.Optional[str] = None,
        spot_instance_pools: typing.Optional[jsii.Number] = None,
        spot_max_price: typing.Optional[str] = None,
    ) -> None:
        """
        :param on_demand_allocation_strategy: 
        :param on_demand_base_capacity: 
        :param on_demand_percentage_above_base_capacity: 
        :param spot_allocation_strategy: 
        :param spot_instance_pools: 
        :param spot_max_price: 
        """
        self._values = {}
        if on_demand_allocation_strategy is not None:
            self._values[
                "on_demand_allocation_strategy"
            ] = on_demand_allocation_strategy
        if on_demand_base_capacity is not None:
            self._values["on_demand_base_capacity"] = on_demand_base_capacity
        if on_demand_percentage_above_base_capacity is not None:
            self._values[
                "on_demand_percentage_above_base_capacity"
            ] = on_demand_percentage_above_base_capacity
        if spot_allocation_strategy is not None:
            self._values["spot_allocation_strategy"] = spot_allocation_strategy
        if spot_instance_pools is not None:
            self._values["spot_instance_pools"] = spot_instance_pools
        if spot_max_price is not None:
            self._values["spot_max_price"] = spot_max_price

    @builtins.property
    def on_demand_allocation_strategy(self) -> typing.Optional[str]:
        return self._values.get("on_demand_allocation_strategy")

    @builtins.property
    def on_demand_base_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("on_demand_base_capacity")

    @builtins.property
    def on_demand_percentage_above_base_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("on_demand_percentage_above_base_capacity")

    @builtins.property
    def spot_allocation_strategy(self) -> typing.Optional[str]:
        return self._values.get("spot_allocation_strategy")

    @builtins.property
    def spot_instance_pools(self) -> typing.Optional[jsii.Number]:
        return self._values.get("spot_instance_pools")

    @builtins.property
    def spot_max_price(self) -> typing.Optional[str]:
        return self._values.get("spot_max_price")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AutoscalingGroupMixedInstancesPolicyInstancesDistribution(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupMixedInstancesPolicyLaunchTemplate",
    jsii_struct_bases=[],
    name_mapping={
        "launch_template_specification": "launchTemplateSpecification",
        "override": "override",
    },
)
class AutoscalingGroupMixedInstancesPolicyLaunchTemplate:
    def __init__(
        self,
        *,
        launch_template_specification: typing.List[
            "AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification"
        ],
        override: typing.Optional[
            typing.List["AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride"]
        ] = None,
    ) -> None:
        """
        :param launch_template_specification: launch_template_specification block.
        :param override: override block.
        """
        self._values = {
            "launch_template_specification": launch_template_specification,
        }
        if override is not None:
            self._values["override"] = override

    @builtins.property
    def launch_template_specification(
        self,
    ) -> typing.List[
        "AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification"
    ]:
        """launch_template_specification block."""
        return self._values.get("launch_template_specification")

    @builtins.property
    def override(
        self,
    ) -> typing.Optional[
        typing.List["AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride"]
    ]:
        """override block."""
        return self._values.get("override")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingGroupMixedInstancesPolicyLaunchTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "launch_template_id": "launchTemplateId",
        "launch_template_name": "launchTemplateName",
        "version": "version",
    },
)
class AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification:
    def __init__(
        self,
        *,
        launch_template_id: typing.Optional[str] = None,
        launch_template_name: typing.Optional[str] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param launch_template_id: 
        :param launch_template_name: 
        :param version: 
        """
        self._values = {}
        if launch_template_id is not None:
            self._values["launch_template_id"] = launch_template_id
        if launch_template_name is not None:
            self._values["launch_template_name"] = launch_template_name
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def launch_template_id(self) -> typing.Optional[str]:
        return self._values.get("launch_template_id")

    @builtins.property
    def launch_template_name(self) -> typing.Optional[str]:
        return self._values.get("launch_template_name")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride",
    jsii_struct_bases=[],
    name_mapping={
        "instance_type": "instanceType",
        "weighted_capacity": "weightedCapacity",
    },
)
class AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride:
    def __init__(
        self,
        *,
        instance_type: typing.Optional[str] = None,
        weighted_capacity: typing.Optional[str] = None,
    ) -> None:
        """
        :param instance_type: 
        :param weighted_capacity: 
        """
        self._values = {}
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if weighted_capacity is not None:
            self._values["weighted_capacity"] = weighted_capacity

    @builtins.property
    def instance_type(self) -> typing.Optional[str]:
        return self._values.get("instance_type")

    @builtins.property
    def weighted_capacity(self) -> typing.Optional[str]:
        return self._values.get("weighted_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupTag",
    jsii_struct_bases=[],
    name_mapping={
        "key": "key",
        "propagate_at_launch": "propagateAtLaunch",
        "value": "value",
    },
)
class AutoscalingGroupTag:
    def __init__(self, *, key: str, propagate_at_launch: bool, value: str) -> None:
        """
        :param key: 
        :param propagate_at_launch: 
        :param value: 
        """
        self._values = {
            "key": key,
            "propagate_at_launch": propagate_at_launch,
            "value": value,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def propagate_at_launch(self) -> bool:
        return self._values.get("propagate_at_launch")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingGroupTag(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"delete": "delete"},
)
class AutoscalingGroupTimeouts:
    def __init__(self, *, delete: typing.Optional[str] = None) -> None:
        """
        :param delete: 
        """
        self._values = {}
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutoscalingLifecycleHook(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingLifecycleHook",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        autoscaling_group_name: str,
        lifecycle_transition: str,
        name: str,
        default_result: typing.Optional[str] = None,
        heartbeat_timeout: typing.Optional[jsii.Number] = None,
        notification_metadata: typing.Optional[str] = None,
        notification_target_arn: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param autoscaling_group_name: 
        :param lifecycle_transition: 
        :param name: 
        :param default_result: 
        :param heartbeat_timeout: 
        :param notification_metadata: 
        :param notification_target_arn: 
        :param role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutoscalingLifecycleHookConfig(
            autoscaling_group_name=autoscaling_group_name,
            lifecycle_transition=lifecycle_transition,
            name=name,
            default_result=default_result,
            heartbeat_timeout=heartbeat_timeout,
            notification_metadata=notification_metadata,
            notification_target_arn=notification_target_arn,
            role_arn=role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutoscalingLifecycleHook, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="autoscalingGroupName")
    def autoscaling_group_name(self) -> str:
        return jsii.get(self, "autoscalingGroupName")

    @autoscaling_group_name.setter
    def autoscaling_group_name(self, value: str) -> None:
        jsii.set(self, "autoscalingGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="lifecycleTransition")
    def lifecycle_transition(self) -> str:
        return jsii.get(self, "lifecycleTransition")

    @lifecycle_transition.setter
    def lifecycle_transition(self, value: str) -> None:
        jsii.set(self, "lifecycleTransition", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="defaultResult")
    def default_result(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultResult")

    @default_result.setter
    def default_result(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultResult", value)

    @builtins.property
    @jsii.member(jsii_name="heartbeatTimeout")
    def heartbeat_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "heartbeatTimeout")

    @heartbeat_timeout.setter
    def heartbeat_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "heartbeatTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="notificationMetadata")
    def notification_metadata(self) -> typing.Optional[str]:
        return jsii.get(self, "notificationMetadata")

    @notification_metadata.setter
    def notification_metadata(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "notificationMetadata", value)

    @builtins.property
    @jsii.member(jsii_name="notificationTargetArn")
    def notification_target_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "notificationTargetArn")

    @notification_target_arn.setter
    def notification_target_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "notificationTargetArn", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingLifecycleHookConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "autoscaling_group_name": "autoscalingGroupName",
        "lifecycle_transition": "lifecycleTransition",
        "name": "name",
        "default_result": "defaultResult",
        "heartbeat_timeout": "heartbeatTimeout",
        "notification_metadata": "notificationMetadata",
        "notification_target_arn": "notificationTargetArn",
        "role_arn": "roleArn",
    },
)
class AutoscalingLifecycleHookConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        autoscaling_group_name: str,
        lifecycle_transition: str,
        name: str,
        default_result: typing.Optional[str] = None,
        heartbeat_timeout: typing.Optional[jsii.Number] = None,
        notification_metadata: typing.Optional[str] = None,
        notification_target_arn: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param autoscaling_group_name: 
        :param lifecycle_transition: 
        :param name: 
        :param default_result: 
        :param heartbeat_timeout: 
        :param notification_metadata: 
        :param notification_target_arn: 
        :param role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "autoscaling_group_name": autoscaling_group_name,
            "lifecycle_transition": lifecycle_transition,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_result is not None:
            self._values["default_result"] = default_result
        if heartbeat_timeout is not None:
            self._values["heartbeat_timeout"] = heartbeat_timeout
        if notification_metadata is not None:
            self._values["notification_metadata"] = notification_metadata
        if notification_target_arn is not None:
            self._values["notification_target_arn"] = notification_target_arn
        if role_arn is not None:
            self._values["role_arn"] = role_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def autoscaling_group_name(self) -> str:
        return self._values.get("autoscaling_group_name")

    @builtins.property
    def lifecycle_transition(self) -> str:
        return self._values.get("lifecycle_transition")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def default_result(self) -> typing.Optional[str]:
        return self._values.get("default_result")

    @builtins.property
    def heartbeat_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("heartbeat_timeout")

    @builtins.property
    def notification_metadata(self) -> typing.Optional[str]:
        return self._values.get("notification_metadata")

    @builtins.property
    def notification_target_arn(self) -> typing.Optional[str]:
        return self._values.get("notification_target_arn")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingLifecycleHookConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutoscalingNotification(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingNotification",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        group_names: typing.List[str],
        notifications: typing.List[str],
        topic_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group_names: 
        :param notifications: 
        :param topic_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutoscalingNotificationConfig(
            group_names=group_names,
            notifications=notifications,
            topic_arn=topic_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutoscalingNotification, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="groupNames")
    def group_names(self) -> typing.List[str]:
        return jsii.get(self, "groupNames")

    @group_names.setter
    def group_names(self, value: typing.List[str]) -> None:
        jsii.set(self, "groupNames", value)

    @builtins.property
    @jsii.member(jsii_name="notifications")
    def notifications(self) -> typing.List[str]:
        return jsii.get(self, "notifications")

    @notifications.setter
    def notifications(self, value: typing.List[str]) -> None:
        jsii.set(self, "notifications", value)

    @builtins.property
    @jsii.member(jsii_name="topicArn")
    def topic_arn(self) -> str:
        return jsii.get(self, "topicArn")

    @topic_arn.setter
    def topic_arn(self, value: str) -> None:
        jsii.set(self, "topicArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingNotificationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group_names": "groupNames",
        "notifications": "notifications",
        "topic_arn": "topicArn",
    },
)
class AutoscalingNotificationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group_names: typing.List[str],
        notifications: typing.List[str],
        topic_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group_names: 
        :param notifications: 
        :param topic_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "group_names": group_names,
            "notifications": notifications,
            "topic_arn": topic_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def group_names(self) -> typing.List[str]:
        return self._values.get("group_names")

    @builtins.property
    def notifications(self) -> typing.List[str]:
        return self._values.get("notifications")

    @builtins.property
    def topic_arn(self) -> str:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingNotificationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AutoscalingPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        autoscaling_group_name: str,
        name: str,
        adjustment_type: typing.Optional[str] = None,
        cooldown: typing.Optional[jsii.Number] = None,
        estimated_instance_warmup: typing.Optional[jsii.Number] = None,
        metric_aggregation_type: typing.Optional[str] = None,
        min_adjustment_magnitude: typing.Optional[jsii.Number] = None,
        min_adjustment_step: typing.Optional[jsii.Number] = None,
        policy_type: typing.Optional[str] = None,
        scaling_adjustment: typing.Optional[jsii.Number] = None,
        step_adjustment: typing.Optional[
            typing.List["AutoscalingPolicyStepAdjustment"]
        ] = None,
        target_tracking_configuration: typing.Optional[
            typing.List["AutoscalingPolicyTargetTrackingConfiguration"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param autoscaling_group_name: 
        :param name: 
        :param adjustment_type: 
        :param cooldown: 
        :param estimated_instance_warmup: 
        :param metric_aggregation_type: 
        :param min_adjustment_magnitude: 
        :param min_adjustment_step: 
        :param policy_type: 
        :param scaling_adjustment: 
        :param step_adjustment: step_adjustment block.
        :param target_tracking_configuration: target_tracking_configuration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutoscalingPolicyConfig(
            autoscaling_group_name=autoscaling_group_name,
            name=name,
            adjustment_type=adjustment_type,
            cooldown=cooldown,
            estimated_instance_warmup=estimated_instance_warmup,
            metric_aggregation_type=metric_aggregation_type,
            min_adjustment_magnitude=min_adjustment_magnitude,
            min_adjustment_step=min_adjustment_step,
            policy_type=policy_type,
            scaling_adjustment=scaling_adjustment,
            step_adjustment=step_adjustment,
            target_tracking_configuration=target_tracking_configuration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutoscalingPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="autoscalingGroupName")
    def autoscaling_group_name(self) -> str:
        return jsii.get(self, "autoscalingGroupName")

    @autoscaling_group_name.setter
    def autoscaling_group_name(self, value: str) -> None:
        jsii.set(self, "autoscalingGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="adjustmentType")
    def adjustment_type(self) -> typing.Optional[str]:
        return jsii.get(self, "adjustmentType")

    @adjustment_type.setter
    def adjustment_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "adjustmentType", value)

    @builtins.property
    @jsii.member(jsii_name="cooldown")
    def cooldown(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cooldown")

    @cooldown.setter
    def cooldown(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cooldown", value)

    @builtins.property
    @jsii.member(jsii_name="estimatedInstanceWarmup")
    def estimated_instance_warmup(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "estimatedInstanceWarmup")

    @estimated_instance_warmup.setter
    def estimated_instance_warmup(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "estimatedInstanceWarmup", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="metricAggregationType")
    def metric_aggregation_type(self) -> typing.Optional[str]:
        return jsii.get(self, "metricAggregationType")

    @metric_aggregation_type.setter
    def metric_aggregation_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "metricAggregationType", value)

    @builtins.property
    @jsii.member(jsii_name="minAdjustmentMagnitude")
    def min_adjustment_magnitude(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minAdjustmentMagnitude")

    @min_adjustment_magnitude.setter
    def min_adjustment_magnitude(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minAdjustmentMagnitude", value)

    @builtins.property
    @jsii.member(jsii_name="minAdjustmentStep")
    def min_adjustment_step(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minAdjustmentStep")

    @min_adjustment_step.setter
    def min_adjustment_step(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minAdjustmentStep", value)

    @builtins.property
    @jsii.member(jsii_name="policyType")
    def policy_type(self) -> typing.Optional[str]:
        return jsii.get(self, "policyType")

    @policy_type.setter
    def policy_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policyType", value)

    @builtins.property
    @jsii.member(jsii_name="scalingAdjustment")
    def scaling_adjustment(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "scalingAdjustment")

    @scaling_adjustment.setter
    def scaling_adjustment(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "scalingAdjustment", value)

    @builtins.property
    @jsii.member(jsii_name="stepAdjustment")
    def step_adjustment(
        self,
    ) -> typing.Optional[typing.List["AutoscalingPolicyStepAdjustment"]]:
        return jsii.get(self, "stepAdjustment")

    @step_adjustment.setter
    def step_adjustment(
        self, value: typing.Optional[typing.List["AutoscalingPolicyStepAdjustment"]]
    ) -> None:
        jsii.set(self, "stepAdjustment", value)

    @builtins.property
    @jsii.member(jsii_name="targetTrackingConfiguration")
    def target_tracking_configuration(
        self,
    ) -> typing.Optional[typing.List["AutoscalingPolicyTargetTrackingConfiguration"]]:
        return jsii.get(self, "targetTrackingConfiguration")

    @target_tracking_configuration.setter
    def target_tracking_configuration(
        self,
        value: typing.Optional[
            typing.List["AutoscalingPolicyTargetTrackingConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "targetTrackingConfiguration", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "autoscaling_group_name": "autoscalingGroupName",
        "name": "name",
        "adjustment_type": "adjustmentType",
        "cooldown": "cooldown",
        "estimated_instance_warmup": "estimatedInstanceWarmup",
        "metric_aggregation_type": "metricAggregationType",
        "min_adjustment_magnitude": "minAdjustmentMagnitude",
        "min_adjustment_step": "minAdjustmentStep",
        "policy_type": "policyType",
        "scaling_adjustment": "scalingAdjustment",
        "step_adjustment": "stepAdjustment",
        "target_tracking_configuration": "targetTrackingConfiguration",
    },
)
class AutoscalingPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        autoscaling_group_name: str,
        name: str,
        adjustment_type: typing.Optional[str] = None,
        cooldown: typing.Optional[jsii.Number] = None,
        estimated_instance_warmup: typing.Optional[jsii.Number] = None,
        metric_aggregation_type: typing.Optional[str] = None,
        min_adjustment_magnitude: typing.Optional[jsii.Number] = None,
        min_adjustment_step: typing.Optional[jsii.Number] = None,
        policy_type: typing.Optional[str] = None,
        scaling_adjustment: typing.Optional[jsii.Number] = None,
        step_adjustment: typing.Optional[
            typing.List["AutoscalingPolicyStepAdjustment"]
        ] = None,
        target_tracking_configuration: typing.Optional[
            typing.List["AutoscalingPolicyTargetTrackingConfiguration"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param autoscaling_group_name: 
        :param name: 
        :param adjustment_type: 
        :param cooldown: 
        :param estimated_instance_warmup: 
        :param metric_aggregation_type: 
        :param min_adjustment_magnitude: 
        :param min_adjustment_step: 
        :param policy_type: 
        :param scaling_adjustment: 
        :param step_adjustment: step_adjustment block.
        :param target_tracking_configuration: target_tracking_configuration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "autoscaling_group_name": autoscaling_group_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if adjustment_type is not None:
            self._values["adjustment_type"] = adjustment_type
        if cooldown is not None:
            self._values["cooldown"] = cooldown
        if estimated_instance_warmup is not None:
            self._values["estimated_instance_warmup"] = estimated_instance_warmup
        if metric_aggregation_type is not None:
            self._values["metric_aggregation_type"] = metric_aggregation_type
        if min_adjustment_magnitude is not None:
            self._values["min_adjustment_magnitude"] = min_adjustment_magnitude
        if min_adjustment_step is not None:
            self._values["min_adjustment_step"] = min_adjustment_step
        if policy_type is not None:
            self._values["policy_type"] = policy_type
        if scaling_adjustment is not None:
            self._values["scaling_adjustment"] = scaling_adjustment
        if step_adjustment is not None:
            self._values["step_adjustment"] = step_adjustment
        if target_tracking_configuration is not None:
            self._values[
                "target_tracking_configuration"
            ] = target_tracking_configuration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def autoscaling_group_name(self) -> str:
        return self._values.get("autoscaling_group_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def adjustment_type(self) -> typing.Optional[str]:
        return self._values.get("adjustment_type")

    @builtins.property
    def cooldown(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cooldown")

    @builtins.property
    def estimated_instance_warmup(self) -> typing.Optional[jsii.Number]:
        return self._values.get("estimated_instance_warmup")

    @builtins.property
    def metric_aggregation_type(self) -> typing.Optional[str]:
        return self._values.get("metric_aggregation_type")

    @builtins.property
    def min_adjustment_magnitude(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_adjustment_magnitude")

    @builtins.property
    def min_adjustment_step(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_adjustment_step")

    @builtins.property
    def policy_type(self) -> typing.Optional[str]:
        return self._values.get("policy_type")

    @builtins.property
    def scaling_adjustment(self) -> typing.Optional[jsii.Number]:
        return self._values.get("scaling_adjustment")

    @builtins.property
    def step_adjustment(
        self,
    ) -> typing.Optional[typing.List["AutoscalingPolicyStepAdjustment"]]:
        """step_adjustment block."""
        return self._values.get("step_adjustment")

    @builtins.property
    def target_tracking_configuration(
        self,
    ) -> typing.Optional[typing.List["AutoscalingPolicyTargetTrackingConfiguration"]]:
        """target_tracking_configuration block."""
        return self._values.get("target_tracking_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingPolicyStepAdjustment",
    jsii_struct_bases=[],
    name_mapping={
        "scaling_adjustment": "scalingAdjustment",
        "metric_interval_lower_bound": "metricIntervalLowerBound",
        "metric_interval_upper_bound": "metricIntervalUpperBound",
    },
)
class AutoscalingPolicyStepAdjustment:
    def __init__(
        self,
        *,
        scaling_adjustment: jsii.Number,
        metric_interval_lower_bound: typing.Optional[str] = None,
        metric_interval_upper_bound: typing.Optional[str] = None,
    ) -> None:
        """
        :param scaling_adjustment: 
        :param metric_interval_lower_bound: 
        :param metric_interval_upper_bound: 
        """
        self._values = {
            "scaling_adjustment": scaling_adjustment,
        }
        if metric_interval_lower_bound is not None:
            self._values["metric_interval_lower_bound"] = metric_interval_lower_bound
        if metric_interval_upper_bound is not None:
            self._values["metric_interval_upper_bound"] = metric_interval_upper_bound

    @builtins.property
    def scaling_adjustment(self) -> jsii.Number:
        return self._values.get("scaling_adjustment")

    @builtins.property
    def metric_interval_lower_bound(self) -> typing.Optional[str]:
        return self._values.get("metric_interval_lower_bound")

    @builtins.property
    def metric_interval_upper_bound(self) -> typing.Optional[str]:
        return self._values.get("metric_interval_upper_bound")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingPolicyStepAdjustment(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingPolicyTargetTrackingConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "target_value": "targetValue",
        "customized_metric_specification": "customizedMetricSpecification",
        "disable_scale_in": "disableScaleIn",
        "predefined_metric_specification": "predefinedMetricSpecification",
    },
)
class AutoscalingPolicyTargetTrackingConfiguration:
    def __init__(
        self,
        *,
        target_value: jsii.Number,
        customized_metric_specification: typing.Optional[
            typing.List[
                "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification"
            ]
        ] = None,
        disable_scale_in: typing.Optional[bool] = None,
        predefined_metric_specification: typing.Optional[
            typing.List[
                "AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification"
            ]
        ] = None,
    ) -> None:
        """
        :param target_value: 
        :param customized_metric_specification: customized_metric_specification block.
        :param disable_scale_in: 
        :param predefined_metric_specification: predefined_metric_specification block.
        """
        self._values = {
            "target_value": target_value,
        }
        if customized_metric_specification is not None:
            self._values[
                "customized_metric_specification"
            ] = customized_metric_specification
        if disable_scale_in is not None:
            self._values["disable_scale_in"] = disable_scale_in
        if predefined_metric_specification is not None:
            self._values[
                "predefined_metric_specification"
            ] = predefined_metric_specification

    @builtins.property
    def target_value(self) -> jsii.Number:
        return self._values.get("target_value")

    @builtins.property
    def customized_metric_specification(
        self,
    ) -> typing.Optional[
        typing.List[
            "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification"
        ]
    ]:
        """customized_metric_specification block."""
        return self._values.get("customized_metric_specification")

    @builtins.property
    def disable_scale_in(self) -> typing.Optional[bool]:
        return self._values.get("disable_scale_in")

    @builtins.property
    def predefined_metric_specification(
        self,
    ) -> typing.Optional[
        typing.List[
            "AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification"
        ]
    ]:
        """predefined_metric_specification block."""
        return self._values.get("predefined_metric_specification")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingPolicyTargetTrackingConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "namespace": "namespace",
        "statistic": "statistic",
        "metric_dimension": "metricDimension",
        "unit": "unit",
    },
)
class AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification:
    def __init__(
        self,
        *,
        metric_name: str,
        namespace: str,
        statistic: str,
        metric_dimension: typing.Optional[
            typing.List[
                "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension"
            ]
        ] = None,
        unit: typing.Optional[str] = None,
    ) -> None:
        """
        :param metric_name: 
        :param namespace: 
        :param statistic: 
        :param metric_dimension: metric_dimension block.
        :param unit: 
        """
        self._values = {
            "metric_name": metric_name,
            "namespace": namespace,
            "statistic": statistic,
        }
        if metric_dimension is not None:
            self._values["metric_dimension"] = metric_dimension
        if unit is not None:
            self._values["unit"] = unit

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def namespace(self) -> str:
        return self._values.get("namespace")

    @builtins.property
    def statistic(self) -> str:
        return self._values.get("statistic")

    @builtins.property
    def metric_dimension(
        self,
    ) -> typing.Optional[
        typing.List[
            "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension"
        ]
    ]:
        """metric_dimension block."""
        return self._values.get("metric_dimension")

    @builtins.property
    def unit(self) -> typing.Optional[str]:
        return self._values.get("unit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "predefined_metric_type": "predefinedMetricType",
        "resource_label": "resourceLabel",
    },
)
class AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification:
    def __init__(
        self,
        *,
        predefined_metric_type: str,
        resource_label: typing.Optional[str] = None,
    ) -> None:
        """
        :param predefined_metric_type: 
        :param resource_label: 
        """
        self._values = {
            "predefined_metric_type": predefined_metric_type,
        }
        if resource_label is not None:
            self._values["resource_label"] = resource_label

    @builtins.property
    def predefined_metric_type(self) -> str:
        return self._values.get("predefined_metric_type")

    @builtins.property
    def resource_label(self) -> typing.Optional[str]:
        return self._values.get("resource_label")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class AutoscalingSchedule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingSchedule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        autoscaling_group_name: str,
        scheduled_action_name: str,
        desired_capacity: typing.Optional[jsii.Number] = None,
        end_time: typing.Optional[str] = None,
        max_size: typing.Optional[jsii.Number] = None,
        min_size: typing.Optional[jsii.Number] = None,
        recurrence: typing.Optional[str] = None,
        start_time: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param autoscaling_group_name: 
        :param scheduled_action_name: 
        :param desired_capacity: 
        :param end_time: 
        :param max_size: 
        :param min_size: 
        :param recurrence: 
        :param start_time: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = AutoscalingScheduleConfig(
            autoscaling_group_name=autoscaling_group_name,
            scheduled_action_name=scheduled_action_name,
            desired_capacity=desired_capacity,
            end_time=end_time,
            max_size=max_size,
            min_size=min_size,
            recurrence=recurrence,
            start_time=start_time,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(AutoscalingSchedule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="autoscalingGroupName")
    def autoscaling_group_name(self) -> str:
        return jsii.get(self, "autoscalingGroupName")

    @autoscaling_group_name.setter
    def autoscaling_group_name(self, value: str) -> None:
        jsii.set(self, "autoscalingGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="scheduledActionName")
    def scheduled_action_name(self) -> str:
        return jsii.get(self, "scheduledActionName")

    @scheduled_action_name.setter
    def scheduled_action_name(self, value: str) -> None:
        jsii.set(self, "scheduledActionName", value)

    @builtins.property
    @jsii.member(jsii_name="desiredCapacity")
    def desired_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "desiredCapacity")

    @desired_capacity.setter
    def desired_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "desiredCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="endTime")
    def end_time(self) -> typing.Optional[str]:
        return jsii.get(self, "endTime")

    @end_time.setter
    def end_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endTime", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maxSize")
    def max_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxSize")

    @max_size.setter
    def max_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxSize", value)

    @builtins.property
    @jsii.member(jsii_name="minSize")
    def min_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minSize")

    @min_size.setter
    def min_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minSize", value)

    @builtins.property
    @jsii.member(jsii_name="recurrence")
    def recurrence(self) -> typing.Optional[str]:
        return jsii.get(self, "recurrence")

    @recurrence.setter
    def recurrence(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "recurrence", value)

    @builtins.property
    @jsii.member(jsii_name="startTime")
    def start_time(self) -> typing.Optional[str]:
        return jsii.get(self, "startTime")

    @start_time.setter
    def start_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "startTime", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AutoscalingScheduleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "autoscaling_group_name": "autoscalingGroupName",
        "scheduled_action_name": "scheduledActionName",
        "desired_capacity": "desiredCapacity",
        "end_time": "endTime",
        "max_size": "maxSize",
        "min_size": "minSize",
        "recurrence": "recurrence",
        "start_time": "startTime",
    },
)
class AutoscalingScheduleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        autoscaling_group_name: str,
        scheduled_action_name: str,
        desired_capacity: typing.Optional[jsii.Number] = None,
        end_time: typing.Optional[str] = None,
        max_size: typing.Optional[jsii.Number] = None,
        min_size: typing.Optional[jsii.Number] = None,
        recurrence: typing.Optional[str] = None,
        start_time: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param autoscaling_group_name: 
        :param scheduled_action_name: 
        :param desired_capacity: 
        :param end_time: 
        :param max_size: 
        :param min_size: 
        :param recurrence: 
        :param start_time: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "autoscaling_group_name": autoscaling_group_name,
            "scheduled_action_name": scheduled_action_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if desired_capacity is not None:
            self._values["desired_capacity"] = desired_capacity
        if end_time is not None:
            self._values["end_time"] = end_time
        if max_size is not None:
            self._values["max_size"] = max_size
        if min_size is not None:
            self._values["min_size"] = min_size
        if recurrence is not None:
            self._values["recurrence"] = recurrence
        if start_time is not None:
            self._values["start_time"] = start_time

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def autoscaling_group_name(self) -> str:
        return self._values.get("autoscaling_group_name")

    @builtins.property
    def scheduled_action_name(self) -> str:
        return self._values.get("scheduled_action_name")

    @builtins.property
    def desired_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("desired_capacity")

    @builtins.property
    def end_time(self) -> typing.Optional[str]:
        return self._values.get("end_time")

    @builtins.property
    def max_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_size")

    @builtins.property
    def min_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_size")

    @builtins.property
    def recurrence(self) -> typing.Optional[str]:
        return self._values.get("recurrence")

    @builtins.property
    def start_time(self) -> typing.Optional[str]:
        return self._values.get("start_time")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AutoscalingScheduleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class AwsProvider(
    cdktf.TerraformProvider,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.AwsProvider",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        region: str,
        access_key: typing.Optional[str] = None,
        alias: typing.Optional[str] = None,
        allowed_account_ids: typing.Optional[typing.List[str]] = None,
        assume_role: typing.Optional[typing.List["AwsProviderAssumeRole"]] = None,
        endpoints: typing.Optional[typing.List["AwsProviderEndpoints"]] = None,
        forbidden_account_ids: typing.Optional[typing.List[str]] = None,
        ignore_tags: typing.Optional[typing.List["AwsProviderIgnoreTags"]] = None,
        insecure: typing.Optional[bool] = None,
        max_retries: typing.Optional[jsii.Number] = None,
        profile: typing.Optional[str] = None,
        s3_force_path_style: typing.Optional[bool] = None,
        secret_key: typing.Optional[str] = None,
        shared_credentials_file: typing.Optional[str] = None,
        skip_credentials_validation: typing.Optional[bool] = None,
        skip_get_ec2_platforms: typing.Optional[bool] = None,
        skip_metadata_api_check: typing.Optional[bool] = None,
        skip_region_validation: typing.Optional[bool] = None,
        skip_requesting_account_id: typing.Optional[bool] = None,
        token: typing.Optional[str] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param region: The region where AWS operations will take place. Examples are us-east-1, us-west-2, etc.
        :param access_key: The access key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
        :param alias: Alias name.
        :param allowed_account_ids: 
        :param assume_role: assume_role block.
        :param endpoints: endpoints block.
        :param forbidden_account_ids: 
        :param ignore_tags: ignore_tags block.
        :param insecure: Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is ``false``
        :param max_retries: The maximum number of times an AWS API request is being executed. If the API request still fails, an error is thrown.
        :param profile: The profile for API operations. If not set, the default profile created with ``aws configure`` will be used.
        :param s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY). Specific to the Amazon S3 service.
        :param secret_key: The secret key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
        :param shared_credentials_file: The path to the shared credentials file. If not set this defaults to ~/.aws/credentials.
        :param skip_credentials_validation: Skip the credentials validation via STS API. Used for AWS API implementations that do not have STS available/implemented.
        :param skip_get_ec2_platforms: Skip getting the supported EC2 platforms. Used by users that don't have ec2:DescribeAccountAttributes permissions.
        :param skip_metadata_api_check: 
        :param skip_region_validation: Skip static validation of region name. Used by users of alternative AWS-like APIs or users w/ access to regions that are not public (yet).
        :param skip_requesting_account_id: Skip requesting the account ID. Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
        :param token: session token. A session token is only required if you are using temporary security credentials.
        """
        config = AwsProviderConfig(
            region=region,
            access_key=access_key,
            alias=alias,
            allowed_account_ids=allowed_account_ids,
            assume_role=assume_role,
            endpoints=endpoints,
            forbidden_account_ids=forbidden_account_ids,
            ignore_tags=ignore_tags,
            insecure=insecure,
            max_retries=max_retries,
            profile=profile,
            s3_force_path_style=s3_force_path_style,
            secret_key=secret_key,
            shared_credentials_file=shared_credentials_file,
            skip_credentials_validation=skip_credentials_validation,
            skip_get_ec2_platforms=skip_get_ec2_platforms,
            skip_metadata_api_check=skip_metadata_api_check,
            skip_region_validation=skip_region_validation,
            skip_requesting_account_id=skip_requesting_account_id,
            token=token,
        )

        jsii.create(AwsProvider, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> str:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: str) -> None:
        jsii.set(self, "region", value)

    @builtins.property
    @jsii.member(jsii_name="accessKey")
    def access_key(self) -> typing.Optional[str]:
        return jsii.get(self, "accessKey")

    @access_key.setter
    def access_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accessKey", value)

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> typing.Optional[str]:
        return jsii.get(self, "alias")

    @alias.setter
    def alias(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "alias", value)

    @builtins.property
    @jsii.member(jsii_name="allowedAccountIds")
    def allowed_account_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "allowedAccountIds")

    @allowed_account_ids.setter
    def allowed_account_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "allowedAccountIds", value)

    @builtins.property
    @jsii.member(jsii_name="assumeRole")
    def assume_role(self) -> typing.Optional[typing.List["AwsProviderAssumeRole"]]:
        return jsii.get(self, "assumeRole")

    @assume_role.setter
    def assume_role(
        self, value: typing.Optional[typing.List["AwsProviderAssumeRole"]]
    ) -> None:
        jsii.set(self, "assumeRole", value)

    @builtins.property
    @jsii.member(jsii_name="endpoints")
    def endpoints(self) -> typing.Optional[typing.List["AwsProviderEndpoints"]]:
        return jsii.get(self, "endpoints")

    @endpoints.setter
    def endpoints(
        self, value: typing.Optional[typing.List["AwsProviderEndpoints"]]
    ) -> None:
        jsii.set(self, "endpoints", value)

    @builtins.property
    @jsii.member(jsii_name="forbiddenAccountIds")
    def forbidden_account_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "forbiddenAccountIds")

    @forbidden_account_ids.setter
    def forbidden_account_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "forbiddenAccountIds", value)

    @builtins.property
    @jsii.member(jsii_name="ignoreTags")
    def ignore_tags(self) -> typing.Optional[typing.List["AwsProviderIgnoreTags"]]:
        return jsii.get(self, "ignoreTags")

    @ignore_tags.setter
    def ignore_tags(
        self, value: typing.Optional[typing.List["AwsProviderIgnoreTags"]]
    ) -> None:
        jsii.set(self, "ignoreTags", value)

    @builtins.property
    @jsii.member(jsii_name="insecure")
    def insecure(self) -> typing.Optional[bool]:
        return jsii.get(self, "insecure")

    @insecure.setter
    def insecure(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "insecure", value)

    @builtins.property
    @jsii.member(jsii_name="maxRetries")
    def max_retries(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxRetries")

    @max_retries.setter
    def max_retries(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxRetries", value)

    @builtins.property
    @jsii.member(jsii_name="profile")
    def profile(self) -> typing.Optional[str]:
        return jsii.get(self, "profile")

    @profile.setter
    def profile(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "profile", value)

    @builtins.property
    @jsii.member(jsii_name="s3ForcePathStyle")
    def s3_force_path_style(self) -> typing.Optional[bool]:
        return jsii.get(self, "s3ForcePathStyle")

    @s3_force_path_style.setter
    def s3_force_path_style(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "s3ForcePathStyle", value)

    @builtins.property
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> typing.Optional[str]:
        return jsii.get(self, "secretKey")

    @secret_key.setter
    def secret_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "secretKey", value)

    @builtins.property
    @jsii.member(jsii_name="sharedCredentialsFile")
    def shared_credentials_file(self) -> typing.Optional[str]:
        return jsii.get(self, "sharedCredentialsFile")

    @shared_credentials_file.setter
    def shared_credentials_file(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sharedCredentialsFile", value)

    @builtins.property
    @jsii.member(jsii_name="skipCredentialsValidation")
    def skip_credentials_validation(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipCredentialsValidation")

    @skip_credentials_validation.setter
    def skip_credentials_validation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipCredentialsValidation", value)

    @builtins.property
    @jsii.member(jsii_name="skipGetEc2Platforms")
    def skip_get_ec2_platforms(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipGetEc2Platforms")

    @skip_get_ec2_platforms.setter
    def skip_get_ec2_platforms(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipGetEc2Platforms", value)

    @builtins.property
    @jsii.member(jsii_name="skipMetadataApiCheck")
    def skip_metadata_api_check(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipMetadataApiCheck")

    @skip_metadata_api_check.setter
    def skip_metadata_api_check(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipMetadataApiCheck", value)

    @builtins.property
    @jsii.member(jsii_name="skipRegionValidation")
    def skip_region_validation(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipRegionValidation")

    @skip_region_validation.setter
    def skip_region_validation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipRegionValidation", value)

    @builtins.property
    @jsii.member(jsii_name="skipRequestingAccountId")
    def skip_requesting_account_id(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipRequestingAccountId")

    @skip_requesting_account_id.setter
    def skip_requesting_account_id(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipRequestingAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="token")
    def token(self) -> typing.Optional[str]:
        return jsii.get(self, "token")

    @token.setter
    def token(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "token", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AwsProviderAssumeRole",
    jsii_struct_bases=[],
    name_mapping={
        "external_id": "externalId",
        "policy": "policy",
        "role_arn": "roleArn",
        "session_name": "sessionName",
    },
)
class AwsProviderAssumeRole:
    def __init__(
        self,
        *,
        external_id: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
        session_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param external_id: The external ID to use when assuming the role. If omitted, no external ID is passed to the AssumeRole call.
        :param policy: The permissions applied when assuming a role. You cannot use, this policy to grant further permissions that are in excess to those of the, role that is being assumed.
        :param role_arn: The ARN of an IAM role to assume prior to making API calls.
        :param session_name: The session name to use when assuming the role. If omitted, no session name is passed to the AssumeRole call.
        """
        self._values = {}
        if external_id is not None:
            self._values["external_id"] = external_id
        if policy is not None:
            self._values["policy"] = policy
        if role_arn is not None:
            self._values["role_arn"] = role_arn
        if session_name is not None:
            self._values["session_name"] = session_name

    @builtins.property
    def external_id(self) -> typing.Optional[str]:
        """The external ID to use when assuming the role.

        If omitted, no external ID is passed to the AssumeRole call.
        """
        return self._values.get("external_id")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        """The permissions applied when assuming a role.

        You cannot use, this policy to grant further permissions that are in excess to those of the,  role that is being assumed.
        """
        return self._values.get("policy")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        """The ARN of an IAM role to assume prior to making API calls."""
        return self._values.get("role_arn")

    @builtins.property
    def session_name(self) -> typing.Optional[str]:
        """The session name to use when assuming the role.

        If omitted, no session name is passed to the AssumeRole call.
        """
        return self._values.get("session_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AwsProviderAssumeRole(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AwsProviderConfig",
    jsii_struct_bases=[],
    name_mapping={
        "region": "region",
        "access_key": "accessKey",
        "alias": "alias",
        "allowed_account_ids": "allowedAccountIds",
        "assume_role": "assumeRole",
        "endpoints": "endpoints",
        "forbidden_account_ids": "forbiddenAccountIds",
        "ignore_tags": "ignoreTags",
        "insecure": "insecure",
        "max_retries": "maxRetries",
        "profile": "profile",
        "s3_force_path_style": "s3ForcePathStyle",
        "secret_key": "secretKey",
        "shared_credentials_file": "sharedCredentialsFile",
        "skip_credentials_validation": "skipCredentialsValidation",
        "skip_get_ec2_platforms": "skipGetEc2Platforms",
        "skip_metadata_api_check": "skipMetadataApiCheck",
        "skip_region_validation": "skipRegionValidation",
        "skip_requesting_account_id": "skipRequestingAccountId",
        "token": "token",
    },
)
class AwsProviderConfig:
    def __init__(
        self,
        *,
        region: str,
        access_key: typing.Optional[str] = None,
        alias: typing.Optional[str] = None,
        allowed_account_ids: typing.Optional[typing.List[str]] = None,
        assume_role: typing.Optional[typing.List["AwsProviderAssumeRole"]] = None,
        endpoints: typing.Optional[typing.List["AwsProviderEndpoints"]] = None,
        forbidden_account_ids: typing.Optional[typing.List[str]] = None,
        ignore_tags: typing.Optional[typing.List["AwsProviderIgnoreTags"]] = None,
        insecure: typing.Optional[bool] = None,
        max_retries: typing.Optional[jsii.Number] = None,
        profile: typing.Optional[str] = None,
        s3_force_path_style: typing.Optional[bool] = None,
        secret_key: typing.Optional[str] = None,
        shared_credentials_file: typing.Optional[str] = None,
        skip_credentials_validation: typing.Optional[bool] = None,
        skip_get_ec2_platforms: typing.Optional[bool] = None,
        skip_metadata_api_check: typing.Optional[bool] = None,
        skip_region_validation: typing.Optional[bool] = None,
        skip_requesting_account_id: typing.Optional[bool] = None,
        token: typing.Optional[str] = None,
    ) -> None:
        """
        :param region: The region where AWS operations will take place. Examples are us-east-1, us-west-2, etc.
        :param access_key: The access key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
        :param alias: Alias name.
        :param allowed_account_ids: 
        :param assume_role: assume_role block.
        :param endpoints: endpoints block.
        :param forbidden_account_ids: 
        :param ignore_tags: ignore_tags block.
        :param insecure: Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is ``false``
        :param max_retries: The maximum number of times an AWS API request is being executed. If the API request still fails, an error is thrown.
        :param profile: The profile for API operations. If not set, the default profile created with ``aws configure`` will be used.
        :param s3_force_path_style: Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY). Specific to the Amazon S3 service.
        :param secret_key: The secret key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
        :param shared_credentials_file: The path to the shared credentials file. If not set this defaults to ~/.aws/credentials.
        :param skip_credentials_validation: Skip the credentials validation via STS API. Used for AWS API implementations that do not have STS available/implemented.
        :param skip_get_ec2_platforms: Skip getting the supported EC2 platforms. Used by users that don't have ec2:DescribeAccountAttributes permissions.
        :param skip_metadata_api_check: 
        :param skip_region_validation: Skip static validation of region name. Used by users of alternative AWS-like APIs or users w/ access to regions that are not public (yet).
        :param skip_requesting_account_id: Skip requesting the account ID. Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
        :param token: session token. A session token is only required if you are using temporary security credentials.
        """
        self._values = {
            "region": region,
        }
        if access_key is not None:
            self._values["access_key"] = access_key
        if alias is not None:
            self._values["alias"] = alias
        if allowed_account_ids is not None:
            self._values["allowed_account_ids"] = allowed_account_ids
        if assume_role is not None:
            self._values["assume_role"] = assume_role
        if endpoints is not None:
            self._values["endpoints"] = endpoints
        if forbidden_account_ids is not None:
            self._values["forbidden_account_ids"] = forbidden_account_ids
        if ignore_tags is not None:
            self._values["ignore_tags"] = ignore_tags
        if insecure is not None:
            self._values["insecure"] = insecure
        if max_retries is not None:
            self._values["max_retries"] = max_retries
        if profile is not None:
            self._values["profile"] = profile
        if s3_force_path_style is not None:
            self._values["s3_force_path_style"] = s3_force_path_style
        if secret_key is not None:
            self._values["secret_key"] = secret_key
        if shared_credentials_file is not None:
            self._values["shared_credentials_file"] = shared_credentials_file
        if skip_credentials_validation is not None:
            self._values["skip_credentials_validation"] = skip_credentials_validation
        if skip_get_ec2_platforms is not None:
            self._values["skip_get_ec2_platforms"] = skip_get_ec2_platforms
        if skip_metadata_api_check is not None:
            self._values["skip_metadata_api_check"] = skip_metadata_api_check
        if skip_region_validation is not None:
            self._values["skip_region_validation"] = skip_region_validation
        if skip_requesting_account_id is not None:
            self._values["skip_requesting_account_id"] = skip_requesting_account_id
        if token is not None:
            self._values["token"] = token

    @builtins.property
    def region(self) -> str:
        """The region where AWS operations will take place.

        Examples
        are us-east-1, us-west-2, etc.
        """
        return self._values.get("region")

    @builtins.property
    def access_key(self) -> typing.Optional[str]:
        """The access key for API operations.

        You can retrieve this
        from the 'Security & Credentials' section of the AWS console.
        """
        return self._values.get("access_key")

    @builtins.property
    def alias(self) -> typing.Optional[str]:
        """Alias name."""
        return self._values.get("alias")

    @builtins.property
    def allowed_account_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allowed_account_ids")

    @builtins.property
    def assume_role(self) -> typing.Optional[typing.List["AwsProviderAssumeRole"]]:
        """assume_role block."""
        return self._values.get("assume_role")

    @builtins.property
    def endpoints(self) -> typing.Optional[typing.List["AwsProviderEndpoints"]]:
        """endpoints block."""
        return self._values.get("endpoints")

    @builtins.property
    def forbidden_account_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("forbidden_account_ids")

    @builtins.property
    def ignore_tags(self) -> typing.Optional[typing.List["AwsProviderIgnoreTags"]]:
        """ignore_tags block."""
        return self._values.get("ignore_tags")

    @builtins.property
    def insecure(self) -> typing.Optional[bool]:
        """Explicitly allow the provider to perform "insecure" SSL requests.

        If omitted,default value is ``false``
        """
        return self._values.get("insecure")

    @builtins.property
    def max_retries(self) -> typing.Optional[jsii.Number]:
        """The maximum number of times an AWS API request is being executed.

        If the API request still fails, an error is
        thrown.
        """
        return self._values.get("max_retries")

    @builtins.property
    def profile(self) -> typing.Optional[str]:
        """The profile for API operations.

        If not set, the default profile
        created with ``aws configure`` will be used.
        """
        return self._values.get("profile")

    @builtins.property
    def s3_force_path_style(self) -> typing.Optional[bool]:
        """Set this to true to force the request to use path-style addressing, i.e., http://s3.amazonaws.com/BUCKET/KEY. By default, the S3 client will use virtual hosted bucket addressing when possible (http://BUCKET.s3.amazonaws.com/KEY). Specific to the Amazon S3 service."""
        return self._values.get("s3_force_path_style")

    @builtins.property
    def secret_key(self) -> typing.Optional[str]:
        """The secret key for API operations.

        You can retrieve this
        from the 'Security & Credentials' section of the AWS console.
        """
        return self._values.get("secret_key")

    @builtins.property
    def shared_credentials_file(self) -> typing.Optional[str]:
        """The path to the shared credentials file.

        If not set
        this defaults to ~/.aws/credentials.
        """
        return self._values.get("shared_credentials_file")

    @builtins.property
    def skip_credentials_validation(self) -> typing.Optional[bool]:
        """Skip the credentials validation via STS API.

        Used for AWS API implementations that do not have STS available/implemented.
        """
        return self._values.get("skip_credentials_validation")

    @builtins.property
    def skip_get_ec2_platforms(self) -> typing.Optional[bool]:
        """Skip getting the supported EC2 platforms.

        Used by users that don't have ec2:DescribeAccountAttributes permissions.
        """
        return self._values.get("skip_get_ec2_platforms")

    @builtins.property
    def skip_metadata_api_check(self) -> typing.Optional[bool]:
        return self._values.get("skip_metadata_api_check")

    @builtins.property
    def skip_region_validation(self) -> typing.Optional[bool]:
        """Skip static validation of region name.

        Used by users of alternative AWS-like APIs or users w/ access to regions that are not public (yet).
        """
        return self._values.get("skip_region_validation")

    @builtins.property
    def skip_requesting_account_id(self) -> typing.Optional[bool]:
        """Skip requesting the account ID.

        Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
        """
        return self._values.get("skip_requesting_account_id")

    @builtins.property
    def token(self) -> typing.Optional[str]:
        """session token.

        A session token is only required if you are
        using temporary security credentials.
        """
        return self._values.get("token")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AwsProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AwsProviderEndpoints",
    jsii_struct_bases=[],
    name_mapping={
        "accessanalyzer": "accessanalyzer",
        "acm": "acm",
        "acmpca": "acmpca",
        "amplify": "amplify",
        "apigateway": "apigateway",
        "applicationautoscaling": "applicationautoscaling",
        "applicationinsights": "applicationinsights",
        "appmesh": "appmesh",
        "appstream": "appstream",
        "appsync": "appsync",
        "athena": "athena",
        "autoscaling": "autoscaling",
        "autoscalingplans": "autoscalingplans",
        "backup": "backup",
        "batch": "batch",
        "budgets": "budgets",
        "cloud9": "cloud9",
        "cloudformation": "cloudformation",
        "cloudfront": "cloudfront",
        "cloudhsm": "cloudhsm",
        "cloudsearch": "cloudsearch",
        "cloudtrail": "cloudtrail",
        "cloudwatch": "cloudwatch",
        "cloudwatchevents": "cloudwatchevents",
        "cloudwatchlogs": "cloudwatchlogs",
        "codeartifact": "codeartifact",
        "codebuild": "codebuild",
        "codecommit": "codecommit",
        "codedeploy": "codedeploy",
        "codepipeline": "codepipeline",
        "cognitoidentity": "cognitoidentity",
        "cognitoidp": "cognitoidp",
        "configservice": "configservice",
        "cur": "cur",
        "dataexchange": "dataexchange",
        "datapipeline": "datapipeline",
        "datasync": "datasync",
        "dax": "dax",
        "devicefarm": "devicefarm",
        "directconnect": "directconnect",
        "dlm": "dlm",
        "dms": "dms",
        "docdb": "docdb",
        "ds": "ds",
        "dynamodb": "dynamodb",
        "ec2": "ec2",
        "ecr": "ecr",
        "ecs": "ecs",
        "efs": "efs",
        "eks": "eks",
        "elasticache": "elasticache",
        "elasticbeanstalk": "elasticbeanstalk",
        "elastictranscoder": "elastictranscoder",
        "elb": "elb",
        "emr": "emr",
        "es": "es",
        "firehose": "firehose",
        "fms": "fms",
        "forecast": "forecast",
        "fsx": "fsx",
        "gamelift": "gamelift",
        "glacier": "glacier",
        "globalaccelerator": "globalaccelerator",
        "glue": "glue",
        "greengrass": "greengrass",
        "guardduty": "guardduty",
        "iam": "iam",
        "imagebuilder": "imagebuilder",
        "inspector": "inspector",
        "iot": "iot",
        "iotanalytics": "iotanalytics",
        "iotevents": "iotevents",
        "kafka": "kafka",
        "kinesis": "kinesis",
        "kinesisanalytics": "kinesisanalytics",
        "kinesis_analytics": "kinesisAnalytics",
        "kinesisanalyticsv2": "kinesisanalyticsv2",
        "kinesisvideo": "kinesisvideo",
        "kms": "kms",
        "lakeformation": "lakeformation",
        "lambda_": "lambda",
        "lexmodels": "lexmodels",
        "licensemanager": "licensemanager",
        "lightsail": "lightsail",
        "macie": "macie",
        "managedblockchain": "managedblockchain",
        "marketplacecatalog": "marketplacecatalog",
        "mediaconnect": "mediaconnect",
        "mediaconvert": "mediaconvert",
        "medialive": "medialive",
        "mediapackage": "mediapackage",
        "mediastore": "mediastore",
        "mediastoredata": "mediastoredata",
        "mq": "mq",
        "neptune": "neptune",
        "networkmanager": "networkmanager",
        "opsworks": "opsworks",
        "organizations": "organizations",
        "outposts": "outposts",
        "personalize": "personalize",
        "pinpoint": "pinpoint",
        "pricing": "pricing",
        "qldb": "qldb",
        "quicksight": "quicksight",
        "r53": "r53",
        "ram": "ram",
        "rds": "rds",
        "redshift": "redshift",
        "resourcegroups": "resourcegroups",
        "resourcegroupstaggingapi": "resourcegroupstaggingapi",
        "route53": "route53",
        "route53_domains": "route53Domains",
        "route53_resolver": "route53Resolver",
        "s3": "s3",
        "s3_control": "s3Control",
        "sagemaker": "sagemaker",
        "sdb": "sdb",
        "secretsmanager": "secretsmanager",
        "securityhub": "securityhub",
        "serverlessrepo": "serverlessrepo",
        "servicecatalog": "servicecatalog",
        "servicediscovery": "servicediscovery",
        "servicequotas": "servicequotas",
        "ses": "ses",
        "shield": "shield",
        "sns": "sns",
        "sqs": "sqs",
        "ssm": "ssm",
        "stepfunctions": "stepfunctions",
        "storagegateway": "storagegateway",
        "sts": "sts",
        "swf": "swf",
        "synthetics": "synthetics",
        "transfer": "transfer",
        "waf": "waf",
        "wafregional": "wafregional",
        "wafv2": "wafv2",
        "worklink": "worklink",
        "workmail": "workmail",
        "workspaces": "workspaces",
        "xray": "xray",
    },
)
class AwsProviderEndpoints:
    def __init__(
        self,
        *,
        accessanalyzer: typing.Optional[str] = None,
        acm: typing.Optional[str] = None,
        acmpca: typing.Optional[str] = None,
        amplify: typing.Optional[str] = None,
        apigateway: typing.Optional[str] = None,
        applicationautoscaling: typing.Optional[str] = None,
        applicationinsights: typing.Optional[str] = None,
        appmesh: typing.Optional[str] = None,
        appstream: typing.Optional[str] = None,
        appsync: typing.Optional[str] = None,
        athena: typing.Optional[str] = None,
        autoscaling: typing.Optional[str] = None,
        autoscalingplans: typing.Optional[str] = None,
        backup: typing.Optional[str] = None,
        batch: typing.Optional[str] = None,
        budgets: typing.Optional[str] = None,
        cloud9: typing.Optional[str] = None,
        cloudformation: typing.Optional[str] = None,
        cloudfront: typing.Optional[str] = None,
        cloudhsm: typing.Optional[str] = None,
        cloudsearch: typing.Optional[str] = None,
        cloudtrail: typing.Optional[str] = None,
        cloudwatch: typing.Optional[str] = None,
        cloudwatchevents: typing.Optional[str] = None,
        cloudwatchlogs: typing.Optional[str] = None,
        codeartifact: typing.Optional[str] = None,
        codebuild: typing.Optional[str] = None,
        codecommit: typing.Optional[str] = None,
        codedeploy: typing.Optional[str] = None,
        codepipeline: typing.Optional[str] = None,
        cognitoidentity: typing.Optional[str] = None,
        cognitoidp: typing.Optional[str] = None,
        configservice: typing.Optional[str] = None,
        cur: typing.Optional[str] = None,
        dataexchange: typing.Optional[str] = None,
        datapipeline: typing.Optional[str] = None,
        datasync: typing.Optional[str] = None,
        dax: typing.Optional[str] = None,
        devicefarm: typing.Optional[str] = None,
        directconnect: typing.Optional[str] = None,
        dlm: typing.Optional[str] = None,
        dms: typing.Optional[str] = None,
        docdb: typing.Optional[str] = None,
        ds: typing.Optional[str] = None,
        dynamodb: typing.Optional[str] = None,
        ec2: typing.Optional[str] = None,
        ecr: typing.Optional[str] = None,
        ecs: typing.Optional[str] = None,
        efs: typing.Optional[str] = None,
        eks: typing.Optional[str] = None,
        elasticache: typing.Optional[str] = None,
        elasticbeanstalk: typing.Optional[str] = None,
        elastictranscoder: typing.Optional[str] = None,
        elb: typing.Optional[str] = None,
        emr: typing.Optional[str] = None,
        es: typing.Optional[str] = None,
        firehose: typing.Optional[str] = None,
        fms: typing.Optional[str] = None,
        forecast: typing.Optional[str] = None,
        fsx: typing.Optional[str] = None,
        gamelift: typing.Optional[str] = None,
        glacier: typing.Optional[str] = None,
        globalaccelerator: typing.Optional[str] = None,
        glue: typing.Optional[str] = None,
        greengrass: typing.Optional[str] = None,
        guardduty: typing.Optional[str] = None,
        iam: typing.Optional[str] = None,
        imagebuilder: typing.Optional[str] = None,
        inspector: typing.Optional[str] = None,
        iot: typing.Optional[str] = None,
        iotanalytics: typing.Optional[str] = None,
        iotevents: typing.Optional[str] = None,
        kafka: typing.Optional[str] = None,
        kinesis: typing.Optional[str] = None,
        kinesisanalytics: typing.Optional[str] = None,
        kinesis_analytics: typing.Optional[str] = None,
        kinesisanalyticsv2: typing.Optional[str] = None,
        kinesisvideo: typing.Optional[str] = None,
        kms: typing.Optional[str] = None,
        lakeformation: typing.Optional[str] = None,
        lambda_: typing.Optional[str] = None,
        lexmodels: typing.Optional[str] = None,
        licensemanager: typing.Optional[str] = None,
        lightsail: typing.Optional[str] = None,
        macie: typing.Optional[str] = None,
        managedblockchain: typing.Optional[str] = None,
        marketplacecatalog: typing.Optional[str] = None,
        mediaconnect: typing.Optional[str] = None,
        mediaconvert: typing.Optional[str] = None,
        medialive: typing.Optional[str] = None,
        mediapackage: typing.Optional[str] = None,
        mediastore: typing.Optional[str] = None,
        mediastoredata: typing.Optional[str] = None,
        mq: typing.Optional[str] = None,
        neptune: typing.Optional[str] = None,
        networkmanager: typing.Optional[str] = None,
        opsworks: typing.Optional[str] = None,
        organizations: typing.Optional[str] = None,
        outposts: typing.Optional[str] = None,
        personalize: typing.Optional[str] = None,
        pinpoint: typing.Optional[str] = None,
        pricing: typing.Optional[str] = None,
        qldb: typing.Optional[str] = None,
        quicksight: typing.Optional[str] = None,
        r53: typing.Optional[str] = None,
        ram: typing.Optional[str] = None,
        rds: typing.Optional[str] = None,
        redshift: typing.Optional[str] = None,
        resourcegroups: typing.Optional[str] = None,
        resourcegroupstaggingapi: typing.Optional[str] = None,
        route53: typing.Optional[str] = None,
        route53_domains: typing.Optional[str] = None,
        route53_resolver: typing.Optional[str] = None,
        s3: typing.Optional[str] = None,
        s3_control: typing.Optional[str] = None,
        sagemaker: typing.Optional[str] = None,
        sdb: typing.Optional[str] = None,
        secretsmanager: typing.Optional[str] = None,
        securityhub: typing.Optional[str] = None,
        serverlessrepo: typing.Optional[str] = None,
        servicecatalog: typing.Optional[str] = None,
        servicediscovery: typing.Optional[str] = None,
        servicequotas: typing.Optional[str] = None,
        ses: typing.Optional[str] = None,
        shield: typing.Optional[str] = None,
        sns: typing.Optional[str] = None,
        sqs: typing.Optional[str] = None,
        ssm: typing.Optional[str] = None,
        stepfunctions: typing.Optional[str] = None,
        storagegateway: typing.Optional[str] = None,
        sts: typing.Optional[str] = None,
        swf: typing.Optional[str] = None,
        synthetics: typing.Optional[str] = None,
        transfer: typing.Optional[str] = None,
        waf: typing.Optional[str] = None,
        wafregional: typing.Optional[str] = None,
        wafv2: typing.Optional[str] = None,
        worklink: typing.Optional[str] = None,
        workmail: typing.Optional[str] = None,
        workspaces: typing.Optional[str] = None,
        xray: typing.Optional[str] = None,
    ) -> None:
        """
        :param accessanalyzer: Use this to override the default service endpoint URL.
        :param acm: Use this to override the default service endpoint URL.
        :param acmpca: Use this to override the default service endpoint URL.
        :param amplify: Use this to override the default service endpoint URL.
        :param apigateway: Use this to override the default service endpoint URL.
        :param applicationautoscaling: Use this to override the default service endpoint URL.
        :param applicationinsights: Use this to override the default service endpoint URL.
        :param appmesh: Use this to override the default service endpoint URL.
        :param appstream: Use this to override the default service endpoint URL.
        :param appsync: Use this to override the default service endpoint URL.
        :param athena: Use this to override the default service endpoint URL.
        :param autoscaling: Use this to override the default service endpoint URL.
        :param autoscalingplans: Use this to override the default service endpoint URL.
        :param backup: Use this to override the default service endpoint URL.
        :param batch: Use this to override the default service endpoint URL.
        :param budgets: Use this to override the default service endpoint URL.
        :param cloud9: Use this to override the default service endpoint URL.
        :param cloudformation: Use this to override the default service endpoint URL.
        :param cloudfront: Use this to override the default service endpoint URL.
        :param cloudhsm: Use this to override the default service endpoint URL.
        :param cloudsearch: Use this to override the default service endpoint URL.
        :param cloudtrail: Use this to override the default service endpoint URL.
        :param cloudwatch: Use this to override the default service endpoint URL.
        :param cloudwatchevents: Use this to override the default service endpoint URL.
        :param cloudwatchlogs: Use this to override the default service endpoint URL.
        :param codeartifact: Use this to override the default service endpoint URL.
        :param codebuild: Use this to override the default service endpoint URL.
        :param codecommit: Use this to override the default service endpoint URL.
        :param codedeploy: Use this to override the default service endpoint URL.
        :param codepipeline: Use this to override the default service endpoint URL.
        :param cognitoidentity: Use this to override the default service endpoint URL.
        :param cognitoidp: Use this to override the default service endpoint URL.
        :param configservice: Use this to override the default service endpoint URL.
        :param cur: Use this to override the default service endpoint URL.
        :param dataexchange: Use this to override the default service endpoint URL.
        :param datapipeline: Use this to override the default service endpoint URL.
        :param datasync: Use this to override the default service endpoint URL.
        :param dax: Use this to override the default service endpoint URL.
        :param devicefarm: Use this to override the default service endpoint URL.
        :param directconnect: Use this to override the default service endpoint URL.
        :param dlm: Use this to override the default service endpoint URL.
        :param dms: Use this to override the default service endpoint URL.
        :param docdb: Use this to override the default service endpoint URL.
        :param ds: Use this to override the default service endpoint URL.
        :param dynamodb: Use this to override the default service endpoint URL.
        :param ec2: Use this to override the default service endpoint URL.
        :param ecr: Use this to override the default service endpoint URL.
        :param ecs: Use this to override the default service endpoint URL.
        :param efs: Use this to override the default service endpoint URL.
        :param eks: Use this to override the default service endpoint URL.
        :param elasticache: Use this to override the default service endpoint URL.
        :param elasticbeanstalk: Use this to override the default service endpoint URL.
        :param elastictranscoder: Use this to override the default service endpoint URL.
        :param elb: Use this to override the default service endpoint URL.
        :param emr: Use this to override the default service endpoint URL.
        :param es: Use this to override the default service endpoint URL.
        :param firehose: Use this to override the default service endpoint URL.
        :param fms: Use this to override the default service endpoint URL.
        :param forecast: Use this to override the default service endpoint URL.
        :param fsx: Use this to override the default service endpoint URL.
        :param gamelift: Use this to override the default service endpoint URL.
        :param glacier: Use this to override the default service endpoint URL.
        :param globalaccelerator: Use this to override the default service endpoint URL.
        :param glue: Use this to override the default service endpoint URL.
        :param greengrass: Use this to override the default service endpoint URL.
        :param guardduty: Use this to override the default service endpoint URL.
        :param iam: Use this to override the default service endpoint URL.
        :param imagebuilder: Use this to override the default service endpoint URL.
        :param inspector: Use this to override the default service endpoint URL.
        :param iot: Use this to override the default service endpoint URL.
        :param iotanalytics: Use this to override the default service endpoint URL.
        :param iotevents: Use this to override the default service endpoint URL.
        :param kafka: Use this to override the default service endpoint URL.
        :param kinesis: Use this to override the default service endpoint URL.
        :param kinesisanalytics: Use this to override the default service endpoint URL.
        :param kinesis_analytics: Use this to override the default service endpoint URL.
        :param kinesisanalyticsv2: Use this to override the default service endpoint URL.
        :param kinesisvideo: Use this to override the default service endpoint URL.
        :param kms: Use this to override the default service endpoint URL.
        :param lakeformation: Use this to override the default service endpoint URL.
        :param lambda_: Use this to override the default service endpoint URL.
        :param lexmodels: Use this to override the default service endpoint URL.
        :param licensemanager: Use this to override the default service endpoint URL.
        :param lightsail: Use this to override the default service endpoint URL.
        :param macie: Use this to override the default service endpoint URL.
        :param managedblockchain: Use this to override the default service endpoint URL.
        :param marketplacecatalog: Use this to override the default service endpoint URL.
        :param mediaconnect: Use this to override the default service endpoint URL.
        :param mediaconvert: Use this to override the default service endpoint URL.
        :param medialive: Use this to override the default service endpoint URL.
        :param mediapackage: Use this to override the default service endpoint URL.
        :param mediastore: Use this to override the default service endpoint URL.
        :param mediastoredata: Use this to override the default service endpoint URL.
        :param mq: Use this to override the default service endpoint URL.
        :param neptune: Use this to override the default service endpoint URL.
        :param networkmanager: Use this to override the default service endpoint URL.
        :param opsworks: Use this to override the default service endpoint URL.
        :param organizations: Use this to override the default service endpoint URL.
        :param outposts: Use this to override the default service endpoint URL.
        :param personalize: Use this to override the default service endpoint URL.
        :param pinpoint: Use this to override the default service endpoint URL.
        :param pricing: Use this to override the default service endpoint URL.
        :param qldb: Use this to override the default service endpoint URL.
        :param quicksight: Use this to override the default service endpoint URL.
        :param r53: Use this to override the default service endpoint URL.
        :param ram: Use this to override the default service endpoint URL.
        :param rds: Use this to override the default service endpoint URL.
        :param redshift: Use this to override the default service endpoint URL.
        :param resourcegroups: Use this to override the default service endpoint URL.
        :param resourcegroupstaggingapi: Use this to override the default service endpoint URL.
        :param route53: Use this to override the default service endpoint URL.
        :param route53_domains: Use this to override the default service endpoint URL.
        :param route53_resolver: Use this to override the default service endpoint URL.
        :param s3: Use this to override the default service endpoint URL.
        :param s3_control: Use this to override the default service endpoint URL.
        :param sagemaker: Use this to override the default service endpoint URL.
        :param sdb: Use this to override the default service endpoint URL.
        :param secretsmanager: Use this to override the default service endpoint URL.
        :param securityhub: Use this to override the default service endpoint URL.
        :param serverlessrepo: Use this to override the default service endpoint URL.
        :param servicecatalog: Use this to override the default service endpoint URL.
        :param servicediscovery: Use this to override the default service endpoint URL.
        :param servicequotas: Use this to override the default service endpoint URL.
        :param ses: Use this to override the default service endpoint URL.
        :param shield: Use this to override the default service endpoint URL.
        :param sns: Use this to override the default service endpoint URL.
        :param sqs: Use this to override the default service endpoint URL.
        :param ssm: Use this to override the default service endpoint URL.
        :param stepfunctions: Use this to override the default service endpoint URL.
        :param storagegateway: Use this to override the default service endpoint URL.
        :param sts: Use this to override the default service endpoint URL.
        :param swf: Use this to override the default service endpoint URL.
        :param synthetics: Use this to override the default service endpoint URL.
        :param transfer: Use this to override the default service endpoint URL.
        :param waf: Use this to override the default service endpoint URL.
        :param wafregional: Use this to override the default service endpoint URL.
        :param wafv2: Use this to override the default service endpoint URL.
        :param worklink: Use this to override the default service endpoint URL.
        :param workmail: Use this to override the default service endpoint URL.
        :param workspaces: Use this to override the default service endpoint URL.
        :param xray: Use this to override the default service endpoint URL.
        """
        self._values = {}
        if accessanalyzer is not None:
            self._values["accessanalyzer"] = accessanalyzer
        if acm is not None:
            self._values["acm"] = acm
        if acmpca is not None:
            self._values["acmpca"] = acmpca
        if amplify is not None:
            self._values["amplify"] = amplify
        if apigateway is not None:
            self._values["apigateway"] = apigateway
        if applicationautoscaling is not None:
            self._values["applicationautoscaling"] = applicationautoscaling
        if applicationinsights is not None:
            self._values["applicationinsights"] = applicationinsights
        if appmesh is not None:
            self._values["appmesh"] = appmesh
        if appstream is not None:
            self._values["appstream"] = appstream
        if appsync is not None:
            self._values["appsync"] = appsync
        if athena is not None:
            self._values["athena"] = athena
        if autoscaling is not None:
            self._values["autoscaling"] = autoscaling
        if autoscalingplans is not None:
            self._values["autoscalingplans"] = autoscalingplans
        if backup is not None:
            self._values["backup"] = backup
        if batch is not None:
            self._values["batch"] = batch
        if budgets is not None:
            self._values["budgets"] = budgets
        if cloud9 is not None:
            self._values["cloud9"] = cloud9
        if cloudformation is not None:
            self._values["cloudformation"] = cloudformation
        if cloudfront is not None:
            self._values["cloudfront"] = cloudfront
        if cloudhsm is not None:
            self._values["cloudhsm"] = cloudhsm
        if cloudsearch is not None:
            self._values["cloudsearch"] = cloudsearch
        if cloudtrail is not None:
            self._values["cloudtrail"] = cloudtrail
        if cloudwatch is not None:
            self._values["cloudwatch"] = cloudwatch
        if cloudwatchevents is not None:
            self._values["cloudwatchevents"] = cloudwatchevents
        if cloudwatchlogs is not None:
            self._values["cloudwatchlogs"] = cloudwatchlogs
        if codeartifact is not None:
            self._values["codeartifact"] = codeartifact
        if codebuild is not None:
            self._values["codebuild"] = codebuild
        if codecommit is not None:
            self._values["codecommit"] = codecommit
        if codedeploy is not None:
            self._values["codedeploy"] = codedeploy
        if codepipeline is not None:
            self._values["codepipeline"] = codepipeline
        if cognitoidentity is not None:
            self._values["cognitoidentity"] = cognitoidentity
        if cognitoidp is not None:
            self._values["cognitoidp"] = cognitoidp
        if configservice is not None:
            self._values["configservice"] = configservice
        if cur is not None:
            self._values["cur"] = cur
        if dataexchange is not None:
            self._values["dataexchange"] = dataexchange
        if datapipeline is not None:
            self._values["datapipeline"] = datapipeline
        if datasync is not None:
            self._values["datasync"] = datasync
        if dax is not None:
            self._values["dax"] = dax
        if devicefarm is not None:
            self._values["devicefarm"] = devicefarm
        if directconnect is not None:
            self._values["directconnect"] = directconnect
        if dlm is not None:
            self._values["dlm"] = dlm
        if dms is not None:
            self._values["dms"] = dms
        if docdb is not None:
            self._values["docdb"] = docdb
        if ds is not None:
            self._values["ds"] = ds
        if dynamodb is not None:
            self._values["dynamodb"] = dynamodb
        if ec2 is not None:
            self._values["ec2"] = ec2
        if ecr is not None:
            self._values["ecr"] = ecr
        if ecs is not None:
            self._values["ecs"] = ecs
        if efs is not None:
            self._values["efs"] = efs
        if eks is not None:
            self._values["eks"] = eks
        if elasticache is not None:
            self._values["elasticache"] = elasticache
        if elasticbeanstalk is not None:
            self._values["elasticbeanstalk"] = elasticbeanstalk
        if elastictranscoder is not None:
            self._values["elastictranscoder"] = elastictranscoder
        if elb is not None:
            self._values["elb"] = elb
        if emr is not None:
            self._values["emr"] = emr
        if es is not None:
            self._values["es"] = es
        if firehose is not None:
            self._values["firehose"] = firehose
        if fms is not None:
            self._values["fms"] = fms
        if forecast is not None:
            self._values["forecast"] = forecast
        if fsx is not None:
            self._values["fsx"] = fsx
        if gamelift is not None:
            self._values["gamelift"] = gamelift
        if glacier is not None:
            self._values["glacier"] = glacier
        if globalaccelerator is not None:
            self._values["globalaccelerator"] = globalaccelerator
        if glue is not None:
            self._values["glue"] = glue
        if greengrass is not None:
            self._values["greengrass"] = greengrass
        if guardduty is not None:
            self._values["guardduty"] = guardduty
        if iam is not None:
            self._values["iam"] = iam
        if imagebuilder is not None:
            self._values["imagebuilder"] = imagebuilder
        if inspector is not None:
            self._values["inspector"] = inspector
        if iot is not None:
            self._values["iot"] = iot
        if iotanalytics is not None:
            self._values["iotanalytics"] = iotanalytics
        if iotevents is not None:
            self._values["iotevents"] = iotevents
        if kafka is not None:
            self._values["kafka"] = kafka
        if kinesis is not None:
            self._values["kinesis"] = kinesis
        if kinesisanalytics is not None:
            self._values["kinesisanalytics"] = kinesisanalytics
        if kinesis_analytics is not None:
            self._values["kinesis_analytics"] = kinesis_analytics
        if kinesisanalyticsv2 is not None:
            self._values["kinesisanalyticsv2"] = kinesisanalyticsv2
        if kinesisvideo is not None:
            self._values["kinesisvideo"] = kinesisvideo
        if kms is not None:
            self._values["kms"] = kms
        if lakeformation is not None:
            self._values["lakeformation"] = lakeformation
        if lambda_ is not None:
            self._values["lambda_"] = lambda_
        if lexmodels is not None:
            self._values["lexmodels"] = lexmodels
        if licensemanager is not None:
            self._values["licensemanager"] = licensemanager
        if lightsail is not None:
            self._values["lightsail"] = lightsail
        if macie is not None:
            self._values["macie"] = macie
        if managedblockchain is not None:
            self._values["managedblockchain"] = managedblockchain
        if marketplacecatalog is not None:
            self._values["marketplacecatalog"] = marketplacecatalog
        if mediaconnect is not None:
            self._values["mediaconnect"] = mediaconnect
        if mediaconvert is not None:
            self._values["mediaconvert"] = mediaconvert
        if medialive is not None:
            self._values["medialive"] = medialive
        if mediapackage is not None:
            self._values["mediapackage"] = mediapackage
        if mediastore is not None:
            self._values["mediastore"] = mediastore
        if mediastoredata is not None:
            self._values["mediastoredata"] = mediastoredata
        if mq is not None:
            self._values["mq"] = mq
        if neptune is not None:
            self._values["neptune"] = neptune
        if networkmanager is not None:
            self._values["networkmanager"] = networkmanager
        if opsworks is not None:
            self._values["opsworks"] = opsworks
        if organizations is not None:
            self._values["organizations"] = organizations
        if outposts is not None:
            self._values["outposts"] = outposts
        if personalize is not None:
            self._values["personalize"] = personalize
        if pinpoint is not None:
            self._values["pinpoint"] = pinpoint
        if pricing is not None:
            self._values["pricing"] = pricing
        if qldb is not None:
            self._values["qldb"] = qldb
        if quicksight is not None:
            self._values["quicksight"] = quicksight
        if r53 is not None:
            self._values["r53"] = r53
        if ram is not None:
            self._values["ram"] = ram
        if rds is not None:
            self._values["rds"] = rds
        if redshift is not None:
            self._values["redshift"] = redshift
        if resourcegroups is not None:
            self._values["resourcegroups"] = resourcegroups
        if resourcegroupstaggingapi is not None:
            self._values["resourcegroupstaggingapi"] = resourcegroupstaggingapi
        if route53 is not None:
            self._values["route53"] = route53
        if route53_domains is not None:
            self._values["route53_domains"] = route53_domains
        if route53_resolver is not None:
            self._values["route53_resolver"] = route53_resolver
        if s3 is not None:
            self._values["s3"] = s3
        if s3_control is not None:
            self._values["s3_control"] = s3_control
        if sagemaker is not None:
            self._values["sagemaker"] = sagemaker
        if sdb is not None:
            self._values["sdb"] = sdb
        if secretsmanager is not None:
            self._values["secretsmanager"] = secretsmanager
        if securityhub is not None:
            self._values["securityhub"] = securityhub
        if serverlessrepo is not None:
            self._values["serverlessrepo"] = serverlessrepo
        if servicecatalog is not None:
            self._values["servicecatalog"] = servicecatalog
        if servicediscovery is not None:
            self._values["servicediscovery"] = servicediscovery
        if servicequotas is not None:
            self._values["servicequotas"] = servicequotas
        if ses is not None:
            self._values["ses"] = ses
        if shield is not None:
            self._values["shield"] = shield
        if sns is not None:
            self._values["sns"] = sns
        if sqs is not None:
            self._values["sqs"] = sqs
        if ssm is not None:
            self._values["ssm"] = ssm
        if stepfunctions is not None:
            self._values["stepfunctions"] = stepfunctions
        if storagegateway is not None:
            self._values["storagegateway"] = storagegateway
        if sts is not None:
            self._values["sts"] = sts
        if swf is not None:
            self._values["swf"] = swf
        if synthetics is not None:
            self._values["synthetics"] = synthetics
        if transfer is not None:
            self._values["transfer"] = transfer
        if waf is not None:
            self._values["waf"] = waf
        if wafregional is not None:
            self._values["wafregional"] = wafregional
        if wafv2 is not None:
            self._values["wafv2"] = wafv2
        if worklink is not None:
            self._values["worklink"] = worklink
        if workmail is not None:
            self._values["workmail"] = workmail
        if workspaces is not None:
            self._values["workspaces"] = workspaces
        if xray is not None:
            self._values["xray"] = xray

    @builtins.property
    def accessanalyzer(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("accessanalyzer")

    @builtins.property
    def acm(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("acm")

    @builtins.property
    def acmpca(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("acmpca")

    @builtins.property
    def amplify(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("amplify")

    @builtins.property
    def apigateway(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("apigateway")

    @builtins.property
    def applicationautoscaling(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("applicationautoscaling")

    @builtins.property
    def applicationinsights(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("applicationinsights")

    @builtins.property
    def appmesh(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("appmesh")

    @builtins.property
    def appstream(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("appstream")

    @builtins.property
    def appsync(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("appsync")

    @builtins.property
    def athena(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("athena")

    @builtins.property
    def autoscaling(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("autoscaling")

    @builtins.property
    def autoscalingplans(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("autoscalingplans")

    @builtins.property
    def backup(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("backup")

    @builtins.property
    def batch(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("batch")

    @builtins.property
    def budgets(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("budgets")

    @builtins.property
    def cloud9(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloud9")

    @builtins.property
    def cloudformation(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudformation")

    @builtins.property
    def cloudfront(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudfront")

    @builtins.property
    def cloudhsm(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudhsm")

    @builtins.property
    def cloudsearch(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudsearch")

    @builtins.property
    def cloudtrail(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudtrail")

    @builtins.property
    def cloudwatch(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudwatch")

    @builtins.property
    def cloudwatchevents(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudwatchevents")

    @builtins.property
    def cloudwatchlogs(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cloudwatchlogs")

    @builtins.property
    def codeartifact(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("codeartifact")

    @builtins.property
    def codebuild(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("codebuild")

    @builtins.property
    def codecommit(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("codecommit")

    @builtins.property
    def codedeploy(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("codedeploy")

    @builtins.property
    def codepipeline(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("codepipeline")

    @builtins.property
    def cognitoidentity(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cognitoidentity")

    @builtins.property
    def cognitoidp(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cognitoidp")

    @builtins.property
    def configservice(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("configservice")

    @builtins.property
    def cur(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("cur")

    @builtins.property
    def dataexchange(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("dataexchange")

    @builtins.property
    def datapipeline(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("datapipeline")

    @builtins.property
    def datasync(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("datasync")

    @builtins.property
    def dax(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("dax")

    @builtins.property
    def devicefarm(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("devicefarm")

    @builtins.property
    def directconnect(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("directconnect")

    @builtins.property
    def dlm(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("dlm")

    @builtins.property
    def dms(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("dms")

    @builtins.property
    def docdb(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("docdb")

    @builtins.property
    def ds(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("ds")

    @builtins.property
    def dynamodb(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("dynamodb")

    @builtins.property
    def ec2(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("ec2")

    @builtins.property
    def ecr(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("ecr")

    @builtins.property
    def ecs(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("ecs")

    @builtins.property
    def efs(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("efs")

    @builtins.property
    def eks(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("eks")

    @builtins.property
    def elasticache(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("elasticache")

    @builtins.property
    def elasticbeanstalk(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("elasticbeanstalk")

    @builtins.property
    def elastictranscoder(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("elastictranscoder")

    @builtins.property
    def elb(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("elb")

    @builtins.property
    def emr(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("emr")

    @builtins.property
    def es(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("es")

    @builtins.property
    def firehose(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("firehose")

    @builtins.property
    def fms(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("fms")

    @builtins.property
    def forecast(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("forecast")

    @builtins.property
    def fsx(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("fsx")

    @builtins.property
    def gamelift(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("gamelift")

    @builtins.property
    def glacier(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("glacier")

    @builtins.property
    def globalaccelerator(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("globalaccelerator")

    @builtins.property
    def glue(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("glue")

    @builtins.property
    def greengrass(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("greengrass")

    @builtins.property
    def guardduty(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("guardduty")

    @builtins.property
    def iam(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("iam")

    @builtins.property
    def imagebuilder(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("imagebuilder")

    @builtins.property
    def inspector(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("inspector")

    @builtins.property
    def iot(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("iot")

    @builtins.property
    def iotanalytics(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("iotanalytics")

    @builtins.property
    def iotevents(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("iotevents")

    @builtins.property
    def kafka(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("kafka")

    @builtins.property
    def kinesis(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("kinesis")

    @builtins.property
    def kinesisanalytics(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("kinesisanalytics")

    @builtins.property
    def kinesis_analytics(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("kinesis_analytics")

    @builtins.property
    def kinesisanalyticsv2(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("kinesisanalyticsv2")

    @builtins.property
    def kinesisvideo(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("kinesisvideo")

    @builtins.property
    def kms(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("kms")

    @builtins.property
    def lakeformation(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("lakeformation")

    @builtins.property
    def lambda_(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("lambda_")

    @builtins.property
    def lexmodels(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("lexmodels")

    @builtins.property
    def licensemanager(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("licensemanager")

    @builtins.property
    def lightsail(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("lightsail")

    @builtins.property
    def macie(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("macie")

    @builtins.property
    def managedblockchain(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("managedblockchain")

    @builtins.property
    def marketplacecatalog(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("marketplacecatalog")

    @builtins.property
    def mediaconnect(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("mediaconnect")

    @builtins.property
    def mediaconvert(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("mediaconvert")

    @builtins.property
    def medialive(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("medialive")

    @builtins.property
    def mediapackage(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("mediapackage")

    @builtins.property
    def mediastore(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("mediastore")

    @builtins.property
    def mediastoredata(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("mediastoredata")

    @builtins.property
    def mq(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("mq")

    @builtins.property
    def neptune(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("neptune")

    @builtins.property
    def networkmanager(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("networkmanager")

    @builtins.property
    def opsworks(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("opsworks")

    @builtins.property
    def organizations(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("organizations")

    @builtins.property
    def outposts(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("outposts")

    @builtins.property
    def personalize(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("personalize")

    @builtins.property
    def pinpoint(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("pinpoint")

    @builtins.property
    def pricing(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("pricing")

    @builtins.property
    def qldb(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("qldb")

    @builtins.property
    def quicksight(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("quicksight")

    @builtins.property
    def r53(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("r53")

    @builtins.property
    def ram(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("ram")

    @builtins.property
    def rds(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("rds")

    @builtins.property
    def redshift(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("redshift")

    @builtins.property
    def resourcegroups(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("resourcegroups")

    @builtins.property
    def resourcegroupstaggingapi(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("resourcegroupstaggingapi")

    @builtins.property
    def route53(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("route53")

    @builtins.property
    def route53_domains(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("route53_domains")

    @builtins.property
    def route53_resolver(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("route53_resolver")

    @builtins.property
    def s3(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("s3")

    @builtins.property
    def s3_control(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("s3_control")

    @builtins.property
    def sagemaker(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("sagemaker")

    @builtins.property
    def sdb(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("sdb")

    @builtins.property
    def secretsmanager(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("secretsmanager")

    @builtins.property
    def securityhub(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("securityhub")

    @builtins.property
    def serverlessrepo(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("serverlessrepo")

    @builtins.property
    def servicecatalog(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("servicecatalog")

    @builtins.property
    def servicediscovery(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("servicediscovery")

    @builtins.property
    def servicequotas(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("servicequotas")

    @builtins.property
    def ses(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("ses")

    @builtins.property
    def shield(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("shield")

    @builtins.property
    def sns(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("sns")

    @builtins.property
    def sqs(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("sqs")

    @builtins.property
    def ssm(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("ssm")

    @builtins.property
    def stepfunctions(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("stepfunctions")

    @builtins.property
    def storagegateway(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("storagegateway")

    @builtins.property
    def sts(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("sts")

    @builtins.property
    def swf(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("swf")

    @builtins.property
    def synthetics(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("synthetics")

    @builtins.property
    def transfer(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("transfer")

    @builtins.property
    def waf(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("waf")

    @builtins.property
    def wafregional(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("wafregional")

    @builtins.property
    def wafv2(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("wafv2")

    @builtins.property
    def worklink(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("worklink")

    @builtins.property
    def workmail(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("workmail")

    @builtins.property
    def workspaces(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("workspaces")

    @builtins.property
    def xray(self) -> typing.Optional[str]:
        """Use this to override the default service endpoint URL."""
        return self._values.get("xray")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AwsProviderEndpoints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.AwsProviderIgnoreTags",
    jsii_struct_bases=[],
    name_mapping={"key_prefixes": "keyPrefixes", "keys": "keys"},
)
class AwsProviderIgnoreTags:
    def __init__(
        self,
        *,
        key_prefixes: typing.Optional[typing.List[str]] = None,
        keys: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param key_prefixes: Resource tag key prefixes to ignore across all resources.
        :param keys: Resource tag keys to ignore across all resources.
        """
        self._values = {}
        if key_prefixes is not None:
            self._values["key_prefixes"] = key_prefixes
        if keys is not None:
            self._values["keys"] = keys

    @builtins.property
    def key_prefixes(self) -> typing.Optional[typing.List[str]]:
        """Resource tag key prefixes to ignore across all resources."""
        return self._values.get("key_prefixes")

    @builtins.property
    def keys(self) -> typing.Optional[typing.List[str]]:
        """Resource tag keys to ignore across all resources."""
        return self._values.get("keys")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "AwsProviderIgnoreTags(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupPlan(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.BackupPlan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        rule: typing.List["BackupPlanRule"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param rule: rule block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupPlanConfig(
            name=name,
            rule=rule,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupPlan, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.List["BackupPlanRule"]:
        return jsii.get(self, "rule")

    @rule.setter
    def rule(self, value: typing.List["BackupPlanRule"]) -> None:
        jsii.set(self, "rule", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupPlanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "rule": "rule",
        "tags": "tags",
    },
)
class BackupPlanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        rule: typing.List["BackupPlanRule"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param rule: rule block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "rule": rule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rule(self) -> typing.List["BackupPlanRule"]:
        """rule block."""
        return self._values.get("rule")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPlanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupPlanRule",
    jsii_struct_bases=[],
    name_mapping={
        "rule_name": "ruleName",
        "target_vault_name": "targetVaultName",
        "completion_window": "completionWindow",
        "copy_action": "copyAction",
        "lifecycle": "lifecycle",
        "recovery_point_tags": "recoveryPointTags",
        "schedule": "schedule",
        "start_window": "startWindow",
    },
)
class BackupPlanRule:
    def __init__(
        self,
        *,
        rule_name: str,
        target_vault_name: str,
        completion_window: typing.Optional[jsii.Number] = None,
        copy_action: typing.Optional[typing.List["BackupPlanRuleCopyAction"]] = None,
        lifecycle: typing.Optional[typing.List["BackupPlanRuleLifecycle"]] = None,
        recovery_point_tags: typing.Optional[typing.Mapping[str, str]] = None,
        schedule: typing.Optional[str] = None,
        start_window: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param rule_name: 
        :param target_vault_name: 
        :param completion_window: 
        :param copy_action: copy_action block.
        :param lifecycle: lifecycle block.
        :param recovery_point_tags: 
        :param schedule: 
        :param start_window: 
        """
        self._values = {
            "rule_name": rule_name,
            "target_vault_name": target_vault_name,
        }
        if completion_window is not None:
            self._values["completion_window"] = completion_window
        if copy_action is not None:
            self._values["copy_action"] = copy_action
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if recovery_point_tags is not None:
            self._values["recovery_point_tags"] = recovery_point_tags
        if schedule is not None:
            self._values["schedule"] = schedule
        if start_window is not None:
            self._values["start_window"] = start_window

    @builtins.property
    def rule_name(self) -> str:
        return self._values.get("rule_name")

    @builtins.property
    def target_vault_name(self) -> str:
        return self._values.get("target_vault_name")

    @builtins.property
    def completion_window(self) -> typing.Optional[jsii.Number]:
        return self._values.get("completion_window")

    @builtins.property
    def copy_action(self) -> typing.Optional[typing.List["BackupPlanRuleCopyAction"]]:
        """copy_action block."""
        return self._values.get("copy_action")

    @builtins.property
    def lifecycle(self) -> typing.Optional[typing.List["BackupPlanRuleLifecycle"]]:
        """lifecycle block."""
        return self._values.get("lifecycle")

    @builtins.property
    def recovery_point_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("recovery_point_tags")

    @builtins.property
    def schedule(self) -> typing.Optional[str]:
        return self._values.get("schedule")

    @builtins.property
    def start_window(self) -> typing.Optional[jsii.Number]:
        return self._values.get("start_window")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPlanRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupPlanRuleCopyAction",
    jsii_struct_bases=[],
    name_mapping={
        "destination_vault_arn": "destinationVaultArn",
        "lifecycle": "lifecycle",
    },
)
class BackupPlanRuleCopyAction:
    def __init__(
        self,
        *,
        destination_vault_arn: str,
        lifecycle: typing.Optional[
            typing.List["BackupPlanRuleCopyActionLifecycle"]
        ] = None,
    ) -> None:
        """
        :param destination_vault_arn: 
        :param lifecycle: lifecycle block.
        """
        self._values = {
            "destination_vault_arn": destination_vault_arn,
        }
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle

    @builtins.property
    def destination_vault_arn(self) -> str:
        return self._values.get("destination_vault_arn")

    @builtins.property
    def lifecycle(
        self,
    ) -> typing.Optional[typing.List["BackupPlanRuleCopyActionLifecycle"]]:
        """lifecycle block."""
        return self._values.get("lifecycle")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPlanRuleCopyAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupPlanRuleCopyActionLifecycle",
    jsii_struct_bases=[],
    name_mapping={
        "cold_storage_after": "coldStorageAfter",
        "delete_after": "deleteAfter",
    },
)
class BackupPlanRuleCopyActionLifecycle:
    def __init__(
        self,
        *,
        cold_storage_after: typing.Optional[jsii.Number] = None,
        delete_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param cold_storage_after: 
        :param delete_after: 
        """
        self._values = {}
        if cold_storage_after is not None:
            self._values["cold_storage_after"] = cold_storage_after
        if delete_after is not None:
            self._values["delete_after"] = delete_after

    @builtins.property
    def cold_storage_after(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cold_storage_after")

    @builtins.property
    def delete_after(self) -> typing.Optional[jsii.Number]:
        return self._values.get("delete_after")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPlanRuleCopyActionLifecycle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupPlanRuleLifecycle",
    jsii_struct_bases=[],
    name_mapping={
        "cold_storage_after": "coldStorageAfter",
        "delete_after": "deleteAfter",
    },
)
class BackupPlanRuleLifecycle:
    def __init__(
        self,
        *,
        cold_storage_after: typing.Optional[jsii.Number] = None,
        delete_after: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param cold_storage_after: 
        :param delete_after: 
        """
        self._values = {}
        if cold_storage_after is not None:
            self._values["cold_storage_after"] = cold_storage_after
        if delete_after is not None:
            self._values["delete_after"] = delete_after

    @builtins.property
    def cold_storage_after(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cold_storage_after")

    @builtins.property
    def delete_after(self) -> typing.Optional[jsii.Number]:
        return self._values.get("delete_after")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupPlanRuleLifecycle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupSelection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.BackupSelection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        iam_role_arn: str,
        name: str,
        plan_id: str,
        resources: typing.Optional[typing.List[str]] = None,
        selection_tag: typing.Optional[
            typing.List["BackupSelectionSelectionTag"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param iam_role_arn: 
        :param name: 
        :param plan_id: 
        :param resources: 
        :param selection_tag: selection_tag block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupSelectionConfig(
            iam_role_arn=iam_role_arn,
            name=name,
            plan_id=plan_id,
            resources=resources,
            selection_tag=selection_tag,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupSelection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="iamRoleArn")
    def iam_role_arn(self) -> str:
        return jsii.get(self, "iamRoleArn")

    @iam_role_arn.setter
    def iam_role_arn(self, value: str) -> None:
        jsii.set(self, "iamRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="planId")
    def plan_id(self) -> str:
        return jsii.get(self, "planId")

    @plan_id.setter
    def plan_id(self, value: str) -> None:
        jsii.set(self, "planId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="resources")
    def resources(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "resources")

    @resources.setter
    def resources(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "resources", value)

    @builtins.property
    @jsii.member(jsii_name="selectionTag")
    def selection_tag(
        self,
    ) -> typing.Optional[typing.List["BackupSelectionSelectionTag"]]:
        return jsii.get(self, "selectionTag")

    @selection_tag.setter
    def selection_tag(
        self, value: typing.Optional[typing.List["BackupSelectionSelectionTag"]]
    ) -> None:
        jsii.set(self, "selectionTag", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupSelectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "iam_role_arn": "iamRoleArn",
        "name": "name",
        "plan_id": "planId",
        "resources": "resources",
        "selection_tag": "selectionTag",
    },
)
class BackupSelectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        iam_role_arn: str,
        name: str,
        plan_id: str,
        resources: typing.Optional[typing.List[str]] = None,
        selection_tag: typing.Optional[
            typing.List["BackupSelectionSelectionTag"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param iam_role_arn: 
        :param name: 
        :param plan_id: 
        :param resources: 
        :param selection_tag: selection_tag block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "iam_role_arn": iam_role_arn,
            "name": name,
            "plan_id": plan_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if resources is not None:
            self._values["resources"] = resources
        if selection_tag is not None:
            self._values["selection_tag"] = selection_tag

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def iam_role_arn(self) -> str:
        return self._values.get("iam_role_arn")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def plan_id(self) -> str:
        return self._values.get("plan_id")

    @builtins.property
    def resources(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("resources")

    @builtins.property
    def selection_tag(
        self,
    ) -> typing.Optional[typing.List["BackupSelectionSelectionTag"]]:
        """selection_tag block."""
        return self._values.get("selection_tag")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupSelectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupSelectionSelectionTag",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "type": "type", "value": "value"},
)
class BackupSelectionSelectionTag:
    def __init__(self, *, key: str, type: str, value: str) -> None:
        """
        :param key: 
        :param type: 
        :param value: 
        """
        self._values = {
            "key": key,
            "type": type,
            "value": value,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupSelectionSelectionTag(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BackupVault(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.BackupVault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        kms_key_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param kms_key_arn: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BackupVaultConfig(
            name=name,
            kms_key_arn=kms_key_arn,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BackupVault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="recoveryPoints")
    def recovery_points(self) -> jsii.Number:
        return jsii.get(self, "recoveryPoints")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BackupVaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "kms_key_arn": "kmsKeyArn",
        "tags": "tags",
    },
)
class BackupVaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        kms_key_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param kms_key_arn: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BackupVaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BatchComputeEnvironment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.BatchComputeEnvironment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        service_role: str,
        type: str,
        compute_environment_name: typing.Optional[str] = None,
        compute_environment_name_prefix: typing.Optional[str] = None,
        compute_resources: typing.Optional[
            typing.List["BatchComputeEnvironmentComputeResources"]
        ] = None,
        state: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param service_role: 
        :param type: 
        :param compute_environment_name: 
        :param compute_environment_name_prefix: 
        :param compute_resources: compute_resources block.
        :param state: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BatchComputeEnvironmentConfig(
            service_role=service_role,
            type=type,
            compute_environment_name=compute_environment_name,
            compute_environment_name_prefix=compute_environment_name_prefix,
            compute_resources=compute_resources,
            state=state,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BatchComputeEnvironment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="eccClusterArn")
    def ecc_cluster_arn(self) -> str:
        return jsii.get(self, "eccClusterArn")

    @builtins.property
    @jsii.member(jsii_name="ecsClusterArn")
    def ecs_cluster_arn(self) -> str:
        return jsii.get(self, "ecsClusterArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="statusReason")
    def status_reason(self) -> str:
        return jsii.get(self, "statusReason")

    @builtins.property
    @jsii.member(jsii_name="serviceRole")
    def service_role(self) -> str:
        return jsii.get(self, "serviceRole")

    @service_role.setter
    def service_role(self, value: str) -> None:
        jsii.set(self, "serviceRole", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="computeEnvironmentName")
    def compute_environment_name(self) -> typing.Optional[str]:
        return jsii.get(self, "computeEnvironmentName")

    @compute_environment_name.setter
    def compute_environment_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "computeEnvironmentName", value)

    @builtins.property
    @jsii.member(jsii_name="computeEnvironmentNamePrefix")
    def compute_environment_name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "computeEnvironmentNamePrefix")

    @compute_environment_name_prefix.setter
    def compute_environment_name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "computeEnvironmentNamePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="computeResources")
    def compute_resources(
        self,
    ) -> typing.Optional[typing.List["BatchComputeEnvironmentComputeResources"]]:
        return jsii.get(self, "computeResources")

    @compute_resources.setter
    def compute_resources(
        self,
        value: typing.Optional[typing.List["BatchComputeEnvironmentComputeResources"]],
    ) -> None:
        jsii.set(self, "computeResources", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BatchComputeEnvironmentComputeResources",
    jsii_struct_bases=[],
    name_mapping={
        "instance_role": "instanceRole",
        "instance_type": "instanceType",
        "max_vcpus": "maxVcpus",
        "min_vcpus": "minVcpus",
        "security_group_ids": "securityGroupIds",
        "subnets": "subnets",
        "type": "type",
        "allocation_strategy": "allocationStrategy",
        "bid_percentage": "bidPercentage",
        "desired_vcpus": "desiredVcpus",
        "ec2_key_pair": "ec2KeyPair",
        "image_id": "imageId",
        "launch_template": "launchTemplate",
        "spot_iam_fleet_role": "spotIamFleetRole",
        "tags": "tags",
    },
)
class BatchComputeEnvironmentComputeResources:
    def __init__(
        self,
        *,
        instance_role: str,
        instance_type: typing.List[str],
        max_vcpus: jsii.Number,
        min_vcpus: jsii.Number,
        security_group_ids: typing.List[str],
        subnets: typing.List[str],
        type: str,
        allocation_strategy: typing.Optional[str] = None,
        bid_percentage: typing.Optional[jsii.Number] = None,
        desired_vcpus: typing.Optional[jsii.Number] = None,
        ec2_key_pair: typing.Optional[str] = None,
        image_id: typing.Optional[str] = None,
        launch_template: typing.Optional[
            typing.List["BatchComputeEnvironmentComputeResourcesLaunchTemplate"]
        ] = None,
        spot_iam_fleet_role: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param instance_role: 
        :param instance_type: 
        :param max_vcpus: 
        :param min_vcpus: 
        :param security_group_ids: 
        :param subnets: 
        :param type: 
        :param allocation_strategy: 
        :param bid_percentage: 
        :param desired_vcpus: 
        :param ec2_key_pair: 
        :param image_id: 
        :param launch_template: launch_template block.
        :param spot_iam_fleet_role: 
        :param tags: 
        """
        self._values = {
            "instance_role": instance_role,
            "instance_type": instance_type,
            "max_vcpus": max_vcpus,
            "min_vcpus": min_vcpus,
            "security_group_ids": security_group_ids,
            "subnets": subnets,
            "type": type,
        }
        if allocation_strategy is not None:
            self._values["allocation_strategy"] = allocation_strategy
        if bid_percentage is not None:
            self._values["bid_percentage"] = bid_percentage
        if desired_vcpus is not None:
            self._values["desired_vcpus"] = desired_vcpus
        if ec2_key_pair is not None:
            self._values["ec2_key_pair"] = ec2_key_pair
        if image_id is not None:
            self._values["image_id"] = image_id
        if launch_template is not None:
            self._values["launch_template"] = launch_template
        if spot_iam_fleet_role is not None:
            self._values["spot_iam_fleet_role"] = spot_iam_fleet_role
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def instance_role(self) -> str:
        return self._values.get("instance_role")

    @builtins.property
    def instance_type(self) -> typing.List[str]:
        return self._values.get("instance_type")

    @builtins.property
    def max_vcpus(self) -> jsii.Number:
        return self._values.get("max_vcpus")

    @builtins.property
    def min_vcpus(self) -> jsii.Number:
        return self._values.get("min_vcpus")

    @builtins.property
    def security_group_ids(self) -> typing.List[str]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnets(self) -> typing.List[str]:
        return self._values.get("subnets")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def allocation_strategy(self) -> typing.Optional[str]:
        return self._values.get("allocation_strategy")

    @builtins.property
    def bid_percentage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("bid_percentage")

    @builtins.property
    def desired_vcpus(self) -> typing.Optional[jsii.Number]:
        return self._values.get("desired_vcpus")

    @builtins.property
    def ec2_key_pair(self) -> typing.Optional[str]:
        return self._values.get("ec2_key_pair")

    @builtins.property
    def image_id(self) -> typing.Optional[str]:
        return self._values.get("image_id")

    @builtins.property
    def launch_template(
        self,
    ) -> typing.Optional[
        typing.List["BatchComputeEnvironmentComputeResourcesLaunchTemplate"]
    ]:
        """launch_template block."""
        return self._values.get("launch_template")

    @builtins.property
    def spot_iam_fleet_role(self) -> typing.Optional[str]:
        return self._values.get("spot_iam_fleet_role")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchComputeEnvironmentComputeResources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BatchComputeEnvironmentComputeResourcesLaunchTemplate",
    jsii_struct_bases=[],
    name_mapping={
        "launch_template_id": "launchTemplateId",
        "launch_template_name": "launchTemplateName",
        "version": "version",
    },
)
class BatchComputeEnvironmentComputeResourcesLaunchTemplate:
    def __init__(
        self,
        *,
        launch_template_id: typing.Optional[str] = None,
        launch_template_name: typing.Optional[str] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param launch_template_id: 
        :param launch_template_name: 
        :param version: 
        """
        self._values = {}
        if launch_template_id is not None:
            self._values["launch_template_id"] = launch_template_id
        if launch_template_name is not None:
            self._values["launch_template_name"] = launch_template_name
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def launch_template_id(self) -> typing.Optional[str]:
        return self._values.get("launch_template_id")

    @builtins.property
    def launch_template_name(self) -> typing.Optional[str]:
        return self._values.get("launch_template_name")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchComputeEnvironmentComputeResourcesLaunchTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BatchComputeEnvironmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "service_role": "serviceRole",
        "type": "type",
        "compute_environment_name": "computeEnvironmentName",
        "compute_environment_name_prefix": "computeEnvironmentNamePrefix",
        "compute_resources": "computeResources",
        "state": "state",
    },
)
class BatchComputeEnvironmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        service_role: str,
        type: str,
        compute_environment_name: typing.Optional[str] = None,
        compute_environment_name_prefix: typing.Optional[str] = None,
        compute_resources: typing.Optional[
            typing.List["BatchComputeEnvironmentComputeResources"]
        ] = None,
        state: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param service_role: 
        :param type: 
        :param compute_environment_name: 
        :param compute_environment_name_prefix: 
        :param compute_resources: compute_resources block.
        :param state: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "service_role": service_role,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if compute_environment_name is not None:
            self._values["compute_environment_name"] = compute_environment_name
        if compute_environment_name_prefix is not None:
            self._values[
                "compute_environment_name_prefix"
            ] = compute_environment_name_prefix
        if compute_resources is not None:
            self._values["compute_resources"] = compute_resources
        if state is not None:
            self._values["state"] = state

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def service_role(self) -> str:
        return self._values.get("service_role")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def compute_environment_name(self) -> typing.Optional[str]:
        return self._values.get("compute_environment_name")

    @builtins.property
    def compute_environment_name_prefix(self) -> typing.Optional[str]:
        return self._values.get("compute_environment_name_prefix")

    @builtins.property
    def compute_resources(
        self,
    ) -> typing.Optional[typing.List["BatchComputeEnvironmentComputeResources"]]:
        """compute_resources block."""
        return self._values.get("compute_resources")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchComputeEnvironmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BatchJobDefinition(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.BatchJobDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        type: str,
        container_properties: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        retry_strategy: typing.Optional[
            typing.List["BatchJobDefinitionRetryStrategy"]
        ] = None,
        timeout: typing.Optional[typing.List["BatchJobDefinitionTimeout"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param type: 
        :param container_properties: 
        :param parameters: 
        :param retry_strategy: retry_strategy block.
        :param timeout: timeout block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BatchJobDefinitionConfig(
            name=name,
            type=type,
            container_properties=container_properties,
            parameters=parameters,
            retry_strategy=retry_strategy,
            timeout=timeout,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BatchJobDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="revision")
    def revision(self) -> jsii.Number:
        return jsii.get(self, "revision")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="containerProperties")
    def container_properties(self) -> typing.Optional[str]:
        return jsii.get(self, "containerProperties")

    @container_properties.setter
    def container_properties(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "containerProperties", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="retryStrategy")
    def retry_strategy(
        self,
    ) -> typing.Optional[typing.List["BatchJobDefinitionRetryStrategy"]]:
        return jsii.get(self, "retryStrategy")

    @retry_strategy.setter
    def retry_strategy(
        self, value: typing.Optional[typing.List["BatchJobDefinitionRetryStrategy"]]
    ) -> None:
        jsii.set(self, "retryStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> typing.Optional[typing.List["BatchJobDefinitionTimeout"]]:
        return jsii.get(self, "timeout")

    @timeout.setter
    def timeout(
        self, value: typing.Optional[typing.List["BatchJobDefinitionTimeout"]]
    ) -> None:
        jsii.set(self, "timeout", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BatchJobDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "type": "type",
        "container_properties": "containerProperties",
        "parameters": "parameters",
        "retry_strategy": "retryStrategy",
        "timeout": "timeout",
    },
)
class BatchJobDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        type: str,
        container_properties: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        retry_strategy: typing.Optional[
            typing.List["BatchJobDefinitionRetryStrategy"]
        ] = None,
        timeout: typing.Optional[typing.List["BatchJobDefinitionTimeout"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param type: 
        :param container_properties: 
        :param parameters: 
        :param retry_strategy: retry_strategy block.
        :param timeout: timeout block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if container_properties is not None:
            self._values["container_properties"] = container_properties
        if parameters is not None:
            self._values["parameters"] = parameters
        if retry_strategy is not None:
            self._values["retry_strategy"] = retry_strategy
        if timeout is not None:
            self._values["timeout"] = timeout

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def container_properties(self) -> typing.Optional[str]:
        return self._values.get("container_properties")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    @builtins.property
    def retry_strategy(
        self,
    ) -> typing.Optional[typing.List["BatchJobDefinitionRetryStrategy"]]:
        """retry_strategy block."""
        return self._values.get("retry_strategy")

    @builtins.property
    def timeout(self) -> typing.Optional[typing.List["BatchJobDefinitionTimeout"]]:
        """timeout block."""
        return self._values.get("timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchJobDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BatchJobDefinitionRetryStrategy",
    jsii_struct_bases=[],
    name_mapping={"attempts": "attempts"},
)
class BatchJobDefinitionRetryStrategy:
    def __init__(self, *, attempts: typing.Optional[jsii.Number] = None) -> None:
        """
        :param attempts: 
        """
        self._values = {}
        if attempts is not None:
            self._values["attempts"] = attempts

    @builtins.property
    def attempts(self) -> typing.Optional[jsii.Number]:
        return self._values.get("attempts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchJobDefinitionRetryStrategy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BatchJobDefinitionTimeout",
    jsii_struct_bases=[],
    name_mapping={"attempt_duration_seconds": "attemptDurationSeconds"},
)
class BatchJobDefinitionTimeout:
    def __init__(
        self, *, attempt_duration_seconds: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param attempt_duration_seconds: 
        """
        self._values = {}
        if attempt_duration_seconds is not None:
            self._values["attempt_duration_seconds"] = attempt_duration_seconds

    @builtins.property
    def attempt_duration_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("attempt_duration_seconds")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchJobDefinitionTimeout(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BatchJobQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.BatchJobQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        compute_environments: typing.List[str],
        name: str,
        priority: jsii.Number,
        state: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param compute_environments: 
        :param name: 
        :param priority: 
        :param state: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BatchJobQueueConfig(
            compute_environments=compute_environments,
            name=name,
            priority=priority,
            state=state,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BatchJobQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="computeEnvironments")
    def compute_environments(self) -> typing.List[str]:
        return jsii.get(self, "computeEnvironments")

    @compute_environments.setter
    def compute_environments(self, value: typing.List[str]) -> None:
        jsii.set(self, "computeEnvironments", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @priority.setter
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: str) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BatchJobQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "compute_environments": "computeEnvironments",
        "name": "name",
        "priority": "priority",
        "state": "state",
    },
)
class BatchJobQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        compute_environments: typing.List[str],
        name: str,
        priority: jsii.Number,
        state: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param compute_environments: 
        :param name: 
        :param priority: 
        :param state: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "compute_environments": compute_environments,
            "name": name,
            "priority": priority,
            "state": state,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def compute_environments(self) -> typing.List[str]:
        return self._values.get("compute_environments")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def state(self) -> str:
        return self._values.get("state")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BatchJobQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class BudgetsBudget(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.BudgetsBudget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        budget_type: str,
        limit_amount: str,
        limit_unit: str,
        time_period_start: str,
        time_unit: str,
        account_id: typing.Optional[str] = None,
        cost_filters: typing.Optional[typing.Mapping[str, str]] = None,
        cost_types: typing.Optional[typing.List["BudgetsBudgetCostTypes"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        notification: typing.Optional[typing.List["BudgetsBudgetNotification"]] = None,
        time_period_end: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param budget_type: 
        :param limit_amount: 
        :param limit_unit: 
        :param time_period_start: 
        :param time_unit: 
        :param account_id: 
        :param cost_filters: 
        :param cost_types: cost_types block.
        :param name: 
        :param name_prefix: 
        :param notification: notification block.
        :param time_period_end: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = BudgetsBudgetConfig(
            budget_type=budget_type,
            limit_amount=limit_amount,
            limit_unit=limit_unit,
            time_period_start=time_period_start,
            time_unit=time_unit,
            account_id=account_id,
            cost_filters=cost_filters,
            cost_types=cost_types,
            name=name,
            name_prefix=name_prefix,
            notification=notification,
            time_period_end=time_period_end,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(BudgetsBudget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="budgetType")
    def budget_type(self) -> str:
        return jsii.get(self, "budgetType")

    @budget_type.setter
    def budget_type(self, value: str) -> None:
        jsii.set(self, "budgetType", value)

    @builtins.property
    @jsii.member(jsii_name="limitAmount")
    def limit_amount(self) -> str:
        return jsii.get(self, "limitAmount")

    @limit_amount.setter
    def limit_amount(self, value: str) -> None:
        jsii.set(self, "limitAmount", value)

    @builtins.property
    @jsii.member(jsii_name="limitUnit")
    def limit_unit(self) -> str:
        return jsii.get(self, "limitUnit")

    @limit_unit.setter
    def limit_unit(self, value: str) -> None:
        jsii.set(self, "limitUnit", value)

    @builtins.property
    @jsii.member(jsii_name="timePeriodStart")
    def time_period_start(self) -> str:
        return jsii.get(self, "timePeriodStart")

    @time_period_start.setter
    def time_period_start(self, value: str) -> None:
        jsii.set(self, "timePeriodStart", value)

    @builtins.property
    @jsii.member(jsii_name="timeUnit")
    def time_unit(self) -> str:
        return jsii.get(self, "timeUnit")

    @time_unit.setter
    def time_unit(self, value: str) -> None:
        jsii.set(self, "timeUnit", value)

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="costFilters")
    def cost_filters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "costFilters")

    @cost_filters.setter
    def cost_filters(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "costFilters", value)

    @builtins.property
    @jsii.member(jsii_name="costTypes")
    def cost_types(self) -> typing.Optional[typing.List["BudgetsBudgetCostTypes"]]:
        return jsii.get(self, "costTypes")

    @cost_types.setter
    def cost_types(
        self, value: typing.Optional[typing.List["BudgetsBudgetCostTypes"]]
    ) -> None:
        jsii.set(self, "costTypes", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="notification")
    def notification(self) -> typing.Optional[typing.List["BudgetsBudgetNotification"]]:
        return jsii.get(self, "notification")

    @notification.setter
    def notification(
        self, value: typing.Optional[typing.List["BudgetsBudgetNotification"]]
    ) -> None:
        jsii.set(self, "notification", value)

    @builtins.property
    @jsii.member(jsii_name="timePeriodEnd")
    def time_period_end(self) -> typing.Optional[str]:
        return jsii.get(self, "timePeriodEnd")

    @time_period_end.setter
    def time_period_end(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "timePeriodEnd", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BudgetsBudgetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "budget_type": "budgetType",
        "limit_amount": "limitAmount",
        "limit_unit": "limitUnit",
        "time_period_start": "timePeriodStart",
        "time_unit": "timeUnit",
        "account_id": "accountId",
        "cost_filters": "costFilters",
        "cost_types": "costTypes",
        "name": "name",
        "name_prefix": "namePrefix",
        "notification": "notification",
        "time_period_end": "timePeriodEnd",
    },
)
class BudgetsBudgetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        budget_type: str,
        limit_amount: str,
        limit_unit: str,
        time_period_start: str,
        time_unit: str,
        account_id: typing.Optional[str] = None,
        cost_filters: typing.Optional[typing.Mapping[str, str]] = None,
        cost_types: typing.Optional[typing.List["BudgetsBudgetCostTypes"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        notification: typing.Optional[typing.List["BudgetsBudgetNotification"]] = None,
        time_period_end: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param budget_type: 
        :param limit_amount: 
        :param limit_unit: 
        :param time_period_start: 
        :param time_unit: 
        :param account_id: 
        :param cost_filters: 
        :param cost_types: cost_types block.
        :param name: 
        :param name_prefix: 
        :param notification: notification block.
        :param time_period_end: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "budget_type": budget_type,
            "limit_amount": limit_amount,
            "limit_unit": limit_unit,
            "time_period_start": time_period_start,
            "time_unit": time_unit,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if account_id is not None:
            self._values["account_id"] = account_id
        if cost_filters is not None:
            self._values["cost_filters"] = cost_filters
        if cost_types is not None:
            self._values["cost_types"] = cost_types
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if notification is not None:
            self._values["notification"] = notification
        if time_period_end is not None:
            self._values["time_period_end"] = time_period_end

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def budget_type(self) -> str:
        return self._values.get("budget_type")

    @builtins.property
    def limit_amount(self) -> str:
        return self._values.get("limit_amount")

    @builtins.property
    def limit_unit(self) -> str:
        return self._values.get("limit_unit")

    @builtins.property
    def time_period_start(self) -> str:
        return self._values.get("time_period_start")

    @builtins.property
    def time_unit(self) -> str:
        return self._values.get("time_unit")

    @builtins.property
    def account_id(self) -> typing.Optional[str]:
        return self._values.get("account_id")

    @builtins.property
    def cost_filters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("cost_filters")

    @builtins.property
    def cost_types(self) -> typing.Optional[typing.List["BudgetsBudgetCostTypes"]]:
        """cost_types block."""
        return self._values.get("cost_types")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def notification(self) -> typing.Optional[typing.List["BudgetsBudgetNotification"]]:
        """notification block."""
        return self._values.get("notification")

    @builtins.property
    def time_period_end(self) -> typing.Optional[str]:
        return self._values.get("time_period_end")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BudgetsBudgetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BudgetsBudgetCostTypes",
    jsii_struct_bases=[],
    name_mapping={
        "include_credit": "includeCredit",
        "include_discount": "includeDiscount",
        "include_other_subscription": "includeOtherSubscription",
        "include_recurring": "includeRecurring",
        "include_refund": "includeRefund",
        "include_subscription": "includeSubscription",
        "include_support": "includeSupport",
        "include_tax": "includeTax",
        "include_upfront": "includeUpfront",
        "use_amortized": "useAmortized",
        "use_blended": "useBlended",
    },
)
class BudgetsBudgetCostTypes:
    def __init__(
        self,
        *,
        include_credit: typing.Optional[bool] = None,
        include_discount: typing.Optional[bool] = None,
        include_other_subscription: typing.Optional[bool] = None,
        include_recurring: typing.Optional[bool] = None,
        include_refund: typing.Optional[bool] = None,
        include_subscription: typing.Optional[bool] = None,
        include_support: typing.Optional[bool] = None,
        include_tax: typing.Optional[bool] = None,
        include_upfront: typing.Optional[bool] = None,
        use_amortized: typing.Optional[bool] = None,
        use_blended: typing.Optional[bool] = None,
    ) -> None:
        """
        :param include_credit: 
        :param include_discount: 
        :param include_other_subscription: 
        :param include_recurring: 
        :param include_refund: 
        :param include_subscription: 
        :param include_support: 
        :param include_tax: 
        :param include_upfront: 
        :param use_amortized: 
        :param use_blended: 
        """
        self._values = {}
        if include_credit is not None:
            self._values["include_credit"] = include_credit
        if include_discount is not None:
            self._values["include_discount"] = include_discount
        if include_other_subscription is not None:
            self._values["include_other_subscription"] = include_other_subscription
        if include_recurring is not None:
            self._values["include_recurring"] = include_recurring
        if include_refund is not None:
            self._values["include_refund"] = include_refund
        if include_subscription is not None:
            self._values["include_subscription"] = include_subscription
        if include_support is not None:
            self._values["include_support"] = include_support
        if include_tax is not None:
            self._values["include_tax"] = include_tax
        if include_upfront is not None:
            self._values["include_upfront"] = include_upfront
        if use_amortized is not None:
            self._values["use_amortized"] = use_amortized
        if use_blended is not None:
            self._values["use_blended"] = use_blended

    @builtins.property
    def include_credit(self) -> typing.Optional[bool]:
        return self._values.get("include_credit")

    @builtins.property
    def include_discount(self) -> typing.Optional[bool]:
        return self._values.get("include_discount")

    @builtins.property
    def include_other_subscription(self) -> typing.Optional[bool]:
        return self._values.get("include_other_subscription")

    @builtins.property
    def include_recurring(self) -> typing.Optional[bool]:
        return self._values.get("include_recurring")

    @builtins.property
    def include_refund(self) -> typing.Optional[bool]:
        return self._values.get("include_refund")

    @builtins.property
    def include_subscription(self) -> typing.Optional[bool]:
        return self._values.get("include_subscription")

    @builtins.property
    def include_support(self) -> typing.Optional[bool]:
        return self._values.get("include_support")

    @builtins.property
    def include_tax(self) -> typing.Optional[bool]:
        return self._values.get("include_tax")

    @builtins.property
    def include_upfront(self) -> typing.Optional[bool]:
        return self._values.get("include_upfront")

    @builtins.property
    def use_amortized(self) -> typing.Optional[bool]:
        return self._values.get("use_amortized")

    @builtins.property
    def use_blended(self) -> typing.Optional[bool]:
        return self._values.get("use_blended")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BudgetsBudgetCostTypes(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.BudgetsBudgetNotification",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "notification_type": "notificationType",
        "threshold": "threshold",
        "threshold_type": "thresholdType",
        "subscriber_email_addresses": "subscriberEmailAddresses",
        "subscriber_sns_topic_arns": "subscriberSnsTopicArns",
    },
)
class BudgetsBudgetNotification:
    def __init__(
        self,
        *,
        comparison_operator: str,
        notification_type: str,
        threshold: jsii.Number,
        threshold_type: str,
        subscriber_email_addresses: typing.Optional[typing.List[str]] = None,
        subscriber_sns_topic_arns: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param notification_type: 
        :param threshold: 
        :param threshold_type: 
        :param subscriber_email_addresses: 
        :param subscriber_sns_topic_arns: 
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "notification_type": notification_type,
            "threshold": threshold,
            "threshold_type": threshold_type,
        }
        if subscriber_email_addresses is not None:
            self._values["subscriber_email_addresses"] = subscriber_email_addresses
        if subscriber_sns_topic_arns is not None:
            self._values["subscriber_sns_topic_arns"] = subscriber_sns_topic_arns

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def notification_type(self) -> str:
        return self._values.get("notification_type")

    @builtins.property
    def threshold(self) -> jsii.Number:
        return self._values.get("threshold")

    @builtins.property
    def threshold_type(self) -> str:
        return self._values.get("threshold_type")

    @builtins.property
    def subscriber_email_addresses(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subscriber_email_addresses")

    @builtins.property
    def subscriber_sns_topic_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subscriber_sns_topic_arns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "BudgetsBudgetNotification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Cloud9EnvironmentEc2(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Cloud9EnvironmentEc2",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        instance_type: str,
        name: str,
        automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        owner_arn: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param instance_type: 
        :param name: 
        :param automatic_stop_time_minutes: 
        :param description: 
        :param owner_arn: 
        :param subnet_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Cloud9EnvironmentEc2Config(
            instance_type=instance_type,
            name=name,
            automatic_stop_time_minutes=automatic_stop_time_minutes,
            description=description,
            owner_arn=owner_arn,
            subnet_id=subnet_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Cloud9EnvironmentEc2, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: str) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="automaticStopTimeMinutes")
    def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "automaticStopTimeMinutes")

    @automatic_stop_time_minutes.setter
    def automatic_stop_time_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "automaticStopTimeMinutes", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ownerArn")
    def owner_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "ownerArn")

    @owner_arn.setter
    def owner_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ownerArn", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Cloud9EnvironmentEc2Config",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "instance_type": "instanceType",
        "name": "name",
        "automatic_stop_time_minutes": "automaticStopTimeMinutes",
        "description": "description",
        "owner_arn": "ownerArn",
        "subnet_id": "subnetId",
        "tags": "tags",
    },
)
class Cloud9EnvironmentEc2Config(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        instance_type: str,
        name: str,
        automatic_stop_time_minutes: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        owner_arn: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param instance_type: 
        :param name: 
        :param automatic_stop_time_minutes: 
        :param description: 
        :param owner_arn: 
        :param subnet_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "instance_type": instance_type,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if automatic_stop_time_minutes is not None:
            self._values["automatic_stop_time_minutes"] = automatic_stop_time_minutes
        if description is not None:
            self._values["description"] = description
        if owner_arn is not None:
            self._values["owner_arn"] = owner_arn
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def automatic_stop_time_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("automatic_stop_time_minutes")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def owner_arn(self) -> typing.Optional[str]:
        return self._values.get("owner_arn")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Cloud9EnvironmentEc2Config(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudformationStack(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStack",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        capabilities: typing.Optional[typing.List[str]] = None,
        disable_rollback: typing.Optional[bool] = None,
        iam_role_arn: typing.Optional[str] = None,
        notification_arns: typing.Optional[typing.List[str]] = None,
        on_failure: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        policy_body: typing.Optional[str] = None,
        policy_url: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        template_body: typing.Optional[str] = None,
        template_url: typing.Optional[str] = None,
        timeout_in_minutes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CloudformationStackTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param capabilities: 
        :param disable_rollback: 
        :param iam_role_arn: 
        :param notification_arns: 
        :param on_failure: 
        :param parameters: 
        :param policy_body: 
        :param policy_url: 
        :param tags: 
        :param template_body: 
        :param template_url: 
        :param timeout_in_minutes: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudformationStackConfig(
            name=name,
            capabilities=capabilities,
            disable_rollback=disable_rollback,
            iam_role_arn=iam_role_arn,
            notification_arns=notification_arns,
            on_failure=on_failure,
            parameters=parameters,
            policy_body=policy_body,
            policy_url=policy_url,
            tags=tags,
            template_body=template_body,
            template_url=template_url,
            timeout_in_minutes=timeout_in_minutes,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudformationStack, self, [scope, id, config])

    @jsii.member(jsii_name="outputs")
    def outputs(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "outputs", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="capabilities")
    def capabilities(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "capabilities")

    @capabilities.setter
    def capabilities(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "capabilities", value)

    @builtins.property
    @jsii.member(jsii_name="disableRollback")
    def disable_rollback(self) -> typing.Optional[bool]:
        return jsii.get(self, "disableRollback")

    @disable_rollback.setter
    def disable_rollback(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "disableRollback", value)

    @builtins.property
    @jsii.member(jsii_name="iamRoleArn")
    def iam_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "iamRoleArn")

    @iam_role_arn.setter
    def iam_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="notificationArns")
    def notification_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "notificationArns")

    @notification_arns.setter
    def notification_arns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "notificationArns", value)

    @builtins.property
    @jsii.member(jsii_name="onFailure")
    def on_failure(self) -> typing.Optional[str]:
        return jsii.get(self, "onFailure")

    @on_failure.setter
    def on_failure(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "onFailure", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="policyBody")
    def policy_body(self) -> typing.Optional[str]:
        return jsii.get(self, "policyBody")

    @policy_body.setter
    def policy_body(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policyBody", value)

    @builtins.property
    @jsii.member(jsii_name="policyUrl")
    def policy_url(self) -> typing.Optional[str]:
        return jsii.get(self, "policyUrl")

    @policy_url.setter
    def policy_url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policyUrl", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="templateBody")
    def template_body(self) -> typing.Optional[str]:
        return jsii.get(self, "templateBody")

    @template_body.setter
    def template_body(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "templateBody", value)

    @builtins.property
    @jsii.member(jsii_name="templateUrl")
    def template_url(self) -> typing.Optional[str]:
        return jsii.get(self, "templateUrl")

    @template_url.setter
    def template_url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "templateUrl", value)

    @builtins.property
    @jsii.member(jsii_name="timeoutInMinutes")
    def timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "timeoutInMinutes")

    @timeout_in_minutes.setter
    def timeout_in_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "timeoutInMinutes", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CloudformationStackTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["CloudformationStackTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "capabilities": "capabilities",
        "disable_rollback": "disableRollback",
        "iam_role_arn": "iamRoleArn",
        "notification_arns": "notificationArns",
        "on_failure": "onFailure",
        "parameters": "parameters",
        "policy_body": "policyBody",
        "policy_url": "policyUrl",
        "tags": "tags",
        "template_body": "templateBody",
        "template_url": "templateUrl",
        "timeout_in_minutes": "timeoutInMinutes",
        "timeouts": "timeouts",
    },
)
class CloudformationStackConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        capabilities: typing.Optional[typing.List[str]] = None,
        disable_rollback: typing.Optional[bool] = None,
        iam_role_arn: typing.Optional[str] = None,
        notification_arns: typing.Optional[typing.List[str]] = None,
        on_failure: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        policy_body: typing.Optional[str] = None,
        policy_url: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        template_body: typing.Optional[str] = None,
        template_url: typing.Optional[str] = None,
        timeout_in_minutes: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["CloudformationStackTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param capabilities: 
        :param disable_rollback: 
        :param iam_role_arn: 
        :param notification_arns: 
        :param on_failure: 
        :param parameters: 
        :param policy_body: 
        :param policy_url: 
        :param tags: 
        :param template_body: 
        :param template_url: 
        :param timeout_in_minutes: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CloudformationStackTimeouts(**timeouts)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if capabilities is not None:
            self._values["capabilities"] = capabilities
        if disable_rollback is not None:
            self._values["disable_rollback"] = disable_rollback
        if iam_role_arn is not None:
            self._values["iam_role_arn"] = iam_role_arn
        if notification_arns is not None:
            self._values["notification_arns"] = notification_arns
        if on_failure is not None:
            self._values["on_failure"] = on_failure
        if parameters is not None:
            self._values["parameters"] = parameters
        if policy_body is not None:
            self._values["policy_body"] = policy_body
        if policy_url is not None:
            self._values["policy_url"] = policy_url
        if tags is not None:
            self._values["tags"] = tags
        if template_body is not None:
            self._values["template_body"] = template_body
        if template_url is not None:
            self._values["template_url"] = template_url
        if timeout_in_minutes is not None:
            self._values["timeout_in_minutes"] = timeout_in_minutes
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def capabilities(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("capabilities")

    @builtins.property
    def disable_rollback(self) -> typing.Optional[bool]:
        return self._values.get("disable_rollback")

    @builtins.property
    def iam_role_arn(self) -> typing.Optional[str]:
        return self._values.get("iam_role_arn")

    @builtins.property
    def notification_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("notification_arns")

    @builtins.property
    def on_failure(self) -> typing.Optional[str]:
        return self._values.get("on_failure")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    @builtins.property
    def policy_body(self) -> typing.Optional[str]:
        return self._values.get("policy_body")

    @builtins.property
    def policy_url(self) -> typing.Optional[str]:
        return self._values.get("policy_url")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def template_body(self) -> typing.Optional[str]:
        return self._values.get("template_body")

    @builtins.property
    def template_url(self) -> typing.Optional[str]:
        return self._values.get("template_url")

    @builtins.property
    def timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout_in_minutes")

    @builtins.property
    def timeouts(self) -> typing.Optional["CloudformationStackTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudformationStackConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudformationStackSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        administration_role_arn: str,
        name: str,
        capabilities: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        execution_role_name: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        template_body: typing.Optional[str] = None,
        template_url: typing.Optional[str] = None,
        timeouts: typing.Optional["CloudformationStackSetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param administration_role_arn: 
        :param name: 
        :param capabilities: 
        :param description: 
        :param execution_role_name: 
        :param parameters: 
        :param tags: 
        :param template_body: 
        :param template_url: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudformationStackSetConfig(
            administration_role_arn=administration_role_arn,
            name=name,
            capabilities=capabilities,
            description=description,
            execution_role_name=execution_role_name,
            parameters=parameters,
            tags=tags,
            template_body=template_body,
            template_url=template_url,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudformationStackSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackSetId")
    def stack_set_id(self) -> str:
        return jsii.get(self, "stackSetId")

    @builtins.property
    @jsii.member(jsii_name="administrationRoleArn")
    def administration_role_arn(self) -> str:
        return jsii.get(self, "administrationRoleArn")

    @administration_role_arn.setter
    def administration_role_arn(self, value: str) -> None:
        jsii.set(self, "administrationRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="capabilities")
    def capabilities(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "capabilities")

    @capabilities.setter
    def capabilities(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "capabilities", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="executionRoleName")
    def execution_role_name(self) -> typing.Optional[str]:
        return jsii.get(self, "executionRoleName")

    @execution_role_name.setter
    def execution_role_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "executionRoleName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="templateBody")
    def template_body(self) -> typing.Optional[str]:
        return jsii.get(self, "templateBody")

    @template_body.setter
    def template_body(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "templateBody", value)

    @builtins.property
    @jsii.member(jsii_name="templateUrl")
    def template_url(self) -> typing.Optional[str]:
        return jsii.get(self, "templateUrl")

    @template_url.setter
    def template_url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "templateUrl", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CloudformationStackSetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["CloudformationStackSetTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "administration_role_arn": "administrationRoleArn",
        "name": "name",
        "capabilities": "capabilities",
        "description": "description",
        "execution_role_name": "executionRoleName",
        "parameters": "parameters",
        "tags": "tags",
        "template_body": "templateBody",
        "template_url": "templateUrl",
        "timeouts": "timeouts",
    },
)
class CloudformationStackSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        administration_role_arn: str,
        name: str,
        capabilities: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        execution_role_name: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        template_body: typing.Optional[str] = None,
        template_url: typing.Optional[str] = None,
        timeouts: typing.Optional["CloudformationStackSetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param administration_role_arn: 
        :param name: 
        :param capabilities: 
        :param description: 
        :param execution_role_name: 
        :param parameters: 
        :param tags: 
        :param template_body: 
        :param template_url: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CloudformationStackSetTimeouts(**timeouts)
        self._values = {
            "administration_role_arn": administration_role_arn,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if capabilities is not None:
            self._values["capabilities"] = capabilities
        if description is not None:
            self._values["description"] = description
        if execution_role_name is not None:
            self._values["execution_role_name"] = execution_role_name
        if parameters is not None:
            self._values["parameters"] = parameters
        if tags is not None:
            self._values["tags"] = tags
        if template_body is not None:
            self._values["template_body"] = template_body
        if template_url is not None:
            self._values["template_url"] = template_url
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def administration_role_arn(self) -> str:
        return self._values.get("administration_role_arn")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def capabilities(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("capabilities")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def execution_role_name(self) -> typing.Optional[str]:
        return self._values.get("execution_role_name")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def template_body(self) -> typing.Optional[str]:
        return self._values.get("template_body")

    @builtins.property
    def template_url(self) -> typing.Optional[str]:
        return self._values.get("template_url")

    @builtins.property
    def timeouts(self) -> typing.Optional["CloudformationStackSetTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudformationStackSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudformationStackSetInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackSetInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_set_name: str,
        account_id: typing.Optional[str] = None,
        parameter_overrides: typing.Optional[typing.Mapping[str, str]] = None,
        region: typing.Optional[str] = None,
        retain_stack: typing.Optional[bool] = None,
        timeouts: typing.Optional["CloudformationStackSetInstanceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_set_name: 
        :param account_id: 
        :param parameter_overrides: 
        :param region: 
        :param retain_stack: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudformationStackSetInstanceConfig(
            stack_set_name=stack_set_name,
            account_id=account_id,
            parameter_overrides=parameter_overrides,
            region=region,
            retain_stack=retain_stack,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudformationStackSetInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @builtins.property
    @jsii.member(jsii_name="stackSetName")
    def stack_set_name(self) -> str:
        return jsii.get(self, "stackSetName")

    @stack_set_name.setter
    def stack_set_name(self, value: str) -> None:
        jsii.set(self, "stackSetName", value)

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parameterOverrides")
    def parameter_overrides(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "parameterOverrides")

    @parameter_overrides.setter
    def parameter_overrides(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "parameterOverrides", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)

    @builtins.property
    @jsii.member(jsii_name="retainStack")
    def retain_stack(self) -> typing.Optional[bool]:
        return jsii.get(self, "retainStack")

    @retain_stack.setter
    def retain_stack(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "retainStack", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CloudformationStackSetInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["CloudformationStackSetInstanceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackSetInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_set_name": "stackSetName",
        "account_id": "accountId",
        "parameter_overrides": "parameterOverrides",
        "region": "region",
        "retain_stack": "retainStack",
        "timeouts": "timeouts",
    },
)
class CloudformationStackSetInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_set_name: str,
        account_id: typing.Optional[str] = None,
        parameter_overrides: typing.Optional[typing.Mapping[str, str]] = None,
        region: typing.Optional[str] = None,
        retain_stack: typing.Optional[bool] = None,
        timeouts: typing.Optional["CloudformationStackSetInstanceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_set_name: 
        :param account_id: 
        :param parameter_overrides: 
        :param region: 
        :param retain_stack: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CloudformationStackSetInstanceTimeouts(**timeouts)
        self._values = {
            "stack_set_name": stack_set_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if account_id is not None:
            self._values["account_id"] = account_id
        if parameter_overrides is not None:
            self._values["parameter_overrides"] = parameter_overrides
        if region is not None:
            self._values["region"] = region
        if retain_stack is not None:
            self._values["retain_stack"] = retain_stack
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_set_name(self) -> str:
        return self._values.get("stack_set_name")

    @builtins.property
    def account_id(self) -> typing.Optional[str]:
        return self._values.get("account_id")

    @builtins.property
    def parameter_overrides(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameter_overrides")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    @builtins.property
    def retain_stack(self) -> typing.Optional[bool]:
        return self._values.get("retain_stack")

    @builtins.property
    def timeouts(self) -> typing.Optional["CloudformationStackSetInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudformationStackSetInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackSetInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class CloudformationStackSetInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudformationStackSetInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackSetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"update": "update"},
)
class CloudformationStackSetTimeouts:
    def __init__(self, *, update: typing.Optional[str] = None) -> None:
        """
        :param update: 
        """
        self._values = {}
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudformationStackSetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudformationStackTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class CloudformationStackTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudformationStackTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudfrontDistribution(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistribution",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_cache_behavior: typing.List[
            "CloudfrontDistributionDefaultCacheBehavior"
        ],
        enabled: bool,
        origin: typing.List["CloudfrontDistributionOrigin"],
        restrictions: typing.List["CloudfrontDistributionRestrictions"],
        viewer_certificate: typing.List["CloudfrontDistributionViewerCertificate"],
        aliases: typing.Optional[typing.List[str]] = None,
        cache_behavior: typing.Optional[
            typing.List["CloudfrontDistributionCacheBehavior"]
        ] = None,
        comment: typing.Optional[str] = None,
        custom_error_response: typing.Optional[
            typing.List["CloudfrontDistributionCustomErrorResponse"]
        ] = None,
        default_root_object: typing.Optional[str] = None,
        http_version: typing.Optional[str] = None,
        is_ipv6_enabled: typing.Optional[bool] = None,
        logging_config: typing.Optional[
            typing.List["CloudfrontDistributionLoggingConfig"]
        ] = None,
        ordered_cache_behavior: typing.Optional[
            typing.List["CloudfrontDistributionOrderedCacheBehavior"]
        ] = None,
        origin_group: typing.Optional[
            typing.List["CloudfrontDistributionOriginGroup"]
        ] = None,
        price_class: typing.Optional[str] = None,
        retain_on_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        wait_for_deployment: typing.Optional[bool] = None,
        web_acl_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_cache_behavior: default_cache_behavior block.
        :param enabled: 
        :param origin: origin block.
        :param restrictions: restrictions block.
        :param viewer_certificate: viewer_certificate block.
        :param aliases: 
        :param cache_behavior: cache_behavior block.
        :param comment: 
        :param custom_error_response: custom_error_response block.
        :param default_root_object: 
        :param http_version: 
        :param is_ipv6_enabled: 
        :param logging_config: logging_config block.
        :param ordered_cache_behavior: ordered_cache_behavior block.
        :param origin_group: origin_group block.
        :param price_class: 
        :param retain_on_delete: 
        :param tags: 
        :param wait_for_deployment: 
        :param web_acl_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudfrontDistributionConfig(
            default_cache_behavior=default_cache_behavior,
            enabled=enabled,
            origin=origin,
            restrictions=restrictions,
            viewer_certificate=viewer_certificate,
            aliases=aliases,
            cache_behavior=cache_behavior,
            comment=comment,
            custom_error_response=custom_error_response,
            default_root_object=default_root_object,
            http_version=http_version,
            is_ipv6_enabled=is_ipv6_enabled,
            logging_config=logging_config,
            ordered_cache_behavior=ordered_cache_behavior,
            origin_group=origin_group,
            price_class=price_class,
            retain_on_delete=retain_on_delete,
            tags=tags,
            wait_for_deployment=wait_for_deployment,
            web_acl_id=web_acl_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudfrontDistribution, self, [scope, id, config])

    @jsii.member(jsii_name="activeTrustedSigners")
    def active_trusted_signers(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "activeTrustedSigners", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="callerReference")
    def caller_reference(self) -> str:
        return jsii.get(self, "callerReference")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @builtins.property
    @jsii.member(jsii_name="etag")
    def etag(self) -> str:
        return jsii.get(self, "etag")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="inProgressValidationBatches")
    def in_progress_validation_batches(self) -> jsii.Number:
        return jsii.get(self, "inProgressValidationBatches")

    @builtins.property
    @jsii.member(jsii_name="lastModifiedTime")
    def last_modified_time(self) -> str:
        return jsii.get(self, "lastModifiedTime")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="defaultCacheBehavior")
    def default_cache_behavior(
        self,
    ) -> typing.List["CloudfrontDistributionDefaultCacheBehavior"]:
        return jsii.get(self, "defaultCacheBehavior")

    @default_cache_behavior.setter
    def default_cache_behavior(
        self, value: typing.List["CloudfrontDistributionDefaultCacheBehavior"]
    ) -> None:
        jsii.set(self, "defaultCacheBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: bool) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="origin")
    def origin(self) -> typing.List["CloudfrontDistributionOrigin"]:
        return jsii.get(self, "origin")

    @origin.setter
    def origin(self, value: typing.List["CloudfrontDistributionOrigin"]) -> None:
        jsii.set(self, "origin", value)

    @builtins.property
    @jsii.member(jsii_name="restrictions")
    def restrictions(self) -> typing.List["CloudfrontDistributionRestrictions"]:
        return jsii.get(self, "restrictions")

    @restrictions.setter
    def restrictions(
        self, value: typing.List["CloudfrontDistributionRestrictions"]
    ) -> None:
        jsii.set(self, "restrictions", value)

    @builtins.property
    @jsii.member(jsii_name="viewerCertificate")
    def viewer_certificate(
        self,
    ) -> typing.List["CloudfrontDistributionViewerCertificate"]:
        return jsii.get(self, "viewerCertificate")

    @viewer_certificate.setter
    def viewer_certificate(
        self, value: typing.List["CloudfrontDistributionViewerCertificate"]
    ) -> None:
        jsii.set(self, "viewerCertificate", value)

    @builtins.property
    @jsii.member(jsii_name="aliases")
    def aliases(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "aliases")

    @aliases.setter
    def aliases(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "aliases", value)

    @builtins.property
    @jsii.member(jsii_name="cacheBehavior")
    def cache_behavior(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionCacheBehavior"]]:
        return jsii.get(self, "cacheBehavior")

    @cache_behavior.setter
    def cache_behavior(
        self, value: typing.Optional[typing.List["CloudfrontDistributionCacheBehavior"]]
    ) -> None:
        jsii.set(self, "cacheBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="comment")
    def comment(self) -> typing.Optional[str]:
        return jsii.get(self, "comment")

    @comment.setter
    def comment(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "comment", value)

    @builtins.property
    @jsii.member(jsii_name="customErrorResponse")
    def custom_error_response(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionCustomErrorResponse"]]:
        return jsii.get(self, "customErrorResponse")

    @custom_error_response.setter
    def custom_error_response(
        self,
        value: typing.Optional[
            typing.List["CloudfrontDistributionCustomErrorResponse"]
        ],
    ) -> None:
        jsii.set(self, "customErrorResponse", value)

    @builtins.property
    @jsii.member(jsii_name="defaultRootObject")
    def default_root_object(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultRootObject")

    @default_root_object.setter
    def default_root_object(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultRootObject", value)

    @builtins.property
    @jsii.member(jsii_name="httpVersion")
    def http_version(self) -> typing.Optional[str]:
        return jsii.get(self, "httpVersion")

    @http_version.setter
    def http_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "httpVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="isIpv6Enabled")
    def is_ipv6_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "isIpv6Enabled")

    @is_ipv6_enabled.setter
    def is_ipv6_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "isIpv6Enabled", value)

    @builtins.property
    @jsii.member(jsii_name="loggingConfig")
    def logging_config(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionLoggingConfig"]]:
        return jsii.get(self, "loggingConfig")

    @logging_config.setter
    def logging_config(
        self, value: typing.Optional[typing.List["CloudfrontDistributionLoggingConfig"]]
    ) -> None:
        jsii.set(self, "loggingConfig", value)

    @builtins.property
    @jsii.member(jsii_name="orderedCacheBehavior")
    def ordered_cache_behavior(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionOrderedCacheBehavior"]]:
        return jsii.get(self, "orderedCacheBehavior")

    @ordered_cache_behavior.setter
    def ordered_cache_behavior(
        self,
        value: typing.Optional[
            typing.List["CloudfrontDistributionOrderedCacheBehavior"]
        ],
    ) -> None:
        jsii.set(self, "orderedCacheBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="originGroup")
    def origin_group(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionOriginGroup"]]:
        return jsii.get(self, "originGroup")

    @origin_group.setter
    def origin_group(
        self, value: typing.Optional[typing.List["CloudfrontDistributionOriginGroup"]]
    ) -> None:
        jsii.set(self, "originGroup", value)

    @builtins.property
    @jsii.member(jsii_name="priceClass")
    def price_class(self) -> typing.Optional[str]:
        return jsii.get(self, "priceClass")

    @price_class.setter
    def price_class(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "priceClass", value)

    @builtins.property
    @jsii.member(jsii_name="retainOnDelete")
    def retain_on_delete(self) -> typing.Optional[bool]:
        return jsii.get(self, "retainOnDelete")

    @retain_on_delete.setter
    def retain_on_delete(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "retainOnDelete", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="waitForDeployment")
    def wait_for_deployment(self) -> typing.Optional[bool]:
        return jsii.get(self, "waitForDeployment")

    @wait_for_deployment.setter
    def wait_for_deployment(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "waitForDeployment", value)

    @builtins.property
    @jsii.member(jsii_name="webAclId")
    def web_acl_id(self) -> typing.Optional[str]:
        return jsii.get(self, "webAclId")

    @web_acl_id.setter
    def web_acl_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "webAclId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionCacheBehavior",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_methods": "allowedMethods",
        "cached_methods": "cachedMethods",
        "forwarded_values": "forwardedValues",
        "path_pattern": "pathPattern",
        "target_origin_id": "targetOriginId",
        "viewer_protocol_policy": "viewerProtocolPolicy",
        "compress": "compress",
        "default_ttl": "defaultTtl",
        "field_level_encryption_id": "fieldLevelEncryptionId",
        "lambda_function_association": "lambdaFunctionAssociation",
        "max_ttl": "maxTtl",
        "min_ttl": "minTtl",
        "smooth_streaming": "smoothStreaming",
        "trusted_signers": "trustedSigners",
    },
)
class CloudfrontDistributionCacheBehavior:
    def __init__(
        self,
        *,
        allowed_methods: typing.List[str],
        cached_methods: typing.List[str],
        forwarded_values: typing.List[
            "CloudfrontDistributionCacheBehaviorForwardedValues"
        ],
        path_pattern: str,
        target_origin_id: str,
        viewer_protocol_policy: str,
        compress: typing.Optional[bool] = None,
        default_ttl: typing.Optional[jsii.Number] = None,
        field_level_encryption_id: typing.Optional[str] = None,
        lambda_function_association: typing.Optional[
            typing.List["CloudfrontDistributionCacheBehaviorLambdaFunctionAssociation"]
        ] = None,
        max_ttl: typing.Optional[jsii.Number] = None,
        min_ttl: typing.Optional[jsii.Number] = None,
        smooth_streaming: typing.Optional[bool] = None,
        trusted_signers: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param allowed_methods: 
        :param cached_methods: 
        :param forwarded_values: forwarded_values block.
        :param path_pattern: 
        :param target_origin_id: 
        :param viewer_protocol_policy: 
        :param compress: 
        :param default_ttl: 
        :param field_level_encryption_id: 
        :param lambda_function_association: lambda_function_association block.
        :param max_ttl: 
        :param min_ttl: 
        :param smooth_streaming: 
        :param trusted_signers: 
        """
        self._values = {
            "allowed_methods": allowed_methods,
            "cached_methods": cached_methods,
            "forwarded_values": forwarded_values,
            "path_pattern": path_pattern,
            "target_origin_id": target_origin_id,
            "viewer_protocol_policy": viewer_protocol_policy,
        }
        if compress is not None:
            self._values["compress"] = compress
        if default_ttl is not None:
            self._values["default_ttl"] = default_ttl
        if field_level_encryption_id is not None:
            self._values["field_level_encryption_id"] = field_level_encryption_id
        if lambda_function_association is not None:
            self._values["lambda_function_association"] = lambda_function_association
        if max_ttl is not None:
            self._values["max_ttl"] = max_ttl
        if min_ttl is not None:
            self._values["min_ttl"] = min_ttl
        if smooth_streaming is not None:
            self._values["smooth_streaming"] = smooth_streaming
        if trusted_signers is not None:
            self._values["trusted_signers"] = trusted_signers

    @builtins.property
    def allowed_methods(self) -> typing.List[str]:
        return self._values.get("allowed_methods")

    @builtins.property
    def cached_methods(self) -> typing.List[str]:
        return self._values.get("cached_methods")

    @builtins.property
    def forwarded_values(
        self,
    ) -> typing.List["CloudfrontDistributionCacheBehaviorForwardedValues"]:
        """forwarded_values block."""
        return self._values.get("forwarded_values")

    @builtins.property
    def path_pattern(self) -> str:
        return self._values.get("path_pattern")

    @builtins.property
    def target_origin_id(self) -> str:
        return self._values.get("target_origin_id")

    @builtins.property
    def viewer_protocol_policy(self) -> str:
        return self._values.get("viewer_protocol_policy")

    @builtins.property
    def compress(self) -> typing.Optional[bool]:
        return self._values.get("compress")

    @builtins.property
    def default_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("default_ttl")

    @builtins.property
    def field_level_encryption_id(self) -> typing.Optional[str]:
        return self._values.get("field_level_encryption_id")

    @builtins.property
    def lambda_function_association(
        self,
    ) -> typing.Optional[
        typing.List["CloudfrontDistributionCacheBehaviorLambdaFunctionAssociation"]
    ]:
        """lambda_function_association block."""
        return self._values.get("lambda_function_association")

    @builtins.property
    def max_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_ttl")

    @builtins.property
    def min_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_ttl")

    @builtins.property
    def smooth_streaming(self) -> typing.Optional[bool]:
        return self._values.get("smooth_streaming")

    @builtins.property
    def trusted_signers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("trusted_signers")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionCacheBehavior(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionCacheBehaviorForwardedValues",
    jsii_struct_bases=[],
    name_mapping={
        "cookies": "cookies",
        "query_string": "queryString",
        "headers": "headers",
        "query_string_cache_keys": "queryStringCacheKeys",
    },
)
class CloudfrontDistributionCacheBehaviorForwardedValues:
    def __init__(
        self,
        *,
        cookies: typing.List[
            "CloudfrontDistributionCacheBehaviorForwardedValuesCookies"
        ],
        query_string: bool,
        headers: typing.Optional[typing.List[str]] = None,
        query_string_cache_keys: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param cookies: cookies block.
        :param query_string: 
        :param headers: 
        :param query_string_cache_keys: 
        """
        self._values = {
            "cookies": cookies,
            "query_string": query_string,
        }
        if headers is not None:
            self._values["headers"] = headers
        if query_string_cache_keys is not None:
            self._values["query_string_cache_keys"] = query_string_cache_keys

    @builtins.property
    def cookies(
        self,
    ) -> typing.List["CloudfrontDistributionCacheBehaviorForwardedValuesCookies"]:
        """cookies block."""
        return self._values.get("cookies")

    @builtins.property
    def query_string(self) -> bool:
        return self._values.get("query_string")

    @builtins.property
    def headers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("headers")

    @builtins.property
    def query_string_cache_keys(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("query_string_cache_keys")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionCacheBehaviorForwardedValues(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionCacheBehaviorForwardedValuesCookies",
    jsii_struct_bases=[],
    name_mapping={"forward": "forward", "whitelisted_names": "whitelistedNames"},
)
class CloudfrontDistributionCacheBehaviorForwardedValuesCookies:
    def __init__(
        self,
        *,
        forward: str,
        whitelisted_names: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param forward: 
        :param whitelisted_names: 
        """
        self._values = {
            "forward": forward,
        }
        if whitelisted_names is not None:
            self._values["whitelisted_names"] = whitelisted_names

    @builtins.property
    def forward(self) -> str:
        return self._values.get("forward")

    @builtins.property
    def whitelisted_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("whitelisted_names")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionCacheBehaviorForwardedValuesCookies(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionCacheBehaviorLambdaFunctionAssociation",
    jsii_struct_bases=[],
    name_mapping={
        "event_type": "eventType",
        "lambda_arn": "lambdaArn",
        "include_body": "includeBody",
    },
)
class CloudfrontDistributionCacheBehaviorLambdaFunctionAssociation:
    def __init__(
        self,
        *,
        event_type: str,
        lambda_arn: str,
        include_body: typing.Optional[bool] = None,
    ) -> None:
        """
        :param event_type: 
        :param lambda_arn: 
        :param include_body: 
        """
        self._values = {
            "event_type": event_type,
            "lambda_arn": lambda_arn,
        }
        if include_body is not None:
            self._values["include_body"] = include_body

    @builtins.property
    def event_type(self) -> str:
        return self._values.get("event_type")

    @builtins.property
    def lambda_arn(self) -> str:
        return self._values.get("lambda_arn")

    @builtins.property
    def include_body(self) -> typing.Optional[bool]:
        return self._values.get("include_body")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionCacheBehaviorLambdaFunctionAssociation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_cache_behavior": "defaultCacheBehavior",
        "enabled": "enabled",
        "origin": "origin",
        "restrictions": "restrictions",
        "viewer_certificate": "viewerCertificate",
        "aliases": "aliases",
        "cache_behavior": "cacheBehavior",
        "comment": "comment",
        "custom_error_response": "customErrorResponse",
        "default_root_object": "defaultRootObject",
        "http_version": "httpVersion",
        "is_ipv6_enabled": "isIpv6Enabled",
        "logging_config": "loggingConfig",
        "ordered_cache_behavior": "orderedCacheBehavior",
        "origin_group": "originGroup",
        "price_class": "priceClass",
        "retain_on_delete": "retainOnDelete",
        "tags": "tags",
        "wait_for_deployment": "waitForDeployment",
        "web_acl_id": "webAclId",
    },
)
class CloudfrontDistributionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_cache_behavior: typing.List[
            "CloudfrontDistributionDefaultCacheBehavior"
        ],
        enabled: bool,
        origin: typing.List["CloudfrontDistributionOrigin"],
        restrictions: typing.List["CloudfrontDistributionRestrictions"],
        viewer_certificate: typing.List["CloudfrontDistributionViewerCertificate"],
        aliases: typing.Optional[typing.List[str]] = None,
        cache_behavior: typing.Optional[
            typing.List["CloudfrontDistributionCacheBehavior"]
        ] = None,
        comment: typing.Optional[str] = None,
        custom_error_response: typing.Optional[
            typing.List["CloudfrontDistributionCustomErrorResponse"]
        ] = None,
        default_root_object: typing.Optional[str] = None,
        http_version: typing.Optional[str] = None,
        is_ipv6_enabled: typing.Optional[bool] = None,
        logging_config: typing.Optional[
            typing.List["CloudfrontDistributionLoggingConfig"]
        ] = None,
        ordered_cache_behavior: typing.Optional[
            typing.List["CloudfrontDistributionOrderedCacheBehavior"]
        ] = None,
        origin_group: typing.Optional[
            typing.List["CloudfrontDistributionOriginGroup"]
        ] = None,
        price_class: typing.Optional[str] = None,
        retain_on_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        wait_for_deployment: typing.Optional[bool] = None,
        web_acl_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_cache_behavior: default_cache_behavior block.
        :param enabled: 
        :param origin: origin block.
        :param restrictions: restrictions block.
        :param viewer_certificate: viewer_certificate block.
        :param aliases: 
        :param cache_behavior: cache_behavior block.
        :param comment: 
        :param custom_error_response: custom_error_response block.
        :param default_root_object: 
        :param http_version: 
        :param is_ipv6_enabled: 
        :param logging_config: logging_config block.
        :param ordered_cache_behavior: ordered_cache_behavior block.
        :param origin_group: origin_group block.
        :param price_class: 
        :param retain_on_delete: 
        :param tags: 
        :param wait_for_deployment: 
        :param web_acl_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "default_cache_behavior": default_cache_behavior,
            "enabled": enabled,
            "origin": origin,
            "restrictions": restrictions,
            "viewer_certificate": viewer_certificate,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if aliases is not None:
            self._values["aliases"] = aliases
        if cache_behavior is not None:
            self._values["cache_behavior"] = cache_behavior
        if comment is not None:
            self._values["comment"] = comment
        if custom_error_response is not None:
            self._values["custom_error_response"] = custom_error_response
        if default_root_object is not None:
            self._values["default_root_object"] = default_root_object
        if http_version is not None:
            self._values["http_version"] = http_version
        if is_ipv6_enabled is not None:
            self._values["is_ipv6_enabled"] = is_ipv6_enabled
        if logging_config is not None:
            self._values["logging_config"] = logging_config
        if ordered_cache_behavior is not None:
            self._values["ordered_cache_behavior"] = ordered_cache_behavior
        if origin_group is not None:
            self._values["origin_group"] = origin_group
        if price_class is not None:
            self._values["price_class"] = price_class
        if retain_on_delete is not None:
            self._values["retain_on_delete"] = retain_on_delete
        if tags is not None:
            self._values["tags"] = tags
        if wait_for_deployment is not None:
            self._values["wait_for_deployment"] = wait_for_deployment
        if web_acl_id is not None:
            self._values["web_acl_id"] = web_acl_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_cache_behavior(
        self,
    ) -> typing.List["CloudfrontDistributionDefaultCacheBehavior"]:
        """default_cache_behavior block."""
        return self._values.get("default_cache_behavior")

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def origin(self) -> typing.List["CloudfrontDistributionOrigin"]:
        """origin block."""
        return self._values.get("origin")

    @builtins.property
    def restrictions(self) -> typing.List["CloudfrontDistributionRestrictions"]:
        """restrictions block."""
        return self._values.get("restrictions")

    @builtins.property
    def viewer_certificate(
        self,
    ) -> typing.List["CloudfrontDistributionViewerCertificate"]:
        """viewer_certificate block."""
        return self._values.get("viewer_certificate")

    @builtins.property
    def aliases(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("aliases")

    @builtins.property
    def cache_behavior(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionCacheBehavior"]]:
        """cache_behavior block."""
        return self._values.get("cache_behavior")

    @builtins.property
    def comment(self) -> typing.Optional[str]:
        return self._values.get("comment")

    @builtins.property
    def custom_error_response(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionCustomErrorResponse"]]:
        """custom_error_response block."""
        return self._values.get("custom_error_response")

    @builtins.property
    def default_root_object(self) -> typing.Optional[str]:
        return self._values.get("default_root_object")

    @builtins.property
    def http_version(self) -> typing.Optional[str]:
        return self._values.get("http_version")

    @builtins.property
    def is_ipv6_enabled(self) -> typing.Optional[bool]:
        return self._values.get("is_ipv6_enabled")

    @builtins.property
    def logging_config(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionLoggingConfig"]]:
        """logging_config block."""
        return self._values.get("logging_config")

    @builtins.property
    def ordered_cache_behavior(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionOrderedCacheBehavior"]]:
        """ordered_cache_behavior block."""
        return self._values.get("ordered_cache_behavior")

    @builtins.property
    def origin_group(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionOriginGroup"]]:
        """origin_group block."""
        return self._values.get("origin_group")

    @builtins.property
    def price_class(self) -> typing.Optional[str]:
        return self._values.get("price_class")

    @builtins.property
    def retain_on_delete(self) -> typing.Optional[bool]:
        return self._values.get("retain_on_delete")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def wait_for_deployment(self) -> typing.Optional[bool]:
        return self._values.get("wait_for_deployment")

    @builtins.property
    def web_acl_id(self) -> typing.Optional[str]:
        return self._values.get("web_acl_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionCustomErrorResponse",
    jsii_struct_bases=[],
    name_mapping={
        "error_code": "errorCode",
        "error_caching_min_ttl": "errorCachingMinTtl",
        "response_code": "responseCode",
        "response_page_path": "responsePagePath",
    },
)
class CloudfrontDistributionCustomErrorResponse:
    def __init__(
        self,
        *,
        error_code: jsii.Number,
        error_caching_min_ttl: typing.Optional[jsii.Number] = None,
        response_code: typing.Optional[jsii.Number] = None,
        response_page_path: typing.Optional[str] = None,
    ) -> None:
        """
        :param error_code: 
        :param error_caching_min_ttl: 
        :param response_code: 
        :param response_page_path: 
        """
        self._values = {
            "error_code": error_code,
        }
        if error_caching_min_ttl is not None:
            self._values["error_caching_min_ttl"] = error_caching_min_ttl
        if response_code is not None:
            self._values["response_code"] = response_code
        if response_page_path is not None:
            self._values["response_page_path"] = response_page_path

    @builtins.property
    def error_code(self) -> jsii.Number:
        return self._values.get("error_code")

    @builtins.property
    def error_caching_min_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("error_caching_min_ttl")

    @builtins.property
    def response_code(self) -> typing.Optional[jsii.Number]:
        return self._values.get("response_code")

    @builtins.property
    def response_page_path(self) -> typing.Optional[str]:
        return self._values.get("response_page_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionCustomErrorResponse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionDefaultCacheBehavior",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_methods": "allowedMethods",
        "cached_methods": "cachedMethods",
        "forwarded_values": "forwardedValues",
        "target_origin_id": "targetOriginId",
        "viewer_protocol_policy": "viewerProtocolPolicy",
        "compress": "compress",
        "default_ttl": "defaultTtl",
        "field_level_encryption_id": "fieldLevelEncryptionId",
        "lambda_function_association": "lambdaFunctionAssociation",
        "max_ttl": "maxTtl",
        "min_ttl": "minTtl",
        "smooth_streaming": "smoothStreaming",
        "trusted_signers": "trustedSigners",
    },
)
class CloudfrontDistributionDefaultCacheBehavior:
    def __init__(
        self,
        *,
        allowed_methods: typing.List[str],
        cached_methods: typing.List[str],
        forwarded_values: typing.List[
            "CloudfrontDistributionDefaultCacheBehaviorForwardedValues"
        ],
        target_origin_id: str,
        viewer_protocol_policy: str,
        compress: typing.Optional[bool] = None,
        default_ttl: typing.Optional[jsii.Number] = None,
        field_level_encryption_id: typing.Optional[str] = None,
        lambda_function_association: typing.Optional[
            typing.List[
                "CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation"
            ]
        ] = None,
        max_ttl: typing.Optional[jsii.Number] = None,
        min_ttl: typing.Optional[jsii.Number] = None,
        smooth_streaming: typing.Optional[bool] = None,
        trusted_signers: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param allowed_methods: 
        :param cached_methods: 
        :param forwarded_values: forwarded_values block.
        :param target_origin_id: 
        :param viewer_protocol_policy: 
        :param compress: 
        :param default_ttl: 
        :param field_level_encryption_id: 
        :param lambda_function_association: lambda_function_association block.
        :param max_ttl: 
        :param min_ttl: 
        :param smooth_streaming: 
        :param trusted_signers: 
        """
        self._values = {
            "allowed_methods": allowed_methods,
            "cached_methods": cached_methods,
            "forwarded_values": forwarded_values,
            "target_origin_id": target_origin_id,
            "viewer_protocol_policy": viewer_protocol_policy,
        }
        if compress is not None:
            self._values["compress"] = compress
        if default_ttl is not None:
            self._values["default_ttl"] = default_ttl
        if field_level_encryption_id is not None:
            self._values["field_level_encryption_id"] = field_level_encryption_id
        if lambda_function_association is not None:
            self._values["lambda_function_association"] = lambda_function_association
        if max_ttl is not None:
            self._values["max_ttl"] = max_ttl
        if min_ttl is not None:
            self._values["min_ttl"] = min_ttl
        if smooth_streaming is not None:
            self._values["smooth_streaming"] = smooth_streaming
        if trusted_signers is not None:
            self._values["trusted_signers"] = trusted_signers

    @builtins.property
    def allowed_methods(self) -> typing.List[str]:
        return self._values.get("allowed_methods")

    @builtins.property
    def cached_methods(self) -> typing.List[str]:
        return self._values.get("cached_methods")

    @builtins.property
    def forwarded_values(
        self,
    ) -> typing.List["CloudfrontDistributionDefaultCacheBehaviorForwardedValues"]:
        """forwarded_values block."""
        return self._values.get("forwarded_values")

    @builtins.property
    def target_origin_id(self) -> str:
        return self._values.get("target_origin_id")

    @builtins.property
    def viewer_protocol_policy(self) -> str:
        return self._values.get("viewer_protocol_policy")

    @builtins.property
    def compress(self) -> typing.Optional[bool]:
        return self._values.get("compress")

    @builtins.property
    def default_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("default_ttl")

    @builtins.property
    def field_level_encryption_id(self) -> typing.Optional[str]:
        return self._values.get("field_level_encryption_id")

    @builtins.property
    def lambda_function_association(
        self,
    ) -> typing.Optional[
        typing.List[
            "CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation"
        ]
    ]:
        """lambda_function_association block."""
        return self._values.get("lambda_function_association")

    @builtins.property
    def max_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_ttl")

    @builtins.property
    def min_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_ttl")

    @builtins.property
    def smooth_streaming(self) -> typing.Optional[bool]:
        return self._values.get("smooth_streaming")

    @builtins.property
    def trusted_signers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("trusted_signers")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionDefaultCacheBehavior(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionDefaultCacheBehaviorForwardedValues",
    jsii_struct_bases=[],
    name_mapping={
        "cookies": "cookies",
        "query_string": "queryString",
        "headers": "headers",
        "query_string_cache_keys": "queryStringCacheKeys",
    },
)
class CloudfrontDistributionDefaultCacheBehaviorForwardedValues:
    def __init__(
        self,
        *,
        cookies: typing.List[
            "CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies"
        ],
        query_string: bool,
        headers: typing.Optional[typing.List[str]] = None,
        query_string_cache_keys: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param cookies: cookies block.
        :param query_string: 
        :param headers: 
        :param query_string_cache_keys: 
        """
        self._values = {
            "cookies": cookies,
            "query_string": query_string,
        }
        if headers is not None:
            self._values["headers"] = headers
        if query_string_cache_keys is not None:
            self._values["query_string_cache_keys"] = query_string_cache_keys

    @builtins.property
    def cookies(
        self,
    ) -> typing.List[
        "CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies"
    ]:
        """cookies block."""
        return self._values.get("cookies")

    @builtins.property
    def query_string(self) -> bool:
        return self._values.get("query_string")

    @builtins.property
    def headers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("headers")

    @builtins.property
    def query_string_cache_keys(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("query_string_cache_keys")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionDefaultCacheBehaviorForwardedValues(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies",
    jsii_struct_bases=[],
    name_mapping={"forward": "forward", "whitelisted_names": "whitelistedNames"},
)
class CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies:
    def __init__(
        self,
        *,
        forward: str,
        whitelisted_names: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param forward: 
        :param whitelisted_names: 
        """
        self._values = {
            "forward": forward,
        }
        if whitelisted_names is not None:
            self._values["whitelisted_names"] = whitelisted_names

    @builtins.property
    def forward(self) -> str:
        return self._values.get("forward")

    @builtins.property
    def whitelisted_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("whitelisted_names")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation",
    jsii_struct_bases=[],
    name_mapping={
        "event_type": "eventType",
        "lambda_arn": "lambdaArn",
        "include_body": "includeBody",
    },
)
class CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation:
    def __init__(
        self,
        *,
        event_type: str,
        lambda_arn: str,
        include_body: typing.Optional[bool] = None,
    ) -> None:
        """
        :param event_type: 
        :param lambda_arn: 
        :param include_body: 
        """
        self._values = {
            "event_type": event_type,
            "lambda_arn": lambda_arn,
        }
        if include_body is not None:
            self._values["include_body"] = include_body

    @builtins.property
    def event_type(self) -> str:
        return self._values.get("event_type")

    @builtins.property
    def lambda_arn(self) -> str:
        return self._values.get("lambda_arn")

    @builtins.property
    def include_body(self) -> typing.Optional[bool]:
        return self._values.get("include_body")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionLoggingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "bucket": "bucket",
        "include_cookies": "includeCookies",
        "prefix": "prefix",
    },
)
class CloudfrontDistributionLoggingConfig:
    def __init__(
        self,
        *,
        bucket: str,
        include_cookies: typing.Optional[bool] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket: 
        :param include_cookies: 
        :param prefix: 
        """
        self._values = {
            "bucket": bucket,
        }
        if include_cookies is not None:
            self._values["include_cookies"] = include_cookies
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def include_cookies(self) -> typing.Optional[bool]:
        return self._values.get("include_cookies")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionLoggingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOrderedCacheBehavior",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_methods": "allowedMethods",
        "cached_methods": "cachedMethods",
        "forwarded_values": "forwardedValues",
        "path_pattern": "pathPattern",
        "target_origin_id": "targetOriginId",
        "viewer_protocol_policy": "viewerProtocolPolicy",
        "compress": "compress",
        "default_ttl": "defaultTtl",
        "field_level_encryption_id": "fieldLevelEncryptionId",
        "lambda_function_association": "lambdaFunctionAssociation",
        "max_ttl": "maxTtl",
        "min_ttl": "minTtl",
        "smooth_streaming": "smoothStreaming",
        "trusted_signers": "trustedSigners",
    },
)
class CloudfrontDistributionOrderedCacheBehavior:
    def __init__(
        self,
        *,
        allowed_methods: typing.List[str],
        cached_methods: typing.List[str],
        forwarded_values: typing.List[
            "CloudfrontDistributionOrderedCacheBehaviorForwardedValues"
        ],
        path_pattern: str,
        target_origin_id: str,
        viewer_protocol_policy: str,
        compress: typing.Optional[bool] = None,
        default_ttl: typing.Optional[jsii.Number] = None,
        field_level_encryption_id: typing.Optional[str] = None,
        lambda_function_association: typing.Optional[
            typing.List[
                "CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation"
            ]
        ] = None,
        max_ttl: typing.Optional[jsii.Number] = None,
        min_ttl: typing.Optional[jsii.Number] = None,
        smooth_streaming: typing.Optional[bool] = None,
        trusted_signers: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param allowed_methods: 
        :param cached_methods: 
        :param forwarded_values: forwarded_values block.
        :param path_pattern: 
        :param target_origin_id: 
        :param viewer_protocol_policy: 
        :param compress: 
        :param default_ttl: 
        :param field_level_encryption_id: 
        :param lambda_function_association: lambda_function_association block.
        :param max_ttl: 
        :param min_ttl: 
        :param smooth_streaming: 
        :param trusted_signers: 
        """
        self._values = {
            "allowed_methods": allowed_methods,
            "cached_methods": cached_methods,
            "forwarded_values": forwarded_values,
            "path_pattern": path_pattern,
            "target_origin_id": target_origin_id,
            "viewer_protocol_policy": viewer_protocol_policy,
        }
        if compress is not None:
            self._values["compress"] = compress
        if default_ttl is not None:
            self._values["default_ttl"] = default_ttl
        if field_level_encryption_id is not None:
            self._values["field_level_encryption_id"] = field_level_encryption_id
        if lambda_function_association is not None:
            self._values["lambda_function_association"] = lambda_function_association
        if max_ttl is not None:
            self._values["max_ttl"] = max_ttl
        if min_ttl is not None:
            self._values["min_ttl"] = min_ttl
        if smooth_streaming is not None:
            self._values["smooth_streaming"] = smooth_streaming
        if trusted_signers is not None:
            self._values["trusted_signers"] = trusted_signers

    @builtins.property
    def allowed_methods(self) -> typing.List[str]:
        return self._values.get("allowed_methods")

    @builtins.property
    def cached_methods(self) -> typing.List[str]:
        return self._values.get("cached_methods")

    @builtins.property
    def forwarded_values(
        self,
    ) -> typing.List["CloudfrontDistributionOrderedCacheBehaviorForwardedValues"]:
        """forwarded_values block."""
        return self._values.get("forwarded_values")

    @builtins.property
    def path_pattern(self) -> str:
        return self._values.get("path_pattern")

    @builtins.property
    def target_origin_id(self) -> str:
        return self._values.get("target_origin_id")

    @builtins.property
    def viewer_protocol_policy(self) -> str:
        return self._values.get("viewer_protocol_policy")

    @builtins.property
    def compress(self) -> typing.Optional[bool]:
        return self._values.get("compress")

    @builtins.property
    def default_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("default_ttl")

    @builtins.property
    def field_level_encryption_id(self) -> typing.Optional[str]:
        return self._values.get("field_level_encryption_id")

    @builtins.property
    def lambda_function_association(
        self,
    ) -> typing.Optional[
        typing.List[
            "CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation"
        ]
    ]:
        """lambda_function_association block."""
        return self._values.get("lambda_function_association")

    @builtins.property
    def max_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_ttl")

    @builtins.property
    def min_ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_ttl")

    @builtins.property
    def smooth_streaming(self) -> typing.Optional[bool]:
        return self._values.get("smooth_streaming")

    @builtins.property
    def trusted_signers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("trusted_signers")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOrderedCacheBehavior(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOrderedCacheBehaviorForwardedValues",
    jsii_struct_bases=[],
    name_mapping={
        "cookies": "cookies",
        "query_string": "queryString",
        "headers": "headers",
        "query_string_cache_keys": "queryStringCacheKeys",
    },
)
class CloudfrontDistributionOrderedCacheBehaviorForwardedValues:
    def __init__(
        self,
        *,
        cookies: typing.List[
            "CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies"
        ],
        query_string: bool,
        headers: typing.Optional[typing.List[str]] = None,
        query_string_cache_keys: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param cookies: cookies block.
        :param query_string: 
        :param headers: 
        :param query_string_cache_keys: 
        """
        self._values = {
            "cookies": cookies,
            "query_string": query_string,
        }
        if headers is not None:
            self._values["headers"] = headers
        if query_string_cache_keys is not None:
            self._values["query_string_cache_keys"] = query_string_cache_keys

    @builtins.property
    def cookies(
        self,
    ) -> typing.List[
        "CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies"
    ]:
        """cookies block."""
        return self._values.get("cookies")

    @builtins.property
    def query_string(self) -> bool:
        return self._values.get("query_string")

    @builtins.property
    def headers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("headers")

    @builtins.property
    def query_string_cache_keys(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("query_string_cache_keys")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionOrderedCacheBehaviorForwardedValues(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies",
    jsii_struct_bases=[],
    name_mapping={"forward": "forward", "whitelisted_names": "whitelistedNames"},
)
class CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies:
    def __init__(
        self,
        *,
        forward: str,
        whitelisted_names: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param forward: 
        :param whitelisted_names: 
        """
        self._values = {
            "forward": forward,
        }
        if whitelisted_names is not None:
            self._values["whitelisted_names"] = whitelisted_names

    @builtins.property
    def forward(self) -> str:
        return self._values.get("forward")

    @builtins.property
    def whitelisted_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("whitelisted_names")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation",
    jsii_struct_bases=[],
    name_mapping={
        "event_type": "eventType",
        "lambda_arn": "lambdaArn",
        "include_body": "includeBody",
    },
)
class CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation:
    def __init__(
        self,
        *,
        event_type: str,
        lambda_arn: str,
        include_body: typing.Optional[bool] = None,
    ) -> None:
        """
        :param event_type: 
        :param lambda_arn: 
        :param include_body: 
        """
        self._values = {
            "event_type": event_type,
            "lambda_arn": lambda_arn,
        }
        if include_body is not None:
            self._values["include_body"] = include_body

    @builtins.property
    def event_type(self) -> str:
        return self._values.get("event_type")

    @builtins.property
    def lambda_arn(self) -> str:
        return self._values.get("lambda_arn")

    @builtins.property
    def include_body(self) -> typing.Optional[bool]:
        return self._values.get("include_body")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOrigin",
    jsii_struct_bases=[],
    name_mapping={
        "domain_name": "domainName",
        "origin_id": "originId",
        "custom_header": "customHeader",
        "custom_origin_config": "customOriginConfig",
        "origin_path": "originPath",
        "s3_origin_config": "s3OriginConfig",
    },
)
class CloudfrontDistributionOrigin:
    def __init__(
        self,
        *,
        domain_name: str,
        origin_id: str,
        custom_header: typing.Optional[
            typing.List["CloudfrontDistributionOriginCustomHeader"]
        ] = None,
        custom_origin_config: typing.Optional[
            typing.List["CloudfrontDistributionOriginCustomOriginConfig"]
        ] = None,
        origin_path: typing.Optional[str] = None,
        s3_origin_config: typing.Optional[
            typing.List["CloudfrontDistributionOriginS3OriginConfig"]
        ] = None,
    ) -> None:
        """
        :param domain_name: 
        :param origin_id: 
        :param custom_header: custom_header block.
        :param custom_origin_config: custom_origin_config block.
        :param origin_path: 
        :param s3_origin_config: s3_origin_config block.
        """
        self._values = {
            "domain_name": domain_name,
            "origin_id": origin_id,
        }
        if custom_header is not None:
            self._values["custom_header"] = custom_header
        if custom_origin_config is not None:
            self._values["custom_origin_config"] = custom_origin_config
        if origin_path is not None:
            self._values["origin_path"] = origin_path
        if s3_origin_config is not None:
            self._values["s3_origin_config"] = s3_origin_config

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def origin_id(self) -> str:
        return self._values.get("origin_id")

    @builtins.property
    def custom_header(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionOriginCustomHeader"]]:
        """custom_header block."""
        return self._values.get("custom_header")

    @builtins.property
    def custom_origin_config(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionOriginCustomOriginConfig"]]:
        """custom_origin_config block."""
        return self._values.get("custom_origin_config")

    @builtins.property
    def origin_path(self) -> typing.Optional[str]:
        return self._values.get("origin_path")

    @builtins.property
    def s3_origin_config(
        self,
    ) -> typing.Optional[typing.List["CloudfrontDistributionOriginS3OriginConfig"]]:
        """s3_origin_config block."""
        return self._values.get("s3_origin_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOrigin(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOriginCustomHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class CloudfrontDistributionOriginCustomHeader:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOriginCustomHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOriginCustomOriginConfig",
    jsii_struct_bases=[],
    name_mapping={
        "http_port": "httpPort",
        "https_port": "httpsPort",
        "origin_protocol_policy": "originProtocolPolicy",
        "origin_ssl_protocols": "originSslProtocols",
        "origin_keepalive_timeout": "originKeepaliveTimeout",
        "origin_read_timeout": "originReadTimeout",
    },
)
class CloudfrontDistributionOriginCustomOriginConfig:
    def __init__(
        self,
        *,
        http_port: jsii.Number,
        https_port: jsii.Number,
        origin_protocol_policy: str,
        origin_ssl_protocols: typing.List[str],
        origin_keepalive_timeout: typing.Optional[jsii.Number] = None,
        origin_read_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param http_port: 
        :param https_port: 
        :param origin_protocol_policy: 
        :param origin_ssl_protocols: 
        :param origin_keepalive_timeout: 
        :param origin_read_timeout: 
        """
        self._values = {
            "http_port": http_port,
            "https_port": https_port,
            "origin_protocol_policy": origin_protocol_policy,
            "origin_ssl_protocols": origin_ssl_protocols,
        }
        if origin_keepalive_timeout is not None:
            self._values["origin_keepalive_timeout"] = origin_keepalive_timeout
        if origin_read_timeout is not None:
            self._values["origin_read_timeout"] = origin_read_timeout

    @builtins.property
    def http_port(self) -> jsii.Number:
        return self._values.get("http_port")

    @builtins.property
    def https_port(self) -> jsii.Number:
        return self._values.get("https_port")

    @builtins.property
    def origin_protocol_policy(self) -> str:
        return self._values.get("origin_protocol_policy")

    @builtins.property
    def origin_ssl_protocols(self) -> typing.List[str]:
        return self._values.get("origin_ssl_protocols")

    @builtins.property
    def origin_keepalive_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("origin_keepalive_timeout")

    @builtins.property
    def origin_read_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("origin_read_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOriginCustomOriginConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOriginGroup",
    jsii_struct_bases=[],
    name_mapping={
        "failover_criteria": "failoverCriteria",
        "member": "member",
        "origin_id": "originId",
    },
)
class CloudfrontDistributionOriginGroup:
    def __init__(
        self,
        *,
        failover_criteria: typing.List[
            "CloudfrontDistributionOriginGroupFailoverCriteria"
        ],
        member: typing.List["CloudfrontDistributionOriginGroupMember"],
        origin_id: str,
    ) -> None:
        """
        :param failover_criteria: failover_criteria block.
        :param member: member block.
        :param origin_id: 
        """
        self._values = {
            "failover_criteria": failover_criteria,
            "member": member,
            "origin_id": origin_id,
        }

    @builtins.property
    def failover_criteria(
        self,
    ) -> typing.List["CloudfrontDistributionOriginGroupFailoverCriteria"]:
        """failover_criteria block."""
        return self._values.get("failover_criteria")

    @builtins.property
    def member(self) -> typing.List["CloudfrontDistributionOriginGroupMember"]:
        """member block."""
        return self._values.get("member")

    @builtins.property
    def origin_id(self) -> str:
        return self._values.get("origin_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOriginGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOriginGroupFailoverCriteria",
    jsii_struct_bases=[],
    name_mapping={"status_codes": "statusCodes"},
)
class CloudfrontDistributionOriginGroupFailoverCriteria:
    def __init__(self, *, status_codes: typing.List[jsii.Number]) -> None:
        """
        :param status_codes: 
        """
        self._values = {
            "status_codes": status_codes,
        }

    @builtins.property
    def status_codes(self) -> typing.List[jsii.Number]:
        return self._values.get("status_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOriginGroupFailoverCriteria(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOriginGroupMember",
    jsii_struct_bases=[],
    name_mapping={"origin_id": "originId"},
)
class CloudfrontDistributionOriginGroupMember:
    def __init__(self, *, origin_id: str) -> None:
        """
        :param origin_id: 
        """
        self._values = {
            "origin_id": origin_id,
        }

    @builtins.property
    def origin_id(self) -> str:
        return self._values.get("origin_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOriginGroupMember(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionOriginS3OriginConfig",
    jsii_struct_bases=[],
    name_mapping={"origin_access_identity": "originAccessIdentity"},
)
class CloudfrontDistributionOriginS3OriginConfig:
    def __init__(self, *, origin_access_identity: str) -> None:
        """
        :param origin_access_identity: 
        """
        self._values = {
            "origin_access_identity": origin_access_identity,
        }

    @builtins.property
    def origin_access_identity(self) -> str:
        return self._values.get("origin_access_identity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionOriginS3OriginConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionRestrictions",
    jsii_struct_bases=[],
    name_mapping={"geo_restriction": "geoRestriction"},
)
class CloudfrontDistributionRestrictions:
    def __init__(
        self,
        *,
        geo_restriction: typing.List[
            "CloudfrontDistributionRestrictionsGeoRestriction"
        ],
    ) -> None:
        """
        :param geo_restriction: geo_restriction block.
        """
        self._values = {
            "geo_restriction": geo_restriction,
        }

    @builtins.property
    def geo_restriction(
        self,
    ) -> typing.List["CloudfrontDistributionRestrictionsGeoRestriction"]:
        """geo_restriction block."""
        return self._values.get("geo_restriction")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionRestrictions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionRestrictionsGeoRestriction",
    jsii_struct_bases=[],
    name_mapping={"restriction_type": "restrictionType", "locations": "locations"},
)
class CloudfrontDistributionRestrictionsGeoRestriction:
    def __init__(
        self,
        *,
        restriction_type: str,
        locations: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param restriction_type: 
        :param locations: 
        """
        self._values = {
            "restriction_type": restriction_type,
        }
        if locations is not None:
            self._values["locations"] = locations

    @builtins.property
    def restriction_type(self) -> str:
        return self._values.get("restriction_type")

    @builtins.property
    def locations(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("locations")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionRestrictionsGeoRestriction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontDistributionViewerCertificate",
    jsii_struct_bases=[],
    name_mapping={
        "acm_certificate_arn": "acmCertificateArn",
        "cloudfront_default_certificate": "cloudfrontDefaultCertificate",
        "iam_certificate_id": "iamCertificateId",
        "minimum_protocol_version": "minimumProtocolVersion",
        "ssl_support_method": "sslSupportMethod",
    },
)
class CloudfrontDistributionViewerCertificate:
    def __init__(
        self,
        *,
        acm_certificate_arn: typing.Optional[str] = None,
        cloudfront_default_certificate: typing.Optional[bool] = None,
        iam_certificate_id: typing.Optional[str] = None,
        minimum_protocol_version: typing.Optional[str] = None,
        ssl_support_method: typing.Optional[str] = None,
    ) -> None:
        """
        :param acm_certificate_arn: 
        :param cloudfront_default_certificate: 
        :param iam_certificate_id: 
        :param minimum_protocol_version: 
        :param ssl_support_method: 
        """
        self._values = {}
        if acm_certificate_arn is not None:
            self._values["acm_certificate_arn"] = acm_certificate_arn
        if cloudfront_default_certificate is not None:
            self._values[
                "cloudfront_default_certificate"
            ] = cloudfront_default_certificate
        if iam_certificate_id is not None:
            self._values["iam_certificate_id"] = iam_certificate_id
        if minimum_protocol_version is not None:
            self._values["minimum_protocol_version"] = minimum_protocol_version
        if ssl_support_method is not None:
            self._values["ssl_support_method"] = ssl_support_method

    @builtins.property
    def acm_certificate_arn(self) -> typing.Optional[str]:
        return self._values.get("acm_certificate_arn")

    @builtins.property
    def cloudfront_default_certificate(self) -> typing.Optional[bool]:
        return self._values.get("cloudfront_default_certificate")

    @builtins.property
    def iam_certificate_id(self) -> typing.Optional[str]:
        return self._values.get("iam_certificate_id")

    @builtins.property
    def minimum_protocol_version(self) -> typing.Optional[str]:
        return self._values.get("minimum_protocol_version")

    @builtins.property
    def ssl_support_method(self) -> typing.Optional[str]:
        return self._values.get("ssl_support_method")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontDistributionViewerCertificate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudfrontOriginAccessIdentity(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontOriginAccessIdentity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        comment: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param comment: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudfrontOriginAccessIdentityConfig(
            comment=comment,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudfrontOriginAccessIdentity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="callerReference")
    def caller_reference(self) -> str:
        return jsii.get(self, "callerReference")

    @builtins.property
    @jsii.member(jsii_name="cloudfrontAccessIdentityPath")
    def cloudfront_access_identity_path(self) -> str:
        return jsii.get(self, "cloudfrontAccessIdentityPath")

    @builtins.property
    @jsii.member(jsii_name="etag")
    def etag(self) -> str:
        return jsii.get(self, "etag")

    @builtins.property
    @jsii.member(jsii_name="iamArn")
    def iam_arn(self) -> str:
        return jsii.get(self, "iamArn")

    @builtins.property
    @jsii.member(jsii_name="s3CanonicalUserId")
    def s3_canonical_user_id(self) -> str:
        return jsii.get(self, "s3CanonicalUserId")

    @builtins.property
    @jsii.member(jsii_name="comment")
    def comment(self) -> typing.Optional[str]:
        return jsii.get(self, "comment")

    @comment.setter
    def comment(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "comment", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontOriginAccessIdentityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "comment": "comment",
    },
)
class CloudfrontOriginAccessIdentityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        comment: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param comment: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if comment is not None:
            self._values["comment"] = comment

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def comment(self) -> typing.Optional[str]:
        return self._values.get("comment")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontOriginAccessIdentityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudfrontPublicKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontPublicKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        encoded_key: str,
        comment: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param encoded_key: 
        :param comment: 
        :param name: 
        :param name_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudfrontPublicKeyConfig(
            encoded_key=encoded_key,
            comment=comment,
            name=name,
            name_prefix=name_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudfrontPublicKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="callerReference")
    def caller_reference(self) -> str:
        return jsii.get(self, "callerReference")

    @builtins.property
    @jsii.member(jsii_name="etag")
    def etag(self) -> str:
        return jsii.get(self, "etag")

    @builtins.property
    @jsii.member(jsii_name="encodedKey")
    def encoded_key(self) -> str:
        return jsii.get(self, "encodedKey")

    @encoded_key.setter
    def encoded_key(self, value: str) -> None:
        jsii.set(self, "encodedKey", value)

    @builtins.property
    @jsii.member(jsii_name="comment")
    def comment(self) -> typing.Optional[str]:
        return jsii.get(self, "comment")

    @comment.setter
    def comment(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "comment", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudfrontPublicKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "encoded_key": "encodedKey",
        "comment": "comment",
        "name": "name",
        "name_prefix": "namePrefix",
    },
)
class CloudfrontPublicKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        encoded_key: str,
        comment: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param encoded_key: 
        :param comment: 
        :param name: 
        :param name_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "encoded_key": encoded_key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if comment is not None:
            self._values["comment"] = comment
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def encoded_key(self) -> str:
        return self._values.get("encoded_key")

    @builtins.property
    def comment(self) -> typing.Optional[str]:
        return self._values.get("comment")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudfrontPublicKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudhsmV2Cluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudhsmV2Cluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        hsm_type: str,
        subnet_ids: typing.List[str],
        source_backup_identifier: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["CloudhsmV2ClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param hsm_type: 
        :param subnet_ids: 
        :param source_backup_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudhsmV2ClusterConfig(
            hsm_type=hsm_type,
            subnet_ids=subnet_ids,
            source_backup_identifier=source_backup_identifier,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudhsmV2Cluster, self, [scope, id, config])

    @jsii.member(jsii_name="clusterCertificates")
    def cluster_certificates(
        self, index: str
    ) -> "CloudhsmV2ClusterClusterCertificates":
        """
        :param index: -
        """
        return jsii.invoke(self, "clusterCertificates", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> str:
        return jsii.get(self, "clusterId")

    @builtins.property
    @jsii.member(jsii_name="clusterState")
    def cluster_state(self) -> str:
        return jsii.get(self, "clusterState")

    @builtins.property
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> str:
        return jsii.get(self, "securityGroupId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="hsmType")
    def hsm_type(self) -> str:
        return jsii.get(self, "hsmType")

    @hsm_type.setter
    def hsm_type(self, value: str) -> None:
        jsii.set(self, "hsmType", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sourceBackupIdentifier")
    def source_backup_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceBackupIdentifier")

    @source_backup_identifier.setter
    def source_backup_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceBackupIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CloudhsmV2ClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["CloudhsmV2ClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class CloudhsmV2ClusterClusterCertificates(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudhsmV2ClusterClusterCertificates",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            CloudhsmV2ClusterClusterCertificates,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="awsHardwareCertificate")
    def aws_hardware_certificate(self) -> str:
        return jsii.get(self, "awsHardwareCertificate")

    @builtins.property
    @jsii.member(jsii_name="clusterCertificate")
    def cluster_certificate(self) -> str:
        return jsii.get(self, "clusterCertificate")

    @builtins.property
    @jsii.member(jsii_name="clusterCsr")
    def cluster_csr(self) -> str:
        return jsii.get(self, "clusterCsr")

    @builtins.property
    @jsii.member(jsii_name="hsmCertificate")
    def hsm_certificate(self) -> str:
        return jsii.get(self, "hsmCertificate")

    @builtins.property
    @jsii.member(jsii_name="manufacturerHardwareCertificate")
    def manufacturer_hardware_certificate(self) -> str:
        return jsii.get(self, "manufacturerHardwareCertificate")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudhsmV2ClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "hsm_type": "hsmType",
        "subnet_ids": "subnetIds",
        "source_backup_identifier": "sourceBackupIdentifier",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class CloudhsmV2ClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        hsm_type: str,
        subnet_ids: typing.List[str],
        source_backup_identifier: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["CloudhsmV2ClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param hsm_type: 
        :param subnet_ids: 
        :param source_backup_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CloudhsmV2ClusterTimeouts(**timeouts)
        self._values = {
            "hsm_type": hsm_type,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if source_backup_identifier is not None:
            self._values["source_backup_identifier"] = source_backup_identifier
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def hsm_type(self) -> str:
        return self._values.get("hsm_type")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def source_backup_identifier(self) -> typing.Optional[str]:
        return self._values.get("source_backup_identifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["CloudhsmV2ClusterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudhsmV2ClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudhsmV2ClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class CloudhsmV2ClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudhsmV2ClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudhsmV2Hsm(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudhsmV2Hsm",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_id: str,
        availability_zone: typing.Optional[str] = None,
        ip_address: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        timeouts: typing.Optional["CloudhsmV2HsmTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_id: 
        :param availability_zone: 
        :param ip_address: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudhsmV2HsmConfig(
            cluster_id=cluster_id,
            availability_zone=availability_zone,
            ip_address=ip_address,
            subnet_id=subnet_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudhsmV2Hsm, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="hsmEniId")
    def hsm_eni_id(self) -> str:
        return jsii.get(self, "hsmEniId")

    @builtins.property
    @jsii.member(jsii_name="hsmId")
    def hsm_id(self) -> str:
        return jsii.get(self, "hsmId")

    @builtins.property
    @jsii.member(jsii_name="hsmState")
    def hsm_state(self) -> str:
        return jsii.get(self, "hsmState")

    @builtins.property
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> str:
        return jsii.get(self, "clusterId")

    @cluster_id.setter
    def cluster_id(self, value: str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> typing.Optional[str]:
        return jsii.get(self, "ipAddress")

    @ip_address.setter
    def ip_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["CloudhsmV2HsmTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["CloudhsmV2HsmTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudhsmV2HsmConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "availability_zone": "availabilityZone",
        "ip_address": "ipAddress",
        "subnet_id": "subnetId",
        "timeouts": "timeouts",
    },
)
class CloudhsmV2HsmConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: str,
        availability_zone: typing.Optional[str] = None,
        ip_address: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        timeouts: typing.Optional["CloudhsmV2HsmTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: 
        :param availability_zone: 
        :param ip_address: 
        :param subnet_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = CloudhsmV2HsmTimeouts(**timeouts)
        self._values = {
            "cluster_id": cluster_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_id(self) -> str:
        return self._values.get("cluster_id")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def ip_address(self) -> typing.Optional[str]:
        return self._values.get("ip_address")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def timeouts(self) -> typing.Optional["CloudhsmV2HsmTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudhsmV2HsmConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudhsmV2HsmTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class CloudhsmV2HsmTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudhsmV2HsmTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Cloudtrail(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Cloudtrail",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        s3_bucket_name: str,
        cloud_watch_logs_group_arn: typing.Optional[str] = None,
        cloud_watch_logs_role_arn: typing.Optional[str] = None,
        enable_log_file_validation: typing.Optional[bool] = None,
        enable_logging: typing.Optional[bool] = None,
        event_selector: typing.Optional[typing.List["CloudtrailEventSelector"]] = None,
        include_global_service_events: typing.Optional[bool] = None,
        is_multi_region_trail: typing.Optional[bool] = None,
        is_organization_trail: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        s3_key_prefix: typing.Optional[str] = None,
        sns_topic_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param s3_bucket_name: 
        :param cloud_watch_logs_group_arn: 
        :param cloud_watch_logs_role_arn: 
        :param enable_log_file_validation: 
        :param enable_logging: 
        :param event_selector: event_selector block.
        :param include_global_service_events: 
        :param is_multi_region_trail: 
        :param is_organization_trail: 
        :param kms_key_id: 
        :param s3_key_prefix: 
        :param sns_topic_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudtrailConfig(
            name=name,
            s3_bucket_name=s3_bucket_name,
            cloud_watch_logs_group_arn=cloud_watch_logs_group_arn,
            cloud_watch_logs_role_arn=cloud_watch_logs_role_arn,
            enable_log_file_validation=enable_log_file_validation,
            enable_logging=enable_logging,
            event_selector=event_selector,
            include_global_service_events=include_global_service_events,
            is_multi_region_trail=is_multi_region_trail,
            is_organization_trail=is_organization_trail,
            kms_key_id=kms_key_id,
            s3_key_prefix=s3_key_prefix,
            sns_topic_name=sns_topic_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Cloudtrail, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="homeRegion")
    def home_region(self) -> str:
        return jsii.get(self, "homeRegion")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="s3BucketName")
    def s3_bucket_name(self) -> str:
        return jsii.get(self, "s3BucketName")

    @s3_bucket_name.setter
    def s3_bucket_name(self, value: str) -> None:
        jsii.set(self, "s3BucketName", value)

    @builtins.property
    @jsii.member(jsii_name="cloudWatchLogsGroupArn")
    def cloud_watch_logs_group_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "cloudWatchLogsGroupArn")

    @cloud_watch_logs_group_arn.setter
    def cloud_watch_logs_group_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cloudWatchLogsGroupArn", value)

    @builtins.property
    @jsii.member(jsii_name="cloudWatchLogsRoleArn")
    def cloud_watch_logs_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "cloudWatchLogsRoleArn")

    @cloud_watch_logs_role_arn.setter
    def cloud_watch_logs_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cloudWatchLogsRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="enableLogFileValidation")
    def enable_log_file_validation(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableLogFileValidation")

    @enable_log_file_validation.setter
    def enable_log_file_validation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableLogFileValidation", value)

    @builtins.property
    @jsii.member(jsii_name="enableLogging")
    def enable_logging(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableLogging")

    @enable_logging.setter
    def enable_logging(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableLogging", value)

    @builtins.property
    @jsii.member(jsii_name="eventSelector")
    def event_selector(self) -> typing.Optional[typing.List["CloudtrailEventSelector"]]:
        return jsii.get(self, "eventSelector")

    @event_selector.setter
    def event_selector(
        self, value: typing.Optional[typing.List["CloudtrailEventSelector"]]
    ) -> None:
        jsii.set(self, "eventSelector", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="includeGlobalServiceEvents")
    def include_global_service_events(self) -> typing.Optional[bool]:
        return jsii.get(self, "includeGlobalServiceEvents")

    @include_global_service_events.setter
    def include_global_service_events(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "includeGlobalServiceEvents", value)

    @builtins.property
    @jsii.member(jsii_name="isMultiRegionTrail")
    def is_multi_region_trail(self) -> typing.Optional[bool]:
        return jsii.get(self, "isMultiRegionTrail")

    @is_multi_region_trail.setter
    def is_multi_region_trail(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "isMultiRegionTrail", value)

    @builtins.property
    @jsii.member(jsii_name="isOrganizationTrail")
    def is_organization_trail(self) -> typing.Optional[bool]:
        return jsii.get(self, "isOrganizationTrail")

    @is_organization_trail.setter
    def is_organization_trail(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "isOrganizationTrail", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="s3KeyPrefix")
    def s3_key_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "s3KeyPrefix")

    @s3_key_prefix.setter
    def s3_key_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3KeyPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="snsTopicName")
    def sns_topic_name(self) -> typing.Optional[str]:
        return jsii.get(self, "snsTopicName")

    @sns_topic_name.setter
    def sns_topic_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snsTopicName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudtrailConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "s3_bucket_name": "s3BucketName",
        "cloud_watch_logs_group_arn": "cloudWatchLogsGroupArn",
        "cloud_watch_logs_role_arn": "cloudWatchLogsRoleArn",
        "enable_log_file_validation": "enableLogFileValidation",
        "enable_logging": "enableLogging",
        "event_selector": "eventSelector",
        "include_global_service_events": "includeGlobalServiceEvents",
        "is_multi_region_trail": "isMultiRegionTrail",
        "is_organization_trail": "isOrganizationTrail",
        "kms_key_id": "kmsKeyId",
        "s3_key_prefix": "s3KeyPrefix",
        "sns_topic_name": "snsTopicName",
        "tags": "tags",
    },
)
class CloudtrailConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        s3_bucket_name: str,
        cloud_watch_logs_group_arn: typing.Optional[str] = None,
        cloud_watch_logs_role_arn: typing.Optional[str] = None,
        enable_log_file_validation: typing.Optional[bool] = None,
        enable_logging: typing.Optional[bool] = None,
        event_selector: typing.Optional[typing.List["CloudtrailEventSelector"]] = None,
        include_global_service_events: typing.Optional[bool] = None,
        is_multi_region_trail: typing.Optional[bool] = None,
        is_organization_trail: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        s3_key_prefix: typing.Optional[str] = None,
        sns_topic_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param s3_bucket_name: 
        :param cloud_watch_logs_group_arn: 
        :param cloud_watch_logs_role_arn: 
        :param enable_log_file_validation: 
        :param enable_logging: 
        :param event_selector: event_selector block.
        :param include_global_service_events: 
        :param is_multi_region_trail: 
        :param is_organization_trail: 
        :param kms_key_id: 
        :param s3_key_prefix: 
        :param sns_topic_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "s3_bucket_name": s3_bucket_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloud_watch_logs_group_arn is not None:
            self._values["cloud_watch_logs_group_arn"] = cloud_watch_logs_group_arn
        if cloud_watch_logs_role_arn is not None:
            self._values["cloud_watch_logs_role_arn"] = cloud_watch_logs_role_arn
        if enable_log_file_validation is not None:
            self._values["enable_log_file_validation"] = enable_log_file_validation
        if enable_logging is not None:
            self._values["enable_logging"] = enable_logging
        if event_selector is not None:
            self._values["event_selector"] = event_selector
        if include_global_service_events is not None:
            self._values[
                "include_global_service_events"
            ] = include_global_service_events
        if is_multi_region_trail is not None:
            self._values["is_multi_region_trail"] = is_multi_region_trail
        if is_organization_trail is not None:
            self._values["is_organization_trail"] = is_organization_trail
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if s3_key_prefix is not None:
            self._values["s3_key_prefix"] = s3_key_prefix
        if sns_topic_name is not None:
            self._values["sns_topic_name"] = sns_topic_name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def s3_bucket_name(self) -> str:
        return self._values.get("s3_bucket_name")

    @builtins.property
    def cloud_watch_logs_group_arn(self) -> typing.Optional[str]:
        return self._values.get("cloud_watch_logs_group_arn")

    @builtins.property
    def cloud_watch_logs_role_arn(self) -> typing.Optional[str]:
        return self._values.get("cloud_watch_logs_role_arn")

    @builtins.property
    def enable_log_file_validation(self) -> typing.Optional[bool]:
        return self._values.get("enable_log_file_validation")

    @builtins.property
    def enable_logging(self) -> typing.Optional[bool]:
        return self._values.get("enable_logging")

    @builtins.property
    def event_selector(self) -> typing.Optional[typing.List["CloudtrailEventSelector"]]:
        """event_selector block."""
        return self._values.get("event_selector")

    @builtins.property
    def include_global_service_events(self) -> typing.Optional[bool]:
        return self._values.get("include_global_service_events")

    @builtins.property
    def is_multi_region_trail(self) -> typing.Optional[bool]:
        return self._values.get("is_multi_region_trail")

    @builtins.property
    def is_organization_trail(self) -> typing.Optional[bool]:
        return self._values.get("is_organization_trail")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def s3_key_prefix(self) -> typing.Optional[str]:
        return self._values.get("s3_key_prefix")

    @builtins.property
    def sns_topic_name(self) -> typing.Optional[str]:
        return self._values.get("sns_topic_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudtrailConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudtrailEventSelector",
    jsii_struct_bases=[],
    name_mapping={
        "data_resource": "dataResource",
        "include_management_events": "includeManagementEvents",
        "read_write_type": "readWriteType",
    },
)
class CloudtrailEventSelector:
    def __init__(
        self,
        *,
        data_resource: typing.Optional[
            typing.List["CloudtrailEventSelectorDataResource"]
        ] = None,
        include_management_events: typing.Optional[bool] = None,
        read_write_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param data_resource: data_resource block.
        :param include_management_events: 
        :param read_write_type: 
        """
        self._values = {}
        if data_resource is not None:
            self._values["data_resource"] = data_resource
        if include_management_events is not None:
            self._values["include_management_events"] = include_management_events
        if read_write_type is not None:
            self._values["read_write_type"] = read_write_type

    @builtins.property
    def data_resource(
        self,
    ) -> typing.Optional[typing.List["CloudtrailEventSelectorDataResource"]]:
        """data_resource block."""
        return self._values.get("data_resource")

    @builtins.property
    def include_management_events(self) -> typing.Optional[bool]:
        return self._values.get("include_management_events")

    @builtins.property
    def read_write_type(self) -> typing.Optional[str]:
        return self._values.get("read_write_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudtrailEventSelector(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudtrailEventSelectorDataResource",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "values": "values"},
)
class CloudtrailEventSelectorDataResource:
    def __init__(self, *, type: str, values: typing.List[str]) -> None:
        """
        :param type: 
        :param values: 
        """
        self._values = {
            "type": type,
            "values": values,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudtrailEventSelectorDataResource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchDashboard(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchDashboard",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dashboard_body: str,
        dashboard_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dashboard_body: 
        :param dashboard_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchDashboardConfig(
            dashboard_body=dashboard_body,
            dashboard_name=dashboard_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchDashboard, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dashboardArn")
    def dashboard_arn(self) -> str:
        return jsii.get(self, "dashboardArn")

    @builtins.property
    @jsii.member(jsii_name="dashboardBody")
    def dashboard_body(self) -> str:
        return jsii.get(self, "dashboardBody")

    @dashboard_body.setter
    def dashboard_body(self, value: str) -> None:
        jsii.set(self, "dashboardBody", value)

    @builtins.property
    @jsii.member(jsii_name="dashboardName")
    def dashboard_name(self) -> str:
        return jsii.get(self, "dashboardName")

    @dashboard_name.setter
    def dashboard_name(self, value: str) -> None:
        jsii.set(self, "dashboardName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchDashboardConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dashboard_body": "dashboardBody",
        "dashboard_name": "dashboardName",
    },
)
class CloudwatchDashboardConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dashboard_body: str,
        dashboard_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dashboard_body: 
        :param dashboard_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "dashboard_body": dashboard_body,
            "dashboard_name": dashboard_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dashboard_body(self) -> str:
        return self._values.get("dashboard_body")

    @builtins.property
    def dashboard_name(self) -> str:
        return self._values.get("dashboard_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchDashboardConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchEventPermission(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventPermission",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        principal: str,
        statement_id: str,
        action: typing.Optional[str] = None,
        condition: typing.Optional[
            typing.List["CloudwatchEventPermissionCondition"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param principal: 
        :param statement_id: 
        :param action: 
        :param condition: condition block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchEventPermissionConfig(
            principal=principal,
            statement_id=statement_id,
            action=action,
            condition=condition,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchEventPermission, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="principal")
    def principal(self) -> str:
        return jsii.get(self, "principal")

    @principal.setter
    def principal(self, value: str) -> None:
        jsii.set(self, "principal", value)

    @builtins.property
    @jsii.member(jsii_name="statementId")
    def statement_id(self) -> str:
        return jsii.get(self, "statementId")

    @statement_id.setter
    def statement_id(self, value: str) -> None:
        jsii.set(self, "statementId", value)

    @builtins.property
    @jsii.member(jsii_name="action")
    def action(self) -> typing.Optional[str]:
        return jsii.get(self, "action")

    @action.setter
    def action(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "action", value)

    @builtins.property
    @jsii.member(jsii_name="condition")
    def condition(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventPermissionCondition"]]:
        return jsii.get(self, "condition")

    @condition.setter
    def condition(
        self, value: typing.Optional[typing.List["CloudwatchEventPermissionCondition"]]
    ) -> None:
        jsii.set(self, "condition", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventPermissionCondition",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "type": "type", "value": "value"},
)
class CloudwatchEventPermissionCondition:
    def __init__(self, *, key: str, type: str, value: str) -> None:
        """
        :param key: 
        :param type: 
        :param value: 
        """
        self._values = {
            "key": key,
            "type": type,
            "value": value,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventPermissionCondition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventPermissionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "principal": "principal",
        "statement_id": "statementId",
        "action": "action",
        "condition": "condition",
    },
)
class CloudwatchEventPermissionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        principal: str,
        statement_id: str,
        action: typing.Optional[str] = None,
        condition: typing.Optional[
            typing.List["CloudwatchEventPermissionCondition"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param principal: 
        :param statement_id: 
        :param action: 
        :param condition: condition block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "principal": principal,
            "statement_id": statement_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if action is not None:
            self._values["action"] = action
        if condition is not None:
            self._values["condition"] = condition

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def principal(self) -> str:
        return self._values.get("principal")

    @builtins.property
    def statement_id(self) -> str:
        return self._values.get("statement_id")

    @builtins.property
    def action(self) -> typing.Optional[str]:
        return self._values.get("action")

    @builtins.property
    def condition(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventPermissionCondition"]]:
        """condition block."""
        return self._values.get("condition")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventPermissionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchEventRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        description: typing.Optional[str] = None,
        event_pattern: typing.Optional[str] = None,
        is_enabled: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
        schedule_expression: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param description: 
        :param event_pattern: 
        :param is_enabled: 
        :param name: 
        :param name_prefix: 
        :param role_arn: 
        :param schedule_expression: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchEventRuleConfig(
            description=description,
            event_pattern=event_pattern,
            is_enabled=is_enabled,
            name=name,
            name_prefix=name_prefix,
            role_arn=role_arn,
            schedule_expression=schedule_expression,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchEventRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="eventPattern")
    def event_pattern(self) -> typing.Optional[str]:
        return jsii.get(self, "eventPattern")

    @event_pattern.setter
    def event_pattern(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "eventPattern", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="isEnabled")
    def is_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "isEnabled")

    @is_enabled.setter
    def is_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "isEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="scheduleExpression")
    def schedule_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "scheduleExpression")

    @schedule_expression.setter
    def schedule_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "scheduleExpression", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "event_pattern": "eventPattern",
        "is_enabled": "isEnabled",
        "name": "name",
        "name_prefix": "namePrefix",
        "role_arn": "roleArn",
        "schedule_expression": "scheduleExpression",
        "tags": "tags",
    },
)
class CloudwatchEventRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[str] = None,
        event_pattern: typing.Optional[str] = None,
        is_enabled: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
        schedule_expression: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: 
        :param event_pattern: 
        :param is_enabled: 
        :param name: 
        :param name_prefix: 
        :param role_arn: 
        :param schedule_expression: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if event_pattern is not None:
            self._values["event_pattern"] = event_pattern
        if is_enabled is not None:
            self._values["is_enabled"] = is_enabled
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if role_arn is not None:
            self._values["role_arn"] = role_arn
        if schedule_expression is not None:
            self._values["schedule_expression"] = schedule_expression
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def event_pattern(self) -> typing.Optional[str]:
        return self._values.get("event_pattern")

    @builtins.property
    def is_enabled(self) -> typing.Optional[bool]:
        return self._values.get("is_enabled")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    @builtins.property
    def schedule_expression(self) -> typing.Optional[str]:
        return self._values.get("schedule_expression")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchEventTarget(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTarget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        arn: str,
        rule: str,
        batch_target: typing.Optional[
            typing.List["CloudwatchEventTargetBatchTarget"]
        ] = None,
        ecs_target: typing.Optional[
            typing.List["CloudwatchEventTargetEcsTarget"]
        ] = None,
        input: typing.Optional[str] = None,
        input_path: typing.Optional[str] = None,
        input_transformer: typing.Optional[
            typing.List["CloudwatchEventTargetInputTransformer"]
        ] = None,
        kinesis_target: typing.Optional[
            typing.List["CloudwatchEventTargetKinesisTarget"]
        ] = None,
        role_arn: typing.Optional[str] = None,
        run_command_targets: typing.Optional[
            typing.List["CloudwatchEventTargetRunCommandTargets"]
        ] = None,
        sqs_target: typing.Optional[
            typing.List["CloudwatchEventTargetSqsTarget"]
        ] = None,
        target_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param arn: 
        :param rule: 
        :param batch_target: batch_target block.
        :param ecs_target: ecs_target block.
        :param input: 
        :param input_path: 
        :param input_transformer: input_transformer block.
        :param kinesis_target: kinesis_target block.
        :param role_arn: 
        :param run_command_targets: run_command_targets block.
        :param sqs_target: sqs_target block.
        :param target_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchEventTargetConfig(
            arn=arn,
            rule=rule,
            batch_target=batch_target,
            ecs_target=ecs_target,
            input=input,
            input_path=input_path,
            input_transformer=input_transformer,
            kinesis_target=kinesis_target,
            role_arn=role_arn,
            run_command_targets=run_command_targets,
            sqs_target=sqs_target,
            target_id=target_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchEventTarget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: str) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="rule")
    def rule(self) -> str:
        return jsii.get(self, "rule")

    @rule.setter
    def rule(self, value: str) -> None:
        jsii.set(self, "rule", value)

    @builtins.property
    @jsii.member(jsii_name="batchTarget")
    def batch_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetBatchTarget"]]:
        return jsii.get(self, "batchTarget")

    @batch_target.setter
    def batch_target(
        self, value: typing.Optional[typing.List["CloudwatchEventTargetBatchTarget"]]
    ) -> None:
        jsii.set(self, "batchTarget", value)

    @builtins.property
    @jsii.member(jsii_name="ecsTarget")
    def ecs_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetEcsTarget"]]:
        return jsii.get(self, "ecsTarget")

    @ecs_target.setter
    def ecs_target(
        self, value: typing.Optional[typing.List["CloudwatchEventTargetEcsTarget"]]
    ) -> None:
        jsii.set(self, "ecsTarget", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="input")
    def input(self) -> typing.Optional[str]:
        return jsii.get(self, "input")

    @input.setter
    def input(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "input", value)

    @builtins.property
    @jsii.member(jsii_name="inputPath")
    def input_path(self) -> typing.Optional[str]:
        return jsii.get(self, "inputPath")

    @input_path.setter
    def input_path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "inputPath", value)

    @builtins.property
    @jsii.member(jsii_name="inputTransformer")
    def input_transformer(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetInputTransformer"]]:
        return jsii.get(self, "inputTransformer")

    @input_transformer.setter
    def input_transformer(
        self,
        value: typing.Optional[typing.List["CloudwatchEventTargetInputTransformer"]],
    ) -> None:
        jsii.set(self, "inputTransformer", value)

    @builtins.property
    @jsii.member(jsii_name="kinesisTarget")
    def kinesis_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetKinesisTarget"]]:
        return jsii.get(self, "kinesisTarget")

    @kinesis_target.setter
    def kinesis_target(
        self, value: typing.Optional[typing.List["CloudwatchEventTargetKinesisTarget"]]
    ) -> None:
        jsii.set(self, "kinesisTarget", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="runCommandTargets")
    def run_command_targets(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetRunCommandTargets"]]:
        return jsii.get(self, "runCommandTargets")

    @run_command_targets.setter
    def run_command_targets(
        self,
        value: typing.Optional[typing.List["CloudwatchEventTargetRunCommandTargets"]],
    ) -> None:
        jsii.set(self, "runCommandTargets", value)

    @builtins.property
    @jsii.member(jsii_name="sqsTarget")
    def sqs_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetSqsTarget"]]:
        return jsii.get(self, "sqsTarget")

    @sqs_target.setter
    def sqs_target(
        self, value: typing.Optional[typing.List["CloudwatchEventTargetSqsTarget"]]
    ) -> None:
        jsii.set(self, "sqsTarget", value)

    @builtins.property
    @jsii.member(jsii_name="targetId")
    def target_id(self) -> typing.Optional[str]:
        return jsii.get(self, "targetId")

    @target_id.setter
    def target_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "targetId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetBatchTarget",
    jsii_struct_bases=[],
    name_mapping={
        "job_definition": "jobDefinition",
        "job_name": "jobName",
        "array_size": "arraySize",
        "job_attempts": "jobAttempts",
    },
)
class CloudwatchEventTargetBatchTarget:
    def __init__(
        self,
        *,
        job_definition: str,
        job_name: str,
        array_size: typing.Optional[jsii.Number] = None,
        job_attempts: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param job_definition: 
        :param job_name: 
        :param array_size: 
        :param job_attempts: 
        """
        self._values = {
            "job_definition": job_definition,
            "job_name": job_name,
        }
        if array_size is not None:
            self._values["array_size"] = array_size
        if job_attempts is not None:
            self._values["job_attempts"] = job_attempts

    @builtins.property
    def job_definition(self) -> str:
        return self._values.get("job_definition")

    @builtins.property
    def job_name(self) -> str:
        return self._values.get("job_name")

    @builtins.property
    def array_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("array_size")

    @builtins.property
    def job_attempts(self) -> typing.Optional[jsii.Number]:
        return self._values.get("job_attempts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetBatchTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "arn": "arn",
        "rule": "rule",
        "batch_target": "batchTarget",
        "ecs_target": "ecsTarget",
        "input": "input",
        "input_path": "inputPath",
        "input_transformer": "inputTransformer",
        "kinesis_target": "kinesisTarget",
        "role_arn": "roleArn",
        "run_command_targets": "runCommandTargets",
        "sqs_target": "sqsTarget",
        "target_id": "targetId",
    },
)
class CloudwatchEventTargetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        arn: str,
        rule: str,
        batch_target: typing.Optional[
            typing.List["CloudwatchEventTargetBatchTarget"]
        ] = None,
        ecs_target: typing.Optional[
            typing.List["CloudwatchEventTargetEcsTarget"]
        ] = None,
        input: typing.Optional[str] = None,
        input_path: typing.Optional[str] = None,
        input_transformer: typing.Optional[
            typing.List["CloudwatchEventTargetInputTransformer"]
        ] = None,
        kinesis_target: typing.Optional[
            typing.List["CloudwatchEventTargetKinesisTarget"]
        ] = None,
        role_arn: typing.Optional[str] = None,
        run_command_targets: typing.Optional[
            typing.List["CloudwatchEventTargetRunCommandTargets"]
        ] = None,
        sqs_target: typing.Optional[
            typing.List["CloudwatchEventTargetSqsTarget"]
        ] = None,
        target_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param arn: 
        :param rule: 
        :param batch_target: batch_target block.
        :param ecs_target: ecs_target block.
        :param input: 
        :param input_path: 
        :param input_transformer: input_transformer block.
        :param kinesis_target: kinesis_target block.
        :param role_arn: 
        :param run_command_targets: run_command_targets block.
        :param sqs_target: sqs_target block.
        :param target_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "arn": arn,
            "rule": rule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if batch_target is not None:
            self._values["batch_target"] = batch_target
        if ecs_target is not None:
            self._values["ecs_target"] = ecs_target
        if input is not None:
            self._values["input"] = input
        if input_path is not None:
            self._values["input_path"] = input_path
        if input_transformer is not None:
            self._values["input_transformer"] = input_transformer
        if kinesis_target is not None:
            self._values["kinesis_target"] = kinesis_target
        if role_arn is not None:
            self._values["role_arn"] = role_arn
        if run_command_targets is not None:
            self._values["run_command_targets"] = run_command_targets
        if sqs_target is not None:
            self._values["sqs_target"] = sqs_target
        if target_id is not None:
            self._values["target_id"] = target_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def rule(self) -> str:
        return self._values.get("rule")

    @builtins.property
    def batch_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetBatchTarget"]]:
        """batch_target block."""
        return self._values.get("batch_target")

    @builtins.property
    def ecs_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetEcsTarget"]]:
        """ecs_target block."""
        return self._values.get("ecs_target")

    @builtins.property
    def input(self) -> typing.Optional[str]:
        return self._values.get("input")

    @builtins.property
    def input_path(self) -> typing.Optional[str]:
        return self._values.get("input_path")

    @builtins.property
    def input_transformer(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetInputTransformer"]]:
        """input_transformer block."""
        return self._values.get("input_transformer")

    @builtins.property
    def kinesis_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetKinesisTarget"]]:
        """kinesis_target block."""
        return self._values.get("kinesis_target")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    @builtins.property
    def run_command_targets(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetRunCommandTargets"]]:
        """run_command_targets block."""
        return self._values.get("run_command_targets")

    @builtins.property
    def sqs_target(
        self,
    ) -> typing.Optional[typing.List["CloudwatchEventTargetSqsTarget"]]:
        """sqs_target block."""
        return self._values.get("sqs_target")

    @builtins.property
    def target_id(self) -> typing.Optional[str]:
        return self._values.get("target_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetEcsTarget",
    jsii_struct_bases=[],
    name_mapping={
        "task_definition_arn": "taskDefinitionArn",
        "group": "group",
        "launch_type": "launchType",
        "network_configuration": "networkConfiguration",
        "platform_version": "platformVersion",
        "task_count": "taskCount",
    },
)
class CloudwatchEventTargetEcsTarget:
    def __init__(
        self,
        *,
        task_definition_arn: str,
        group: typing.Optional[str] = None,
        launch_type: typing.Optional[str] = None,
        network_configuration: typing.Optional[
            typing.List["CloudwatchEventTargetEcsTargetNetworkConfiguration"]
        ] = None,
        platform_version: typing.Optional[str] = None,
        task_count: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param task_definition_arn: 
        :param group: 
        :param launch_type: 
        :param network_configuration: network_configuration block.
        :param platform_version: 
        :param task_count: 
        """
        self._values = {
            "task_definition_arn": task_definition_arn,
        }
        if group is not None:
            self._values["group"] = group
        if launch_type is not None:
            self._values["launch_type"] = launch_type
        if network_configuration is not None:
            self._values["network_configuration"] = network_configuration
        if platform_version is not None:
            self._values["platform_version"] = platform_version
        if task_count is not None:
            self._values["task_count"] = task_count

    @builtins.property
    def task_definition_arn(self) -> str:
        return self._values.get("task_definition_arn")

    @builtins.property
    def group(self) -> typing.Optional[str]:
        return self._values.get("group")

    @builtins.property
    def launch_type(self) -> typing.Optional[str]:
        return self._values.get("launch_type")

    @builtins.property
    def network_configuration(
        self,
    ) -> typing.Optional[
        typing.List["CloudwatchEventTargetEcsTargetNetworkConfiguration"]
    ]:
        """network_configuration block."""
        return self._values.get("network_configuration")

    @builtins.property
    def platform_version(self) -> typing.Optional[str]:
        return self._values.get("platform_version")

    @builtins.property
    def task_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("task_count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetEcsTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetEcsTargetNetworkConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "subnets": "subnets",
        "assign_public_ip": "assignPublicIp",
        "security_groups": "securityGroups",
    },
)
class CloudwatchEventTargetEcsTargetNetworkConfiguration:
    def __init__(
        self,
        *,
        subnets: typing.List[str],
        assign_public_ip: typing.Optional[bool] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param subnets: 
        :param assign_public_ip: 
        :param security_groups: 
        """
        self._values = {
            "subnets": subnets,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if security_groups is not None:
            self._values["security_groups"] = security_groups

    @builtins.property
    def subnets(self) -> typing.List[str]:
        return self._values.get("subnets")

    @builtins.property
    def assign_public_ip(self) -> typing.Optional[bool]:
        return self._values.get("assign_public_ip")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetEcsTargetNetworkConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetInputTransformer",
    jsii_struct_bases=[],
    name_mapping={"input_template": "inputTemplate", "input_paths": "inputPaths"},
)
class CloudwatchEventTargetInputTransformer:
    def __init__(
        self,
        *,
        input_template: str,
        input_paths: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param input_template: 
        :param input_paths: 
        """
        self._values = {
            "input_template": input_template,
        }
        if input_paths is not None:
            self._values["input_paths"] = input_paths

    @builtins.property
    def input_template(self) -> str:
        return self._values.get("input_template")

    @builtins.property
    def input_paths(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("input_paths")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetInputTransformer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetKinesisTarget",
    jsii_struct_bases=[],
    name_mapping={"partition_key_path": "partitionKeyPath"},
)
class CloudwatchEventTargetKinesisTarget:
    def __init__(self, *, partition_key_path: typing.Optional[str] = None) -> None:
        """
        :param partition_key_path: 
        """
        self._values = {}
        if partition_key_path is not None:
            self._values["partition_key_path"] = partition_key_path

    @builtins.property
    def partition_key_path(self) -> typing.Optional[str]:
        return self._values.get("partition_key_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetKinesisTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetRunCommandTargets",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "values": "values"},
)
class CloudwatchEventTargetRunCommandTargets:
    def __init__(self, *, key: str, values: typing.List[str]) -> None:
        """
        :param key: 
        :param values: 
        """
        self._values = {
            "key": key,
            "values": values,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetRunCommandTargets(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchEventTargetSqsTarget",
    jsii_struct_bases=[],
    name_mapping={"message_group_id": "messageGroupId"},
)
class CloudwatchEventTargetSqsTarget:
    def __init__(self, *, message_group_id: typing.Optional[str] = None) -> None:
        """
        :param message_group_id: 
        """
        self._values = {}
        if message_group_id is not None:
            self._values["message_group_id"] = message_group_id

    @builtins.property
    def message_group_id(self) -> typing.Optional[str]:
        return self._values.get("message_group_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchEventTargetSqsTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchLogDestination(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogDestination",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        role_arn: str,
        target_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param role_arn: 
        :param target_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchLogDestinationConfig(
            name=name,
            role_arn=role_arn,
            target_arn=target_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchLogDestination, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="targetArn")
    def target_arn(self) -> str:
        return jsii.get(self, "targetArn")

    @target_arn.setter
    def target_arn(self, value: str) -> None:
        jsii.set(self, "targetArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogDestinationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "role_arn": "roleArn",
        "target_arn": "targetArn",
    },
)
class CloudwatchLogDestinationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        role_arn: str,
        target_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param role_arn: 
        :param target_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "role_arn": role_arn,
            "target_arn": target_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def target_arn(self) -> str:
        return self._values.get("target_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogDestinationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchLogDestinationPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogDestinationPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        access_policy: str,
        destination_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param access_policy: 
        :param destination_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchLogDestinationPolicyConfig(
            access_policy=access_policy,
            destination_name=destination_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchLogDestinationPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accessPolicy")
    def access_policy(self) -> str:
        return jsii.get(self, "accessPolicy")

    @access_policy.setter
    def access_policy(self, value: str) -> None:
        jsii.set(self, "accessPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="destinationName")
    def destination_name(self) -> str:
        return jsii.get(self, "destinationName")

    @destination_name.setter
    def destination_name(self, value: str) -> None:
        jsii.set(self, "destinationName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogDestinationPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_policy": "accessPolicy",
        "destination_name": "destinationName",
    },
)
class CloudwatchLogDestinationPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_policy: str,
        destination_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_policy: 
        :param destination_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "access_policy": access_policy,
            "destination_name": destination_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def access_policy(self) -> str:
        return self._values.get("access_policy")

    @builtins.property
    def destination_name(self) -> str:
        return self._values.get("destination_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogDestinationPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchLogGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        kms_key_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        retention_in_days: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param kms_key_id: 
        :param name: 
        :param name_prefix: 
        :param retention_in_days: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchLogGroupConfig(
            kms_key_id=kms_key_id,
            name=name,
            name_prefix=name_prefix,
            retention_in_days=retention_in_days,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchLogGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="retentionInDays")
    def retention_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "retentionInDays")

    @retention_in_days.setter
    def retention_in_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "retentionInDays", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "kms_key_id": "kmsKeyId",
        "name": "name",
        "name_prefix": "namePrefix",
        "retention_in_days": "retentionInDays",
        "tags": "tags",
    },
)
class CloudwatchLogGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        kms_key_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        retention_in_days: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param kms_key_id: 
        :param name: 
        :param name_prefix: 
        :param retention_in_days: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if retention_in_days is not None:
            self._values["retention_in_days"] = retention_in_days
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def retention_in_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("retention_in_days")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchLogMetricFilter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogMetricFilter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        log_group_name: str,
        metric_transformation: typing.List[
            "CloudwatchLogMetricFilterMetricTransformation"
        ],
        name: str,
        pattern: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param log_group_name: 
        :param metric_transformation: metric_transformation block.
        :param name: 
        :param pattern: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchLogMetricFilterConfig(
            log_group_name=log_group_name,
            metric_transformation=metric_transformation,
            name=name,
            pattern=pattern,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchLogMetricFilter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="logGroupName")
    def log_group_name(self) -> str:
        return jsii.get(self, "logGroupName")

    @log_group_name.setter
    def log_group_name(self, value: str) -> None:
        jsii.set(self, "logGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="metricTransformation")
    def metric_transformation(
        self,
    ) -> typing.List["CloudwatchLogMetricFilterMetricTransformation"]:
        return jsii.get(self, "metricTransformation")

    @metric_transformation.setter
    def metric_transformation(
        self, value: typing.List["CloudwatchLogMetricFilterMetricTransformation"]
    ) -> None:
        jsii.set(self, "metricTransformation", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="pattern")
    def pattern(self) -> str:
        return jsii.get(self, "pattern")

    @pattern.setter
    def pattern(self, value: str) -> None:
        jsii.set(self, "pattern", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogMetricFilterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "log_group_name": "logGroupName",
        "metric_transformation": "metricTransformation",
        "name": "name",
        "pattern": "pattern",
    },
)
class CloudwatchLogMetricFilterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        log_group_name: str,
        metric_transformation: typing.List[
            "CloudwatchLogMetricFilterMetricTransformation"
        ],
        name: str,
        pattern: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param log_group_name: 
        :param metric_transformation: metric_transformation block.
        :param name: 
        :param pattern: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "log_group_name": log_group_name,
            "metric_transformation": metric_transformation,
            "name": name,
            "pattern": pattern,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def log_group_name(self) -> str:
        return self._values.get("log_group_name")

    @builtins.property
    def metric_transformation(
        self,
    ) -> typing.List["CloudwatchLogMetricFilterMetricTransformation"]:
        """metric_transformation block."""
        return self._values.get("metric_transformation")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def pattern(self) -> str:
        return self._values.get("pattern")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogMetricFilterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogMetricFilterMetricTransformation",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "namespace": "namespace",
        "value": "value",
        "default_value": "defaultValue",
    },
)
class CloudwatchLogMetricFilterMetricTransformation:
    def __init__(
        self,
        *,
        name: str,
        namespace: str,
        value: str,
        default_value: typing.Optional[str] = None,
    ) -> None:
        """
        :param name: 
        :param namespace: 
        :param value: 
        :param default_value: 
        """
        self._values = {
            "name": name,
            "namespace": namespace,
            "value": value,
        }
        if default_value is not None:
            self._values["default_value"] = default_value

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def namespace(self) -> str:
        return self._values.get("namespace")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def default_value(self) -> typing.Optional[str]:
        return self._values.get("default_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogMetricFilterMetricTransformation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchLogResourcePolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogResourcePolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy_document: str,
        policy_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy_document: 
        :param policy_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchLogResourcePolicyConfig(
            policy_document=policy_document,
            policy_name=policy_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchLogResourcePolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policyDocument")
    def policy_document(self) -> str:
        return jsii.get(self, "policyDocument")

    @policy_document.setter
    def policy_document(self, value: str) -> None:
        jsii.set(self, "policyDocument", value)

    @builtins.property
    @jsii.member(jsii_name="policyName")
    def policy_name(self) -> str:
        return jsii.get(self, "policyName")

    @policy_name.setter
    def policy_name(self, value: str) -> None:
        jsii.set(self, "policyName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogResourcePolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy_document": "policyDocument",
        "policy_name": "policyName",
    },
)
class CloudwatchLogResourcePolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy_document: str,
        policy_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy_document: 
        :param policy_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy_document": policy_document,
            "policy_name": policy_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy_document(self) -> str:
        return self._values.get("policy_document")

    @builtins.property
    def policy_name(self) -> str:
        return self._values.get("policy_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogResourcePolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchLogStream(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogStream",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        log_group_name: str,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param log_group_name: 
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchLogStreamConfig(
            log_group_name=log_group_name,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchLogStream, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="logGroupName")
    def log_group_name(self) -> str:
        return jsii.get(self, "logGroupName")

    @log_group_name.setter
    def log_group_name(self, value: str) -> None:
        jsii.set(self, "logGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogStreamConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "log_group_name": "logGroupName",
        "name": "name",
    },
)
class CloudwatchLogStreamConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        log_group_name: str,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param log_group_name: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "log_group_name": log_group_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def log_group_name(self) -> str:
        return self._values.get("log_group_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogStreamConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchLogSubscriptionFilter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogSubscriptionFilter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        destination_arn: str,
        filter_pattern: str,
        log_group_name: str,
        name: str,
        distribution: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination_arn: 
        :param filter_pattern: 
        :param log_group_name: 
        :param name: 
        :param distribution: 
        :param role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchLogSubscriptionFilterConfig(
            destination_arn=destination_arn,
            filter_pattern=filter_pattern,
            log_group_name=log_group_name,
            name=name,
            distribution=distribution,
            role_arn=role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchLogSubscriptionFilter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="destinationArn")
    def destination_arn(self) -> str:
        return jsii.get(self, "destinationArn")

    @destination_arn.setter
    def destination_arn(self, value: str) -> None:
        jsii.set(self, "destinationArn", value)

    @builtins.property
    @jsii.member(jsii_name="filterPattern")
    def filter_pattern(self) -> str:
        return jsii.get(self, "filterPattern")

    @filter_pattern.setter
    def filter_pattern(self, value: str) -> None:
        jsii.set(self, "filterPattern", value)

    @builtins.property
    @jsii.member(jsii_name="logGroupName")
    def log_group_name(self) -> str:
        return jsii.get(self, "logGroupName")

    @log_group_name.setter
    def log_group_name(self, value: str) -> None:
        jsii.set(self, "logGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="distribution")
    def distribution(self) -> typing.Optional[str]:
        return jsii.get(self, "distribution")

    @distribution.setter
    def distribution(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "distribution", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchLogSubscriptionFilterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination_arn": "destinationArn",
        "filter_pattern": "filterPattern",
        "log_group_name": "logGroupName",
        "name": "name",
        "distribution": "distribution",
        "role_arn": "roleArn",
    },
)
class CloudwatchLogSubscriptionFilterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination_arn: str,
        filter_pattern: str,
        log_group_name: str,
        name: str,
        distribution: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination_arn: 
        :param filter_pattern: 
        :param log_group_name: 
        :param name: 
        :param distribution: 
        :param role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "destination_arn": destination_arn,
            "filter_pattern": filter_pattern,
            "log_group_name": log_group_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if distribution is not None:
            self._values["distribution"] = distribution
        if role_arn is not None:
            self._values["role_arn"] = role_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def destination_arn(self) -> str:
        return self._values.get("destination_arn")

    @builtins.property
    def filter_pattern(self) -> str:
        return self._values.get("filter_pattern")

    @builtins.property
    def log_group_name(self) -> str:
        return self._values.get("log_group_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def distribution(self) -> typing.Optional[str]:
        return self._values.get("distribution")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchLogSubscriptionFilterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CloudwatchMetricAlarm(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchMetricAlarm",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        alarm_name: str,
        comparison_operator: str,
        evaluation_periods: jsii.Number,
        actions_enabled: typing.Optional[bool] = None,
        alarm_actions: typing.Optional[typing.List[str]] = None,
        alarm_description: typing.Optional[str] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dimensions: typing.Optional[typing.Mapping[str, str]] = None,
        evaluate_low_sample_count_percentiles: typing.Optional[str] = None,
        extended_statistic: typing.Optional[str] = None,
        insufficient_data_actions: typing.Optional[typing.List[str]] = None,
        metric_name: typing.Optional[str] = None,
        metric_query: typing.Optional[
            typing.List["CloudwatchMetricAlarmMetricQuery"]
        ] = None,
        namespace: typing.Optional[str] = None,
        ok_actions: typing.Optional[typing.List[str]] = None,
        period: typing.Optional[jsii.Number] = None,
        statistic: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        threshold: typing.Optional[jsii.Number] = None,
        threshold_metric_id: typing.Optional[str] = None,
        treat_missing_data: typing.Optional[str] = None,
        unit: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param alarm_name: 
        :param comparison_operator: 
        :param evaluation_periods: 
        :param actions_enabled: 
        :param alarm_actions: 
        :param alarm_description: 
        :param datapoints_to_alarm: 
        :param dimensions: 
        :param evaluate_low_sample_count_percentiles: 
        :param extended_statistic: 
        :param insufficient_data_actions: 
        :param metric_name: 
        :param metric_query: metric_query block.
        :param namespace: 
        :param ok_actions: 
        :param period: 
        :param statistic: 
        :param tags: 
        :param threshold: 
        :param threshold_metric_id: 
        :param treat_missing_data: 
        :param unit: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CloudwatchMetricAlarmConfig(
            alarm_name=alarm_name,
            comparison_operator=comparison_operator,
            evaluation_periods=evaluation_periods,
            actions_enabled=actions_enabled,
            alarm_actions=alarm_actions,
            alarm_description=alarm_description,
            datapoints_to_alarm=datapoints_to_alarm,
            dimensions=dimensions,
            evaluate_low_sample_count_percentiles=evaluate_low_sample_count_percentiles,
            extended_statistic=extended_statistic,
            insufficient_data_actions=insufficient_data_actions,
            metric_name=metric_name,
            metric_query=metric_query,
            namespace=namespace,
            ok_actions=ok_actions,
            period=period,
            statistic=statistic,
            tags=tags,
            threshold=threshold,
            threshold_metric_id=threshold_metric_id,
            treat_missing_data=treat_missing_data,
            unit=unit,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CloudwatchMetricAlarm, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="alarmName")
    def alarm_name(self) -> str:
        return jsii.get(self, "alarmName")

    @alarm_name.setter
    def alarm_name(self, value: str) -> None:
        jsii.set(self, "alarmName", value)

    @builtins.property
    @jsii.member(jsii_name="comparisonOperator")
    def comparison_operator(self) -> str:
        return jsii.get(self, "comparisonOperator")

    @comparison_operator.setter
    def comparison_operator(self, value: str) -> None:
        jsii.set(self, "comparisonOperator", value)

    @builtins.property
    @jsii.member(jsii_name="evaluationPeriods")
    def evaluation_periods(self) -> jsii.Number:
        return jsii.get(self, "evaluationPeriods")

    @evaluation_periods.setter
    def evaluation_periods(self, value: jsii.Number) -> None:
        jsii.set(self, "evaluationPeriods", value)

    @builtins.property
    @jsii.member(jsii_name="actionsEnabled")
    def actions_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "actionsEnabled")

    @actions_enabled.setter
    def actions_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "actionsEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="alarmActions")
    def alarm_actions(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "alarmActions")

    @alarm_actions.setter
    def alarm_actions(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "alarmActions", value)

    @builtins.property
    @jsii.member(jsii_name="alarmDescription")
    def alarm_description(self) -> typing.Optional[str]:
        return jsii.get(self, "alarmDescription")

    @alarm_description.setter
    def alarm_description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "alarmDescription", value)

    @builtins.property
    @jsii.member(jsii_name="datapointsToAlarm")
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "datapointsToAlarm")

    @datapoints_to_alarm.setter
    def datapoints_to_alarm(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "datapointsToAlarm", value)

    @builtins.property
    @jsii.member(jsii_name="dimensions")
    def dimensions(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "dimensions")

    @dimensions.setter
    def dimensions(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "dimensions", value)

    @builtins.property
    @jsii.member(jsii_name="evaluateLowSampleCountPercentiles")
    def evaluate_low_sample_count_percentiles(self) -> typing.Optional[str]:
        return jsii.get(self, "evaluateLowSampleCountPercentiles")

    @evaluate_low_sample_count_percentiles.setter
    def evaluate_low_sample_count_percentiles(
        self, value: typing.Optional[str]
    ) -> None:
        jsii.set(self, "evaluateLowSampleCountPercentiles", value)

    @builtins.property
    @jsii.member(jsii_name="extendedStatistic")
    def extended_statistic(self) -> typing.Optional[str]:
        return jsii.get(self, "extendedStatistic")

    @extended_statistic.setter
    def extended_statistic(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "extendedStatistic", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="insufficientDataActions")
    def insufficient_data_actions(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "insufficientDataActions")

    @insufficient_data_actions.setter
    def insufficient_data_actions(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "insufficientDataActions", value)

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> typing.Optional[str]:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="metricQuery")
    def metric_query(
        self,
    ) -> typing.Optional[typing.List["CloudwatchMetricAlarmMetricQuery"]]:
        return jsii.get(self, "metricQuery")

    @metric_query.setter
    def metric_query(
        self, value: typing.Optional[typing.List["CloudwatchMetricAlarmMetricQuery"]]
    ) -> None:
        jsii.set(self, "metricQuery", value)

    @builtins.property
    @jsii.member(jsii_name="namespace")
    def namespace(self) -> typing.Optional[str]:
        return jsii.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namespace", value)

    @builtins.property
    @jsii.member(jsii_name="okActions")
    def ok_actions(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "okActions")

    @ok_actions.setter
    def ok_actions(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "okActions", value)

    @builtins.property
    @jsii.member(jsii_name="period")
    def period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "period")

    @period.setter
    def period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "period", value)

    @builtins.property
    @jsii.member(jsii_name="statistic")
    def statistic(self) -> typing.Optional[str]:
        return jsii.get(self, "statistic")

    @statistic.setter
    def statistic(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "statistic", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="threshold")
    def threshold(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "threshold")

    @threshold.setter
    def threshold(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "threshold", value)

    @builtins.property
    @jsii.member(jsii_name="thresholdMetricId")
    def threshold_metric_id(self) -> typing.Optional[str]:
        return jsii.get(self, "thresholdMetricId")

    @threshold_metric_id.setter
    def threshold_metric_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "thresholdMetricId", value)

    @builtins.property
    @jsii.member(jsii_name="treatMissingData")
    def treat_missing_data(self) -> typing.Optional[str]:
        return jsii.get(self, "treatMissingData")

    @treat_missing_data.setter
    def treat_missing_data(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "treatMissingData", value)

    @builtins.property
    @jsii.member(jsii_name="unit")
    def unit(self) -> typing.Optional[str]:
        return jsii.get(self, "unit")

    @unit.setter
    def unit(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "unit", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchMetricAlarmConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "alarm_name": "alarmName",
        "comparison_operator": "comparisonOperator",
        "evaluation_periods": "evaluationPeriods",
        "actions_enabled": "actionsEnabled",
        "alarm_actions": "alarmActions",
        "alarm_description": "alarmDescription",
        "datapoints_to_alarm": "datapointsToAlarm",
        "dimensions": "dimensions",
        "evaluate_low_sample_count_percentiles": "evaluateLowSampleCountPercentiles",
        "extended_statistic": "extendedStatistic",
        "insufficient_data_actions": "insufficientDataActions",
        "metric_name": "metricName",
        "metric_query": "metricQuery",
        "namespace": "namespace",
        "ok_actions": "okActions",
        "period": "period",
        "statistic": "statistic",
        "tags": "tags",
        "threshold": "threshold",
        "threshold_metric_id": "thresholdMetricId",
        "treat_missing_data": "treatMissingData",
        "unit": "unit",
    },
)
class CloudwatchMetricAlarmConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        alarm_name: str,
        comparison_operator: str,
        evaluation_periods: jsii.Number,
        actions_enabled: typing.Optional[bool] = None,
        alarm_actions: typing.Optional[typing.List[str]] = None,
        alarm_description: typing.Optional[str] = None,
        datapoints_to_alarm: typing.Optional[jsii.Number] = None,
        dimensions: typing.Optional[typing.Mapping[str, str]] = None,
        evaluate_low_sample_count_percentiles: typing.Optional[str] = None,
        extended_statistic: typing.Optional[str] = None,
        insufficient_data_actions: typing.Optional[typing.List[str]] = None,
        metric_name: typing.Optional[str] = None,
        metric_query: typing.Optional[
            typing.List["CloudwatchMetricAlarmMetricQuery"]
        ] = None,
        namespace: typing.Optional[str] = None,
        ok_actions: typing.Optional[typing.List[str]] = None,
        period: typing.Optional[jsii.Number] = None,
        statistic: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        threshold: typing.Optional[jsii.Number] = None,
        threshold_metric_id: typing.Optional[str] = None,
        treat_missing_data: typing.Optional[str] = None,
        unit: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param alarm_name: 
        :param comparison_operator: 
        :param evaluation_periods: 
        :param actions_enabled: 
        :param alarm_actions: 
        :param alarm_description: 
        :param datapoints_to_alarm: 
        :param dimensions: 
        :param evaluate_low_sample_count_percentiles: 
        :param extended_statistic: 
        :param insufficient_data_actions: 
        :param metric_name: 
        :param metric_query: metric_query block.
        :param namespace: 
        :param ok_actions: 
        :param period: 
        :param statistic: 
        :param tags: 
        :param threshold: 
        :param threshold_metric_id: 
        :param treat_missing_data: 
        :param unit: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "alarm_name": alarm_name,
            "comparison_operator": comparison_operator,
            "evaluation_periods": evaluation_periods,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if actions_enabled is not None:
            self._values["actions_enabled"] = actions_enabled
        if alarm_actions is not None:
            self._values["alarm_actions"] = alarm_actions
        if alarm_description is not None:
            self._values["alarm_description"] = alarm_description
        if datapoints_to_alarm is not None:
            self._values["datapoints_to_alarm"] = datapoints_to_alarm
        if dimensions is not None:
            self._values["dimensions"] = dimensions
        if evaluate_low_sample_count_percentiles is not None:
            self._values[
                "evaluate_low_sample_count_percentiles"
            ] = evaluate_low_sample_count_percentiles
        if extended_statistic is not None:
            self._values["extended_statistic"] = extended_statistic
        if insufficient_data_actions is not None:
            self._values["insufficient_data_actions"] = insufficient_data_actions
        if metric_name is not None:
            self._values["metric_name"] = metric_name
        if metric_query is not None:
            self._values["metric_query"] = metric_query
        if namespace is not None:
            self._values["namespace"] = namespace
        if ok_actions is not None:
            self._values["ok_actions"] = ok_actions
        if period is not None:
            self._values["period"] = period
        if statistic is not None:
            self._values["statistic"] = statistic
        if tags is not None:
            self._values["tags"] = tags
        if threshold is not None:
            self._values["threshold"] = threshold
        if threshold_metric_id is not None:
            self._values["threshold_metric_id"] = threshold_metric_id
        if treat_missing_data is not None:
            self._values["treat_missing_data"] = treat_missing_data
        if unit is not None:
            self._values["unit"] = unit

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def alarm_name(self) -> str:
        return self._values.get("alarm_name")

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def evaluation_periods(self) -> jsii.Number:
        return self._values.get("evaluation_periods")

    @builtins.property
    def actions_enabled(self) -> typing.Optional[bool]:
        return self._values.get("actions_enabled")

    @builtins.property
    def alarm_actions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("alarm_actions")

    @builtins.property
    def alarm_description(self) -> typing.Optional[str]:
        return self._values.get("alarm_description")

    @builtins.property
    def datapoints_to_alarm(self) -> typing.Optional[jsii.Number]:
        return self._values.get("datapoints_to_alarm")

    @builtins.property
    def dimensions(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("dimensions")

    @builtins.property
    def evaluate_low_sample_count_percentiles(self) -> typing.Optional[str]:
        return self._values.get("evaluate_low_sample_count_percentiles")

    @builtins.property
    def extended_statistic(self) -> typing.Optional[str]:
        return self._values.get("extended_statistic")

    @builtins.property
    def insufficient_data_actions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("insufficient_data_actions")

    @builtins.property
    def metric_name(self) -> typing.Optional[str]:
        return self._values.get("metric_name")

    @builtins.property
    def metric_query(
        self,
    ) -> typing.Optional[typing.List["CloudwatchMetricAlarmMetricQuery"]]:
        """metric_query block."""
        return self._values.get("metric_query")

    @builtins.property
    def namespace(self) -> typing.Optional[str]:
        return self._values.get("namespace")

    @builtins.property
    def ok_actions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ok_actions")

    @builtins.property
    def period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("period")

    @builtins.property
    def statistic(self) -> typing.Optional[str]:
        return self._values.get("statistic")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("threshold")

    @builtins.property
    def threshold_metric_id(self) -> typing.Optional[str]:
        return self._values.get("threshold_metric_id")

    @builtins.property
    def treat_missing_data(self) -> typing.Optional[str]:
        return self._values.get("treat_missing_data")

    @builtins.property
    def unit(self) -> typing.Optional[str]:
        return self._values.get("unit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchMetricAlarmConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchMetricAlarmMetricQuery",
    jsii_struct_bases=[],
    name_mapping={
        "id": "id",
        "expression": "expression",
        "label": "label",
        "metric": "metric",
        "return_data": "returnData",
    },
)
class CloudwatchMetricAlarmMetricQuery:
    def __init__(
        self,
        *,
        id: str,
        expression: typing.Optional[str] = None,
        label: typing.Optional[str] = None,
        metric: typing.Optional[
            typing.List["CloudwatchMetricAlarmMetricQueryMetric"]
        ] = None,
        return_data: typing.Optional[bool] = None,
    ) -> None:
        """
        :param id: 
        :param expression: 
        :param label: 
        :param metric: metric block.
        :param return_data: 
        """
        self._values = {
            "id": id,
        }
        if expression is not None:
            self._values["expression"] = expression
        if label is not None:
            self._values["label"] = label
        if metric is not None:
            self._values["metric"] = metric
        if return_data is not None:
            self._values["return_data"] = return_data

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    @builtins.property
    def expression(self) -> typing.Optional[str]:
        return self._values.get("expression")

    @builtins.property
    def label(self) -> typing.Optional[str]:
        return self._values.get("label")

    @builtins.property
    def metric(
        self,
    ) -> typing.Optional[typing.List["CloudwatchMetricAlarmMetricQueryMetric"]]:
        """metric block."""
        return self._values.get("metric")

    @builtins.property
    def return_data(self) -> typing.Optional[bool]:
        return self._values.get("return_data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchMetricAlarmMetricQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CloudwatchMetricAlarmMetricQueryMetric",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "period": "period",
        "stat": "stat",
        "dimensions": "dimensions",
        "namespace": "namespace",
        "unit": "unit",
    },
)
class CloudwatchMetricAlarmMetricQueryMetric:
    def __init__(
        self,
        *,
        metric_name: str,
        period: jsii.Number,
        stat: str,
        dimensions: typing.Optional[typing.Mapping[str, str]] = None,
        namespace: typing.Optional[str] = None,
        unit: typing.Optional[str] = None,
    ) -> None:
        """
        :param metric_name: 
        :param period: 
        :param stat: 
        :param dimensions: 
        :param namespace: 
        :param unit: 
        """
        self._values = {
            "metric_name": metric_name,
            "period": period,
            "stat": stat,
        }
        if dimensions is not None:
            self._values["dimensions"] = dimensions
        if namespace is not None:
            self._values["namespace"] = namespace
        if unit is not None:
            self._values["unit"] = unit

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def period(self) -> jsii.Number:
        return self._values.get("period")

    @builtins.property
    def stat(self) -> str:
        return self._values.get("stat")

    @builtins.property
    def dimensions(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("dimensions")

    @builtins.property
    def namespace(self) -> typing.Optional[str]:
        return self._values.get("namespace")

    @builtins.property
    def unit(self) -> typing.Optional[str]:
        return self._values.get("unit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CloudwatchMetricAlarmMetricQueryMetric(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodebuildProject(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProject",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        artifacts: typing.List["CodebuildProjectArtifacts"],
        environment: typing.List["CodebuildProjectEnvironment"],
        name: str,
        service_role: str,
        source: typing.List["CodebuildProjectSource"],
        badge_enabled: typing.Optional[bool] = None,
        build_timeout: typing.Optional[jsii.Number] = None,
        cache: typing.Optional[typing.List["CodebuildProjectCache"]] = None,
        description: typing.Optional[str] = None,
        encryption_key: typing.Optional[str] = None,
        logs_config: typing.Optional[typing.List["CodebuildProjectLogsConfig"]] = None,
        queued_timeout: typing.Optional[jsii.Number] = None,
        secondary_artifacts: typing.Optional[
            typing.List["CodebuildProjectSecondaryArtifacts"]
        ] = None,
        secondary_sources: typing.Optional[
            typing.List["CodebuildProjectSecondarySources"]
        ] = None,
        source_version: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_config: typing.Optional[typing.List["CodebuildProjectVpcConfig"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param artifacts: artifacts block.
        :param environment: environment block.
        :param name: 
        :param service_role: 
        :param source: source block.
        :param badge_enabled: 
        :param build_timeout: 
        :param cache: cache block.
        :param description: 
        :param encryption_key: 
        :param logs_config: logs_config block.
        :param queued_timeout: 
        :param secondary_artifacts: secondary_artifacts block.
        :param secondary_sources: secondary_sources block.
        :param source_version: 
        :param tags: 
        :param vpc_config: vpc_config block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodebuildProjectConfig(
            artifacts=artifacts,
            environment=environment,
            name=name,
            service_role=service_role,
            source=source,
            badge_enabled=badge_enabled,
            build_timeout=build_timeout,
            cache=cache,
            description=description,
            encryption_key=encryption_key,
            logs_config=logs_config,
            queued_timeout=queued_timeout,
            secondary_artifacts=secondary_artifacts,
            secondary_sources=secondary_sources,
            source_version=source_version,
            tags=tags,
            vpc_config=vpc_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodebuildProject, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="badgeUrl")
    def badge_url(self) -> str:
        return jsii.get(self, "badgeUrl")

    @builtins.property
    @jsii.member(jsii_name="artifacts")
    def artifacts(self) -> typing.List["CodebuildProjectArtifacts"]:
        return jsii.get(self, "artifacts")

    @artifacts.setter
    def artifacts(self, value: typing.List["CodebuildProjectArtifacts"]) -> None:
        jsii.set(self, "artifacts", value)

    @builtins.property
    @jsii.member(jsii_name="environment")
    def environment(self) -> typing.List["CodebuildProjectEnvironment"]:
        return jsii.get(self, "environment")

    @environment.setter
    def environment(self, value: typing.List["CodebuildProjectEnvironment"]) -> None:
        jsii.set(self, "environment", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="serviceRole")
    def service_role(self) -> str:
        return jsii.get(self, "serviceRole")

    @service_role.setter
    def service_role(self, value: str) -> None:
        jsii.set(self, "serviceRole", value)

    @builtins.property
    @jsii.member(jsii_name="source")
    def source(self) -> typing.List["CodebuildProjectSource"]:
        return jsii.get(self, "source")

    @source.setter
    def source(self, value: typing.List["CodebuildProjectSource"]) -> None:
        jsii.set(self, "source", value)

    @builtins.property
    @jsii.member(jsii_name="badgeEnabled")
    def badge_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "badgeEnabled")

    @badge_enabled.setter
    def badge_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "badgeEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="buildTimeout")
    def build_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "buildTimeout")

    @build_timeout.setter
    def build_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "buildTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="cache")
    def cache(self) -> typing.Optional[typing.List["CodebuildProjectCache"]]:
        return jsii.get(self, "cache")

    @cache.setter
    def cache(
        self, value: typing.Optional[typing.List["CodebuildProjectCache"]]
    ) -> None:
        jsii.set(self, "cache", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="encryptionKey")
    def encryption_key(self) -> typing.Optional[str]:
        return jsii.get(self, "encryptionKey")

    @encryption_key.setter
    def encryption_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "encryptionKey", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="logsConfig")
    def logs_config(self) -> typing.Optional[typing.List["CodebuildProjectLogsConfig"]]:
        return jsii.get(self, "logsConfig")

    @logs_config.setter
    def logs_config(
        self, value: typing.Optional[typing.List["CodebuildProjectLogsConfig"]]
    ) -> None:
        jsii.set(self, "logsConfig", value)

    @builtins.property
    @jsii.member(jsii_name="queuedTimeout")
    def queued_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "queuedTimeout")

    @queued_timeout.setter
    def queued_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "queuedTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="secondaryArtifacts")
    def secondary_artifacts(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectSecondaryArtifacts"]]:
        return jsii.get(self, "secondaryArtifacts")

    @secondary_artifacts.setter
    def secondary_artifacts(
        self, value: typing.Optional[typing.List["CodebuildProjectSecondaryArtifacts"]]
    ) -> None:
        jsii.set(self, "secondaryArtifacts", value)

    @builtins.property
    @jsii.member(jsii_name="secondarySources")
    def secondary_sources(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectSecondarySources"]]:
        return jsii.get(self, "secondarySources")

    @secondary_sources.setter
    def secondary_sources(
        self, value: typing.Optional[typing.List["CodebuildProjectSecondarySources"]]
    ) -> None:
        jsii.set(self, "secondarySources", value)

    @builtins.property
    @jsii.member(jsii_name="sourceVersion")
    def source_version(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceVersion")

    @source_version.setter
    def source_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceVersion", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConfig")
    def vpc_config(self) -> typing.Optional[typing.List["CodebuildProjectVpcConfig"]]:
        return jsii.get(self, "vpcConfig")

    @vpc_config.setter
    def vpc_config(
        self, value: typing.Optional[typing.List["CodebuildProjectVpcConfig"]]
    ) -> None:
        jsii.set(self, "vpcConfig", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectArtifacts",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "artifact_identifier": "artifactIdentifier",
        "encryption_disabled": "encryptionDisabled",
        "location": "location",
        "name": "name",
        "namespace_type": "namespaceType",
        "override_artifact_name": "overrideArtifactName",
        "packaging": "packaging",
        "path": "path",
    },
)
class CodebuildProjectArtifacts:
    def __init__(
        self,
        *,
        type: str,
        artifact_identifier: typing.Optional[str] = None,
        encryption_disabled: typing.Optional[bool] = None,
        location: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        namespace_type: typing.Optional[str] = None,
        override_artifact_name: typing.Optional[bool] = None,
        packaging: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param artifact_identifier: 
        :param encryption_disabled: 
        :param location: 
        :param name: 
        :param namespace_type: 
        :param override_artifact_name: 
        :param packaging: 
        :param path: 
        """
        self._values = {
            "type": type,
        }
        if artifact_identifier is not None:
            self._values["artifact_identifier"] = artifact_identifier
        if encryption_disabled is not None:
            self._values["encryption_disabled"] = encryption_disabled
        if location is not None:
            self._values["location"] = location
        if name is not None:
            self._values["name"] = name
        if namespace_type is not None:
            self._values["namespace_type"] = namespace_type
        if override_artifact_name is not None:
            self._values["override_artifact_name"] = override_artifact_name
        if packaging is not None:
            self._values["packaging"] = packaging
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def artifact_identifier(self) -> typing.Optional[str]:
        return self._values.get("artifact_identifier")

    @builtins.property
    def encryption_disabled(self) -> typing.Optional[bool]:
        return self._values.get("encryption_disabled")

    @builtins.property
    def location(self) -> typing.Optional[str]:
        return self._values.get("location")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def namespace_type(self) -> typing.Optional[str]:
        return self._values.get("namespace_type")

    @builtins.property
    def override_artifact_name(self) -> typing.Optional[bool]:
        return self._values.get("override_artifact_name")

    @builtins.property
    def packaging(self) -> typing.Optional[str]:
        return self._values.get("packaging")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectArtifacts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectCache",
    jsii_struct_bases=[],
    name_mapping={"location": "location", "modes": "modes", "type": "type"},
)
class CodebuildProjectCache:
    def __init__(
        self,
        *,
        location: typing.Optional[str] = None,
        modes: typing.Optional[typing.List[str]] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param location: 
        :param modes: 
        :param type: 
        """
        self._values = {}
        if location is not None:
            self._values["location"] = location
        if modes is not None:
            self._values["modes"] = modes
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def location(self) -> typing.Optional[str]:
        return self._values.get("location")

    @builtins.property
    def modes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("modes")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectCache(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "artifacts": "artifacts",
        "environment": "environment",
        "name": "name",
        "service_role": "serviceRole",
        "source": "source",
        "badge_enabled": "badgeEnabled",
        "build_timeout": "buildTimeout",
        "cache": "cache",
        "description": "description",
        "encryption_key": "encryptionKey",
        "logs_config": "logsConfig",
        "queued_timeout": "queuedTimeout",
        "secondary_artifacts": "secondaryArtifacts",
        "secondary_sources": "secondarySources",
        "source_version": "sourceVersion",
        "tags": "tags",
        "vpc_config": "vpcConfig",
    },
)
class CodebuildProjectConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        artifacts: typing.List["CodebuildProjectArtifacts"],
        environment: typing.List["CodebuildProjectEnvironment"],
        name: str,
        service_role: str,
        source: typing.List["CodebuildProjectSource"],
        badge_enabled: typing.Optional[bool] = None,
        build_timeout: typing.Optional[jsii.Number] = None,
        cache: typing.Optional[typing.List["CodebuildProjectCache"]] = None,
        description: typing.Optional[str] = None,
        encryption_key: typing.Optional[str] = None,
        logs_config: typing.Optional[typing.List["CodebuildProjectLogsConfig"]] = None,
        queued_timeout: typing.Optional[jsii.Number] = None,
        secondary_artifacts: typing.Optional[
            typing.List["CodebuildProjectSecondaryArtifacts"]
        ] = None,
        secondary_sources: typing.Optional[
            typing.List["CodebuildProjectSecondarySources"]
        ] = None,
        source_version: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_config: typing.Optional[typing.List["CodebuildProjectVpcConfig"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param artifacts: artifacts block.
        :param environment: environment block.
        :param name: 
        :param service_role: 
        :param source: source block.
        :param badge_enabled: 
        :param build_timeout: 
        :param cache: cache block.
        :param description: 
        :param encryption_key: 
        :param logs_config: logs_config block.
        :param queued_timeout: 
        :param secondary_artifacts: secondary_artifacts block.
        :param secondary_sources: secondary_sources block.
        :param source_version: 
        :param tags: 
        :param vpc_config: vpc_config block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "artifacts": artifacts,
            "environment": environment,
            "name": name,
            "service_role": service_role,
            "source": source,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if badge_enabled is not None:
            self._values["badge_enabled"] = badge_enabled
        if build_timeout is not None:
            self._values["build_timeout"] = build_timeout
        if cache is not None:
            self._values["cache"] = cache
        if description is not None:
            self._values["description"] = description
        if encryption_key is not None:
            self._values["encryption_key"] = encryption_key
        if logs_config is not None:
            self._values["logs_config"] = logs_config
        if queued_timeout is not None:
            self._values["queued_timeout"] = queued_timeout
        if secondary_artifacts is not None:
            self._values["secondary_artifacts"] = secondary_artifacts
        if secondary_sources is not None:
            self._values["secondary_sources"] = secondary_sources
        if source_version is not None:
            self._values["source_version"] = source_version
        if tags is not None:
            self._values["tags"] = tags
        if vpc_config is not None:
            self._values["vpc_config"] = vpc_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def artifacts(self) -> typing.List["CodebuildProjectArtifacts"]:
        """artifacts block."""
        return self._values.get("artifacts")

    @builtins.property
    def environment(self) -> typing.List["CodebuildProjectEnvironment"]:
        """environment block."""
        return self._values.get("environment")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def service_role(self) -> str:
        return self._values.get("service_role")

    @builtins.property
    def source(self) -> typing.List["CodebuildProjectSource"]:
        """source block."""
        return self._values.get("source")

    @builtins.property
    def badge_enabled(self) -> typing.Optional[bool]:
        return self._values.get("badge_enabled")

    @builtins.property
    def build_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("build_timeout")

    @builtins.property
    def cache(self) -> typing.Optional[typing.List["CodebuildProjectCache"]]:
        """cache block."""
        return self._values.get("cache")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def encryption_key(self) -> typing.Optional[str]:
        return self._values.get("encryption_key")

    @builtins.property
    def logs_config(self) -> typing.Optional[typing.List["CodebuildProjectLogsConfig"]]:
        """logs_config block."""
        return self._values.get("logs_config")

    @builtins.property
    def queued_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("queued_timeout")

    @builtins.property
    def secondary_artifacts(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectSecondaryArtifacts"]]:
        """secondary_artifacts block."""
        return self._values.get("secondary_artifacts")

    @builtins.property
    def secondary_sources(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectSecondarySources"]]:
        """secondary_sources block."""
        return self._values.get("secondary_sources")

    @builtins.property
    def source_version(self) -> typing.Optional[str]:
        return self._values.get("source_version")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_config(self) -> typing.Optional[typing.List["CodebuildProjectVpcConfig"]]:
        """vpc_config block."""
        return self._values.get("vpc_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectEnvironment",
    jsii_struct_bases=[],
    name_mapping={
        "compute_type": "computeType",
        "image": "image",
        "type": "type",
        "certificate": "certificate",
        "environment_variable": "environmentVariable",
        "image_pull_credentials_type": "imagePullCredentialsType",
        "privileged_mode": "privilegedMode",
        "registry_credential": "registryCredential",
    },
)
class CodebuildProjectEnvironment:
    def __init__(
        self,
        *,
        compute_type: str,
        image: str,
        type: str,
        certificate: typing.Optional[str] = None,
        environment_variable: typing.Optional[
            typing.List["CodebuildProjectEnvironmentEnvironmentVariable"]
        ] = None,
        image_pull_credentials_type: typing.Optional[str] = None,
        privileged_mode: typing.Optional[bool] = None,
        registry_credential: typing.Optional[
            typing.List["CodebuildProjectEnvironmentRegistryCredential"]
        ] = None,
    ) -> None:
        """
        :param compute_type: 
        :param image: 
        :param type: 
        :param certificate: 
        :param environment_variable: environment_variable block.
        :param image_pull_credentials_type: 
        :param privileged_mode: 
        :param registry_credential: registry_credential block.
        """
        self._values = {
            "compute_type": compute_type,
            "image": image,
            "type": type,
        }
        if certificate is not None:
            self._values["certificate"] = certificate
        if environment_variable is not None:
            self._values["environment_variable"] = environment_variable
        if image_pull_credentials_type is not None:
            self._values["image_pull_credentials_type"] = image_pull_credentials_type
        if privileged_mode is not None:
            self._values["privileged_mode"] = privileged_mode
        if registry_credential is not None:
            self._values["registry_credential"] = registry_credential

    @builtins.property
    def compute_type(self) -> str:
        return self._values.get("compute_type")

    @builtins.property
    def image(self) -> str:
        return self._values.get("image")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def certificate(self) -> typing.Optional[str]:
        return self._values.get("certificate")

    @builtins.property
    def environment_variable(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectEnvironmentEnvironmentVariable"]]:
        """environment_variable block."""
        return self._values.get("environment_variable")

    @builtins.property
    def image_pull_credentials_type(self) -> typing.Optional[str]:
        return self._values.get("image_pull_credentials_type")

    @builtins.property
    def privileged_mode(self) -> typing.Optional[bool]:
        return self._values.get("privileged_mode")

    @builtins.property
    def registry_credential(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectEnvironmentRegistryCredential"]]:
        """registry_credential block."""
        return self._values.get("registry_credential")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectEnvironment(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectEnvironmentEnvironmentVariable",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value", "type": "type"},
)
class CodebuildProjectEnvironmentEnvironmentVariable:
    def __init__(
        self, *, name: str, value: str, type: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        :param type: 
        """
        self._values = {
            "name": name,
            "value": value,
        }
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectEnvironmentEnvironmentVariable(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectEnvironmentRegistryCredential",
    jsii_struct_bases=[],
    name_mapping={
        "credential": "credential",
        "credential_provider": "credentialProvider",
    },
)
class CodebuildProjectEnvironmentRegistryCredential:
    def __init__(self, *, credential: str, credential_provider: str) -> None:
        """
        :param credential: 
        :param credential_provider: 
        """
        self._values = {
            "credential": credential,
            "credential_provider": credential_provider,
        }

    @builtins.property
    def credential(self) -> str:
        return self._values.get("credential")

    @builtins.property
    def credential_provider(self) -> str:
        return self._values.get("credential_provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectEnvironmentRegistryCredential(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectLogsConfig",
    jsii_struct_bases=[],
    name_mapping={"cloudwatch_logs": "cloudwatchLogs", "s3_logs": "s3Logs"},
)
class CodebuildProjectLogsConfig:
    def __init__(
        self,
        *,
        cloudwatch_logs: typing.Optional[
            typing.List["CodebuildProjectLogsConfigCloudwatchLogs"]
        ] = None,
        s3_logs: typing.Optional[
            typing.List["CodebuildProjectLogsConfigS3Logs"]
        ] = None,
    ) -> None:
        """
        :param cloudwatch_logs: cloudwatch_logs block.
        :param s3_logs: s3_logs block.
        """
        self._values = {}
        if cloudwatch_logs is not None:
            self._values["cloudwatch_logs"] = cloudwatch_logs
        if s3_logs is not None:
            self._values["s3_logs"] = s3_logs

    @builtins.property
    def cloudwatch_logs(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectLogsConfigCloudwatchLogs"]]:
        """cloudwatch_logs block."""
        return self._values.get("cloudwatch_logs")

    @builtins.property
    def s3_logs(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectLogsConfigS3Logs"]]:
        """s3_logs block."""
        return self._values.get("s3_logs")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectLogsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectLogsConfigCloudwatchLogs",
    jsii_struct_bases=[],
    name_mapping={
        "group_name": "groupName",
        "status": "status",
        "stream_name": "streamName",
    },
)
class CodebuildProjectLogsConfigCloudwatchLogs:
    def __init__(
        self,
        *,
        group_name: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param group_name: 
        :param status: 
        :param stream_name: 
        """
        self._values = {}
        if group_name is not None:
            self._values["group_name"] = group_name
        if status is not None:
            self._values["status"] = status
        if stream_name is not None:
            self._values["stream_name"] = stream_name

    @builtins.property
    def group_name(self) -> typing.Optional[str]:
        return self._values.get("group_name")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    @builtins.property
    def stream_name(self) -> typing.Optional[str]:
        return self._values.get("stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectLogsConfigCloudwatchLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectLogsConfigS3Logs",
    jsii_struct_bases=[],
    name_mapping={
        "encryption_disabled": "encryptionDisabled",
        "location": "location",
        "status": "status",
    },
)
class CodebuildProjectLogsConfigS3Logs:
    def __init__(
        self,
        *,
        encryption_disabled: typing.Optional[bool] = None,
        location: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
    ) -> None:
        """
        :param encryption_disabled: 
        :param location: 
        :param status: 
        """
        self._values = {}
        if encryption_disabled is not None:
            self._values["encryption_disabled"] = encryption_disabled
        if location is not None:
            self._values["location"] = location
        if status is not None:
            self._values["status"] = status

    @builtins.property
    def encryption_disabled(self) -> typing.Optional[bool]:
        return self._values.get("encryption_disabled")

    @builtins.property
    def location(self) -> typing.Optional[str]:
        return self._values.get("location")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectLogsConfigS3Logs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectSecondaryArtifacts",
    jsii_struct_bases=[],
    name_mapping={
        "artifact_identifier": "artifactIdentifier",
        "type": "type",
        "encryption_disabled": "encryptionDisabled",
        "location": "location",
        "name": "name",
        "namespace_type": "namespaceType",
        "override_artifact_name": "overrideArtifactName",
        "packaging": "packaging",
        "path": "path",
    },
)
class CodebuildProjectSecondaryArtifacts:
    def __init__(
        self,
        *,
        artifact_identifier: str,
        type: str,
        encryption_disabled: typing.Optional[bool] = None,
        location: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        namespace_type: typing.Optional[str] = None,
        override_artifact_name: typing.Optional[bool] = None,
        packaging: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
    ) -> None:
        """
        :param artifact_identifier: 
        :param type: 
        :param encryption_disabled: 
        :param location: 
        :param name: 
        :param namespace_type: 
        :param override_artifact_name: 
        :param packaging: 
        :param path: 
        """
        self._values = {
            "artifact_identifier": artifact_identifier,
            "type": type,
        }
        if encryption_disabled is not None:
            self._values["encryption_disabled"] = encryption_disabled
        if location is not None:
            self._values["location"] = location
        if name is not None:
            self._values["name"] = name
        if namespace_type is not None:
            self._values["namespace_type"] = namespace_type
        if override_artifact_name is not None:
            self._values["override_artifact_name"] = override_artifact_name
        if packaging is not None:
            self._values["packaging"] = packaging
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def artifact_identifier(self) -> str:
        return self._values.get("artifact_identifier")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def encryption_disabled(self) -> typing.Optional[bool]:
        return self._values.get("encryption_disabled")

    @builtins.property
    def location(self) -> typing.Optional[str]:
        return self._values.get("location")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def namespace_type(self) -> typing.Optional[str]:
        return self._values.get("namespace_type")

    @builtins.property
    def override_artifact_name(self) -> typing.Optional[bool]:
        return self._values.get("override_artifact_name")

    @builtins.property
    def packaging(self) -> typing.Optional[str]:
        return self._values.get("packaging")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectSecondaryArtifacts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectSecondarySources",
    jsii_struct_bases=[],
    name_mapping={
        "source_identifier": "sourceIdentifier",
        "type": "type",
        "auth": "auth",
        "buildspec": "buildspec",
        "git_clone_depth": "gitCloneDepth",
        "git_submodules_config": "gitSubmodulesConfig",
        "insecure_ssl": "insecureSsl",
        "location": "location",
        "report_build_status": "reportBuildStatus",
    },
)
class CodebuildProjectSecondarySources:
    def __init__(
        self,
        *,
        source_identifier: str,
        type: str,
        auth: typing.Optional[
            typing.List["CodebuildProjectSecondarySourcesAuth"]
        ] = None,
        buildspec: typing.Optional[str] = None,
        git_clone_depth: typing.Optional[jsii.Number] = None,
        git_submodules_config: typing.Optional[
            typing.List["CodebuildProjectSecondarySourcesGitSubmodulesConfig"]
        ] = None,
        insecure_ssl: typing.Optional[bool] = None,
        location: typing.Optional[str] = None,
        report_build_status: typing.Optional[bool] = None,
    ) -> None:
        """
        :param source_identifier: 
        :param type: 
        :param auth: auth block.
        :param buildspec: 
        :param git_clone_depth: 
        :param git_submodules_config: git_submodules_config block.
        :param insecure_ssl: 
        :param location: 
        :param report_build_status: 
        """
        self._values = {
            "source_identifier": source_identifier,
            "type": type,
        }
        if auth is not None:
            self._values["auth"] = auth
        if buildspec is not None:
            self._values["buildspec"] = buildspec
        if git_clone_depth is not None:
            self._values["git_clone_depth"] = git_clone_depth
        if git_submodules_config is not None:
            self._values["git_submodules_config"] = git_submodules_config
        if insecure_ssl is not None:
            self._values["insecure_ssl"] = insecure_ssl
        if location is not None:
            self._values["location"] = location
        if report_build_status is not None:
            self._values["report_build_status"] = report_build_status

    @builtins.property
    def source_identifier(self) -> str:
        return self._values.get("source_identifier")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def auth(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectSecondarySourcesAuth"]]:
        """auth block."""
        return self._values.get("auth")

    @builtins.property
    def buildspec(self) -> typing.Optional[str]:
        return self._values.get("buildspec")

    @builtins.property
    def git_clone_depth(self) -> typing.Optional[jsii.Number]:
        return self._values.get("git_clone_depth")

    @builtins.property
    def git_submodules_config(
        self,
    ) -> typing.Optional[
        typing.List["CodebuildProjectSecondarySourcesGitSubmodulesConfig"]
    ]:
        """git_submodules_config block."""
        return self._values.get("git_submodules_config")

    @builtins.property
    def insecure_ssl(self) -> typing.Optional[bool]:
        return self._values.get("insecure_ssl")

    @builtins.property
    def location(self) -> typing.Optional[str]:
        return self._values.get("location")

    @builtins.property
    def report_build_status(self) -> typing.Optional[bool]:
        return self._values.get("report_build_status")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectSecondarySources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectSecondarySourcesAuth",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "resource": "resource"},
)
class CodebuildProjectSecondarySourcesAuth:
    def __init__(self, *, type: str, resource: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param resource: 
        """
        self._values = {
            "type": type,
        }
        if resource is not None:
            self._values["resource"] = resource

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def resource(self) -> typing.Optional[str]:
        return self._values.get("resource")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectSecondarySourcesAuth(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectSecondarySourcesGitSubmodulesConfig",
    jsii_struct_bases=[],
    name_mapping={"fetch_submodules": "fetchSubmodules"},
)
class CodebuildProjectSecondarySourcesGitSubmodulesConfig:
    def __init__(self, *, fetch_submodules: bool) -> None:
        """
        :param fetch_submodules: 
        """
        self._values = {
            "fetch_submodules": fetch_submodules,
        }

    @builtins.property
    def fetch_submodules(self) -> bool:
        return self._values.get("fetch_submodules")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectSecondarySourcesGitSubmodulesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectSource",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "auth": "auth",
        "buildspec": "buildspec",
        "git_clone_depth": "gitCloneDepth",
        "git_submodules_config": "gitSubmodulesConfig",
        "insecure_ssl": "insecureSsl",
        "location": "location",
        "report_build_status": "reportBuildStatus",
    },
)
class CodebuildProjectSource:
    def __init__(
        self,
        *,
        type: str,
        auth: typing.Optional[typing.List["CodebuildProjectSourceAuth"]] = None,
        buildspec: typing.Optional[str] = None,
        git_clone_depth: typing.Optional[jsii.Number] = None,
        git_submodules_config: typing.Optional[
            typing.List["CodebuildProjectSourceGitSubmodulesConfig"]
        ] = None,
        insecure_ssl: typing.Optional[bool] = None,
        location: typing.Optional[str] = None,
        report_build_status: typing.Optional[bool] = None,
    ) -> None:
        """
        :param type: 
        :param auth: auth block.
        :param buildspec: 
        :param git_clone_depth: 
        :param git_submodules_config: git_submodules_config block.
        :param insecure_ssl: 
        :param location: 
        :param report_build_status: 
        """
        self._values = {
            "type": type,
        }
        if auth is not None:
            self._values["auth"] = auth
        if buildspec is not None:
            self._values["buildspec"] = buildspec
        if git_clone_depth is not None:
            self._values["git_clone_depth"] = git_clone_depth
        if git_submodules_config is not None:
            self._values["git_submodules_config"] = git_submodules_config
        if insecure_ssl is not None:
            self._values["insecure_ssl"] = insecure_ssl
        if location is not None:
            self._values["location"] = location
        if report_build_status is not None:
            self._values["report_build_status"] = report_build_status

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def auth(self) -> typing.Optional[typing.List["CodebuildProjectSourceAuth"]]:
        """auth block."""
        return self._values.get("auth")

    @builtins.property
    def buildspec(self) -> typing.Optional[str]:
        return self._values.get("buildspec")

    @builtins.property
    def git_clone_depth(self) -> typing.Optional[jsii.Number]:
        return self._values.get("git_clone_depth")

    @builtins.property
    def git_submodules_config(
        self,
    ) -> typing.Optional[typing.List["CodebuildProjectSourceGitSubmodulesConfig"]]:
        """git_submodules_config block."""
        return self._values.get("git_submodules_config")

    @builtins.property
    def insecure_ssl(self) -> typing.Optional[bool]:
        return self._values.get("insecure_ssl")

    @builtins.property
    def location(self) -> typing.Optional[str]:
        return self._values.get("location")

    @builtins.property
    def report_build_status(self) -> typing.Optional[bool]:
        return self._values.get("report_build_status")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectSourceAuth",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "resource": "resource"},
)
class CodebuildProjectSourceAuth:
    def __init__(self, *, type: str, resource: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param resource: 
        """
        self._values = {
            "type": type,
        }
        if resource is not None:
            self._values["resource"] = resource

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def resource(self) -> typing.Optional[str]:
        return self._values.get("resource")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectSourceAuth(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectSourceGitSubmodulesConfig",
    jsii_struct_bases=[],
    name_mapping={"fetch_submodules": "fetchSubmodules"},
)
class CodebuildProjectSourceGitSubmodulesConfig:
    def __init__(self, *, fetch_submodules: bool) -> None:
        """
        :param fetch_submodules: 
        """
        self._values = {
            "fetch_submodules": fetch_submodules,
        }

    @builtins.property
    def fetch_submodules(self) -> bool:
        return self._values.get("fetch_submodules")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectSourceGitSubmodulesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildProjectVpcConfig",
    jsii_struct_bases=[],
    name_mapping={
        "security_group_ids": "securityGroupIds",
        "subnets": "subnets",
        "vpc_id": "vpcId",
    },
)
class CodebuildProjectVpcConfig:
    def __init__(
        self,
        *,
        security_group_ids: typing.List[str],
        subnets: typing.List[str],
        vpc_id: str,
    ) -> None:
        """
        :param security_group_ids: 
        :param subnets: 
        :param vpc_id: 
        """
        self._values = {
            "security_group_ids": security_group_ids,
            "subnets": subnets,
            "vpc_id": vpc_id,
        }

    @builtins.property
    def security_group_ids(self) -> typing.List[str]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnets(self) -> typing.List[str]:
        return self._values.get("subnets")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildProjectVpcConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodebuildSourceCredential(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildSourceCredential",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        auth_type: str,
        server_type: str,
        token: str,
        user_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param auth_type: 
        :param server_type: 
        :param token: 
        :param user_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodebuildSourceCredentialConfig(
            auth_type=auth_type,
            server_type=server_type,
            token=token,
            user_name=user_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodebuildSourceCredential, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="authType")
    def auth_type(self) -> str:
        return jsii.get(self, "authType")

    @auth_type.setter
    def auth_type(self, value: str) -> None:
        jsii.set(self, "authType", value)

    @builtins.property
    @jsii.member(jsii_name="serverType")
    def server_type(self) -> str:
        return jsii.get(self, "serverType")

    @server_type.setter
    def server_type(self, value: str) -> None:
        jsii.set(self, "serverType", value)

    @builtins.property
    @jsii.member(jsii_name="token")
    def token(self) -> str:
        return jsii.get(self, "token")

    @token.setter
    def token(self, value: str) -> None:
        jsii.set(self, "token", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> typing.Optional[str]:
        return jsii.get(self, "userName")

    @user_name.setter
    def user_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildSourceCredentialConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "auth_type": "authType",
        "server_type": "serverType",
        "token": "token",
        "user_name": "userName",
    },
)
class CodebuildSourceCredentialConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        auth_type: str,
        server_type: str,
        token: str,
        user_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param auth_type: 
        :param server_type: 
        :param token: 
        :param user_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "auth_type": auth_type,
            "server_type": server_type,
            "token": token,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if user_name is not None:
            self._values["user_name"] = user_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def auth_type(self) -> str:
        return self._values.get("auth_type")

    @builtins.property
    def server_type(self) -> str:
        return self._values.get("server_type")

    @builtins.property
    def token(self) -> str:
        return self._values.get("token")

    @builtins.property
    def user_name(self) -> typing.Optional[str]:
        return self._values.get("user_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildSourceCredentialConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodebuildWebhook(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildWebhook",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        project_name: str,
        branch_filter: typing.Optional[str] = None,
        filter_group: typing.Optional[
            typing.List["CodebuildWebhookFilterGroup"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param project_name: 
        :param branch_filter: 
        :param filter_group: filter_group block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodebuildWebhookConfig(
            project_name=project_name,
            branch_filter=branch_filter,
            filter_group=filter_group,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodebuildWebhook, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="payloadUrl")
    def payload_url(self) -> str:
        return jsii.get(self, "payloadUrl")

    @builtins.property
    @jsii.member(jsii_name="secret")
    def secret(self) -> str:
        return jsii.get(self, "secret")

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> str:
        return jsii.get(self, "url")

    @builtins.property
    @jsii.member(jsii_name="projectName")
    def project_name(self) -> str:
        return jsii.get(self, "projectName")

    @project_name.setter
    def project_name(self, value: str) -> None:
        jsii.set(self, "projectName", value)

    @builtins.property
    @jsii.member(jsii_name="branchFilter")
    def branch_filter(self) -> typing.Optional[str]:
        return jsii.get(self, "branchFilter")

    @branch_filter.setter
    def branch_filter(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "branchFilter", value)

    @builtins.property
    @jsii.member(jsii_name="filterGroup")
    def filter_group(
        self,
    ) -> typing.Optional[typing.List["CodebuildWebhookFilterGroup"]]:
        return jsii.get(self, "filterGroup")

    @filter_group.setter
    def filter_group(
        self, value: typing.Optional[typing.List["CodebuildWebhookFilterGroup"]]
    ) -> None:
        jsii.set(self, "filterGroup", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildWebhookConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "project_name": "projectName",
        "branch_filter": "branchFilter",
        "filter_group": "filterGroup",
    },
)
class CodebuildWebhookConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        project_name: str,
        branch_filter: typing.Optional[str] = None,
        filter_group: typing.Optional[
            typing.List["CodebuildWebhookFilterGroup"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param project_name: 
        :param branch_filter: 
        :param filter_group: filter_group block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "project_name": project_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if branch_filter is not None:
            self._values["branch_filter"] = branch_filter
        if filter_group is not None:
            self._values["filter_group"] = filter_group

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def project_name(self) -> str:
        return self._values.get("project_name")

    @builtins.property
    def branch_filter(self) -> typing.Optional[str]:
        return self._values.get("branch_filter")

    @builtins.property
    def filter_group(
        self,
    ) -> typing.Optional[typing.List["CodebuildWebhookFilterGroup"]]:
        """filter_group block."""
        return self._values.get("filter_group")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildWebhookConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildWebhookFilterGroup",
    jsii_struct_bases=[],
    name_mapping={"filter": "filter"},
)
class CodebuildWebhookFilterGroup:
    def __init__(
        self,
        *,
        filter: typing.Optional[
            typing.List["CodebuildWebhookFilterGroupFilter"]
        ] = None,
    ) -> None:
        """
        :param filter: filter block.
        """
        self._values = {}
        if filter is not None:
            self._values["filter"] = filter

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["CodebuildWebhookFilterGroupFilter"]]:
        """filter block."""
        return self._values.get("filter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildWebhookFilterGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodebuildWebhookFilterGroupFilter",
    jsii_struct_bases=[],
    name_mapping={
        "pattern": "pattern",
        "type": "type",
        "exclude_matched_pattern": "excludeMatchedPattern",
    },
)
class CodebuildWebhookFilterGroupFilter:
    def __init__(
        self,
        *,
        pattern: str,
        type: str,
        exclude_matched_pattern: typing.Optional[bool] = None,
    ) -> None:
        """
        :param pattern: 
        :param type: 
        :param exclude_matched_pattern: 
        """
        self._values = {
            "pattern": pattern,
            "type": type,
        }
        if exclude_matched_pattern is not None:
            self._values["exclude_matched_pattern"] = exclude_matched_pattern

    @builtins.property
    def pattern(self) -> str:
        return self._values.get("pattern")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def exclude_matched_pattern(self) -> typing.Optional[bool]:
        return self._values.get("exclude_matched_pattern")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodebuildWebhookFilterGroupFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodecommitRepository(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodecommitRepository",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        repository_name: str,
        default_branch: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param repository_name: 
        :param default_branch: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodecommitRepositoryConfig(
            repository_name=repository_name,
            default_branch=default_branch,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodecommitRepository, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="cloneUrlHttp")
    def clone_url_http(self) -> str:
        return jsii.get(self, "cloneUrlHttp")

    @builtins.property
    @jsii.member(jsii_name="cloneUrlSsh")
    def clone_url_ssh(self) -> str:
        return jsii.get(self, "cloneUrlSsh")

    @builtins.property
    @jsii.member(jsii_name="repositoryId")
    def repository_id(self) -> str:
        return jsii.get(self, "repositoryId")

    @builtins.property
    @jsii.member(jsii_name="repositoryName")
    def repository_name(self) -> str:
        return jsii.get(self, "repositoryName")

    @repository_name.setter
    def repository_name(self, value: str) -> None:
        jsii.set(self, "repositoryName", value)

    @builtins.property
    @jsii.member(jsii_name="defaultBranch")
    def default_branch(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultBranch")

    @default_branch.setter
    def default_branch(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultBranch", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodecommitRepositoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "repository_name": "repositoryName",
        "default_branch": "defaultBranch",
        "description": "description",
        "tags": "tags",
    },
)
class CodecommitRepositoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        repository_name: str,
        default_branch: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param repository_name: 
        :param default_branch: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "repository_name": repository_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_branch is not None:
            self._values["default_branch"] = default_branch
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def repository_name(self) -> str:
        return self._values.get("repository_name")

    @builtins.property
    def default_branch(self) -> typing.Optional[str]:
        return self._values.get("default_branch")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodecommitRepositoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodecommitTrigger(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodecommitTrigger",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        repository_name: str,
        trigger: typing.List["CodecommitTriggerTrigger"],
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param repository_name: 
        :param trigger: trigger block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodecommitTriggerConfig(
            repository_name=repository_name,
            trigger=trigger,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodecommitTrigger, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="configurationId")
    def configuration_id(self) -> str:
        return jsii.get(self, "configurationId")

    @builtins.property
    @jsii.member(jsii_name="repositoryName")
    def repository_name(self) -> str:
        return jsii.get(self, "repositoryName")

    @repository_name.setter
    def repository_name(self, value: str) -> None:
        jsii.set(self, "repositoryName", value)

    @builtins.property
    @jsii.member(jsii_name="trigger")
    def trigger(self) -> typing.List["CodecommitTriggerTrigger"]:
        return jsii.get(self, "trigger")

    @trigger.setter
    def trigger(self, value: typing.List["CodecommitTriggerTrigger"]) -> None:
        jsii.set(self, "trigger", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodecommitTriggerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "repository_name": "repositoryName",
        "trigger": "trigger",
    },
)
class CodecommitTriggerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        repository_name: str,
        trigger: typing.List["CodecommitTriggerTrigger"],
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param repository_name: 
        :param trigger: trigger block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "repository_name": repository_name,
            "trigger": trigger,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def repository_name(self) -> str:
        return self._values.get("repository_name")

    @builtins.property
    def trigger(self) -> typing.List["CodecommitTriggerTrigger"]:
        """trigger block."""
        return self._values.get("trigger")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodecommitTriggerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodecommitTriggerTrigger",
    jsii_struct_bases=[],
    name_mapping={
        "destination_arn": "destinationArn",
        "events": "events",
        "name": "name",
        "branches": "branches",
        "custom_data": "customData",
    },
)
class CodecommitTriggerTrigger:
    def __init__(
        self,
        *,
        destination_arn: str,
        events: typing.List[str],
        name: str,
        branches: typing.Optional[typing.List[str]] = None,
        custom_data: typing.Optional[str] = None,
    ) -> None:
        """
        :param destination_arn: 
        :param events: 
        :param name: 
        :param branches: 
        :param custom_data: 
        """
        self._values = {
            "destination_arn": destination_arn,
            "events": events,
            "name": name,
        }
        if branches is not None:
            self._values["branches"] = branches
        if custom_data is not None:
            self._values["custom_data"] = custom_data

    @builtins.property
    def destination_arn(self) -> str:
        return self._values.get("destination_arn")

    @builtins.property
    def events(self) -> typing.List[str]:
        return self._values.get("events")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def branches(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("branches")

    @builtins.property
    def custom_data(self) -> typing.Optional[str]:
        return self._values.get("custom_data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodecommitTriggerTrigger(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodedeployApp(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployApp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        compute_platform: typing.Optional[str] = None,
        unique_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param compute_platform: 
        :param unique_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodedeployAppConfig(
            name=name,
            compute_platform=compute_platform,
            unique_id=unique_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodedeployApp, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="computePlatform")
    def compute_platform(self) -> typing.Optional[str]:
        return jsii.get(self, "computePlatform")

    @compute_platform.setter
    def compute_platform(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "computePlatform", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> typing.Optional[str]:
        return jsii.get(self, "uniqueId")

    @unique_id.setter
    def unique_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "uniqueId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployAppConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "compute_platform": "computePlatform",
        "unique_id": "uniqueId",
    },
)
class CodedeployAppConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        compute_platform: typing.Optional[str] = None,
        unique_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param compute_platform: 
        :param unique_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if compute_platform is not None:
            self._values["compute_platform"] = compute_platform
        if unique_id is not None:
            self._values["unique_id"] = unique_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def compute_platform(self) -> typing.Optional[str]:
        return self._values.get("compute_platform")

    @builtins.property
    def unique_id(self) -> typing.Optional[str]:
        return self._values.get("unique_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployAppConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodedeployDeploymentConfig(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentConfig",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        deployment_config_name: str,
        compute_platform: typing.Optional[str] = None,
        minimum_healthy_hosts: typing.Optional[
            typing.List["CodedeployDeploymentConfigMinimumHealthyHosts"]
        ] = None,
        traffic_routing_config: typing.Optional[
            typing.List["CodedeployDeploymentConfigTrafficRoutingConfig"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param deployment_config_name: 
        :param compute_platform: 
        :param minimum_healthy_hosts: minimum_healthy_hosts block.
        :param traffic_routing_config: traffic_routing_config block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodedeployDeploymentConfigConfig(
            deployment_config_name=deployment_config_name,
            compute_platform=compute_platform,
            minimum_healthy_hosts=minimum_healthy_hosts,
            traffic_routing_config=traffic_routing_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodedeployDeploymentConfig, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="deploymentConfigId")
    def deployment_config_id(self) -> str:
        return jsii.get(self, "deploymentConfigId")

    @builtins.property
    @jsii.member(jsii_name="deploymentConfigName")
    def deployment_config_name(self) -> str:
        return jsii.get(self, "deploymentConfigName")

    @deployment_config_name.setter
    def deployment_config_name(self, value: str) -> None:
        jsii.set(self, "deploymentConfigName", value)

    @builtins.property
    @jsii.member(jsii_name="computePlatform")
    def compute_platform(self) -> typing.Optional[str]:
        return jsii.get(self, "computePlatform")

    @compute_platform.setter
    def compute_platform(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "computePlatform", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="minimumHealthyHosts")
    def minimum_healthy_hosts(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentConfigMinimumHealthyHosts"]]:
        return jsii.get(self, "minimumHealthyHosts")

    @minimum_healthy_hosts.setter
    def minimum_healthy_hosts(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentConfigMinimumHealthyHosts"]
        ],
    ) -> None:
        jsii.set(self, "minimumHealthyHosts", value)

    @builtins.property
    @jsii.member(jsii_name="trafficRoutingConfig")
    def traffic_routing_config(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentConfigTrafficRoutingConfig"]]:
        return jsii.get(self, "trafficRoutingConfig")

    @traffic_routing_config.setter
    def traffic_routing_config(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentConfigTrafficRoutingConfig"]
        ],
    ) -> None:
        jsii.set(self, "trafficRoutingConfig", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentConfigConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "deployment_config_name": "deploymentConfigName",
        "compute_platform": "computePlatform",
        "minimum_healthy_hosts": "minimumHealthyHosts",
        "traffic_routing_config": "trafficRoutingConfig",
    },
)
class CodedeployDeploymentConfigConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        deployment_config_name: str,
        compute_platform: typing.Optional[str] = None,
        minimum_healthy_hosts: typing.Optional[
            typing.List["CodedeployDeploymentConfigMinimumHealthyHosts"]
        ] = None,
        traffic_routing_config: typing.Optional[
            typing.List["CodedeployDeploymentConfigTrafficRoutingConfig"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param deployment_config_name: 
        :param compute_platform: 
        :param minimum_healthy_hosts: minimum_healthy_hosts block.
        :param traffic_routing_config: traffic_routing_config block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "deployment_config_name": deployment_config_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if compute_platform is not None:
            self._values["compute_platform"] = compute_platform
        if minimum_healthy_hosts is not None:
            self._values["minimum_healthy_hosts"] = minimum_healthy_hosts
        if traffic_routing_config is not None:
            self._values["traffic_routing_config"] = traffic_routing_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def deployment_config_name(self) -> str:
        return self._values.get("deployment_config_name")

    @builtins.property
    def compute_platform(self) -> typing.Optional[str]:
        return self._values.get("compute_platform")

    @builtins.property
    def minimum_healthy_hosts(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentConfigMinimumHealthyHosts"]]:
        """minimum_healthy_hosts block."""
        return self._values.get("minimum_healthy_hosts")

    @builtins.property
    def traffic_routing_config(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentConfigTrafficRoutingConfig"]]:
        """traffic_routing_config block."""
        return self._values.get("traffic_routing_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentConfigConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentConfigMinimumHealthyHosts",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "value": "value"},
)
class CodedeployDeploymentConfigMinimumHealthyHosts:
    def __init__(
        self,
        *,
        type: typing.Optional[str] = None,
        value: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param type: 
        :param value: 
        """
        self._values = {}
        if type is not None:
            self._values["type"] = type
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    @builtins.property
    def value(self) -> typing.Optional[jsii.Number]:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentConfigMinimumHealthyHosts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentConfigTrafficRoutingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "time_based_canary": "timeBasedCanary",
        "time_based_linear": "timeBasedLinear",
        "type": "type",
    },
)
class CodedeployDeploymentConfigTrafficRoutingConfig:
    def __init__(
        self,
        *,
        time_based_canary: typing.Optional[
            typing.List["CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary"]
        ] = None,
        time_based_linear: typing.Optional[
            typing.List["CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear"]
        ] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param time_based_canary: time_based_canary block.
        :param time_based_linear: time_based_linear block.
        :param type: 
        """
        self._values = {}
        if time_based_canary is not None:
            self._values["time_based_canary"] = time_based_canary
        if time_based_linear is not None:
            self._values["time_based_linear"] = time_based_linear
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def time_based_canary(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary"]
    ]:
        """time_based_canary block."""
        return self._values.get("time_based_canary")

    @builtins.property
    def time_based_linear(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear"]
    ]:
        """time_based_linear block."""
        return self._values.get("time_based_linear")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentConfigTrafficRoutingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary",
    jsii_struct_bases=[],
    name_mapping={"interval": "interval", "percentage": "percentage"},
)
class CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary:
    def __init__(
        self,
        *,
        interval: typing.Optional[jsii.Number] = None,
        percentage: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param interval: 
        :param percentage: 
        """
        self._values = {}
        if interval is not None:
            self._values["interval"] = interval
        if percentage is not None:
            self._values["percentage"] = percentage

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("interval")

    @builtins.property
    def percentage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("percentage")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear",
    jsii_struct_bases=[],
    name_mapping={"interval": "interval", "percentage": "percentage"},
)
class CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear:
    def __init__(
        self,
        *,
        interval: typing.Optional[jsii.Number] = None,
        percentage: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param interval: 
        :param percentage: 
        """
        self._values = {}
        if interval is not None:
            self._values["interval"] = interval
        if percentage is not None:
            self._values["percentage"] = percentage

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("interval")

    @builtins.property
    def percentage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("percentage")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class CodedeployDeploymentGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        app_name: str,
        deployment_group_name: str,
        service_role_arn: str,
        alarm_configuration: typing.Optional[
            typing.List["CodedeployDeploymentGroupAlarmConfiguration"]
        ] = None,
        auto_rollback_configuration: typing.Optional[
            typing.List["CodedeployDeploymentGroupAutoRollbackConfiguration"]
        ] = None,
        autoscaling_groups: typing.Optional[typing.List[str]] = None,
        blue_green_deployment_config: typing.Optional[
            typing.List["CodedeployDeploymentGroupBlueGreenDeploymentConfig"]
        ] = None,
        deployment_config_name: typing.Optional[str] = None,
        deployment_style: typing.Optional[
            typing.List["CodedeployDeploymentGroupDeploymentStyle"]
        ] = None,
        ec2_tag_filter: typing.Optional[
            typing.List["CodedeployDeploymentGroupEc2TagFilter"]
        ] = None,
        ec2_tag_set: typing.Optional[
            typing.List["CodedeployDeploymentGroupEc2TagSet"]
        ] = None,
        ecs_service: typing.Optional[
            typing.List["CodedeployDeploymentGroupEcsService"]
        ] = None,
        load_balancer_info: typing.Optional[
            typing.List["CodedeployDeploymentGroupLoadBalancerInfo"]
        ] = None,
        on_premises_instance_tag_filter: typing.Optional[
            typing.List["CodedeployDeploymentGroupOnPremisesInstanceTagFilter"]
        ] = None,
        trigger_configuration: typing.Optional[
            typing.List["CodedeployDeploymentGroupTriggerConfiguration"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param app_name: 
        :param deployment_group_name: 
        :param service_role_arn: 
        :param alarm_configuration: alarm_configuration block.
        :param auto_rollback_configuration: auto_rollback_configuration block.
        :param autoscaling_groups: 
        :param blue_green_deployment_config: blue_green_deployment_config block.
        :param deployment_config_name: 
        :param deployment_style: deployment_style block.
        :param ec2_tag_filter: ec2_tag_filter block.
        :param ec2_tag_set: ec2_tag_set block.
        :param ecs_service: ecs_service block.
        :param load_balancer_info: load_balancer_info block.
        :param on_premises_instance_tag_filter: on_premises_instance_tag_filter block.
        :param trigger_configuration: trigger_configuration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodedeployDeploymentGroupConfig(
            app_name=app_name,
            deployment_group_name=deployment_group_name,
            service_role_arn=service_role_arn,
            alarm_configuration=alarm_configuration,
            auto_rollback_configuration=auto_rollback_configuration,
            autoscaling_groups=autoscaling_groups,
            blue_green_deployment_config=blue_green_deployment_config,
            deployment_config_name=deployment_config_name,
            deployment_style=deployment_style,
            ec2_tag_filter=ec2_tag_filter,
            ec2_tag_set=ec2_tag_set,
            ecs_service=ecs_service,
            load_balancer_info=load_balancer_info,
            on_premises_instance_tag_filter=on_premises_instance_tag_filter,
            trigger_configuration=trigger_configuration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodedeployDeploymentGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="appName")
    def app_name(self) -> str:
        return jsii.get(self, "appName")

    @app_name.setter
    def app_name(self, value: str) -> None:
        jsii.set(self, "appName", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentGroupName")
    def deployment_group_name(self) -> str:
        return jsii.get(self, "deploymentGroupName")

    @deployment_group_name.setter
    def deployment_group_name(self, value: str) -> None:
        jsii.set(self, "deploymentGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="serviceRoleArn")
    def service_role_arn(self) -> str:
        return jsii.get(self, "serviceRoleArn")

    @service_role_arn.setter
    def service_role_arn(self, value: str) -> None:
        jsii.set(self, "serviceRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="alarmConfiguration")
    def alarm_configuration(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupAlarmConfiguration"]]:
        return jsii.get(self, "alarmConfiguration")

    @alarm_configuration.setter
    def alarm_configuration(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentGroupAlarmConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "alarmConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="autoRollbackConfiguration")
    def auto_rollback_configuration(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupAutoRollbackConfiguration"]
    ]:
        return jsii.get(self, "autoRollbackConfiguration")

    @auto_rollback_configuration.setter
    def auto_rollback_configuration(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentGroupAutoRollbackConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "autoRollbackConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="autoscalingGroups")
    def autoscaling_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "autoscalingGroups")

    @autoscaling_groups.setter
    def autoscaling_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "autoscalingGroups", value)

    @builtins.property
    @jsii.member(jsii_name="blueGreenDeploymentConfig")
    def blue_green_deployment_config(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupBlueGreenDeploymentConfig"]
    ]:
        return jsii.get(self, "blueGreenDeploymentConfig")

    @blue_green_deployment_config.setter
    def blue_green_deployment_config(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentGroupBlueGreenDeploymentConfig"]
        ],
    ) -> None:
        jsii.set(self, "blueGreenDeploymentConfig", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentConfigName")
    def deployment_config_name(self) -> typing.Optional[str]:
        return jsii.get(self, "deploymentConfigName")

    @deployment_config_name.setter
    def deployment_config_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deploymentConfigName", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentStyle")
    def deployment_style(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupDeploymentStyle"]]:
        return jsii.get(self, "deploymentStyle")

    @deployment_style.setter
    def deployment_style(
        self,
        value: typing.Optional[typing.List["CodedeployDeploymentGroupDeploymentStyle"]],
    ) -> None:
        jsii.set(self, "deploymentStyle", value)

    @builtins.property
    @jsii.member(jsii_name="ec2TagFilter")
    def ec2_tag_filter(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupEc2TagFilter"]]:
        return jsii.get(self, "ec2TagFilter")

    @ec2_tag_filter.setter
    def ec2_tag_filter(
        self,
        value: typing.Optional[typing.List["CodedeployDeploymentGroupEc2TagFilter"]],
    ) -> None:
        jsii.set(self, "ec2TagFilter", value)

    @builtins.property
    @jsii.member(jsii_name="ec2TagSet")
    def ec2_tag_set(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupEc2TagSet"]]:
        return jsii.get(self, "ec2TagSet")

    @ec2_tag_set.setter
    def ec2_tag_set(
        self, value: typing.Optional[typing.List["CodedeployDeploymentGroupEc2TagSet"]]
    ) -> None:
        jsii.set(self, "ec2TagSet", value)

    @builtins.property
    @jsii.member(jsii_name="ecsService")
    def ecs_service(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupEcsService"]]:
        return jsii.get(self, "ecsService")

    @ecs_service.setter
    def ecs_service(
        self, value: typing.Optional[typing.List["CodedeployDeploymentGroupEcsService"]]
    ) -> None:
        jsii.set(self, "ecsService", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerInfo")
    def load_balancer_info(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupLoadBalancerInfo"]]:
        return jsii.get(self, "loadBalancerInfo")

    @load_balancer_info.setter
    def load_balancer_info(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentGroupLoadBalancerInfo"]
        ],
    ) -> None:
        jsii.set(self, "loadBalancerInfo", value)

    @builtins.property
    @jsii.member(jsii_name="onPremisesInstanceTagFilter")
    def on_premises_instance_tag_filter(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupOnPremisesInstanceTagFilter"]
    ]:
        return jsii.get(self, "onPremisesInstanceTagFilter")

    @on_premises_instance_tag_filter.setter
    def on_premises_instance_tag_filter(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentGroupOnPremisesInstanceTagFilter"]
        ],
    ) -> None:
        jsii.set(self, "onPremisesInstanceTagFilter", value)

    @builtins.property
    @jsii.member(jsii_name="triggerConfiguration")
    def trigger_configuration(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupTriggerConfiguration"]]:
        return jsii.get(self, "triggerConfiguration")

    @trigger_configuration.setter
    def trigger_configuration(
        self,
        value: typing.Optional[
            typing.List["CodedeployDeploymentGroupTriggerConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "triggerConfiguration", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupAlarmConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "alarms": "alarms",
        "enabled": "enabled",
        "ignore_poll_alarm_failure": "ignorePollAlarmFailure",
    },
)
class CodedeployDeploymentGroupAlarmConfiguration:
    def __init__(
        self,
        *,
        alarms: typing.Optional[typing.List[str]] = None,
        enabled: typing.Optional[bool] = None,
        ignore_poll_alarm_failure: typing.Optional[bool] = None,
    ) -> None:
        """
        :param alarms: 
        :param enabled: 
        :param ignore_poll_alarm_failure: 
        """
        self._values = {}
        if alarms is not None:
            self._values["alarms"] = alarms
        if enabled is not None:
            self._values["enabled"] = enabled
        if ignore_poll_alarm_failure is not None:
            self._values["ignore_poll_alarm_failure"] = ignore_poll_alarm_failure

    @builtins.property
    def alarms(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("alarms")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def ignore_poll_alarm_failure(self) -> typing.Optional[bool]:
        return self._values.get("ignore_poll_alarm_failure")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupAlarmConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupAutoRollbackConfiguration",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "events": "events"},
)
class CodedeployDeploymentGroupAutoRollbackConfiguration:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        events: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param enabled: 
        :param events: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if events is not None:
            self._values["events"] = events

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def events(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("events")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupAutoRollbackConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupBlueGreenDeploymentConfig",
    jsii_struct_bases=[],
    name_mapping={
        "deployment_ready_option": "deploymentReadyOption",
        "green_fleet_provisioning_option": "greenFleetProvisioningOption",
        "terminate_blue_instances_on_deployment_success": "terminateBlueInstancesOnDeploymentSuccess",
    },
)
class CodedeployDeploymentGroupBlueGreenDeploymentConfig:
    def __init__(
        self,
        *,
        deployment_ready_option: typing.Optional[
            typing.List[
                "CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption"
            ]
        ] = None,
        green_fleet_provisioning_option: typing.Optional[
            typing.List[
                "CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption"
            ]
        ] = None,
        terminate_blue_instances_on_deployment_success: typing.Optional[
            typing.List[
                "CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess"
            ]
        ] = None,
    ) -> None:
        """
        :param deployment_ready_option: deployment_ready_option block.
        :param green_fleet_provisioning_option: green_fleet_provisioning_option block.
        :param terminate_blue_instances_on_deployment_success: terminate_blue_instances_on_deployment_success block.
        """
        self._values = {}
        if deployment_ready_option is not None:
            self._values["deployment_ready_option"] = deployment_ready_option
        if green_fleet_provisioning_option is not None:
            self._values[
                "green_fleet_provisioning_option"
            ] = green_fleet_provisioning_option
        if terminate_blue_instances_on_deployment_success is not None:
            self._values[
                "terminate_blue_instances_on_deployment_success"
            ] = terminate_blue_instances_on_deployment_success

    @builtins.property
    def deployment_ready_option(
        self,
    ) -> typing.Optional[
        typing.List[
            "CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption"
        ]
    ]:
        """deployment_ready_option block."""
        return self._values.get("deployment_ready_option")

    @builtins.property
    def green_fleet_provisioning_option(
        self,
    ) -> typing.Optional[
        typing.List[
            "CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption"
        ]
    ]:
        """green_fleet_provisioning_option block."""
        return self._values.get("green_fleet_provisioning_option")

    @builtins.property
    def terminate_blue_instances_on_deployment_success(
        self,
    ) -> typing.Optional[
        typing.List[
            "CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess"
        ]
    ]:
        """terminate_blue_instances_on_deployment_success block."""
        return self._values.get("terminate_blue_instances_on_deployment_success")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupBlueGreenDeploymentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption",
    jsii_struct_bases=[],
    name_mapping={
        "action_on_timeout": "actionOnTimeout",
        "wait_time_in_minutes": "waitTimeInMinutes",
    },
)
class CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption:
    def __init__(
        self,
        *,
        action_on_timeout: typing.Optional[str] = None,
        wait_time_in_minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param action_on_timeout: 
        :param wait_time_in_minutes: 
        """
        self._values = {}
        if action_on_timeout is not None:
            self._values["action_on_timeout"] = action_on_timeout
        if wait_time_in_minutes is not None:
            self._values["wait_time_in_minutes"] = wait_time_in_minutes

    @builtins.property
    def action_on_timeout(self) -> typing.Optional[str]:
        return self._values.get("action_on_timeout")

    @builtins.property
    def wait_time_in_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("wait_time_in_minutes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption",
    jsii_struct_bases=[],
    name_mapping={"action": "action"},
)
class CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption:
    def __init__(self, *, action: typing.Optional[str] = None) -> None:
        """
        :param action: 
        """
        self._values = {}
        if action is not None:
            self._values["action"] = action

    @builtins.property
    def action(self) -> typing.Optional[str]:
        return self._values.get("action")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "termination_wait_time_in_minutes": "terminationWaitTimeInMinutes",
    },
)
class CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess:
    def __init__(
        self,
        *,
        action: typing.Optional[str] = None,
        termination_wait_time_in_minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param action: 
        :param termination_wait_time_in_minutes: 
        """
        self._values = {}
        if action is not None:
            self._values["action"] = action
        if termination_wait_time_in_minutes is not None:
            self._values[
                "termination_wait_time_in_minutes"
            ] = termination_wait_time_in_minutes

    @builtins.property
    def action(self) -> typing.Optional[str]:
        return self._values.get("action")

    @builtins.property
    def termination_wait_time_in_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("termination_wait_time_in_minutes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "app_name": "appName",
        "deployment_group_name": "deploymentGroupName",
        "service_role_arn": "serviceRoleArn",
        "alarm_configuration": "alarmConfiguration",
        "auto_rollback_configuration": "autoRollbackConfiguration",
        "autoscaling_groups": "autoscalingGroups",
        "blue_green_deployment_config": "blueGreenDeploymentConfig",
        "deployment_config_name": "deploymentConfigName",
        "deployment_style": "deploymentStyle",
        "ec2_tag_filter": "ec2TagFilter",
        "ec2_tag_set": "ec2TagSet",
        "ecs_service": "ecsService",
        "load_balancer_info": "loadBalancerInfo",
        "on_premises_instance_tag_filter": "onPremisesInstanceTagFilter",
        "trigger_configuration": "triggerConfiguration",
    },
)
class CodedeployDeploymentGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        app_name: str,
        deployment_group_name: str,
        service_role_arn: str,
        alarm_configuration: typing.Optional[
            typing.List["CodedeployDeploymentGroupAlarmConfiguration"]
        ] = None,
        auto_rollback_configuration: typing.Optional[
            typing.List["CodedeployDeploymentGroupAutoRollbackConfiguration"]
        ] = None,
        autoscaling_groups: typing.Optional[typing.List[str]] = None,
        blue_green_deployment_config: typing.Optional[
            typing.List["CodedeployDeploymentGroupBlueGreenDeploymentConfig"]
        ] = None,
        deployment_config_name: typing.Optional[str] = None,
        deployment_style: typing.Optional[
            typing.List["CodedeployDeploymentGroupDeploymentStyle"]
        ] = None,
        ec2_tag_filter: typing.Optional[
            typing.List["CodedeployDeploymentGroupEc2TagFilter"]
        ] = None,
        ec2_tag_set: typing.Optional[
            typing.List["CodedeployDeploymentGroupEc2TagSet"]
        ] = None,
        ecs_service: typing.Optional[
            typing.List["CodedeployDeploymentGroupEcsService"]
        ] = None,
        load_balancer_info: typing.Optional[
            typing.List["CodedeployDeploymentGroupLoadBalancerInfo"]
        ] = None,
        on_premises_instance_tag_filter: typing.Optional[
            typing.List["CodedeployDeploymentGroupOnPremisesInstanceTagFilter"]
        ] = None,
        trigger_configuration: typing.Optional[
            typing.List["CodedeployDeploymentGroupTriggerConfiguration"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param app_name: 
        :param deployment_group_name: 
        :param service_role_arn: 
        :param alarm_configuration: alarm_configuration block.
        :param auto_rollback_configuration: auto_rollback_configuration block.
        :param autoscaling_groups: 
        :param blue_green_deployment_config: blue_green_deployment_config block.
        :param deployment_config_name: 
        :param deployment_style: deployment_style block.
        :param ec2_tag_filter: ec2_tag_filter block.
        :param ec2_tag_set: ec2_tag_set block.
        :param ecs_service: ecs_service block.
        :param load_balancer_info: load_balancer_info block.
        :param on_premises_instance_tag_filter: on_premises_instance_tag_filter block.
        :param trigger_configuration: trigger_configuration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "app_name": app_name,
            "deployment_group_name": deployment_group_name,
            "service_role_arn": service_role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if alarm_configuration is not None:
            self._values["alarm_configuration"] = alarm_configuration
        if auto_rollback_configuration is not None:
            self._values["auto_rollback_configuration"] = auto_rollback_configuration
        if autoscaling_groups is not None:
            self._values["autoscaling_groups"] = autoscaling_groups
        if blue_green_deployment_config is not None:
            self._values["blue_green_deployment_config"] = blue_green_deployment_config
        if deployment_config_name is not None:
            self._values["deployment_config_name"] = deployment_config_name
        if deployment_style is not None:
            self._values["deployment_style"] = deployment_style
        if ec2_tag_filter is not None:
            self._values["ec2_tag_filter"] = ec2_tag_filter
        if ec2_tag_set is not None:
            self._values["ec2_tag_set"] = ec2_tag_set
        if ecs_service is not None:
            self._values["ecs_service"] = ecs_service
        if load_balancer_info is not None:
            self._values["load_balancer_info"] = load_balancer_info
        if on_premises_instance_tag_filter is not None:
            self._values[
                "on_premises_instance_tag_filter"
            ] = on_premises_instance_tag_filter
        if trigger_configuration is not None:
            self._values["trigger_configuration"] = trigger_configuration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def app_name(self) -> str:
        return self._values.get("app_name")

    @builtins.property
    def deployment_group_name(self) -> str:
        return self._values.get("deployment_group_name")

    @builtins.property
    def service_role_arn(self) -> str:
        return self._values.get("service_role_arn")

    @builtins.property
    def alarm_configuration(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupAlarmConfiguration"]]:
        """alarm_configuration block."""
        return self._values.get("alarm_configuration")

    @builtins.property
    def auto_rollback_configuration(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupAutoRollbackConfiguration"]
    ]:
        """auto_rollback_configuration block."""
        return self._values.get("auto_rollback_configuration")

    @builtins.property
    def autoscaling_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("autoscaling_groups")

    @builtins.property
    def blue_green_deployment_config(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupBlueGreenDeploymentConfig"]
    ]:
        """blue_green_deployment_config block."""
        return self._values.get("blue_green_deployment_config")

    @builtins.property
    def deployment_config_name(self) -> typing.Optional[str]:
        return self._values.get("deployment_config_name")

    @builtins.property
    def deployment_style(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupDeploymentStyle"]]:
        """deployment_style block."""
        return self._values.get("deployment_style")

    @builtins.property
    def ec2_tag_filter(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupEc2TagFilter"]]:
        """ec2_tag_filter block."""
        return self._values.get("ec2_tag_filter")

    @builtins.property
    def ec2_tag_set(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupEc2TagSet"]]:
        """ec2_tag_set block."""
        return self._values.get("ec2_tag_set")

    @builtins.property
    def ecs_service(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupEcsService"]]:
        """ecs_service block."""
        return self._values.get("ecs_service")

    @builtins.property
    def load_balancer_info(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupLoadBalancerInfo"]]:
        """load_balancer_info block."""
        return self._values.get("load_balancer_info")

    @builtins.property
    def on_premises_instance_tag_filter(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupOnPremisesInstanceTagFilter"]
    ]:
        """on_premises_instance_tag_filter block."""
        return self._values.get("on_premises_instance_tag_filter")

    @builtins.property
    def trigger_configuration(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupTriggerConfiguration"]]:
        """trigger_configuration block."""
        return self._values.get("trigger_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupDeploymentStyle",
    jsii_struct_bases=[],
    name_mapping={
        "deployment_option": "deploymentOption",
        "deployment_type": "deploymentType",
    },
)
class CodedeployDeploymentGroupDeploymentStyle:
    def __init__(
        self,
        *,
        deployment_option: typing.Optional[str] = None,
        deployment_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param deployment_option: 
        :param deployment_type: 
        """
        self._values = {}
        if deployment_option is not None:
            self._values["deployment_option"] = deployment_option
        if deployment_type is not None:
            self._values["deployment_type"] = deployment_type

    @builtins.property
    def deployment_option(self) -> typing.Optional[str]:
        return self._values.get("deployment_option")

    @builtins.property
    def deployment_type(self) -> typing.Optional[str]:
        return self._values.get("deployment_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupDeploymentStyle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupEc2TagFilter",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "type": "type", "value": "value"},
)
class CodedeployDeploymentGroupEc2TagFilter:
    def __init__(
        self,
        *,
        key: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        value: typing.Optional[str] = None,
    ) -> None:
        """
        :param key: 
        :param type: 
        :param value: 
        """
        self._values = {}
        if key is not None:
            self._values["key"] = key
        if type is not None:
            self._values["type"] = type
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def key(self) -> typing.Optional[str]:
        return self._values.get("key")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    @builtins.property
    def value(self) -> typing.Optional[str]:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupEc2TagFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupEc2TagSet",
    jsii_struct_bases=[],
    name_mapping={"ec2_tag_filter": "ec2TagFilter"},
)
class CodedeployDeploymentGroupEc2TagSet:
    def __init__(
        self,
        *,
        ec2_tag_filter: typing.Optional[
            typing.List["CodedeployDeploymentGroupEc2TagSetEc2TagFilter"]
        ] = None,
    ) -> None:
        """
        :param ec2_tag_filter: ec2_tag_filter block.
        """
        self._values = {}
        if ec2_tag_filter is not None:
            self._values["ec2_tag_filter"] = ec2_tag_filter

    @builtins.property
    def ec2_tag_filter(
        self,
    ) -> typing.Optional[typing.List["CodedeployDeploymentGroupEc2TagSetEc2TagFilter"]]:
        """ec2_tag_filter block."""
        return self._values.get("ec2_tag_filter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupEc2TagSet(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupEc2TagSetEc2TagFilter",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "type": "type", "value": "value"},
)
class CodedeployDeploymentGroupEc2TagSetEc2TagFilter:
    def __init__(
        self,
        *,
        key: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        value: typing.Optional[str] = None,
    ) -> None:
        """
        :param key: 
        :param type: 
        :param value: 
        """
        self._values = {}
        if key is not None:
            self._values["key"] = key
        if type is not None:
            self._values["type"] = type
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def key(self) -> typing.Optional[str]:
        return self._values.get("key")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    @builtins.property
    def value(self) -> typing.Optional[str]:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupEc2TagSetEc2TagFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupEcsService",
    jsii_struct_bases=[],
    name_mapping={"cluster_name": "clusterName", "service_name": "serviceName"},
)
class CodedeployDeploymentGroupEcsService:
    def __init__(self, *, cluster_name: str, service_name: str) -> None:
        """
        :param cluster_name: 
        :param service_name: 
        """
        self._values = {
            "cluster_name": cluster_name,
            "service_name": service_name,
        }

    @builtins.property
    def cluster_name(self) -> str:
        return self._values.get("cluster_name")

    @builtins.property
    def service_name(self) -> str:
        return self._values.get("service_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupEcsService(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupLoadBalancerInfo",
    jsii_struct_bases=[],
    name_mapping={
        "elb_info": "elbInfo",
        "target_group_info": "targetGroupInfo",
        "target_group_pair_info": "targetGroupPairInfo",
    },
)
class CodedeployDeploymentGroupLoadBalancerInfo:
    def __init__(
        self,
        *,
        elb_info: typing.Optional[
            typing.List["CodedeployDeploymentGroupLoadBalancerInfoElbInfo"]
        ] = None,
        target_group_info: typing.Optional[
            typing.List["CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo"]
        ] = None,
        target_group_pair_info: typing.Optional[
            typing.List["CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo"]
        ] = None,
    ) -> None:
        """
        :param elb_info: elb_info block.
        :param target_group_info: target_group_info block.
        :param target_group_pair_info: target_group_pair_info block.
        """
        self._values = {}
        if elb_info is not None:
            self._values["elb_info"] = elb_info
        if target_group_info is not None:
            self._values["target_group_info"] = target_group_info
        if target_group_pair_info is not None:
            self._values["target_group_pair_info"] = target_group_pair_info

    @builtins.property
    def elb_info(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupLoadBalancerInfoElbInfo"]
    ]:
        """elb_info block."""
        return self._values.get("elb_info")

    @builtins.property
    def target_group_info(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo"]
    ]:
        """target_group_info block."""
        return self._values.get("target_group_info")

    @builtins.property
    def target_group_pair_info(
        self,
    ) -> typing.Optional[
        typing.List["CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo"]
    ]:
        """target_group_pair_info block."""
        return self._values.get("target_group_pair_info")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupLoadBalancerInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupLoadBalancerInfoElbInfo",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class CodedeployDeploymentGroupLoadBalancerInfoElbInfo:
    def __init__(self, *, name: typing.Optional[str] = None) -> None:
        """
        :param name: 
        """
        self._values = {}
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupLoadBalancerInfoElbInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo:
    def __init__(self, *, name: typing.Optional[str] = None) -> None:
        """
        :param name: 
        """
        self._values = {}
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo",
    jsii_struct_bases=[],
    name_mapping={
        "prod_traffic_route": "prodTrafficRoute",
        "target_group": "targetGroup",
        "test_traffic_route": "testTrafficRoute",
    },
)
class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo:
    def __init__(
        self,
        *,
        prod_traffic_route: typing.List[
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute"
        ],
        target_group: typing.List[
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup"
        ],
        test_traffic_route: typing.Optional[
            typing.List[
                "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute"
            ]
        ] = None,
    ) -> None:
        """
        :param prod_traffic_route: prod_traffic_route block.
        :param target_group: target_group block.
        :param test_traffic_route: test_traffic_route block.
        """
        self._values = {
            "prod_traffic_route": prod_traffic_route,
            "target_group": target_group,
        }
        if test_traffic_route is not None:
            self._values["test_traffic_route"] = test_traffic_route

    @builtins.property
    def prod_traffic_route(
        self,
    ) -> typing.List[
        "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute"
    ]:
        """prod_traffic_route block."""
        return self._values.get("prod_traffic_route")

    @builtins.property
    def target_group(
        self,
    ) -> typing.List[
        "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup"
    ]:
        """target_group block."""
        return self._values.get("target_group")

    @builtins.property
    def test_traffic_route(
        self,
    ) -> typing.Optional[
        typing.List[
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute"
        ]
    ]:
        """test_traffic_route block."""
        return self._values.get("test_traffic_route")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute",
    jsii_struct_bases=[],
    name_mapping={"listener_arns": "listenerArns"},
)
class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute:
    def __init__(self, *, listener_arns: typing.List[str]) -> None:
        """
        :param listener_arns: 
        """
        self._values = {
            "listener_arns": listener_arns,
        }

    @builtins.property
    def listener_arns(self) -> typing.List[str]:
        return self._values.get("listener_arns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute",
    jsii_struct_bases=[],
    name_mapping={"listener_arns": "listenerArns"},
)
class CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute:
    def __init__(self, *, listener_arns: typing.List[str]) -> None:
        """
        :param listener_arns: 
        """
        self._values = {
            "listener_arns": listener_arns,
        }

    @builtins.property
    def listener_arns(self) -> typing.List[str]:
        return self._values.get("listener_arns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupOnPremisesInstanceTagFilter",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "type": "type", "value": "value"},
)
class CodedeployDeploymentGroupOnPremisesInstanceTagFilter:
    def __init__(
        self,
        *,
        key: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        value: typing.Optional[str] = None,
    ) -> None:
        """
        :param key: 
        :param type: 
        :param value: 
        """
        self._values = {}
        if key is not None:
            self._values["key"] = key
        if type is not None:
            self._values["type"] = type
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def key(self) -> typing.Optional[str]:
        return self._values.get("key")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    @builtins.property
    def value(self) -> typing.Optional[str]:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupOnPremisesInstanceTagFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodedeployDeploymentGroupTriggerConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "trigger_events": "triggerEvents",
        "trigger_name": "triggerName",
        "trigger_target_arn": "triggerTargetArn",
    },
)
class CodedeployDeploymentGroupTriggerConfiguration:
    def __init__(
        self,
        *,
        trigger_events: typing.List[str],
        trigger_name: str,
        trigger_target_arn: str,
    ) -> None:
        """
        :param trigger_events: 
        :param trigger_name: 
        :param trigger_target_arn: 
        """
        self._values = {
            "trigger_events": trigger_events,
            "trigger_name": trigger_name,
            "trigger_target_arn": trigger_target_arn,
        }

    @builtins.property
    def trigger_events(self) -> typing.List[str]:
        return self._values.get("trigger_events")

    @builtins.property
    def trigger_name(self) -> str:
        return self._values.get("trigger_name")

    @builtins.property
    def trigger_target_arn(self) -> str:
        return self._values.get("trigger_target_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodedeployDeploymentGroupTriggerConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Codepipeline(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Codepipeline",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        artifact_store: typing.List["CodepipelineArtifactStore"],
        name: str,
        role_arn: str,
        stage: typing.List["CodepipelineStage"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param artifact_store: artifact_store block.
        :param name: 
        :param role_arn: 
        :param stage: stage block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodepipelineConfig(
            artifact_store=artifact_store,
            name=name,
            role_arn=role_arn,
            stage=stage,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Codepipeline, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="artifactStore")
    def artifact_store(self) -> typing.List["CodepipelineArtifactStore"]:
        return jsii.get(self, "artifactStore")

    @artifact_store.setter
    def artifact_store(self, value: typing.List["CodepipelineArtifactStore"]) -> None:
        jsii.set(self, "artifactStore", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="stage")
    def stage(self) -> typing.List["CodepipelineStage"]:
        return jsii.get(self, "stage")

    @stage.setter
    def stage(self, value: typing.List["CodepipelineStage"]) -> None:
        jsii.set(self, "stage", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineArtifactStore",
    jsii_struct_bases=[],
    name_mapping={
        "location": "location",
        "type": "type",
        "encryption_key": "encryptionKey",
        "region": "region",
    },
)
class CodepipelineArtifactStore:
    def __init__(
        self,
        *,
        location: str,
        type: str,
        encryption_key: typing.Optional[
            typing.List["CodepipelineArtifactStoreEncryptionKey"]
        ] = None,
        region: typing.Optional[str] = None,
    ) -> None:
        """
        :param location: 
        :param type: 
        :param encryption_key: encryption_key block.
        :param region: 
        """
        self._values = {
            "location": location,
            "type": type,
        }
        if encryption_key is not None:
            self._values["encryption_key"] = encryption_key
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def location(self) -> str:
        return self._values.get("location")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def encryption_key(
        self,
    ) -> typing.Optional[typing.List["CodepipelineArtifactStoreEncryptionKey"]]:
        """encryption_key block."""
        return self._values.get("encryption_key")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineArtifactStore(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineArtifactStoreEncryptionKey",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "type": "type"},
)
class CodepipelineArtifactStoreEncryptionKey:
    def __init__(self, *, id: str, type: str) -> None:
        """
        :param id: 
        :param type: 
        """
        self._values = {
            "id": id,
            "type": type,
        }

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineArtifactStoreEncryptionKey(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "artifact_store": "artifactStore",
        "name": "name",
        "role_arn": "roleArn",
        "stage": "stage",
        "tags": "tags",
    },
)
class CodepipelineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        artifact_store: typing.List["CodepipelineArtifactStore"],
        name: str,
        role_arn: str,
        stage: typing.List["CodepipelineStage"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param artifact_store: artifact_store block.
        :param name: 
        :param role_arn: 
        :param stage: stage block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "artifact_store": artifact_store,
            "name": name,
            "role_arn": role_arn,
            "stage": stage,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def artifact_store(self) -> typing.List["CodepipelineArtifactStore"]:
        """artifact_store block."""
        return self._values.get("artifact_store")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def stage(self) -> typing.List["CodepipelineStage"]:
        """stage block."""
        return self._values.get("stage")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineStage",
    jsii_struct_bases=[],
    name_mapping={"action": "action", "name": "name"},
)
class CodepipelineStage:
    def __init__(
        self, *, action: typing.List["CodepipelineStageAction"], name: str
    ) -> None:
        """
        :param action: action block.
        :param name: 
        """
        self._values = {
            "action": action,
            "name": name,
        }

    @builtins.property
    def action(self) -> typing.List["CodepipelineStageAction"]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineStage(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineStageAction",
    jsii_struct_bases=[],
    name_mapping={
        "category": "category",
        "name": "name",
        "owner": "owner",
        "provider": "provider",
        "version": "version",
        "configuration": "configuration",
        "input_artifacts": "inputArtifacts",
        "namespace": "namespace",
        "output_artifacts": "outputArtifacts",
        "region": "region",
        "role_arn": "roleArn",
        "run_order": "runOrder",
    },
)
class CodepipelineStageAction:
    def __init__(
        self,
        *,
        category: str,
        name: str,
        owner: str,
        provider: str,
        version: str,
        configuration: typing.Optional[typing.Mapping[str, str]] = None,
        input_artifacts: typing.Optional[typing.List[str]] = None,
        namespace: typing.Optional[str] = None,
        output_artifacts: typing.Optional[typing.List[str]] = None,
        region: typing.Optional[str] = None,
        role_arn: typing.Optional[str] = None,
        run_order: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param category: 
        :param name: 
        :param owner: 
        :param provider: 
        :param version: 
        :param configuration: 
        :param input_artifacts: 
        :param namespace: 
        :param output_artifacts: 
        :param region: 
        :param role_arn: 
        :param run_order: 
        """
        self._values = {
            "category": category,
            "name": name,
            "owner": owner,
            "provider": provider,
            "version": version,
        }
        if configuration is not None:
            self._values["configuration"] = configuration
        if input_artifacts is not None:
            self._values["input_artifacts"] = input_artifacts
        if namespace is not None:
            self._values["namespace"] = namespace
        if output_artifacts is not None:
            self._values["output_artifacts"] = output_artifacts
        if region is not None:
            self._values["region"] = region
        if role_arn is not None:
            self._values["role_arn"] = role_arn
        if run_order is not None:
            self._values["run_order"] = run_order

    @builtins.property
    def category(self) -> str:
        return self._values.get("category")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def owner(self) -> str:
        return self._values.get("owner")

    @builtins.property
    def provider(self) -> str:
        return self._values.get("provider")

    @builtins.property
    def version(self) -> str:
        return self._values.get("version")

    @builtins.property
    def configuration(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("configuration")

    @builtins.property
    def input_artifacts(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("input_artifacts")

    @builtins.property
    def namespace(self) -> typing.Optional[str]:
        return self._values.get("namespace")

    @builtins.property
    def output_artifacts(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("output_artifacts")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    @builtins.property
    def run_order(self) -> typing.Optional[jsii.Number]:
        return self._values.get("run_order")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineStageAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodepipelineWebhook(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineWebhook",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        authentication: str,
        filter: typing.List["CodepipelineWebhookFilter"],
        name: str,
        target_action: str,
        target_pipeline: str,
        authentication_configuration: typing.Optional[
            typing.List["CodepipelineWebhookAuthenticationConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param authentication: 
        :param filter: filter block.
        :param name: 
        :param target_action: 
        :param target_pipeline: 
        :param authentication_configuration: authentication_configuration block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodepipelineWebhookConfig(
            authentication=authentication,
            filter=filter,
            name=name,
            target_action=target_action,
            target_pipeline=target_pipeline,
            authentication_configuration=authentication_configuration,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodepipelineWebhook, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> str:
        return jsii.get(self, "url")

    @builtins.property
    @jsii.member(jsii_name="authentication")
    def authentication(self) -> str:
        return jsii.get(self, "authentication")

    @authentication.setter
    def authentication(self, value: str) -> None:
        jsii.set(self, "authentication", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.List["CodepipelineWebhookFilter"]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(self, value: typing.List["CodepipelineWebhookFilter"]) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="targetAction")
    def target_action(self) -> str:
        return jsii.get(self, "targetAction")

    @target_action.setter
    def target_action(self, value: str) -> None:
        jsii.set(self, "targetAction", value)

    @builtins.property
    @jsii.member(jsii_name="targetPipeline")
    def target_pipeline(self) -> str:
        return jsii.get(self, "targetPipeline")

    @target_pipeline.setter
    def target_pipeline(self, value: str) -> None:
        jsii.set(self, "targetPipeline", value)

    @builtins.property
    @jsii.member(jsii_name="authenticationConfiguration")
    def authentication_configuration(
        self,
    ) -> typing.Optional[typing.List["CodepipelineWebhookAuthenticationConfiguration"]]:
        return jsii.get(self, "authenticationConfiguration")

    @authentication_configuration.setter
    def authentication_configuration(
        self,
        value: typing.Optional[
            typing.List["CodepipelineWebhookAuthenticationConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "authenticationConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineWebhookAuthenticationConfiguration",
    jsii_struct_bases=[],
    name_mapping={"allowed_ip_range": "allowedIpRange", "secret_token": "secretToken"},
)
class CodepipelineWebhookAuthenticationConfiguration:
    def __init__(
        self,
        *,
        allowed_ip_range: typing.Optional[str] = None,
        secret_token: typing.Optional[str] = None,
    ) -> None:
        """
        :param allowed_ip_range: 
        :param secret_token: 
        """
        self._values = {}
        if allowed_ip_range is not None:
            self._values["allowed_ip_range"] = allowed_ip_range
        if secret_token is not None:
            self._values["secret_token"] = secret_token

    @builtins.property
    def allowed_ip_range(self) -> typing.Optional[str]:
        return self._values.get("allowed_ip_range")

    @builtins.property
    def secret_token(self) -> typing.Optional[str]:
        return self._values.get("secret_token")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineWebhookAuthenticationConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineWebhookConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "authentication": "authentication",
        "filter": "filter",
        "name": "name",
        "target_action": "targetAction",
        "target_pipeline": "targetPipeline",
        "authentication_configuration": "authenticationConfiguration",
        "tags": "tags",
    },
)
class CodepipelineWebhookConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        authentication: str,
        filter: typing.List["CodepipelineWebhookFilter"],
        name: str,
        target_action: str,
        target_pipeline: str,
        authentication_configuration: typing.Optional[
            typing.List["CodepipelineWebhookAuthenticationConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param authentication: 
        :param filter: filter block.
        :param name: 
        :param target_action: 
        :param target_pipeline: 
        :param authentication_configuration: authentication_configuration block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "authentication": authentication,
            "filter": filter,
            "name": name,
            "target_action": target_action,
            "target_pipeline": target_pipeline,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authentication_configuration is not None:
            self._values["authentication_configuration"] = authentication_configuration
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def authentication(self) -> str:
        return self._values.get("authentication")

    @builtins.property
    def filter(self) -> typing.List["CodepipelineWebhookFilter"]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def target_action(self) -> str:
        return self._values.get("target_action")

    @builtins.property
    def target_pipeline(self) -> str:
        return self._values.get("target_pipeline")

    @builtins.property
    def authentication_configuration(
        self,
    ) -> typing.Optional[typing.List["CodepipelineWebhookAuthenticationConfiguration"]]:
        """authentication_configuration block."""
        return self._values.get("authentication_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineWebhookConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodepipelineWebhookFilter",
    jsii_struct_bases=[],
    name_mapping={"json_path": "jsonPath", "match_equals": "matchEquals"},
)
class CodepipelineWebhookFilter:
    def __init__(self, *, json_path: str, match_equals: str) -> None:
        """
        :param json_path: 
        :param match_equals: 
        """
        self._values = {
            "json_path": json_path,
            "match_equals": match_equals,
        }

    @builtins.property
    def json_path(self) -> str:
        return self._values.get("json_path")

    @builtins.property
    def match_equals(self) -> str:
        return self._values.get("match_equals")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodepipelineWebhookFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CodestarnotificationsNotificationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CodestarnotificationsNotificationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        detail_type: str,
        event_type_ids: typing.List[str],
        name: str,
        resource: str,
        status: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target: typing.Optional[
            typing.List["CodestarnotificationsNotificationRuleTarget"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param detail_type: 
        :param event_type_ids: 
        :param name: 
        :param resource: 
        :param status: 
        :param tags: 
        :param target: target block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CodestarnotificationsNotificationRuleConfig(
            detail_type=detail_type,
            event_type_ids=event_type_ids,
            name=name,
            resource=resource,
            status=status,
            tags=tags,
            target=target,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CodestarnotificationsNotificationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="detailType")
    def detail_type(self) -> str:
        return jsii.get(self, "detailType")

    @detail_type.setter
    def detail_type(self, value: str) -> None:
        jsii.set(self, "detailType", value)

    @builtins.property
    @jsii.member(jsii_name="eventTypeIds")
    def event_type_ids(self) -> typing.List[str]:
        return jsii.get(self, "eventTypeIds")

    @event_type_ids.setter
    def event_type_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "eventTypeIds", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resource")
    def resource(self) -> str:
        return jsii.get(self, "resource")

    @resource.setter
    def resource(self, value: str) -> None:
        jsii.set(self, "resource", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[str]:
        return jsii.get(self, "status")

    @status.setter
    def status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "status", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="target")
    def target(
        self,
    ) -> typing.Optional[typing.List["CodestarnotificationsNotificationRuleTarget"]]:
        return jsii.get(self, "target")

    @target.setter
    def target(
        self,
        value: typing.Optional[
            typing.List["CodestarnotificationsNotificationRuleTarget"]
        ],
    ) -> None:
        jsii.set(self, "target", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodestarnotificationsNotificationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "detail_type": "detailType",
        "event_type_ids": "eventTypeIds",
        "name": "name",
        "resource": "resource",
        "status": "status",
        "tags": "tags",
        "target": "target",
    },
)
class CodestarnotificationsNotificationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        detail_type: str,
        event_type_ids: typing.List[str],
        name: str,
        resource: str,
        status: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target: typing.Optional[
            typing.List["CodestarnotificationsNotificationRuleTarget"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param detail_type: 
        :param event_type_ids: 
        :param name: 
        :param resource: 
        :param status: 
        :param tags: 
        :param target: target block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "detail_type": detail_type,
            "event_type_ids": event_type_ids,
            "name": name,
            "resource": resource,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags
        if target is not None:
            self._values["target"] = target

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def detail_type(self) -> str:
        return self._values.get("detail_type")

    @builtins.property
    def event_type_ids(self) -> typing.List[str]:
        return self._values.get("event_type_ids")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def resource(self) -> str:
        return self._values.get("resource")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target(
        self,
    ) -> typing.Optional[typing.List["CodestarnotificationsNotificationRuleTarget"]]:
        """target block."""
        return self._values.get("target")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodestarnotificationsNotificationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CodestarnotificationsNotificationRuleTarget",
    jsii_struct_bases=[],
    name_mapping={"address": "address", "type": "type"},
)
class CodestarnotificationsNotificationRuleTarget:
    def __init__(self, *, address: str, type: typing.Optional[str] = None) -> None:
        """
        :param address: 
        :param type: 
        """
        self._values = {
            "address": address,
        }
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def address(self) -> str:
        return self._values.get("address")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CodestarnotificationsNotificationRuleTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CognitoIdentityPool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        identity_pool_name: str,
        allow_unauthenticated_identities: typing.Optional[bool] = None,
        cognito_identity_providers: typing.Optional[
            typing.List["CognitoIdentityPoolCognitoIdentityProviders"]
        ] = None,
        developer_provider_name: typing.Optional[str] = None,
        openid_connect_provider_arns: typing.Optional[typing.List[str]] = None,
        saml_provider_arns: typing.Optional[typing.List[str]] = None,
        supported_login_providers: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param identity_pool_name: 
        :param allow_unauthenticated_identities: 
        :param cognito_identity_providers: cognito_identity_providers block.
        :param developer_provider_name: 
        :param openid_connect_provider_arns: 
        :param saml_provider_arns: 
        :param supported_login_providers: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoIdentityPoolConfig(
            identity_pool_name=identity_pool_name,
            allow_unauthenticated_identities=allow_unauthenticated_identities,
            cognito_identity_providers=cognito_identity_providers,
            developer_provider_name=developer_provider_name,
            openid_connect_provider_arns=openid_connect_provider_arns,
            saml_provider_arns=saml_provider_arns,
            supported_login_providers=supported_login_providers,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoIdentityPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="identityPoolName")
    def identity_pool_name(self) -> str:
        return jsii.get(self, "identityPoolName")

    @identity_pool_name.setter
    def identity_pool_name(self, value: str) -> None:
        jsii.set(self, "identityPoolName", value)

    @builtins.property
    @jsii.member(jsii_name="allowUnauthenticatedIdentities")
    def allow_unauthenticated_identities(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowUnauthenticatedIdentities")

    @allow_unauthenticated_identities.setter
    def allow_unauthenticated_identities(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowUnauthenticatedIdentities", value)

    @builtins.property
    @jsii.member(jsii_name="cognitoIdentityProviders")
    def cognito_identity_providers(
        self,
    ) -> typing.Optional[typing.List["CognitoIdentityPoolCognitoIdentityProviders"]]:
        return jsii.get(self, "cognitoIdentityProviders")

    @cognito_identity_providers.setter
    def cognito_identity_providers(
        self,
        value: typing.Optional[
            typing.List["CognitoIdentityPoolCognitoIdentityProviders"]
        ],
    ) -> None:
        jsii.set(self, "cognitoIdentityProviders", value)

    @builtins.property
    @jsii.member(jsii_name="developerProviderName")
    def developer_provider_name(self) -> typing.Optional[str]:
        return jsii.get(self, "developerProviderName")

    @developer_provider_name.setter
    def developer_provider_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "developerProviderName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="openidConnectProviderArns")
    def openid_connect_provider_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "openidConnectProviderArns")

    @openid_connect_provider_arns.setter
    def openid_connect_provider_arns(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "openidConnectProviderArns", value)

    @builtins.property
    @jsii.member(jsii_name="samlProviderArns")
    def saml_provider_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "samlProviderArns")

    @saml_provider_arns.setter
    def saml_provider_arns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "samlProviderArns", value)

    @builtins.property
    @jsii.member(jsii_name="supportedLoginProviders")
    def supported_login_providers(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "supportedLoginProviders")

    @supported_login_providers.setter
    def supported_login_providers(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "supportedLoginProviders", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityPoolCognitoIdentityProviders",
    jsii_struct_bases=[],
    name_mapping={
        "client_id": "clientId",
        "provider_name": "providerName",
        "server_side_token_check": "serverSideTokenCheck",
    },
)
class CognitoIdentityPoolCognitoIdentityProviders:
    def __init__(
        self,
        *,
        client_id: typing.Optional[str] = None,
        provider_name: typing.Optional[str] = None,
        server_side_token_check: typing.Optional[bool] = None,
    ) -> None:
        """
        :param client_id: 
        :param provider_name: 
        :param server_side_token_check: 
        """
        self._values = {}
        if client_id is not None:
            self._values["client_id"] = client_id
        if provider_name is not None:
            self._values["provider_name"] = provider_name
        if server_side_token_check is not None:
            self._values["server_side_token_check"] = server_side_token_check

    @builtins.property
    def client_id(self) -> typing.Optional[str]:
        return self._values.get("client_id")

    @builtins.property
    def provider_name(self) -> typing.Optional[str]:
        return self._values.get("provider_name")

    @builtins.property
    def server_side_token_check(self) -> typing.Optional[bool]:
        return self._values.get("server_side_token_check")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoIdentityPoolCognitoIdentityProviders(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "identity_pool_name": "identityPoolName",
        "allow_unauthenticated_identities": "allowUnauthenticatedIdentities",
        "cognito_identity_providers": "cognitoIdentityProviders",
        "developer_provider_name": "developerProviderName",
        "openid_connect_provider_arns": "openidConnectProviderArns",
        "saml_provider_arns": "samlProviderArns",
        "supported_login_providers": "supportedLoginProviders",
        "tags": "tags",
    },
)
class CognitoIdentityPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        identity_pool_name: str,
        allow_unauthenticated_identities: typing.Optional[bool] = None,
        cognito_identity_providers: typing.Optional[
            typing.List["CognitoIdentityPoolCognitoIdentityProviders"]
        ] = None,
        developer_provider_name: typing.Optional[str] = None,
        openid_connect_provider_arns: typing.Optional[typing.List[str]] = None,
        saml_provider_arns: typing.Optional[typing.List[str]] = None,
        supported_login_providers: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param identity_pool_name: 
        :param allow_unauthenticated_identities: 
        :param cognito_identity_providers: cognito_identity_providers block.
        :param developer_provider_name: 
        :param openid_connect_provider_arns: 
        :param saml_provider_arns: 
        :param supported_login_providers: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "identity_pool_name": identity_pool_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_unauthenticated_identities is not None:
            self._values[
                "allow_unauthenticated_identities"
            ] = allow_unauthenticated_identities
        if cognito_identity_providers is not None:
            self._values["cognito_identity_providers"] = cognito_identity_providers
        if developer_provider_name is not None:
            self._values["developer_provider_name"] = developer_provider_name
        if openid_connect_provider_arns is not None:
            self._values["openid_connect_provider_arns"] = openid_connect_provider_arns
        if saml_provider_arns is not None:
            self._values["saml_provider_arns"] = saml_provider_arns
        if supported_login_providers is not None:
            self._values["supported_login_providers"] = supported_login_providers
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def identity_pool_name(self) -> str:
        return self._values.get("identity_pool_name")

    @builtins.property
    def allow_unauthenticated_identities(self) -> typing.Optional[bool]:
        return self._values.get("allow_unauthenticated_identities")

    @builtins.property
    def cognito_identity_providers(
        self,
    ) -> typing.Optional[typing.List["CognitoIdentityPoolCognitoIdentityProviders"]]:
        """cognito_identity_providers block."""
        return self._values.get("cognito_identity_providers")

    @builtins.property
    def developer_provider_name(self) -> typing.Optional[str]:
        return self._values.get("developer_provider_name")

    @builtins.property
    def openid_connect_provider_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("openid_connect_provider_arns")

    @builtins.property
    def saml_provider_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("saml_provider_arns")

    @builtins.property
    def supported_login_providers(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("supported_login_providers")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoIdentityPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CognitoIdentityPoolRolesAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityPoolRolesAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        identity_pool_id: str,
        roles: typing.Mapping[str, str],
        role_mapping: typing.Optional[
            typing.List["CognitoIdentityPoolRolesAttachmentRoleMapping"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param identity_pool_id: 
        :param roles: 
        :param role_mapping: role_mapping block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoIdentityPoolRolesAttachmentConfig(
            identity_pool_id=identity_pool_id,
            roles=roles,
            role_mapping=role_mapping,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoIdentityPoolRolesAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="identityPoolId")
    def identity_pool_id(self) -> str:
        return jsii.get(self, "identityPoolId")

    @identity_pool_id.setter
    def identity_pool_id(self, value: str) -> None:
        jsii.set(self, "identityPoolId", value)

    @builtins.property
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.Mapping[str, str]:
        return jsii.get(self, "roles")

    @roles.setter
    def roles(self, value: typing.Mapping[str, str]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="roleMapping")
    def role_mapping(
        self,
    ) -> typing.Optional[typing.List["CognitoIdentityPoolRolesAttachmentRoleMapping"]]:
        return jsii.get(self, "roleMapping")

    @role_mapping.setter
    def role_mapping(
        self,
        value: typing.Optional[
            typing.List["CognitoIdentityPoolRolesAttachmentRoleMapping"]
        ],
    ) -> None:
        jsii.set(self, "roleMapping", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityPoolRolesAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "identity_pool_id": "identityPoolId",
        "roles": "roles",
        "role_mapping": "roleMapping",
    },
)
class CognitoIdentityPoolRolesAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        identity_pool_id: str,
        roles: typing.Mapping[str, str],
        role_mapping: typing.Optional[
            typing.List["CognitoIdentityPoolRolesAttachmentRoleMapping"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param identity_pool_id: 
        :param roles: 
        :param role_mapping: role_mapping block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "identity_pool_id": identity_pool_id,
            "roles": roles,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if role_mapping is not None:
            self._values["role_mapping"] = role_mapping

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def identity_pool_id(self) -> str:
        return self._values.get("identity_pool_id")

    @builtins.property
    def roles(self) -> typing.Mapping[str, str]:
        return self._values.get("roles")

    @builtins.property
    def role_mapping(
        self,
    ) -> typing.Optional[typing.List["CognitoIdentityPoolRolesAttachmentRoleMapping"]]:
        """role_mapping block."""
        return self._values.get("role_mapping")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoIdentityPoolRolesAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityPoolRolesAttachmentRoleMapping",
    jsii_struct_bases=[],
    name_mapping={
        "identity_provider": "identityProvider",
        "type": "type",
        "ambiguous_role_resolution": "ambiguousRoleResolution",
        "mapping_rule": "mappingRule",
    },
)
class CognitoIdentityPoolRolesAttachmentRoleMapping:
    def __init__(
        self,
        *,
        identity_provider: str,
        type: str,
        ambiguous_role_resolution: typing.Optional[str] = None,
        mapping_rule: typing.Optional[
            typing.List["CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule"]
        ] = None,
    ) -> None:
        """
        :param identity_provider: 
        :param type: 
        :param ambiguous_role_resolution: 
        :param mapping_rule: mapping_rule block.
        """
        self._values = {
            "identity_provider": identity_provider,
            "type": type,
        }
        if ambiguous_role_resolution is not None:
            self._values["ambiguous_role_resolution"] = ambiguous_role_resolution
        if mapping_rule is not None:
            self._values["mapping_rule"] = mapping_rule

    @builtins.property
    def identity_provider(self) -> str:
        return self._values.get("identity_provider")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def ambiguous_role_resolution(self) -> typing.Optional[str]:
        return self._values.get("ambiguous_role_resolution")

    @builtins.property
    def mapping_rule(
        self,
    ) -> typing.Optional[
        typing.List["CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule"]
    ]:
        """mapping_rule block."""
        return self._values.get("mapping_rule")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoIdentityPoolRolesAttachmentRoleMapping(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule",
    jsii_struct_bases=[],
    name_mapping={
        "claim": "claim",
        "match_type": "matchType",
        "role_arn": "roleArn",
        "value": "value",
    },
)
class CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule:
    def __init__(
        self, *, claim: str, match_type: str, role_arn: str, value: str
    ) -> None:
        """
        :param claim: 
        :param match_type: 
        :param role_arn: 
        :param value: 
        """
        self._values = {
            "claim": claim,
            "match_type": match_type,
            "role_arn": role_arn,
            "value": value,
        }

    @builtins.property
    def claim(self) -> str:
        return self._values.get("claim")

    @builtins.property
    def match_type(self) -> str:
        return self._values.get("match_type")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class CognitoIdentityProvider(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityProvider",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        provider_details: typing.Mapping[str, str],
        provider_name: str,
        provider_type: str,
        user_pool_id: str,
        attribute_mapping: typing.Optional[typing.Mapping[str, str]] = None,
        idp_identifiers: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param provider_details: 
        :param provider_name: 
        :param provider_type: 
        :param user_pool_id: 
        :param attribute_mapping: 
        :param idp_identifiers: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoIdentityProviderConfig(
            provider_details=provider_details,
            provider_name=provider_name,
            provider_type=provider_type,
            user_pool_id=user_pool_id,
            attribute_mapping=attribute_mapping,
            idp_identifiers=idp_identifiers,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoIdentityProvider, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="providerDetails")
    def provider_details(self) -> typing.Mapping[str, str]:
        return jsii.get(self, "providerDetails")

    @provider_details.setter
    def provider_details(self, value: typing.Mapping[str, str]) -> None:
        jsii.set(self, "providerDetails", value)

    @builtins.property
    @jsii.member(jsii_name="providerName")
    def provider_name(self) -> str:
        return jsii.get(self, "providerName")

    @provider_name.setter
    def provider_name(self, value: str) -> None:
        jsii.set(self, "providerName", value)

    @builtins.property
    @jsii.member(jsii_name="providerType")
    def provider_type(self) -> str:
        return jsii.get(self, "providerType")

    @provider_type.setter
    def provider_type(self, value: str) -> None:
        jsii.set(self, "providerType", value)

    @builtins.property
    @jsii.member(jsii_name="userPoolId")
    def user_pool_id(self) -> str:
        return jsii.get(self, "userPoolId")

    @user_pool_id.setter
    def user_pool_id(self, value: str) -> None:
        jsii.set(self, "userPoolId", value)

    @builtins.property
    @jsii.member(jsii_name="attributeMapping")
    def attribute_mapping(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "attributeMapping")

    @attribute_mapping.setter
    def attribute_mapping(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "attributeMapping", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="idpIdentifiers")
    def idp_identifiers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "idpIdentifiers")

    @idp_identifiers.setter
    def idp_identifiers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "idpIdentifiers", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoIdentityProviderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "provider_details": "providerDetails",
        "provider_name": "providerName",
        "provider_type": "providerType",
        "user_pool_id": "userPoolId",
        "attribute_mapping": "attributeMapping",
        "idp_identifiers": "idpIdentifiers",
    },
)
class CognitoIdentityProviderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        provider_details: typing.Mapping[str, str],
        provider_name: str,
        provider_type: str,
        user_pool_id: str,
        attribute_mapping: typing.Optional[typing.Mapping[str, str]] = None,
        idp_identifiers: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param provider_details: 
        :param provider_name: 
        :param provider_type: 
        :param user_pool_id: 
        :param attribute_mapping: 
        :param idp_identifiers: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "provider_details": provider_details,
            "provider_name": provider_name,
            "provider_type": provider_type,
            "user_pool_id": user_pool_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attribute_mapping is not None:
            self._values["attribute_mapping"] = attribute_mapping
        if idp_identifiers is not None:
            self._values["idp_identifiers"] = idp_identifiers

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def provider_details(self) -> typing.Mapping[str, str]:
        return self._values.get("provider_details")

    @builtins.property
    def provider_name(self) -> str:
        return self._values.get("provider_name")

    @builtins.property
    def provider_type(self) -> str:
        return self._values.get("provider_type")

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def attribute_mapping(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("attribute_mapping")

    @builtins.property
    def idp_identifiers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("idp_identifiers")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoIdentityProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CognitoResourceServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoResourceServer",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        identifier: str,
        name: str,
        user_pool_id: str,
        scope: typing.Optional[typing.List["CognitoResourceServerScope"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param identifier: 
        :param name: 
        :param user_pool_id: 
        :param scope: scope block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoResourceServerConfig(
            identifier=identifier,
            name=name,
            user_pool_id=user_pool_id,
            scope=scope,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoResourceServer, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="scopeIdentifiers")
    def scope_identifiers(self) -> typing.List[str]:
        return jsii.get(self, "scopeIdentifiers")

    @builtins.property
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> str:
        return jsii.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: str) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="userPoolId")
    def user_pool_id(self) -> str:
        return jsii.get(self, "userPoolId")

    @user_pool_id.setter
    def user_pool_id(self, value: str) -> None:
        jsii.set(self, "userPoolId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> typing.Optional[typing.List["CognitoResourceServerScope"]]:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(
        self, value: typing.Optional[typing.List["CognitoResourceServerScope"]]
    ) -> None:
        jsii.set(self, "scope", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoResourceServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "identifier": "identifier",
        "name": "name",
        "user_pool_id": "userPoolId",
        "scope": "scope",
    },
)
class CognitoResourceServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        identifier: str,
        name: str,
        user_pool_id: str,
        scope: typing.Optional[typing.List["CognitoResourceServerScope"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param identifier: 
        :param name: 
        :param user_pool_id: 
        :param scope: scope block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "identifier": identifier,
            "name": name,
            "user_pool_id": user_pool_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if scope is not None:
            self._values["scope"] = scope

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def identifier(self) -> str:
        return self._values.get("identifier")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def scope(self) -> typing.Optional[typing.List["CognitoResourceServerScope"]]:
        """scope block."""
        return self._values.get("scope")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoResourceServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoResourceServerScope",
    jsii_struct_bases=[],
    name_mapping={"scope_description": "scopeDescription", "scope_name": "scopeName"},
)
class CognitoResourceServerScope:
    def __init__(self, *, scope_description: str, scope_name: str) -> None:
        """
        :param scope_description: 
        :param scope_name: 
        """
        self._values = {
            "scope_description": scope_description,
            "scope_name": scope_name,
        }

    @builtins.property
    def scope_description(self) -> str:
        return self._values.get("scope_description")

    @builtins.property
    def scope_name(self) -> str:
        return self._values.get("scope_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoResourceServerScope(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CognitoUserGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        user_pool_id: str,
        description: typing.Optional[str] = None,
        precedence: typing.Optional[jsii.Number] = None,
        role_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param user_pool_id: 
        :param description: 
        :param precedence: 
        :param role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoUserGroupConfig(
            name=name,
            user_pool_id=user_pool_id,
            description=description,
            precedence=precedence,
            role_arn=role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoUserGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="userPoolId")
    def user_pool_id(self) -> str:
        return jsii.get(self, "userPoolId")

    @user_pool_id.setter
    def user_pool_id(self, value: str) -> None:
        jsii.set(self, "userPoolId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="precedence")
    def precedence(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "precedence")

    @precedence.setter
    def precedence(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "precedence", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "user_pool_id": "userPoolId",
        "description": "description",
        "precedence": "precedence",
        "role_arn": "roleArn",
    },
)
class CognitoUserGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        user_pool_id: str,
        description: typing.Optional[str] = None,
        precedence: typing.Optional[jsii.Number] = None,
        role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param user_pool_id: 
        :param description: 
        :param precedence: 
        :param role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "user_pool_id": user_pool_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if precedence is not None:
            self._values["precedence"] = precedence
        if role_arn is not None:
            self._values["role_arn"] = role_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def precedence(self) -> typing.Optional[jsii.Number]:
        return self._values.get("precedence")

    @builtins.property
    def role_arn(self) -> typing.Optional[str]:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CognitoUserPool(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        admin_create_user_config: typing.Optional[
            typing.List["CognitoUserPoolAdminCreateUserConfig"]
        ] = None,
        alias_attributes: typing.Optional[typing.List[str]] = None,
        auto_verified_attributes: typing.Optional[typing.List[str]] = None,
        device_configuration: typing.Optional[
            typing.List["CognitoUserPoolDeviceConfiguration"]
        ] = None,
        email_configuration: typing.Optional[
            typing.List["CognitoUserPoolEmailConfiguration"]
        ] = None,
        email_verification_message: typing.Optional[str] = None,
        email_verification_subject: typing.Optional[str] = None,
        lambda_config: typing.Optional[
            typing.List["CognitoUserPoolLambdaConfig"]
        ] = None,
        mfa_configuration: typing.Optional[str] = None,
        password_policy: typing.Optional[
            typing.List["CognitoUserPoolPasswordPolicy"]
        ] = None,
        schema: typing.Optional[typing.List["CognitoUserPoolSchema"]] = None,
        sms_authentication_message: typing.Optional[str] = None,
        sms_configuration: typing.Optional[
            typing.List["CognitoUserPoolSmsConfiguration"]
        ] = None,
        sms_verification_message: typing.Optional[str] = None,
        software_token_mfa_configuration: typing.Optional[
            typing.List["CognitoUserPoolSoftwareTokenMfaConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        username_attributes: typing.Optional[typing.List[str]] = None,
        username_configuration: typing.Optional[
            typing.List["CognitoUserPoolUsernameConfiguration"]
        ] = None,
        user_pool_add_ons: typing.Optional[
            typing.List["CognitoUserPoolUserPoolAddOns"]
        ] = None,
        verification_message_template: typing.Optional[
            typing.List["CognitoUserPoolVerificationMessageTemplate"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param admin_create_user_config: admin_create_user_config block.
        :param alias_attributes: 
        :param auto_verified_attributes: 
        :param device_configuration: device_configuration block.
        :param email_configuration: email_configuration block.
        :param email_verification_message: 
        :param email_verification_subject: 
        :param lambda_config: lambda_config block.
        :param mfa_configuration: 
        :param password_policy: password_policy block.
        :param schema: schema block.
        :param sms_authentication_message: 
        :param sms_configuration: sms_configuration block.
        :param sms_verification_message: 
        :param software_token_mfa_configuration: software_token_mfa_configuration block.
        :param tags: 
        :param username_attributes: 
        :param username_configuration: username_configuration block.
        :param user_pool_add_ons: user_pool_add_ons block.
        :param verification_message_template: verification_message_template block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoUserPoolConfig(
            name=name,
            admin_create_user_config=admin_create_user_config,
            alias_attributes=alias_attributes,
            auto_verified_attributes=auto_verified_attributes,
            device_configuration=device_configuration,
            email_configuration=email_configuration,
            email_verification_message=email_verification_message,
            email_verification_subject=email_verification_subject,
            lambda_config=lambda_config,
            mfa_configuration=mfa_configuration,
            password_policy=password_policy,
            schema=schema,
            sms_authentication_message=sms_authentication_message,
            sms_configuration=sms_configuration,
            sms_verification_message=sms_verification_message,
            software_token_mfa_configuration=software_token_mfa_configuration,
            tags=tags,
            username_attributes=username_attributes,
            username_configuration=username_configuration,
            user_pool_add_ons=user_pool_add_ons,
            verification_message_template=verification_message_template,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoUserPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="lastModifiedDate")
    def last_modified_date(self) -> str:
        return jsii.get(self, "lastModifiedDate")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="adminCreateUserConfig")
    def admin_create_user_config(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolAdminCreateUserConfig"]]:
        return jsii.get(self, "adminCreateUserConfig")

    @admin_create_user_config.setter
    def admin_create_user_config(
        self,
        value: typing.Optional[typing.List["CognitoUserPoolAdminCreateUserConfig"]],
    ) -> None:
        jsii.set(self, "adminCreateUserConfig", value)

    @builtins.property
    @jsii.member(jsii_name="aliasAttributes")
    def alias_attributes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "aliasAttributes")

    @alias_attributes.setter
    def alias_attributes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "aliasAttributes", value)

    @builtins.property
    @jsii.member(jsii_name="autoVerifiedAttributes")
    def auto_verified_attributes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "autoVerifiedAttributes")

    @auto_verified_attributes.setter
    def auto_verified_attributes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "autoVerifiedAttributes", value)

    @builtins.property
    @jsii.member(jsii_name="deviceConfiguration")
    def device_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolDeviceConfiguration"]]:
        return jsii.get(self, "deviceConfiguration")

    @device_configuration.setter
    def device_configuration(
        self, value: typing.Optional[typing.List["CognitoUserPoolDeviceConfiguration"]]
    ) -> None:
        jsii.set(self, "deviceConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="emailConfiguration")
    def email_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolEmailConfiguration"]]:
        return jsii.get(self, "emailConfiguration")

    @email_configuration.setter
    def email_configuration(
        self, value: typing.Optional[typing.List["CognitoUserPoolEmailConfiguration"]]
    ) -> None:
        jsii.set(self, "emailConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="emailVerificationMessage")
    def email_verification_message(self) -> typing.Optional[str]:
        return jsii.get(self, "emailVerificationMessage")

    @email_verification_message.setter
    def email_verification_message(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "emailVerificationMessage", value)

    @builtins.property
    @jsii.member(jsii_name="emailVerificationSubject")
    def email_verification_subject(self) -> typing.Optional[str]:
        return jsii.get(self, "emailVerificationSubject")

    @email_verification_subject.setter
    def email_verification_subject(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "emailVerificationSubject", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaConfig")
    def lambda_config(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolLambdaConfig"]]:
        return jsii.get(self, "lambdaConfig")

    @lambda_config.setter
    def lambda_config(
        self, value: typing.Optional[typing.List["CognitoUserPoolLambdaConfig"]]
    ) -> None:
        jsii.set(self, "lambdaConfig", value)

    @builtins.property
    @jsii.member(jsii_name="mfaConfiguration")
    def mfa_configuration(self) -> typing.Optional[str]:
        return jsii.get(self, "mfaConfiguration")

    @mfa_configuration.setter
    def mfa_configuration(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "mfaConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="passwordPolicy")
    def password_policy(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolPasswordPolicy"]]:
        return jsii.get(self, "passwordPolicy")

    @password_policy.setter
    def password_policy(
        self, value: typing.Optional[typing.List["CognitoUserPoolPasswordPolicy"]]
    ) -> None:
        jsii.set(self, "passwordPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="schema")
    def schema(self) -> typing.Optional[typing.List["CognitoUserPoolSchema"]]:
        return jsii.get(self, "schema")

    @schema.setter
    def schema(
        self, value: typing.Optional[typing.List["CognitoUserPoolSchema"]]
    ) -> None:
        jsii.set(self, "schema", value)

    @builtins.property
    @jsii.member(jsii_name="smsAuthenticationMessage")
    def sms_authentication_message(self) -> typing.Optional[str]:
        return jsii.get(self, "smsAuthenticationMessage")

    @sms_authentication_message.setter
    def sms_authentication_message(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "smsAuthenticationMessage", value)

    @builtins.property
    @jsii.member(jsii_name="smsConfiguration")
    def sms_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolSmsConfiguration"]]:
        return jsii.get(self, "smsConfiguration")

    @sms_configuration.setter
    def sms_configuration(
        self, value: typing.Optional[typing.List["CognitoUserPoolSmsConfiguration"]]
    ) -> None:
        jsii.set(self, "smsConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="smsVerificationMessage")
    def sms_verification_message(self) -> typing.Optional[str]:
        return jsii.get(self, "smsVerificationMessage")

    @sms_verification_message.setter
    def sms_verification_message(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "smsVerificationMessage", value)

    @builtins.property
    @jsii.member(jsii_name="softwareTokenMfaConfiguration")
    def software_token_mfa_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolSoftwareTokenMfaConfiguration"]]:
        return jsii.get(self, "softwareTokenMfaConfiguration")

    @software_token_mfa_configuration.setter
    def software_token_mfa_configuration(
        self,
        value: typing.Optional[
            typing.List["CognitoUserPoolSoftwareTokenMfaConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "softwareTokenMfaConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="usernameAttributes")
    def username_attributes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "usernameAttributes")

    @username_attributes.setter
    def username_attributes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "usernameAttributes", value)

    @builtins.property
    @jsii.member(jsii_name="usernameConfiguration")
    def username_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolUsernameConfiguration"]]:
        return jsii.get(self, "usernameConfiguration")

    @username_configuration.setter
    def username_configuration(
        self,
        value: typing.Optional[typing.List["CognitoUserPoolUsernameConfiguration"]],
    ) -> None:
        jsii.set(self, "usernameConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="userPoolAddOns")
    def user_pool_add_ons(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolUserPoolAddOns"]]:
        return jsii.get(self, "userPoolAddOns")

    @user_pool_add_ons.setter
    def user_pool_add_ons(
        self, value: typing.Optional[typing.List["CognitoUserPoolUserPoolAddOns"]]
    ) -> None:
        jsii.set(self, "userPoolAddOns", value)

    @builtins.property
    @jsii.member(jsii_name="verificationMessageTemplate")
    def verification_message_template(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolVerificationMessageTemplate"]]:
        return jsii.get(self, "verificationMessageTemplate")

    @verification_message_template.setter
    def verification_message_template(
        self,
        value: typing.Optional[
            typing.List["CognitoUserPoolVerificationMessageTemplate"]
        ],
    ) -> None:
        jsii.set(self, "verificationMessageTemplate", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolAdminCreateUserConfig",
    jsii_struct_bases=[],
    name_mapping={
        "allow_admin_create_user_only": "allowAdminCreateUserOnly",
        "invite_message_template": "inviteMessageTemplate",
        "unused_account_validity_days": "unusedAccountValidityDays",
    },
)
class CognitoUserPoolAdminCreateUserConfig:
    def __init__(
        self,
        *,
        allow_admin_create_user_only: typing.Optional[bool] = None,
        invite_message_template: typing.Optional[
            typing.List["CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate"]
        ] = None,
        unused_account_validity_days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param allow_admin_create_user_only: 
        :param invite_message_template: invite_message_template block.
        :param unused_account_validity_days: 
        """
        self._values = {}
        if allow_admin_create_user_only is not None:
            self._values["allow_admin_create_user_only"] = allow_admin_create_user_only
        if invite_message_template is not None:
            self._values["invite_message_template"] = invite_message_template
        if unused_account_validity_days is not None:
            self._values["unused_account_validity_days"] = unused_account_validity_days

    @builtins.property
    def allow_admin_create_user_only(self) -> typing.Optional[bool]:
        return self._values.get("allow_admin_create_user_only")

    @builtins.property
    def invite_message_template(
        self,
    ) -> typing.Optional[
        typing.List["CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate"]
    ]:
        """invite_message_template block."""
        return self._values.get("invite_message_template")

    @builtins.property
    def unused_account_validity_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("unused_account_validity_days")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolAdminCreateUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate",
    jsii_struct_bases=[],
    name_mapping={
        "email_message": "emailMessage",
        "email_subject": "emailSubject",
        "sms_message": "smsMessage",
    },
)
class CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate:
    def __init__(
        self,
        *,
        email_message: typing.Optional[str] = None,
        email_subject: typing.Optional[str] = None,
        sms_message: typing.Optional[str] = None,
    ) -> None:
        """
        :param email_message: 
        :param email_subject: 
        :param sms_message: 
        """
        self._values = {}
        if email_message is not None:
            self._values["email_message"] = email_message
        if email_subject is not None:
            self._values["email_subject"] = email_subject
        if sms_message is not None:
            self._values["sms_message"] = sms_message

    @builtins.property
    def email_message(self) -> typing.Optional[str]:
        return self._values.get("email_message")

    @builtins.property
    def email_subject(self) -> typing.Optional[str]:
        return self._values.get("email_subject")

    @builtins.property
    def sms_message(self) -> typing.Optional[str]:
        return self._values.get("sms_message")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class CognitoUserPoolClient(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolClient",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        user_pool_id: str,
        allowed_oauth_flows: typing.Optional[typing.List[str]] = None,
        allowed_oauth_flows_user_pool_client: typing.Optional[bool] = None,
        allowed_oauth_scopes: typing.Optional[typing.List[str]] = None,
        analytics_configuration: typing.Optional[
            typing.List["CognitoUserPoolClientAnalyticsConfiguration"]
        ] = None,
        callback_urls: typing.Optional[typing.List[str]] = None,
        default_redirect_uri: typing.Optional[str] = None,
        explicit_auth_flows: typing.Optional[typing.List[str]] = None,
        generate_secret: typing.Optional[bool] = None,
        logout_urls: typing.Optional[typing.List[str]] = None,
        prevent_user_existence_errors: typing.Optional[str] = None,
        read_attributes: typing.Optional[typing.List[str]] = None,
        refresh_token_validity: typing.Optional[jsii.Number] = None,
        supported_identity_providers: typing.Optional[typing.List[str]] = None,
        write_attributes: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param user_pool_id: 
        :param allowed_oauth_flows: 
        :param allowed_oauth_flows_user_pool_client: 
        :param allowed_oauth_scopes: 
        :param analytics_configuration: analytics_configuration block.
        :param callback_urls: 
        :param default_redirect_uri: 
        :param explicit_auth_flows: 
        :param generate_secret: 
        :param logout_urls: 
        :param prevent_user_existence_errors: 
        :param read_attributes: 
        :param refresh_token_validity: 
        :param supported_identity_providers: 
        :param write_attributes: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoUserPoolClientConfig(
            name=name,
            user_pool_id=user_pool_id,
            allowed_oauth_flows=allowed_oauth_flows,
            allowed_oauth_flows_user_pool_client=allowed_oauth_flows_user_pool_client,
            allowed_oauth_scopes=allowed_oauth_scopes,
            analytics_configuration=analytics_configuration,
            callback_urls=callback_urls,
            default_redirect_uri=default_redirect_uri,
            explicit_auth_flows=explicit_auth_flows,
            generate_secret=generate_secret,
            logout_urls=logout_urls,
            prevent_user_existence_errors=prevent_user_existence_errors,
            read_attributes=read_attributes,
            refresh_token_validity=refresh_token_validity,
            supported_identity_providers=supported_identity_providers,
            write_attributes=write_attributes,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoUserPoolClient, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> str:
        return jsii.get(self, "clientSecret")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="userPoolId")
    def user_pool_id(self) -> str:
        return jsii.get(self, "userPoolId")

    @user_pool_id.setter
    def user_pool_id(self, value: str) -> None:
        jsii.set(self, "userPoolId", value)

    @builtins.property
    @jsii.member(jsii_name="allowedOauthFlows")
    def allowed_oauth_flows(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "allowedOauthFlows")

    @allowed_oauth_flows.setter
    def allowed_oauth_flows(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "allowedOauthFlows", value)

    @builtins.property
    @jsii.member(jsii_name="allowedOauthFlowsUserPoolClient")
    def allowed_oauth_flows_user_pool_client(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowedOauthFlowsUserPoolClient")

    @allowed_oauth_flows_user_pool_client.setter
    def allowed_oauth_flows_user_pool_client(
        self, value: typing.Optional[bool]
    ) -> None:
        jsii.set(self, "allowedOauthFlowsUserPoolClient", value)

    @builtins.property
    @jsii.member(jsii_name="allowedOauthScopes")
    def allowed_oauth_scopes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "allowedOauthScopes")

    @allowed_oauth_scopes.setter
    def allowed_oauth_scopes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "allowedOauthScopes", value)

    @builtins.property
    @jsii.member(jsii_name="analyticsConfiguration")
    def analytics_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolClientAnalyticsConfiguration"]]:
        return jsii.get(self, "analyticsConfiguration")

    @analytics_configuration.setter
    def analytics_configuration(
        self,
        value: typing.Optional[
            typing.List["CognitoUserPoolClientAnalyticsConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "analyticsConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="callbackUrls")
    def callback_urls(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "callbackUrls")

    @callback_urls.setter
    def callback_urls(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "callbackUrls", value)

    @builtins.property
    @jsii.member(jsii_name="defaultRedirectUri")
    def default_redirect_uri(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultRedirectUri")

    @default_redirect_uri.setter
    def default_redirect_uri(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultRedirectUri", value)

    @builtins.property
    @jsii.member(jsii_name="explicitAuthFlows")
    def explicit_auth_flows(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "explicitAuthFlows")

    @explicit_auth_flows.setter
    def explicit_auth_flows(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "explicitAuthFlows", value)

    @builtins.property
    @jsii.member(jsii_name="generateSecret")
    def generate_secret(self) -> typing.Optional[bool]:
        return jsii.get(self, "generateSecret")

    @generate_secret.setter
    def generate_secret(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "generateSecret", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="logoutUrls")
    def logout_urls(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "logoutUrls")

    @logout_urls.setter
    def logout_urls(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "logoutUrls", value)

    @builtins.property
    @jsii.member(jsii_name="preventUserExistenceErrors")
    def prevent_user_existence_errors(self) -> typing.Optional[str]:
        return jsii.get(self, "preventUserExistenceErrors")

    @prevent_user_existence_errors.setter
    def prevent_user_existence_errors(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preventUserExistenceErrors", value)

    @builtins.property
    @jsii.member(jsii_name="readAttributes")
    def read_attributes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "readAttributes")

    @read_attributes.setter
    def read_attributes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "readAttributes", value)

    @builtins.property
    @jsii.member(jsii_name="refreshTokenValidity")
    def refresh_token_validity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "refreshTokenValidity")

    @refresh_token_validity.setter
    def refresh_token_validity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "refreshTokenValidity", value)

    @builtins.property
    @jsii.member(jsii_name="supportedIdentityProviders")
    def supported_identity_providers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "supportedIdentityProviders")

    @supported_identity_providers.setter
    def supported_identity_providers(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "supportedIdentityProviders", value)

    @builtins.property
    @jsii.member(jsii_name="writeAttributes")
    def write_attributes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "writeAttributes")

    @write_attributes.setter
    def write_attributes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "writeAttributes", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolClientAnalyticsConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "application_id": "applicationId",
        "external_id": "externalId",
        "role_arn": "roleArn",
        "user_data_shared": "userDataShared",
    },
)
class CognitoUserPoolClientAnalyticsConfiguration:
    def __init__(
        self,
        *,
        application_id: str,
        external_id: str,
        role_arn: str,
        user_data_shared: typing.Optional[bool] = None,
    ) -> None:
        """
        :param application_id: 
        :param external_id: 
        :param role_arn: 
        :param user_data_shared: 
        """
        self._values = {
            "application_id": application_id,
            "external_id": external_id,
            "role_arn": role_arn,
        }
        if user_data_shared is not None:
            self._values["user_data_shared"] = user_data_shared

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def external_id(self) -> str:
        return self._values.get("external_id")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def user_data_shared(self) -> typing.Optional[bool]:
        return self._values.get("user_data_shared")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolClientAnalyticsConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolClientConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "user_pool_id": "userPoolId",
        "allowed_oauth_flows": "allowedOauthFlows",
        "allowed_oauth_flows_user_pool_client": "allowedOauthFlowsUserPoolClient",
        "allowed_oauth_scopes": "allowedOauthScopes",
        "analytics_configuration": "analyticsConfiguration",
        "callback_urls": "callbackUrls",
        "default_redirect_uri": "defaultRedirectUri",
        "explicit_auth_flows": "explicitAuthFlows",
        "generate_secret": "generateSecret",
        "logout_urls": "logoutUrls",
        "prevent_user_existence_errors": "preventUserExistenceErrors",
        "read_attributes": "readAttributes",
        "refresh_token_validity": "refreshTokenValidity",
        "supported_identity_providers": "supportedIdentityProviders",
        "write_attributes": "writeAttributes",
    },
)
class CognitoUserPoolClientConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        user_pool_id: str,
        allowed_oauth_flows: typing.Optional[typing.List[str]] = None,
        allowed_oauth_flows_user_pool_client: typing.Optional[bool] = None,
        allowed_oauth_scopes: typing.Optional[typing.List[str]] = None,
        analytics_configuration: typing.Optional[
            typing.List["CognitoUserPoolClientAnalyticsConfiguration"]
        ] = None,
        callback_urls: typing.Optional[typing.List[str]] = None,
        default_redirect_uri: typing.Optional[str] = None,
        explicit_auth_flows: typing.Optional[typing.List[str]] = None,
        generate_secret: typing.Optional[bool] = None,
        logout_urls: typing.Optional[typing.List[str]] = None,
        prevent_user_existence_errors: typing.Optional[str] = None,
        read_attributes: typing.Optional[typing.List[str]] = None,
        refresh_token_validity: typing.Optional[jsii.Number] = None,
        supported_identity_providers: typing.Optional[typing.List[str]] = None,
        write_attributes: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param user_pool_id: 
        :param allowed_oauth_flows: 
        :param allowed_oauth_flows_user_pool_client: 
        :param allowed_oauth_scopes: 
        :param analytics_configuration: analytics_configuration block.
        :param callback_urls: 
        :param default_redirect_uri: 
        :param explicit_auth_flows: 
        :param generate_secret: 
        :param logout_urls: 
        :param prevent_user_existence_errors: 
        :param read_attributes: 
        :param refresh_token_validity: 
        :param supported_identity_providers: 
        :param write_attributes: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "user_pool_id": user_pool_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allowed_oauth_flows is not None:
            self._values["allowed_oauth_flows"] = allowed_oauth_flows
        if allowed_oauth_flows_user_pool_client is not None:
            self._values[
                "allowed_oauth_flows_user_pool_client"
            ] = allowed_oauth_flows_user_pool_client
        if allowed_oauth_scopes is not None:
            self._values["allowed_oauth_scopes"] = allowed_oauth_scopes
        if analytics_configuration is not None:
            self._values["analytics_configuration"] = analytics_configuration
        if callback_urls is not None:
            self._values["callback_urls"] = callback_urls
        if default_redirect_uri is not None:
            self._values["default_redirect_uri"] = default_redirect_uri
        if explicit_auth_flows is not None:
            self._values["explicit_auth_flows"] = explicit_auth_flows
        if generate_secret is not None:
            self._values["generate_secret"] = generate_secret
        if logout_urls is not None:
            self._values["logout_urls"] = logout_urls
        if prevent_user_existence_errors is not None:
            self._values[
                "prevent_user_existence_errors"
            ] = prevent_user_existence_errors
        if read_attributes is not None:
            self._values["read_attributes"] = read_attributes
        if refresh_token_validity is not None:
            self._values["refresh_token_validity"] = refresh_token_validity
        if supported_identity_providers is not None:
            self._values["supported_identity_providers"] = supported_identity_providers
        if write_attributes is not None:
            self._values["write_attributes"] = write_attributes

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def allowed_oauth_flows(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allowed_oauth_flows")

    @builtins.property
    def allowed_oauth_flows_user_pool_client(self) -> typing.Optional[bool]:
        return self._values.get("allowed_oauth_flows_user_pool_client")

    @builtins.property
    def allowed_oauth_scopes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allowed_oauth_scopes")

    @builtins.property
    def analytics_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolClientAnalyticsConfiguration"]]:
        """analytics_configuration block."""
        return self._values.get("analytics_configuration")

    @builtins.property
    def callback_urls(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("callback_urls")

    @builtins.property
    def default_redirect_uri(self) -> typing.Optional[str]:
        return self._values.get("default_redirect_uri")

    @builtins.property
    def explicit_auth_flows(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("explicit_auth_flows")

    @builtins.property
    def generate_secret(self) -> typing.Optional[bool]:
        return self._values.get("generate_secret")

    @builtins.property
    def logout_urls(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("logout_urls")

    @builtins.property
    def prevent_user_existence_errors(self) -> typing.Optional[str]:
        return self._values.get("prevent_user_existence_errors")

    @builtins.property
    def read_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("read_attributes")

    @builtins.property
    def refresh_token_validity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("refresh_token_validity")

    @builtins.property
    def supported_identity_providers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("supported_identity_providers")

    @builtins.property
    def write_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("write_attributes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolClientConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "admin_create_user_config": "adminCreateUserConfig",
        "alias_attributes": "aliasAttributes",
        "auto_verified_attributes": "autoVerifiedAttributes",
        "device_configuration": "deviceConfiguration",
        "email_configuration": "emailConfiguration",
        "email_verification_message": "emailVerificationMessage",
        "email_verification_subject": "emailVerificationSubject",
        "lambda_config": "lambdaConfig",
        "mfa_configuration": "mfaConfiguration",
        "password_policy": "passwordPolicy",
        "schema": "schema",
        "sms_authentication_message": "smsAuthenticationMessage",
        "sms_configuration": "smsConfiguration",
        "sms_verification_message": "smsVerificationMessage",
        "software_token_mfa_configuration": "softwareTokenMfaConfiguration",
        "tags": "tags",
        "username_attributes": "usernameAttributes",
        "username_configuration": "usernameConfiguration",
        "user_pool_add_ons": "userPoolAddOns",
        "verification_message_template": "verificationMessageTemplate",
    },
)
class CognitoUserPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        admin_create_user_config: typing.Optional[
            typing.List["CognitoUserPoolAdminCreateUserConfig"]
        ] = None,
        alias_attributes: typing.Optional[typing.List[str]] = None,
        auto_verified_attributes: typing.Optional[typing.List[str]] = None,
        device_configuration: typing.Optional[
            typing.List["CognitoUserPoolDeviceConfiguration"]
        ] = None,
        email_configuration: typing.Optional[
            typing.List["CognitoUserPoolEmailConfiguration"]
        ] = None,
        email_verification_message: typing.Optional[str] = None,
        email_verification_subject: typing.Optional[str] = None,
        lambda_config: typing.Optional[
            typing.List["CognitoUserPoolLambdaConfig"]
        ] = None,
        mfa_configuration: typing.Optional[str] = None,
        password_policy: typing.Optional[
            typing.List["CognitoUserPoolPasswordPolicy"]
        ] = None,
        schema: typing.Optional[typing.List["CognitoUserPoolSchema"]] = None,
        sms_authentication_message: typing.Optional[str] = None,
        sms_configuration: typing.Optional[
            typing.List["CognitoUserPoolSmsConfiguration"]
        ] = None,
        sms_verification_message: typing.Optional[str] = None,
        software_token_mfa_configuration: typing.Optional[
            typing.List["CognitoUserPoolSoftwareTokenMfaConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        username_attributes: typing.Optional[typing.List[str]] = None,
        username_configuration: typing.Optional[
            typing.List["CognitoUserPoolUsernameConfiguration"]
        ] = None,
        user_pool_add_ons: typing.Optional[
            typing.List["CognitoUserPoolUserPoolAddOns"]
        ] = None,
        verification_message_template: typing.Optional[
            typing.List["CognitoUserPoolVerificationMessageTemplate"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param admin_create_user_config: admin_create_user_config block.
        :param alias_attributes: 
        :param auto_verified_attributes: 
        :param device_configuration: device_configuration block.
        :param email_configuration: email_configuration block.
        :param email_verification_message: 
        :param email_verification_subject: 
        :param lambda_config: lambda_config block.
        :param mfa_configuration: 
        :param password_policy: password_policy block.
        :param schema: schema block.
        :param sms_authentication_message: 
        :param sms_configuration: sms_configuration block.
        :param sms_verification_message: 
        :param software_token_mfa_configuration: software_token_mfa_configuration block.
        :param tags: 
        :param username_attributes: 
        :param username_configuration: username_configuration block.
        :param user_pool_add_ons: user_pool_add_ons block.
        :param verification_message_template: verification_message_template block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if admin_create_user_config is not None:
            self._values["admin_create_user_config"] = admin_create_user_config
        if alias_attributes is not None:
            self._values["alias_attributes"] = alias_attributes
        if auto_verified_attributes is not None:
            self._values["auto_verified_attributes"] = auto_verified_attributes
        if device_configuration is not None:
            self._values["device_configuration"] = device_configuration
        if email_configuration is not None:
            self._values["email_configuration"] = email_configuration
        if email_verification_message is not None:
            self._values["email_verification_message"] = email_verification_message
        if email_verification_subject is not None:
            self._values["email_verification_subject"] = email_verification_subject
        if lambda_config is not None:
            self._values["lambda_config"] = lambda_config
        if mfa_configuration is not None:
            self._values["mfa_configuration"] = mfa_configuration
        if password_policy is not None:
            self._values["password_policy"] = password_policy
        if schema is not None:
            self._values["schema"] = schema
        if sms_authentication_message is not None:
            self._values["sms_authentication_message"] = sms_authentication_message
        if sms_configuration is not None:
            self._values["sms_configuration"] = sms_configuration
        if sms_verification_message is not None:
            self._values["sms_verification_message"] = sms_verification_message
        if software_token_mfa_configuration is not None:
            self._values[
                "software_token_mfa_configuration"
            ] = software_token_mfa_configuration
        if tags is not None:
            self._values["tags"] = tags
        if username_attributes is not None:
            self._values["username_attributes"] = username_attributes
        if username_configuration is not None:
            self._values["username_configuration"] = username_configuration
        if user_pool_add_ons is not None:
            self._values["user_pool_add_ons"] = user_pool_add_ons
        if verification_message_template is not None:
            self._values[
                "verification_message_template"
            ] = verification_message_template

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def admin_create_user_config(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolAdminCreateUserConfig"]]:
        """admin_create_user_config block."""
        return self._values.get("admin_create_user_config")

    @builtins.property
    def alias_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("alias_attributes")

    @builtins.property
    def auto_verified_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("auto_verified_attributes")

    @builtins.property
    def device_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolDeviceConfiguration"]]:
        """device_configuration block."""
        return self._values.get("device_configuration")

    @builtins.property
    def email_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolEmailConfiguration"]]:
        """email_configuration block."""
        return self._values.get("email_configuration")

    @builtins.property
    def email_verification_message(self) -> typing.Optional[str]:
        return self._values.get("email_verification_message")

    @builtins.property
    def email_verification_subject(self) -> typing.Optional[str]:
        return self._values.get("email_verification_subject")

    @builtins.property
    def lambda_config(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolLambdaConfig"]]:
        """lambda_config block."""
        return self._values.get("lambda_config")

    @builtins.property
    def mfa_configuration(self) -> typing.Optional[str]:
        return self._values.get("mfa_configuration")

    @builtins.property
    def password_policy(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolPasswordPolicy"]]:
        """password_policy block."""
        return self._values.get("password_policy")

    @builtins.property
    def schema(self) -> typing.Optional[typing.List["CognitoUserPoolSchema"]]:
        """schema block."""
        return self._values.get("schema")

    @builtins.property
    def sms_authentication_message(self) -> typing.Optional[str]:
        return self._values.get("sms_authentication_message")

    @builtins.property
    def sms_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolSmsConfiguration"]]:
        """sms_configuration block."""
        return self._values.get("sms_configuration")

    @builtins.property
    def sms_verification_message(self) -> typing.Optional[str]:
        return self._values.get("sms_verification_message")

    @builtins.property
    def software_token_mfa_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolSoftwareTokenMfaConfiguration"]]:
        """software_token_mfa_configuration block."""
        return self._values.get("software_token_mfa_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def username_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("username_attributes")

    @builtins.property
    def username_configuration(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolUsernameConfiguration"]]:
        """username_configuration block."""
        return self._values.get("username_configuration")

    @builtins.property
    def user_pool_add_ons(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolUserPoolAddOns"]]:
        """user_pool_add_ons block."""
        return self._values.get("user_pool_add_ons")

    @builtins.property
    def verification_message_template(
        self,
    ) -> typing.Optional[typing.List["CognitoUserPoolVerificationMessageTemplate"]]:
        """verification_message_template block."""
        return self._values.get("verification_message_template")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolDeviceConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "challenge_required_on_new_device": "challengeRequiredOnNewDevice",
        "device_only_remembered_on_user_prompt": "deviceOnlyRememberedOnUserPrompt",
    },
)
class CognitoUserPoolDeviceConfiguration:
    def __init__(
        self,
        *,
        challenge_required_on_new_device: typing.Optional[bool] = None,
        device_only_remembered_on_user_prompt: typing.Optional[bool] = None,
    ) -> None:
        """
        :param challenge_required_on_new_device: 
        :param device_only_remembered_on_user_prompt: 
        """
        self._values = {}
        if challenge_required_on_new_device is not None:
            self._values[
                "challenge_required_on_new_device"
            ] = challenge_required_on_new_device
        if device_only_remembered_on_user_prompt is not None:
            self._values[
                "device_only_remembered_on_user_prompt"
            ] = device_only_remembered_on_user_prompt

    @builtins.property
    def challenge_required_on_new_device(self) -> typing.Optional[bool]:
        return self._values.get("challenge_required_on_new_device")

    @builtins.property
    def device_only_remembered_on_user_prompt(self) -> typing.Optional[bool]:
        return self._values.get("device_only_remembered_on_user_prompt")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolDeviceConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CognitoUserPoolDomain(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolDomain",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain: str,
        user_pool_id: str,
        certificate_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain: 
        :param user_pool_id: 
        :param certificate_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CognitoUserPoolDomainConfig(
            domain=domain,
            user_pool_id=user_pool_id,
            certificate_arn=certificate_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CognitoUserPoolDomain, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> str:
        return jsii.get(self, "awsAccountId")

    @builtins.property
    @jsii.member(jsii_name="cloudfrontDistributionArn")
    def cloudfront_distribution_arn(self) -> str:
        return jsii.get(self, "cloudfrontDistributionArn")

    @builtins.property
    @jsii.member(jsii_name="s3Bucket")
    def s3_bucket(self) -> str:
        return jsii.get(self, "s3Bucket")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: str) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="userPoolId")
    def user_pool_id(self) -> str:
        return jsii.get(self, "userPoolId")

    @user_pool_id.setter
    def user_pool_id(self, value: str) -> None:
        jsii.set(self, "userPoolId", value)

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolDomainConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain": "domain",
        "user_pool_id": "userPoolId",
        "certificate_arn": "certificateArn",
    },
)
class CognitoUserPoolDomainConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain: str,
        user_pool_id: str,
        certificate_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain: 
        :param user_pool_id: 
        :param certificate_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain": domain,
            "user_pool_id": user_pool_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_arn is not None:
            self._values["certificate_arn"] = certificate_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain(self) -> str:
        return self._values.get("domain")

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def certificate_arn(self) -> typing.Optional[str]:
        return self._values.get("certificate_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolDomainConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolEmailConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "email_sending_account": "emailSendingAccount",
        "from_email_address": "fromEmailAddress",
        "reply_to_email_address": "replyToEmailAddress",
        "source_arn": "sourceArn",
    },
)
class CognitoUserPoolEmailConfiguration:
    def __init__(
        self,
        *,
        email_sending_account: typing.Optional[str] = None,
        from_email_address: typing.Optional[str] = None,
        reply_to_email_address: typing.Optional[str] = None,
        source_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param email_sending_account: 
        :param from_email_address: 
        :param reply_to_email_address: 
        :param source_arn: 
        """
        self._values = {}
        if email_sending_account is not None:
            self._values["email_sending_account"] = email_sending_account
        if from_email_address is not None:
            self._values["from_email_address"] = from_email_address
        if reply_to_email_address is not None:
            self._values["reply_to_email_address"] = reply_to_email_address
        if source_arn is not None:
            self._values["source_arn"] = source_arn

    @builtins.property
    def email_sending_account(self) -> typing.Optional[str]:
        return self._values.get("email_sending_account")

    @builtins.property
    def from_email_address(self) -> typing.Optional[str]:
        return self._values.get("from_email_address")

    @builtins.property
    def reply_to_email_address(self) -> typing.Optional[str]:
        return self._values.get("reply_to_email_address")

    @builtins.property
    def source_arn(self) -> typing.Optional[str]:
        return self._values.get("source_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolEmailConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolLambdaConfig",
    jsii_struct_bases=[],
    name_mapping={
        "create_auth_challenge": "createAuthChallenge",
        "custom_message": "customMessage",
        "define_auth_challenge": "defineAuthChallenge",
        "post_authentication": "postAuthentication",
        "post_confirmation": "postConfirmation",
        "pre_authentication": "preAuthentication",
        "pre_sign_up": "preSignUp",
        "pre_token_generation": "preTokenGeneration",
        "user_migration": "userMigration",
        "verify_auth_challenge_response": "verifyAuthChallengeResponse",
    },
)
class CognitoUserPoolLambdaConfig:
    def __init__(
        self,
        *,
        create_auth_challenge: typing.Optional[str] = None,
        custom_message: typing.Optional[str] = None,
        define_auth_challenge: typing.Optional[str] = None,
        post_authentication: typing.Optional[str] = None,
        post_confirmation: typing.Optional[str] = None,
        pre_authentication: typing.Optional[str] = None,
        pre_sign_up: typing.Optional[str] = None,
        pre_token_generation: typing.Optional[str] = None,
        user_migration: typing.Optional[str] = None,
        verify_auth_challenge_response: typing.Optional[str] = None,
    ) -> None:
        """
        :param create_auth_challenge: 
        :param custom_message: 
        :param define_auth_challenge: 
        :param post_authentication: 
        :param post_confirmation: 
        :param pre_authentication: 
        :param pre_sign_up: 
        :param pre_token_generation: 
        :param user_migration: 
        :param verify_auth_challenge_response: 
        """
        self._values = {}
        if create_auth_challenge is not None:
            self._values["create_auth_challenge"] = create_auth_challenge
        if custom_message is not None:
            self._values["custom_message"] = custom_message
        if define_auth_challenge is not None:
            self._values["define_auth_challenge"] = define_auth_challenge
        if post_authentication is not None:
            self._values["post_authentication"] = post_authentication
        if post_confirmation is not None:
            self._values["post_confirmation"] = post_confirmation
        if pre_authentication is not None:
            self._values["pre_authentication"] = pre_authentication
        if pre_sign_up is not None:
            self._values["pre_sign_up"] = pre_sign_up
        if pre_token_generation is not None:
            self._values["pre_token_generation"] = pre_token_generation
        if user_migration is not None:
            self._values["user_migration"] = user_migration
        if verify_auth_challenge_response is not None:
            self._values[
                "verify_auth_challenge_response"
            ] = verify_auth_challenge_response

    @builtins.property
    def create_auth_challenge(self) -> typing.Optional[str]:
        return self._values.get("create_auth_challenge")

    @builtins.property
    def custom_message(self) -> typing.Optional[str]:
        return self._values.get("custom_message")

    @builtins.property
    def define_auth_challenge(self) -> typing.Optional[str]:
        return self._values.get("define_auth_challenge")

    @builtins.property
    def post_authentication(self) -> typing.Optional[str]:
        return self._values.get("post_authentication")

    @builtins.property
    def post_confirmation(self) -> typing.Optional[str]:
        return self._values.get("post_confirmation")

    @builtins.property
    def pre_authentication(self) -> typing.Optional[str]:
        return self._values.get("pre_authentication")

    @builtins.property
    def pre_sign_up(self) -> typing.Optional[str]:
        return self._values.get("pre_sign_up")

    @builtins.property
    def pre_token_generation(self) -> typing.Optional[str]:
        return self._values.get("pre_token_generation")

    @builtins.property
    def user_migration(self) -> typing.Optional[str]:
        return self._values.get("user_migration")

    @builtins.property
    def verify_auth_challenge_response(self) -> typing.Optional[str]:
        return self._values.get("verify_auth_challenge_response")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolLambdaConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolPasswordPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "minimum_length": "minimumLength",
        "require_lowercase": "requireLowercase",
        "require_numbers": "requireNumbers",
        "require_symbols": "requireSymbols",
        "require_uppercase": "requireUppercase",
        "temporary_password_validity_days": "temporaryPasswordValidityDays",
    },
)
class CognitoUserPoolPasswordPolicy:
    def __init__(
        self,
        *,
        minimum_length: typing.Optional[jsii.Number] = None,
        require_lowercase: typing.Optional[bool] = None,
        require_numbers: typing.Optional[bool] = None,
        require_symbols: typing.Optional[bool] = None,
        require_uppercase: typing.Optional[bool] = None,
        temporary_password_validity_days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param minimum_length: 
        :param require_lowercase: 
        :param require_numbers: 
        :param require_symbols: 
        :param require_uppercase: 
        :param temporary_password_validity_days: 
        """
        self._values = {}
        if minimum_length is not None:
            self._values["minimum_length"] = minimum_length
        if require_lowercase is not None:
            self._values["require_lowercase"] = require_lowercase
        if require_numbers is not None:
            self._values["require_numbers"] = require_numbers
        if require_symbols is not None:
            self._values["require_symbols"] = require_symbols
        if require_uppercase is not None:
            self._values["require_uppercase"] = require_uppercase
        if temporary_password_validity_days is not None:
            self._values[
                "temporary_password_validity_days"
            ] = temporary_password_validity_days

    @builtins.property
    def minimum_length(self) -> typing.Optional[jsii.Number]:
        return self._values.get("minimum_length")

    @builtins.property
    def require_lowercase(self) -> typing.Optional[bool]:
        return self._values.get("require_lowercase")

    @builtins.property
    def require_numbers(self) -> typing.Optional[bool]:
        return self._values.get("require_numbers")

    @builtins.property
    def require_symbols(self) -> typing.Optional[bool]:
        return self._values.get("require_symbols")

    @builtins.property
    def require_uppercase(self) -> typing.Optional[bool]:
        return self._values.get("require_uppercase")

    @builtins.property
    def temporary_password_validity_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("temporary_password_validity_days")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolPasswordPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolSchema",
    jsii_struct_bases=[],
    name_mapping={
        "attribute_data_type": "attributeDataType",
        "name": "name",
        "developer_only_attribute": "developerOnlyAttribute",
        "mutable": "mutable",
        "number_attribute_constraints": "numberAttributeConstraints",
        "required": "required",
        "string_attribute_constraints": "stringAttributeConstraints",
    },
)
class CognitoUserPoolSchema:
    def __init__(
        self,
        *,
        attribute_data_type: str,
        name: str,
        developer_only_attribute: typing.Optional[bool] = None,
        mutable: typing.Optional[bool] = None,
        number_attribute_constraints: typing.Optional[
            typing.List["CognitoUserPoolSchemaNumberAttributeConstraints"]
        ] = None,
        required: typing.Optional[bool] = None,
        string_attribute_constraints: typing.Optional[
            typing.List["CognitoUserPoolSchemaStringAttributeConstraints"]
        ] = None,
    ) -> None:
        """
        :param attribute_data_type: 
        :param name: 
        :param developer_only_attribute: 
        :param mutable: 
        :param number_attribute_constraints: number_attribute_constraints block.
        :param required: 
        :param string_attribute_constraints: string_attribute_constraints block.
        """
        self._values = {
            "attribute_data_type": attribute_data_type,
            "name": name,
        }
        if developer_only_attribute is not None:
            self._values["developer_only_attribute"] = developer_only_attribute
        if mutable is not None:
            self._values["mutable"] = mutable
        if number_attribute_constraints is not None:
            self._values["number_attribute_constraints"] = number_attribute_constraints
        if required is not None:
            self._values["required"] = required
        if string_attribute_constraints is not None:
            self._values["string_attribute_constraints"] = string_attribute_constraints

    @builtins.property
    def attribute_data_type(self) -> str:
        return self._values.get("attribute_data_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def developer_only_attribute(self) -> typing.Optional[bool]:
        return self._values.get("developer_only_attribute")

    @builtins.property
    def mutable(self) -> typing.Optional[bool]:
        return self._values.get("mutable")

    @builtins.property
    def number_attribute_constraints(
        self,
    ) -> typing.Optional[
        typing.List["CognitoUserPoolSchemaNumberAttributeConstraints"]
    ]:
        """number_attribute_constraints block."""
        return self._values.get("number_attribute_constraints")

    @builtins.property
    def required(self) -> typing.Optional[bool]:
        return self._values.get("required")

    @builtins.property
    def string_attribute_constraints(
        self,
    ) -> typing.Optional[
        typing.List["CognitoUserPoolSchemaStringAttributeConstraints"]
    ]:
        """string_attribute_constraints block."""
        return self._values.get("string_attribute_constraints")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolSchema(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolSchemaNumberAttributeConstraints",
    jsii_struct_bases=[],
    name_mapping={"max_value": "maxValue", "min_value": "minValue"},
)
class CognitoUserPoolSchemaNumberAttributeConstraints:
    def __init__(
        self,
        *,
        max_value: typing.Optional[str] = None,
        min_value: typing.Optional[str] = None,
    ) -> None:
        """
        :param max_value: 
        :param min_value: 
        """
        self._values = {}
        if max_value is not None:
            self._values["max_value"] = max_value
        if min_value is not None:
            self._values["min_value"] = min_value

    @builtins.property
    def max_value(self) -> typing.Optional[str]:
        return self._values.get("max_value")

    @builtins.property
    def min_value(self) -> typing.Optional[str]:
        return self._values.get("min_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolSchemaNumberAttributeConstraints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolSchemaStringAttributeConstraints",
    jsii_struct_bases=[],
    name_mapping={"max_length": "maxLength", "min_length": "minLength"},
)
class CognitoUserPoolSchemaStringAttributeConstraints:
    def __init__(
        self,
        *,
        max_length: typing.Optional[str] = None,
        min_length: typing.Optional[str] = None,
    ) -> None:
        """
        :param max_length: 
        :param min_length: 
        """
        self._values = {}
        if max_length is not None:
            self._values["max_length"] = max_length
        if min_length is not None:
            self._values["min_length"] = min_length

    @builtins.property
    def max_length(self) -> typing.Optional[str]:
        return self._values.get("max_length")

    @builtins.property
    def min_length(self) -> typing.Optional[str]:
        return self._values.get("min_length")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolSchemaStringAttributeConstraints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolSmsConfiguration",
    jsii_struct_bases=[],
    name_mapping={"external_id": "externalId", "sns_caller_arn": "snsCallerArn"},
)
class CognitoUserPoolSmsConfiguration:
    def __init__(self, *, external_id: str, sns_caller_arn: str) -> None:
        """
        :param external_id: 
        :param sns_caller_arn: 
        """
        self._values = {
            "external_id": external_id,
            "sns_caller_arn": sns_caller_arn,
        }

    @builtins.property
    def external_id(self) -> str:
        return self._values.get("external_id")

    @builtins.property
    def sns_caller_arn(self) -> str:
        return self._values.get("sns_caller_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolSmsConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolSoftwareTokenMfaConfiguration",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class CognitoUserPoolSoftwareTokenMfaConfiguration:
    def __init__(self, *, enabled: bool) -> None:
        """
        :param enabled: 
        """
        self._values = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolSoftwareTokenMfaConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolUserPoolAddOns",
    jsii_struct_bases=[],
    name_mapping={"advanced_security_mode": "advancedSecurityMode"},
)
class CognitoUserPoolUserPoolAddOns:
    def __init__(self, *, advanced_security_mode: str) -> None:
        """
        :param advanced_security_mode: 
        """
        self._values = {
            "advanced_security_mode": advanced_security_mode,
        }

    @builtins.property
    def advanced_security_mode(self) -> str:
        return self._values.get("advanced_security_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolUserPoolAddOns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolUsernameConfiguration",
    jsii_struct_bases=[],
    name_mapping={"case_sensitive": "caseSensitive"},
)
class CognitoUserPoolUsernameConfiguration:
    def __init__(self, *, case_sensitive: bool) -> None:
        """
        :param case_sensitive: 
        """
        self._values = {
            "case_sensitive": case_sensitive,
        }

    @builtins.property
    def case_sensitive(self) -> bool:
        return self._values.get("case_sensitive")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolUsernameConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CognitoUserPoolVerificationMessageTemplate",
    jsii_struct_bases=[],
    name_mapping={
        "default_email_option": "defaultEmailOption",
        "email_message": "emailMessage",
        "email_message_by_link": "emailMessageByLink",
        "email_subject": "emailSubject",
        "email_subject_by_link": "emailSubjectByLink",
        "sms_message": "smsMessage",
    },
)
class CognitoUserPoolVerificationMessageTemplate:
    def __init__(
        self,
        *,
        default_email_option: typing.Optional[str] = None,
        email_message: typing.Optional[str] = None,
        email_message_by_link: typing.Optional[str] = None,
        email_subject: typing.Optional[str] = None,
        email_subject_by_link: typing.Optional[str] = None,
        sms_message: typing.Optional[str] = None,
    ) -> None:
        """
        :param default_email_option: 
        :param email_message: 
        :param email_message_by_link: 
        :param email_subject: 
        :param email_subject_by_link: 
        :param sms_message: 
        """
        self._values = {}
        if default_email_option is not None:
            self._values["default_email_option"] = default_email_option
        if email_message is not None:
            self._values["email_message"] = email_message
        if email_message_by_link is not None:
            self._values["email_message_by_link"] = email_message_by_link
        if email_subject is not None:
            self._values["email_subject"] = email_subject
        if email_subject_by_link is not None:
            self._values["email_subject_by_link"] = email_subject_by_link
        if sms_message is not None:
            self._values["sms_message"] = sms_message

    @builtins.property
    def default_email_option(self) -> typing.Optional[str]:
        return self._values.get("default_email_option")

    @builtins.property
    def email_message(self) -> typing.Optional[str]:
        return self._values.get("email_message")

    @builtins.property
    def email_message_by_link(self) -> typing.Optional[str]:
        return self._values.get("email_message_by_link")

    @builtins.property
    def email_subject(self) -> typing.Optional[str]:
        return self._values.get("email_subject")

    @builtins.property
    def email_subject_by_link(self) -> typing.Optional[str]:
        return self._values.get("email_subject_by_link")

    @builtins.property
    def sms_message(self) -> typing.Optional[str]:
        return self._values.get("sms_message")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CognitoUserPoolVerificationMessageTemplate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ConfigAggregateAuthorization(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigAggregateAuthorization",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_id: str,
        region: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_id: 
        :param region: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigAggregateAuthorizationConfig(
            account_id=account_id,
            region=region,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigAggregateAuthorization, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: str) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> str:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: str) -> None:
        jsii.set(self, "region", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigAggregateAuthorizationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_id": "accountId",
        "region": "region",
        "tags": "tags",
    },
)
class ConfigAggregateAuthorizationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_id: str,
        region: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_id: 
        :param region: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "account_id": account_id,
            "region": region,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_id(self) -> str:
        return self._values.get("account_id")

    @builtins.property
    def region(self) -> str:
        return self._values.get("region")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigAggregateAuthorizationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ConfigConfigRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigRule",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        name: str,
        source: typing.List["ConfigConfigRuleSource"],
        description: typing.Optional[str] = None,
        input_parameters: typing.Optional[str] = None,
        maximum_execution_frequency: typing.Optional[str] = None,
        scope: typing.Optional[typing.List["ConfigConfigRuleScope"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param source: source block.
        :param description: 
        :param input_parameters: 
        :param maximum_execution_frequency: 
        :param scope: scope block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigConfigRuleConfig(
            name=name,
            source=source,
            description=description,
            input_parameters=input_parameters,
            maximum_execution_frequency=maximum_execution_frequency,
            scope=scope,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigConfigRule, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ruleId")
    def rule_id(self) -> str:
        return jsii.get(self, "ruleId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="source")
    def source(self) -> typing.List["ConfigConfigRuleSource"]:
        return jsii.get(self, "source")

    @source.setter
    def source(self, value: typing.List["ConfigConfigRuleSource"]) -> None:
        jsii.set(self, "source", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="inputParameters")
    def input_parameters(self) -> typing.Optional[str]:
        return jsii.get(self, "inputParameters")

    @input_parameters.setter
    def input_parameters(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "inputParameters", value)

    @builtins.property
    @jsii.member(jsii_name="maximumExecutionFrequency")
    def maximum_execution_frequency(self) -> typing.Optional[str]:
        return jsii.get(self, "maximumExecutionFrequency")

    @maximum_execution_frequency.setter
    def maximum_execution_frequency(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maximumExecutionFrequency", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> typing.Optional[typing.List["ConfigConfigRuleScope"]]:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(
        self, value: typing.Optional[typing.List["ConfigConfigRuleScope"]]
    ) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "source": "source",
        "description": "description",
        "input_parameters": "inputParameters",
        "maximum_execution_frequency": "maximumExecutionFrequency",
        "scope": "scope",
        "tags": "tags",
    },
)
class ConfigConfigRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        source: typing.List["ConfigConfigRuleSource"],
        description: typing.Optional[str] = None,
        input_parameters: typing.Optional[str] = None,
        maximum_execution_frequency: typing.Optional[str] = None,
        scope: typing.Optional[typing.List["ConfigConfigRuleScope"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param source: source block.
        :param description: 
        :param input_parameters: 
        :param maximum_execution_frequency: 
        :param scope: scope block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "source": source,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if input_parameters is not None:
            self._values["input_parameters"] = input_parameters
        if maximum_execution_frequency is not None:
            self._values["maximum_execution_frequency"] = maximum_execution_frequency
        if scope is not None:
            self._values["scope"] = scope
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def source(self) -> typing.List["ConfigConfigRuleSource"]:
        """source block."""
        return self._values.get("source")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def input_parameters(self) -> typing.Optional[str]:
        return self._values.get("input_parameters")

    @builtins.property
    def maximum_execution_frequency(self) -> typing.Optional[str]:
        return self._values.get("maximum_execution_frequency")

    @builtins.property
    def scope(self) -> typing.Optional[typing.List["ConfigConfigRuleScope"]]:
        """scope block."""
        return self._values.get("scope")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigRuleScope",
    jsii_struct_bases=[],
    name_mapping={
        "compliance_resource_id": "complianceResourceId",
        "compliance_resource_types": "complianceResourceTypes",
        "tag_key": "tagKey",
        "tag_value": "tagValue",
    },
)
class ConfigConfigRuleScope:
    def __init__(
        self,
        *,
        compliance_resource_id: typing.Optional[str] = None,
        compliance_resource_types: typing.Optional[typing.List[str]] = None,
        tag_key: typing.Optional[str] = None,
        tag_value: typing.Optional[str] = None,
    ) -> None:
        """
        :param compliance_resource_id: 
        :param compliance_resource_types: 
        :param tag_key: 
        :param tag_value: 
        """
        self._values = {}
        if compliance_resource_id is not None:
            self._values["compliance_resource_id"] = compliance_resource_id
        if compliance_resource_types is not None:
            self._values["compliance_resource_types"] = compliance_resource_types
        if tag_key is not None:
            self._values["tag_key"] = tag_key
        if tag_value is not None:
            self._values["tag_value"] = tag_value

    @builtins.property
    def compliance_resource_id(self) -> typing.Optional[str]:
        return self._values.get("compliance_resource_id")

    @builtins.property
    def compliance_resource_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("compliance_resource_types")

    @builtins.property
    def tag_key(self) -> typing.Optional[str]:
        return self._values.get("tag_key")

    @builtins.property
    def tag_value(self) -> typing.Optional[str]:
        return self._values.get("tag_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigRuleScope(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigRuleSource",
    jsii_struct_bases=[],
    name_mapping={
        "owner": "owner",
        "source_identifier": "sourceIdentifier",
        "source_detail": "sourceDetail",
    },
)
class ConfigConfigRuleSource:
    def __init__(
        self,
        *,
        owner: str,
        source_identifier: str,
        source_detail: typing.Optional[
            typing.List["ConfigConfigRuleSourceSourceDetail"]
        ] = None,
    ) -> None:
        """
        :param owner: 
        :param source_identifier: 
        :param source_detail: source_detail block.
        """
        self._values = {
            "owner": owner,
            "source_identifier": source_identifier,
        }
        if source_detail is not None:
            self._values["source_detail"] = source_detail

    @builtins.property
    def owner(self) -> str:
        return self._values.get("owner")

    @builtins.property
    def source_identifier(self) -> str:
        return self._values.get("source_identifier")

    @builtins.property
    def source_detail(
        self,
    ) -> typing.Optional[typing.List["ConfigConfigRuleSourceSourceDetail"]]:
        """source_detail block."""
        return self._values.get("source_detail")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigRuleSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigRuleSourceSourceDetail",
    jsii_struct_bases=[],
    name_mapping={
        "event_source": "eventSource",
        "maximum_execution_frequency": "maximumExecutionFrequency",
        "message_type": "messageType",
    },
)
class ConfigConfigRuleSourceSourceDetail:
    def __init__(
        self,
        *,
        event_source: typing.Optional[str] = None,
        maximum_execution_frequency: typing.Optional[str] = None,
        message_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param event_source: 
        :param maximum_execution_frequency: 
        :param message_type: 
        """
        self._values = {}
        if event_source is not None:
            self._values["event_source"] = event_source
        if maximum_execution_frequency is not None:
            self._values["maximum_execution_frequency"] = maximum_execution_frequency
        if message_type is not None:
            self._values["message_type"] = message_type

    @builtins.property
    def event_source(self) -> typing.Optional[str]:
        return self._values.get("event_source")

    @builtins.property
    def maximum_execution_frequency(self) -> typing.Optional[str]:
        return self._values.get("maximum_execution_frequency")

    @builtins.property
    def message_type(self) -> typing.Optional[str]:
        return self._values.get("message_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigRuleSourceSourceDetail(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ConfigConfigurationAggregator(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationAggregator",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        account_aggregation_source: typing.Optional[
            typing.List["ConfigConfigurationAggregatorAccountAggregationSource"]
        ] = None,
        organization_aggregation_source: typing.Optional[
            typing.List["ConfigConfigurationAggregatorOrganizationAggregationSource"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param account_aggregation_source: account_aggregation_source block.
        :param organization_aggregation_source: organization_aggregation_source block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigConfigurationAggregatorConfig(
            name=name,
            account_aggregation_source=account_aggregation_source,
            organization_aggregation_source=organization_aggregation_source,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigConfigurationAggregator, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="accountAggregationSource")
    def account_aggregation_source(
        self,
    ) -> typing.Optional[
        typing.List["ConfigConfigurationAggregatorAccountAggregationSource"]
    ]:
        return jsii.get(self, "accountAggregationSource")

    @account_aggregation_source.setter
    def account_aggregation_source(
        self,
        value: typing.Optional[
            typing.List["ConfigConfigurationAggregatorAccountAggregationSource"]
        ],
    ) -> None:
        jsii.set(self, "accountAggregationSource", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="organizationAggregationSource")
    def organization_aggregation_source(
        self,
    ) -> typing.Optional[
        typing.List["ConfigConfigurationAggregatorOrganizationAggregationSource"]
    ]:
        return jsii.get(self, "organizationAggregationSource")

    @organization_aggregation_source.setter
    def organization_aggregation_source(
        self,
        value: typing.Optional[
            typing.List["ConfigConfigurationAggregatorOrganizationAggregationSource"]
        ],
    ) -> None:
        jsii.set(self, "organizationAggregationSource", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationAggregatorAccountAggregationSource",
    jsii_struct_bases=[],
    name_mapping={
        "account_ids": "accountIds",
        "all_regions": "allRegions",
        "regions": "regions",
    },
)
class ConfigConfigurationAggregatorAccountAggregationSource:
    def __init__(
        self,
        *,
        account_ids: typing.List[str],
        all_regions: typing.Optional[bool] = None,
        regions: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param account_ids: 
        :param all_regions: 
        :param regions: 
        """
        self._values = {
            "account_ids": account_ids,
        }
        if all_regions is not None:
            self._values["all_regions"] = all_regions
        if regions is not None:
            self._values["regions"] = regions

    @builtins.property
    def account_ids(self) -> typing.List[str]:
        return self._values.get("account_ids")

    @builtins.property
    def all_regions(self) -> typing.Optional[bool]:
        return self._values.get("all_regions")

    @builtins.property
    def regions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("regions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigurationAggregatorAccountAggregationSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationAggregatorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "account_aggregation_source": "accountAggregationSource",
        "organization_aggregation_source": "organizationAggregationSource",
        "tags": "tags",
    },
)
class ConfigConfigurationAggregatorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        account_aggregation_source: typing.Optional[
            typing.List["ConfigConfigurationAggregatorAccountAggregationSource"]
        ] = None,
        organization_aggregation_source: typing.Optional[
            typing.List["ConfigConfigurationAggregatorOrganizationAggregationSource"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param account_aggregation_source: account_aggregation_source block.
        :param organization_aggregation_source: organization_aggregation_source block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if account_aggregation_source is not None:
            self._values["account_aggregation_source"] = account_aggregation_source
        if organization_aggregation_source is not None:
            self._values[
                "organization_aggregation_source"
            ] = organization_aggregation_source
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def account_aggregation_source(
        self,
    ) -> typing.Optional[
        typing.List["ConfigConfigurationAggregatorAccountAggregationSource"]
    ]:
        """account_aggregation_source block."""
        return self._values.get("account_aggregation_source")

    @builtins.property
    def organization_aggregation_source(
        self,
    ) -> typing.Optional[
        typing.List["ConfigConfigurationAggregatorOrganizationAggregationSource"]
    ]:
        """organization_aggregation_source block."""
        return self._values.get("organization_aggregation_source")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigurationAggregatorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationAggregatorOrganizationAggregationSource",
    jsii_struct_bases=[],
    name_mapping={
        "role_arn": "roleArn",
        "all_regions": "allRegions",
        "regions": "regions",
    },
)
class ConfigConfigurationAggregatorOrganizationAggregationSource:
    def __init__(
        self,
        *,
        role_arn: str,
        all_regions: typing.Optional[bool] = None,
        regions: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param role_arn: 
        :param all_regions: 
        :param regions: 
        """
        self._values = {
            "role_arn": role_arn,
        }
        if all_regions is not None:
            self._values["all_regions"] = all_regions
        if regions is not None:
            self._values["regions"] = regions

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def all_regions(self) -> typing.Optional[bool]:
        return self._values.get("all_regions")

    @builtins.property
    def regions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("regions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "ConfigConfigurationAggregatorOrganizationAggregationSource(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class ConfigConfigurationRecorder(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationRecorder",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        role_arn: str,
        name: typing.Optional[str] = None,
        recording_group: typing.Optional[
            typing.List["ConfigConfigurationRecorderRecordingGroup"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param role_arn: 
        :param name: 
        :param recording_group: recording_group block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigConfigurationRecorderConfig(
            role_arn=role_arn,
            name=name,
            recording_group=recording_group,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigConfigurationRecorder, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="recordingGroup")
    def recording_group(
        self,
    ) -> typing.Optional[typing.List["ConfigConfigurationRecorderRecordingGroup"]]:
        return jsii.get(self, "recordingGroup")

    @recording_group.setter
    def recording_group(
        self,
        value: typing.Optional[
            typing.List["ConfigConfigurationRecorderRecordingGroup"]
        ],
    ) -> None:
        jsii.set(self, "recordingGroup", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationRecorderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "role_arn": "roleArn",
        "name": "name",
        "recording_group": "recordingGroup",
    },
)
class ConfigConfigurationRecorderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        role_arn: str,
        name: typing.Optional[str] = None,
        recording_group: typing.Optional[
            typing.List["ConfigConfigurationRecorderRecordingGroup"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param role_arn: 
        :param name: 
        :param recording_group: recording_group block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if recording_group is not None:
            self._values["recording_group"] = recording_group

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def recording_group(
        self,
    ) -> typing.Optional[typing.List["ConfigConfigurationRecorderRecordingGroup"]]:
        """recording_group block."""
        return self._values.get("recording_group")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigurationRecorderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationRecorderRecordingGroup",
    jsii_struct_bases=[],
    name_mapping={
        "all_supported": "allSupported",
        "include_global_resource_types": "includeGlobalResourceTypes",
        "resource_types": "resourceTypes",
    },
)
class ConfigConfigurationRecorderRecordingGroup:
    def __init__(
        self,
        *,
        all_supported: typing.Optional[bool] = None,
        include_global_resource_types: typing.Optional[bool] = None,
        resource_types: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param all_supported: 
        :param include_global_resource_types: 
        :param resource_types: 
        """
        self._values = {}
        if all_supported is not None:
            self._values["all_supported"] = all_supported
        if include_global_resource_types is not None:
            self._values[
                "include_global_resource_types"
            ] = include_global_resource_types
        if resource_types is not None:
            self._values["resource_types"] = resource_types

    @builtins.property
    def all_supported(self) -> typing.Optional[bool]:
        return self._values.get("all_supported")

    @builtins.property
    def include_global_resource_types(self) -> typing.Optional[bool]:
        return self._values.get("include_global_resource_types")

    @builtins.property
    def resource_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("resource_types")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigurationRecorderRecordingGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ConfigConfigurationRecorderStatus(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationRecorderStatus",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        is_enabled: bool,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param is_enabled: 
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigConfigurationRecorderStatusConfig(
            is_enabled=is_enabled,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigConfigurationRecorderStatus, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="isEnabled")
    def is_enabled(self) -> bool:
        return jsii.get(self, "isEnabled")

    @is_enabled.setter
    def is_enabled(self, value: bool) -> None:
        jsii.set(self, "isEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigConfigurationRecorderStatusConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "is_enabled": "isEnabled",
        "name": "name",
    },
)
class ConfigConfigurationRecorderStatusConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        is_enabled: bool,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param is_enabled: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "is_enabled": is_enabled,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def is_enabled(self) -> bool:
        return self._values.get("is_enabled")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigConfigurationRecorderStatusConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ConfigDeliveryChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigDeliveryChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        s3_bucket_name: str,
        name: typing.Optional[str] = None,
        s3_key_prefix: typing.Optional[str] = None,
        snapshot_delivery_properties: typing.Optional[
            typing.List["ConfigDeliveryChannelSnapshotDeliveryProperties"]
        ] = None,
        sns_topic_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param s3_bucket_name: 
        :param name: 
        :param s3_key_prefix: 
        :param snapshot_delivery_properties: snapshot_delivery_properties block.
        :param sns_topic_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigDeliveryChannelConfig(
            s3_bucket_name=s3_bucket_name,
            name=name,
            s3_key_prefix=s3_key_prefix,
            snapshot_delivery_properties=snapshot_delivery_properties,
            sns_topic_arn=sns_topic_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigDeliveryChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="s3BucketName")
    def s3_bucket_name(self) -> str:
        return jsii.get(self, "s3BucketName")

    @s3_bucket_name.setter
    def s3_bucket_name(self, value: str) -> None:
        jsii.set(self, "s3BucketName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="s3KeyPrefix")
    def s3_key_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "s3KeyPrefix")

    @s3_key_prefix.setter
    def s3_key_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3KeyPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotDeliveryProperties")
    def snapshot_delivery_properties(
        self,
    ) -> typing.Optional[
        typing.List["ConfigDeliveryChannelSnapshotDeliveryProperties"]
    ]:
        return jsii.get(self, "snapshotDeliveryProperties")

    @snapshot_delivery_properties.setter
    def snapshot_delivery_properties(
        self,
        value: typing.Optional[
            typing.List["ConfigDeliveryChannelSnapshotDeliveryProperties"]
        ],
    ) -> None:
        jsii.set(self, "snapshotDeliveryProperties", value)

    @builtins.property
    @jsii.member(jsii_name="snsTopicArn")
    def sns_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "snsTopicArn")

    @sns_topic_arn.setter
    def sns_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snsTopicArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigDeliveryChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "s3_bucket_name": "s3BucketName",
        "name": "name",
        "s3_key_prefix": "s3KeyPrefix",
        "snapshot_delivery_properties": "snapshotDeliveryProperties",
        "sns_topic_arn": "snsTopicArn",
    },
)
class ConfigDeliveryChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        s3_bucket_name: str,
        name: typing.Optional[str] = None,
        s3_key_prefix: typing.Optional[str] = None,
        snapshot_delivery_properties: typing.Optional[
            typing.List["ConfigDeliveryChannelSnapshotDeliveryProperties"]
        ] = None,
        sns_topic_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param s3_bucket_name: 
        :param name: 
        :param s3_key_prefix: 
        :param snapshot_delivery_properties: snapshot_delivery_properties block.
        :param sns_topic_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "s3_bucket_name": s3_bucket_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if s3_key_prefix is not None:
            self._values["s3_key_prefix"] = s3_key_prefix
        if snapshot_delivery_properties is not None:
            self._values["snapshot_delivery_properties"] = snapshot_delivery_properties
        if sns_topic_arn is not None:
            self._values["sns_topic_arn"] = sns_topic_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def s3_bucket_name(self) -> str:
        return self._values.get("s3_bucket_name")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def s3_key_prefix(self) -> typing.Optional[str]:
        return self._values.get("s3_key_prefix")

    @builtins.property
    def snapshot_delivery_properties(
        self,
    ) -> typing.Optional[
        typing.List["ConfigDeliveryChannelSnapshotDeliveryProperties"]
    ]:
        """snapshot_delivery_properties block."""
        return self._values.get("snapshot_delivery_properties")

    @builtins.property
    def sns_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("sns_topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigDeliveryChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigDeliveryChannelSnapshotDeliveryProperties",
    jsii_struct_bases=[],
    name_mapping={"delivery_frequency": "deliveryFrequency"},
)
class ConfigDeliveryChannelSnapshotDeliveryProperties:
    def __init__(self, *, delivery_frequency: typing.Optional[str] = None) -> None:
        """
        :param delivery_frequency: 
        """
        self._values = {}
        if delivery_frequency is not None:
            self._values["delivery_frequency"] = delivery_frequency

    @builtins.property
    def delivery_frequency(self) -> typing.Optional[str]:
        return self._values.get("delivery_frequency")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigDeliveryChannelSnapshotDeliveryProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ConfigOrganizationCustomRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigOrganizationCustomRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        lambda_function_arn: str,
        name: str,
        trigger_types: typing.List[str],
        description: typing.Optional[str] = None,
        excluded_accounts: typing.Optional[typing.List[str]] = None,
        input_parameters: typing.Optional[str] = None,
        maximum_execution_frequency: typing.Optional[str] = None,
        resource_id_scope: typing.Optional[str] = None,
        resource_types_scope: typing.Optional[typing.List[str]] = None,
        tag_key_scope: typing.Optional[str] = None,
        tag_value_scope: typing.Optional[str] = None,
        timeouts: typing.Optional["ConfigOrganizationCustomRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param lambda_function_arn: 
        :param name: 
        :param trigger_types: 
        :param description: 
        :param excluded_accounts: 
        :param input_parameters: 
        :param maximum_execution_frequency: 
        :param resource_id_scope: 
        :param resource_types_scope: 
        :param tag_key_scope: 
        :param tag_value_scope: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigOrganizationCustomRuleConfig(
            lambda_function_arn=lambda_function_arn,
            name=name,
            trigger_types=trigger_types,
            description=description,
            excluded_accounts=excluded_accounts,
            input_parameters=input_parameters,
            maximum_execution_frequency=maximum_execution_frequency,
            resource_id_scope=resource_id_scope,
            resource_types_scope=resource_types_scope,
            tag_key_scope=tag_key_scope,
            tag_value_scope=tag_value_scope,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigOrganizationCustomRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="lambdaFunctionArn")
    def lambda_function_arn(self) -> str:
        return jsii.get(self, "lambdaFunctionArn")

    @lambda_function_arn.setter
    def lambda_function_arn(self, value: str) -> None:
        jsii.set(self, "lambdaFunctionArn", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="triggerTypes")
    def trigger_types(self) -> typing.List[str]:
        return jsii.get(self, "triggerTypes")

    @trigger_types.setter
    def trigger_types(self, value: typing.List[str]) -> None:
        jsii.set(self, "triggerTypes", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="excludedAccounts")
    def excluded_accounts(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "excludedAccounts")

    @excluded_accounts.setter
    def excluded_accounts(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "excludedAccounts", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="inputParameters")
    def input_parameters(self) -> typing.Optional[str]:
        return jsii.get(self, "inputParameters")

    @input_parameters.setter
    def input_parameters(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "inputParameters", value)

    @builtins.property
    @jsii.member(jsii_name="maximumExecutionFrequency")
    def maximum_execution_frequency(self) -> typing.Optional[str]:
        return jsii.get(self, "maximumExecutionFrequency")

    @maximum_execution_frequency.setter
    def maximum_execution_frequency(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maximumExecutionFrequency", value)

    @builtins.property
    @jsii.member(jsii_name="resourceIdScope")
    def resource_id_scope(self) -> typing.Optional[str]:
        return jsii.get(self, "resourceIdScope")

    @resource_id_scope.setter
    def resource_id_scope(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resourceIdScope", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypesScope")
    def resource_types_scope(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "resourceTypesScope")

    @resource_types_scope.setter
    def resource_types_scope(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "resourceTypesScope", value)

    @builtins.property
    @jsii.member(jsii_name="tagKeyScope")
    def tag_key_scope(self) -> typing.Optional[str]:
        return jsii.get(self, "tagKeyScope")

    @tag_key_scope.setter
    def tag_key_scope(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tagKeyScope", value)

    @builtins.property
    @jsii.member(jsii_name="tagValueScope")
    def tag_value_scope(self) -> typing.Optional[str]:
        return jsii.get(self, "tagValueScope")

    @tag_value_scope.setter
    def tag_value_scope(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tagValueScope", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ConfigOrganizationCustomRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["ConfigOrganizationCustomRuleTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigOrganizationCustomRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "lambda_function_arn": "lambdaFunctionArn",
        "name": "name",
        "trigger_types": "triggerTypes",
        "description": "description",
        "excluded_accounts": "excludedAccounts",
        "input_parameters": "inputParameters",
        "maximum_execution_frequency": "maximumExecutionFrequency",
        "resource_id_scope": "resourceIdScope",
        "resource_types_scope": "resourceTypesScope",
        "tag_key_scope": "tagKeyScope",
        "tag_value_scope": "tagValueScope",
        "timeouts": "timeouts",
    },
)
class ConfigOrganizationCustomRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        lambda_function_arn: str,
        name: str,
        trigger_types: typing.List[str],
        description: typing.Optional[str] = None,
        excluded_accounts: typing.Optional[typing.List[str]] = None,
        input_parameters: typing.Optional[str] = None,
        maximum_execution_frequency: typing.Optional[str] = None,
        resource_id_scope: typing.Optional[str] = None,
        resource_types_scope: typing.Optional[typing.List[str]] = None,
        tag_key_scope: typing.Optional[str] = None,
        tag_value_scope: typing.Optional[str] = None,
        timeouts: typing.Optional["ConfigOrganizationCustomRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param lambda_function_arn: 
        :param name: 
        :param trigger_types: 
        :param description: 
        :param excluded_accounts: 
        :param input_parameters: 
        :param maximum_execution_frequency: 
        :param resource_id_scope: 
        :param resource_types_scope: 
        :param tag_key_scope: 
        :param tag_value_scope: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ConfigOrganizationCustomRuleTimeouts(**timeouts)
        self._values = {
            "lambda_function_arn": lambda_function_arn,
            "name": name,
            "trigger_types": trigger_types,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if excluded_accounts is not None:
            self._values["excluded_accounts"] = excluded_accounts
        if input_parameters is not None:
            self._values["input_parameters"] = input_parameters
        if maximum_execution_frequency is not None:
            self._values["maximum_execution_frequency"] = maximum_execution_frequency
        if resource_id_scope is not None:
            self._values["resource_id_scope"] = resource_id_scope
        if resource_types_scope is not None:
            self._values["resource_types_scope"] = resource_types_scope
        if tag_key_scope is not None:
            self._values["tag_key_scope"] = tag_key_scope
        if tag_value_scope is not None:
            self._values["tag_value_scope"] = tag_value_scope
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def lambda_function_arn(self) -> str:
        return self._values.get("lambda_function_arn")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def trigger_types(self) -> typing.List[str]:
        return self._values.get("trigger_types")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def excluded_accounts(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("excluded_accounts")

    @builtins.property
    def input_parameters(self) -> typing.Optional[str]:
        return self._values.get("input_parameters")

    @builtins.property
    def maximum_execution_frequency(self) -> typing.Optional[str]:
        return self._values.get("maximum_execution_frequency")

    @builtins.property
    def resource_id_scope(self) -> typing.Optional[str]:
        return self._values.get("resource_id_scope")

    @builtins.property
    def resource_types_scope(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("resource_types_scope")

    @builtins.property
    def tag_key_scope(self) -> typing.Optional[str]:
        return self._values.get("tag_key_scope")

    @builtins.property
    def tag_value_scope(self) -> typing.Optional[str]:
        return self._values.get("tag_value_scope")

    @builtins.property
    def timeouts(self) -> typing.Optional["ConfigOrganizationCustomRuleTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigOrganizationCustomRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigOrganizationCustomRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ConfigOrganizationCustomRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigOrganizationCustomRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ConfigOrganizationManagedRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigOrganizationManagedRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        rule_identifier: str,
        description: typing.Optional[str] = None,
        excluded_accounts: typing.Optional[typing.List[str]] = None,
        input_parameters: typing.Optional[str] = None,
        maximum_execution_frequency: typing.Optional[str] = None,
        resource_id_scope: typing.Optional[str] = None,
        resource_types_scope: typing.Optional[typing.List[str]] = None,
        tag_key_scope: typing.Optional[str] = None,
        tag_value_scope: typing.Optional[str] = None,
        timeouts: typing.Optional["ConfigOrganizationManagedRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param rule_identifier: 
        :param description: 
        :param excluded_accounts: 
        :param input_parameters: 
        :param maximum_execution_frequency: 
        :param resource_id_scope: 
        :param resource_types_scope: 
        :param tag_key_scope: 
        :param tag_value_scope: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ConfigOrganizationManagedRuleConfig(
            name=name,
            rule_identifier=rule_identifier,
            description=description,
            excluded_accounts=excluded_accounts,
            input_parameters=input_parameters,
            maximum_execution_frequency=maximum_execution_frequency,
            resource_id_scope=resource_id_scope,
            resource_types_scope=resource_types_scope,
            tag_key_scope=tag_key_scope,
            tag_value_scope=tag_value_scope,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ConfigOrganizationManagedRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="ruleIdentifier")
    def rule_identifier(self) -> str:
        return jsii.get(self, "ruleIdentifier")

    @rule_identifier.setter
    def rule_identifier(self, value: str) -> None:
        jsii.set(self, "ruleIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="excludedAccounts")
    def excluded_accounts(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "excludedAccounts")

    @excluded_accounts.setter
    def excluded_accounts(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "excludedAccounts", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="inputParameters")
    def input_parameters(self) -> typing.Optional[str]:
        return jsii.get(self, "inputParameters")

    @input_parameters.setter
    def input_parameters(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "inputParameters", value)

    @builtins.property
    @jsii.member(jsii_name="maximumExecutionFrequency")
    def maximum_execution_frequency(self) -> typing.Optional[str]:
        return jsii.get(self, "maximumExecutionFrequency")

    @maximum_execution_frequency.setter
    def maximum_execution_frequency(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maximumExecutionFrequency", value)

    @builtins.property
    @jsii.member(jsii_name="resourceIdScope")
    def resource_id_scope(self) -> typing.Optional[str]:
        return jsii.get(self, "resourceIdScope")

    @resource_id_scope.setter
    def resource_id_scope(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resourceIdScope", value)

    @builtins.property
    @jsii.member(jsii_name="resourceTypesScope")
    def resource_types_scope(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "resourceTypesScope")

    @resource_types_scope.setter
    def resource_types_scope(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "resourceTypesScope", value)

    @builtins.property
    @jsii.member(jsii_name="tagKeyScope")
    def tag_key_scope(self) -> typing.Optional[str]:
        return jsii.get(self, "tagKeyScope")

    @tag_key_scope.setter
    def tag_key_scope(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tagKeyScope", value)

    @builtins.property
    @jsii.member(jsii_name="tagValueScope")
    def tag_value_scope(self) -> typing.Optional[str]:
        return jsii.get(self, "tagValueScope")

    @tag_value_scope.setter
    def tag_value_scope(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tagValueScope", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ConfigOrganizationManagedRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["ConfigOrganizationManagedRuleTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigOrganizationManagedRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "rule_identifier": "ruleIdentifier",
        "description": "description",
        "excluded_accounts": "excludedAccounts",
        "input_parameters": "inputParameters",
        "maximum_execution_frequency": "maximumExecutionFrequency",
        "resource_id_scope": "resourceIdScope",
        "resource_types_scope": "resourceTypesScope",
        "tag_key_scope": "tagKeyScope",
        "tag_value_scope": "tagValueScope",
        "timeouts": "timeouts",
    },
)
class ConfigOrganizationManagedRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        rule_identifier: str,
        description: typing.Optional[str] = None,
        excluded_accounts: typing.Optional[typing.List[str]] = None,
        input_parameters: typing.Optional[str] = None,
        maximum_execution_frequency: typing.Optional[str] = None,
        resource_id_scope: typing.Optional[str] = None,
        resource_types_scope: typing.Optional[typing.List[str]] = None,
        tag_key_scope: typing.Optional[str] = None,
        tag_value_scope: typing.Optional[str] = None,
        timeouts: typing.Optional["ConfigOrganizationManagedRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param rule_identifier: 
        :param description: 
        :param excluded_accounts: 
        :param input_parameters: 
        :param maximum_execution_frequency: 
        :param resource_id_scope: 
        :param resource_types_scope: 
        :param tag_key_scope: 
        :param tag_value_scope: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ConfigOrganizationManagedRuleTimeouts(**timeouts)
        self._values = {
            "name": name,
            "rule_identifier": rule_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if excluded_accounts is not None:
            self._values["excluded_accounts"] = excluded_accounts
        if input_parameters is not None:
            self._values["input_parameters"] = input_parameters
        if maximum_execution_frequency is not None:
            self._values["maximum_execution_frequency"] = maximum_execution_frequency
        if resource_id_scope is not None:
            self._values["resource_id_scope"] = resource_id_scope
        if resource_types_scope is not None:
            self._values["resource_types_scope"] = resource_types_scope
        if tag_key_scope is not None:
            self._values["tag_key_scope"] = tag_key_scope
        if tag_value_scope is not None:
            self._values["tag_value_scope"] = tag_value_scope
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rule_identifier(self) -> str:
        return self._values.get("rule_identifier")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def excluded_accounts(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("excluded_accounts")

    @builtins.property
    def input_parameters(self) -> typing.Optional[str]:
        return self._values.get("input_parameters")

    @builtins.property
    def maximum_execution_frequency(self) -> typing.Optional[str]:
        return self._values.get("maximum_execution_frequency")

    @builtins.property
    def resource_id_scope(self) -> typing.Optional[str]:
        return self._values.get("resource_id_scope")

    @builtins.property
    def resource_types_scope(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("resource_types_scope")

    @builtins.property
    def tag_key_scope(self) -> typing.Optional[str]:
        return self._values.get("tag_key_scope")

    @builtins.property
    def tag_value_scope(self) -> typing.Optional[str]:
        return self._values.get("tag_value_scope")

    @builtins.property
    def timeouts(self) -> typing.Optional["ConfigOrganizationManagedRuleTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigOrganizationManagedRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ConfigOrganizationManagedRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ConfigOrganizationManagedRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ConfigOrganizationManagedRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CurReportDefinition(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CurReportDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        additional_schema_elements: typing.List[str],
        compression: str,
        format: str,
        report_name: str,
        s3_bucket: str,
        s3_region: str,
        time_unit: str,
        additional_artifacts: typing.Optional[typing.List[str]] = None,
        s3_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param additional_schema_elements: 
        :param compression: 
        :param format: 
        :param report_name: 
        :param s3_bucket: 
        :param s3_region: 
        :param time_unit: 
        :param additional_artifacts: 
        :param s3_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CurReportDefinitionConfig(
            additional_schema_elements=additional_schema_elements,
            compression=compression,
            format=format,
            report_name=report_name,
            s3_bucket=s3_bucket,
            s3_region=s3_region,
            time_unit=time_unit,
            additional_artifacts=additional_artifacts,
            s3_prefix=s3_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CurReportDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="additionalSchemaElements")
    def additional_schema_elements(self) -> typing.List[str]:
        return jsii.get(self, "additionalSchemaElements")

    @additional_schema_elements.setter
    def additional_schema_elements(self, value: typing.List[str]) -> None:
        jsii.set(self, "additionalSchemaElements", value)

    @builtins.property
    @jsii.member(jsii_name="compression")
    def compression(self) -> str:
        return jsii.get(self, "compression")

    @compression.setter
    def compression(self, value: str) -> None:
        jsii.set(self, "compression", value)

    @builtins.property
    @jsii.member(jsii_name="format")
    def format(self) -> str:
        return jsii.get(self, "format")

    @format.setter
    def format(self, value: str) -> None:
        jsii.set(self, "format", value)

    @builtins.property
    @jsii.member(jsii_name="reportName")
    def report_name(self) -> str:
        return jsii.get(self, "reportName")

    @report_name.setter
    def report_name(self, value: str) -> None:
        jsii.set(self, "reportName", value)

    @builtins.property
    @jsii.member(jsii_name="s3Bucket")
    def s3_bucket(self) -> str:
        return jsii.get(self, "s3Bucket")

    @s3_bucket.setter
    def s3_bucket(self, value: str) -> None:
        jsii.set(self, "s3Bucket", value)

    @builtins.property
    @jsii.member(jsii_name="s3Region")
    def s3_region(self) -> str:
        return jsii.get(self, "s3Region")

    @s3_region.setter
    def s3_region(self, value: str) -> None:
        jsii.set(self, "s3Region", value)

    @builtins.property
    @jsii.member(jsii_name="timeUnit")
    def time_unit(self) -> str:
        return jsii.get(self, "timeUnit")

    @time_unit.setter
    def time_unit(self, value: str) -> None:
        jsii.set(self, "timeUnit", value)

    @builtins.property
    @jsii.member(jsii_name="additionalArtifacts")
    def additional_artifacts(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "additionalArtifacts")

    @additional_artifacts.setter
    def additional_artifacts(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "additionalArtifacts", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="s3Prefix")
    def s3_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "s3Prefix")

    @s3_prefix.setter
    def s3_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3Prefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CurReportDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "additional_schema_elements": "additionalSchemaElements",
        "compression": "compression",
        "format": "format",
        "report_name": "reportName",
        "s3_bucket": "s3Bucket",
        "s3_region": "s3Region",
        "time_unit": "timeUnit",
        "additional_artifacts": "additionalArtifacts",
        "s3_prefix": "s3Prefix",
    },
)
class CurReportDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        additional_schema_elements: typing.List[str],
        compression: str,
        format: str,
        report_name: str,
        s3_bucket: str,
        s3_region: str,
        time_unit: str,
        additional_artifacts: typing.Optional[typing.List[str]] = None,
        s3_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param additional_schema_elements: 
        :param compression: 
        :param format: 
        :param report_name: 
        :param s3_bucket: 
        :param s3_region: 
        :param time_unit: 
        :param additional_artifacts: 
        :param s3_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "additional_schema_elements": additional_schema_elements,
            "compression": compression,
            "format": format,
            "report_name": report_name,
            "s3_bucket": s3_bucket,
            "s3_region": s3_region,
            "time_unit": time_unit,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_artifacts is not None:
            self._values["additional_artifacts"] = additional_artifacts
        if s3_prefix is not None:
            self._values["s3_prefix"] = s3_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def additional_schema_elements(self) -> typing.List[str]:
        return self._values.get("additional_schema_elements")

    @builtins.property
    def compression(self) -> str:
        return self._values.get("compression")

    @builtins.property
    def format(self) -> str:
        return self._values.get("format")

    @builtins.property
    def report_name(self) -> str:
        return self._values.get("report_name")

    @builtins.property
    def s3_bucket(self) -> str:
        return self._values.get("s3_bucket")

    @builtins.property
    def s3_region(self) -> str:
        return self._values.get("s3_region")

    @builtins.property
    def time_unit(self) -> str:
        return self._values.get("time_unit")

    @builtins.property
    def additional_artifacts(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("additional_artifacts")

    @builtins.property
    def s3_prefix(self) -> typing.Optional[str]:
        return self._values.get("s3_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CurReportDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class CustomerGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.CustomerGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bgp_asn: str,
        ip_address: str,
        type: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bgp_asn: 
        :param ip_address: 
        :param type: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = CustomerGatewayConfig(
            bgp_asn=bgp_asn,
            ip_address=ip_address,
            type=type,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(CustomerGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> str:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: str) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")

    @ip_address.setter
    def ip_address(self, value: str) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.CustomerGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bgp_asn": "bgpAsn",
        "ip_address": "ipAddress",
        "type": "type",
        "tags": "tags",
    },
)
class CustomerGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bgp_asn: str,
        ip_address: str,
        type: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bgp_asn: 
        :param ip_address: 
        :param type: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bgp_asn": bgp_asn,
            "ip_address": ip_address,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bgp_asn(self) -> str:
        return self._values.get("bgp_asn")

    @builtins.property
    def ip_address(self) -> str:
        return self._values.get("ip_address")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "CustomerGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAcmCertificate(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAcmCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain: str,
        key_types: typing.Optional[typing.List[str]] = None,
        most_recent: typing.Optional[bool] = None,
        statuses: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        types: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain: 
        :param key_types: 
        :param most_recent: 
        :param statuses: 
        :param tags: 
        :param types: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAcmCertificateConfig(
            domain=domain,
            key_types=key_types,
            most_recent=most_recent,
            statuses=statuses,
            tags=tags,
            types=types,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAcmCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: str) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="keyTypes")
    def key_types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "keyTypes")

    @key_types.setter
    def key_types(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "keyTypes", value)

    @builtins.property
    @jsii.member(jsii_name="mostRecent")
    def most_recent(self) -> typing.Optional[bool]:
        return jsii.get(self, "mostRecent")

    @most_recent.setter
    def most_recent(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mostRecent", value)

    @builtins.property
    @jsii.member(jsii_name="statuses")
    def statuses(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "statuses")

    @statuses.setter
    def statuses(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "statuses", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="types")
    def types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "types")

    @types.setter
    def types(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "types", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAcmCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain": "domain",
        "key_types": "keyTypes",
        "most_recent": "mostRecent",
        "statuses": "statuses",
        "tags": "tags",
        "types": "types",
    },
)
class DataAwsAcmCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain: str,
        key_types: typing.Optional[typing.List[str]] = None,
        most_recent: typing.Optional[bool] = None,
        statuses: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        types: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain: 
        :param key_types: 
        :param most_recent: 
        :param statuses: 
        :param tags: 
        :param types: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain": domain,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if key_types is not None:
            self._values["key_types"] = key_types
        if most_recent is not None:
            self._values["most_recent"] = most_recent
        if statuses is not None:
            self._values["statuses"] = statuses
        if tags is not None:
            self._values["tags"] = tags
        if types is not None:
            self._values["types"] = types

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain(self) -> str:
        return self._values.get("domain")

    @builtins.property
    def key_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("key_types")

    @builtins.property
    def most_recent(self) -> typing.Optional[bool]:
        return self._values.get("most_recent")

    @builtins.property
    def statuses(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("statuses")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("types")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAcmCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAcmpcaCertificateAuthority(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAcmpcaCertificateAuthority",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        arn: str,
        revocation_configuration: typing.Optional[
            typing.List["DataAwsAcmpcaCertificateAuthorityRevocationConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param arn: 
        :param revocation_configuration: revocation_configuration block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAcmpcaCertificateAuthorityConfig(
            arn=arn,
            revocation_configuration=revocation_configuration,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAcmpcaCertificateAuthority, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> str:
        return jsii.get(self, "certificate")

    @builtins.property
    @jsii.member(jsii_name="certificateChain")
    def certificate_chain(self) -> str:
        return jsii.get(self, "certificateChain")

    @builtins.property
    @jsii.member(jsii_name="certificateSigningRequest")
    def certificate_signing_request(self) -> str:
        return jsii.get(self, "certificateSigningRequest")

    @builtins.property
    @jsii.member(jsii_name="notAfter")
    def not_after(self) -> str:
        return jsii.get(self, "notAfter")

    @builtins.property
    @jsii.member(jsii_name="notBefore")
    def not_before(self) -> str:
        return jsii.get(self, "notBefore")

    @builtins.property
    @jsii.member(jsii_name="serial")
    def serial(self) -> str:
        return jsii.get(self, "serial")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: str) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="revocationConfiguration")
    def revocation_configuration(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsAcmpcaCertificateAuthorityRevocationConfiguration"]
    ]:
        return jsii.get(self, "revocationConfiguration")

    @revocation_configuration.setter
    def revocation_configuration(
        self,
        value: typing.Optional[
            typing.List["DataAwsAcmpcaCertificateAuthorityRevocationConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "revocationConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAcmpcaCertificateAuthorityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "arn": "arn",
        "revocation_configuration": "revocationConfiguration",
        "tags": "tags",
    },
)
class DataAwsAcmpcaCertificateAuthorityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        arn: str,
        revocation_configuration: typing.Optional[
            typing.List["DataAwsAcmpcaCertificateAuthorityRevocationConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param arn: 
        :param revocation_configuration: revocation_configuration block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "arn": arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if revocation_configuration is not None:
            self._values["revocation_configuration"] = revocation_configuration
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def revocation_configuration(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsAcmpcaCertificateAuthorityRevocationConfiguration"]
    ]:
        """revocation_configuration block."""
        return self._values.get("revocation_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAcmpcaCertificateAuthorityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAcmpcaCertificateAuthorityRevocationConfiguration",
    jsii_struct_bases=[],
    name_mapping={"crl_configuration": "crlConfiguration"},
)
class DataAwsAcmpcaCertificateAuthorityRevocationConfiguration:
    def __init__(
        self,
        *,
        crl_configuration: typing.Optional[
            typing.List[
                "DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration"
            ]
        ] = None,
    ) -> None:
        """
        :param crl_configuration: crl_configuration block.
        """
        self._values = {}
        if crl_configuration is not None:
            self._values["crl_configuration"] = crl_configuration

    @builtins.property
    def crl_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration"
        ]
    ]:
        """crl_configuration block."""
        return self._values.get("crl_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "DataAwsAcmpcaCertificateAuthorityRevocationConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class DataAwsAlb(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAlbConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAlb, self, [scope, id, config])

    @jsii.member(jsii_name="accessLogs")
    def access_logs(self, index: str) -> "DataAwsAlbAccessLogs":
        """
        :param index: -
        """
        return jsii.invoke(self, "accessLogs", [index])

    @jsii.member(jsii_name="subnetMapping")
    def subnet_mapping(self, index: str) -> "DataAwsAlbSubnetMapping":
        """
        :param index: -
        """
        return jsii.invoke(self, "subnetMapping", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="dropInvalidHeaderFields")
    def drop_invalid_header_fields(self) -> bool:
        return jsii.get(self, "dropInvalidHeaderFields")

    @builtins.property
    @jsii.member(jsii_name="enableDeletionProtection")
    def enable_deletion_protection(self) -> bool:
        return jsii.get(self, "enableDeletionProtection")

    @builtins.property
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> jsii.Number:
        return jsii.get(self, "idleTimeout")

    @builtins.property
    @jsii.member(jsii_name="internal")
    def internal(self) -> bool:
        return jsii.get(self, "internal")

    @builtins.property
    @jsii.member(jsii_name="ipAddressType")
    def ip_address_type(self) -> str:
        return jsii.get(self, "ipAddressType")

    @builtins.property
    @jsii.member(jsii_name="loadBalancerType")
    def load_balancer_type(self) -> str:
        return jsii.get(self, "loadBalancerType")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.List[str]:
        return jsii.get(self, "subnets")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsAlbAccessLogs(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbAccessLogs",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbAccessLogs, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> str:
        return jsii.get(self, "prefix")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsAlbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAlbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAlbListener(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbListener",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        load_balancer_arn: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param load_balancer_arn: 
        :param port: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAlbListenerConfig(
            load_balancer_arn=load_balancer_arn,
            port=port,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAlbListener, self, [scope, id, config])

    @jsii.member(jsii_name="defaultAction")
    def default_action(self, index: str) -> "DataAwsAlbListenerDefaultAction":
        """
        :param index: -
        """
        return jsii.invoke(self, "defaultAction", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> str:
        return jsii.get(self, "certificateArn")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="sslPolicy")
    def ssl_policy(self) -> str:
        return jsii.get(self, "sslPolicy")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerArn")
    def load_balancer_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "loadBalancerArn")

    @load_balancer_arn.setter
    def load_balancer_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "loadBalancerArn", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbListenerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "load_balancer_arn": "loadBalancerArn",
        "port": "port",
    },
)
class DataAwsAlbListenerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        load_balancer_arn: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param load_balancer_arn: 
        :param port: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if load_balancer_arn is not None:
            self._values["load_balancer_arn"] = load_balancer_arn
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def load_balancer_arn(self) -> typing.Optional[str]:
        return self._values.get("load_balancer_arn")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAlbListenerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAlbListenerDefaultAction(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbListenerDefaultAction",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbListenerDefaultAction,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="authenticateCognito")
    def authenticate_cognito(self) -> typing.Any:
        return jsii.get(self, "authenticateCognito")

    @builtins.property
    @jsii.member(jsii_name="authenticateOidc")
    def authenticate_oidc(self) -> typing.Any:
        return jsii.get(self, "authenticateOidc")

    @builtins.property
    @jsii.member(jsii_name="fixedResponse")
    def fixed_response(self) -> typing.Any:
        return jsii.get(self, "fixedResponse")

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> jsii.Number:
        return jsii.get(self, "order")

    @builtins.property
    @jsii.member(jsii_name="redirect")
    def redirect(self) -> typing.Any:
        return jsii.get(self, "redirect")

    @builtins.property
    @jsii.member(jsii_name="targetGroupArn")
    def target_group_arn(self) -> str:
        return jsii.get(self, "targetGroupArn")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


class DataAwsAlbListenerDefaultActionAuthenticateCognito(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbListenerDefaultActionAuthenticateCognito",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbListenerDefaultActionAuthenticateCognito,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="authenticationRequestExtraParams")
    def authentication_request_extra_params(self) -> typing.Any:
        return jsii.get(self, "authenticationRequestExtraParams")

    @builtins.property
    @jsii.member(jsii_name="onUnauthenticatedRequest")
    def on_unauthenticated_request(self) -> str:
        return jsii.get(self, "onUnauthenticatedRequest")

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @builtins.property
    @jsii.member(jsii_name="sessionCookieName")
    def session_cookie_name(self) -> str:
        return jsii.get(self, "sessionCookieName")

    @builtins.property
    @jsii.member(jsii_name="sessionTimeout")
    def session_timeout(self) -> jsii.Number:
        return jsii.get(self, "sessionTimeout")

    @builtins.property
    @jsii.member(jsii_name="userPoolArn")
    def user_pool_arn(self) -> str:
        return jsii.get(self, "userPoolArn")

    @builtins.property
    @jsii.member(jsii_name="userPoolClientId")
    def user_pool_client_id(self) -> str:
        return jsii.get(self, "userPoolClientId")

    @builtins.property
    @jsii.member(jsii_name="userPoolDomain")
    def user_pool_domain(self) -> str:
        return jsii.get(self, "userPoolDomain")


class DataAwsAlbListenerDefaultActionAuthenticateOidc(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbListenerDefaultActionAuthenticateOidc",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbListenerDefaultActionAuthenticateOidc,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="authenticationRequestExtraParams")
    def authentication_request_extra_params(self) -> typing.Any:
        return jsii.get(self, "authenticationRequestExtraParams")

    @builtins.property
    @jsii.member(jsii_name="authorizationEndpoint")
    def authorization_endpoint(self) -> str:
        return jsii.get(self, "authorizationEndpoint")

    @builtins.property
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> str:
        return jsii.get(self, "clientId")

    @builtins.property
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> str:
        return jsii.get(self, "clientSecret")

    @builtins.property
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> str:
        return jsii.get(self, "issuer")

    @builtins.property
    @jsii.member(jsii_name="onUnauthenticatedRequest")
    def on_unauthenticated_request(self) -> str:
        return jsii.get(self, "onUnauthenticatedRequest")

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @builtins.property
    @jsii.member(jsii_name="sessionCookieName")
    def session_cookie_name(self) -> str:
        return jsii.get(self, "sessionCookieName")

    @builtins.property
    @jsii.member(jsii_name="sessionTimeout")
    def session_timeout(self) -> jsii.Number:
        return jsii.get(self, "sessionTimeout")

    @builtins.property
    @jsii.member(jsii_name="tokenEndpoint")
    def token_endpoint(self) -> str:
        return jsii.get(self, "tokenEndpoint")

    @builtins.property
    @jsii.member(jsii_name="userInfoEndpoint")
    def user_info_endpoint(self) -> str:
        return jsii.get(self, "userInfoEndpoint")


class DataAwsAlbListenerDefaultActionFixedResponse(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbListenerDefaultActionFixedResponse",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbListenerDefaultActionFixedResponse,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> str:
        return jsii.get(self, "contentType")

    @builtins.property
    @jsii.member(jsii_name="messageBody")
    def message_body(self) -> str:
        return jsii.get(self, "messageBody")

    @builtins.property
    @jsii.member(jsii_name="statusCode")
    def status_code(self) -> str:
        return jsii.get(self, "statusCode")


class DataAwsAlbListenerDefaultActionRedirect(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbListenerDefaultActionRedirect",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbListenerDefaultActionRedirect,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="host")
    def host(self) -> str:
        return jsii.get(self, "host")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> str:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> str:
        return jsii.get(self, "query")

    @builtins.property
    @jsii.member(jsii_name="statusCode")
    def status_code(self) -> str:
        return jsii.get(self, "statusCode")


class DataAwsAlbSubnetMapping(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbSubnetMapping",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbSubnetMapping,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="allocationId")
    def allocation_id(self) -> str:
        return jsii.get(self, "allocationId")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")


class DataAwsAlbTargetGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbTargetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAlbTargetGroupConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAlbTargetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="healthCheck")
    def health_check(self, index: str) -> "DataAwsAlbTargetGroupHealthCheck":
        """
        :param index: -
        """
        return jsii.invoke(self, "healthCheck", [index])

    @jsii.member(jsii_name="stickiness")
    def stickiness(self, index: str) -> "DataAwsAlbTargetGroupStickiness":
        """
        :param index: -
        """
        return jsii.invoke(self, "stickiness", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="deregistrationDelay")
    def deregistration_delay(self) -> jsii.Number:
        return jsii.get(self, "deregistrationDelay")

    @builtins.property
    @jsii.member(jsii_name="lambdaMultiValueHeadersEnabled")
    def lambda_multi_value_headers_enabled(self) -> bool:
        return jsii.get(self, "lambdaMultiValueHeadersEnabled")

    @builtins.property
    @jsii.member(jsii_name="loadBalancingAlgorithmType")
    def load_balancing_algorithm_type(self) -> str:
        return jsii.get(self, "loadBalancingAlgorithmType")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="proxyProtocolV2")
    def proxy_protocol_v2(self) -> bool:
        return jsii.get(self, "proxyProtocolV2")

    @builtins.property
    @jsii.member(jsii_name="slowStart")
    def slow_start(self) -> jsii.Number:
        return jsii.get(self, "slowStart")

    @builtins.property
    @jsii.member(jsii_name="targetType")
    def target_type(self) -> str:
        return jsii.get(self, "targetType")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsAlbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAlbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAlbTargetGroupHealthCheck(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbTargetGroupHealthCheck",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbTargetGroupHealthCheck,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return jsii.get(self, "healthyThreshold")

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return jsii.get(self, "interval")

    @builtins.property
    @jsii.member(jsii_name="matcher")
    def matcher(self) -> str:
        return jsii.get(self, "matcher")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> str:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return jsii.get(self, "timeout")

    @builtins.property
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return jsii.get(self, "unhealthyThreshold")


class DataAwsAlbTargetGroupStickiness(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAlbTargetGroupStickiness",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAlbTargetGroupStickiness,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="cookieDuration")
    def cookie_duration(self) -> jsii.Number:
        return jsii.get(self, "cookieDuration")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


class DataAwsAmi(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmi",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        owners: typing.List[str],
        executable_users: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[typing.List["DataAwsAmiFilter"]] = None,
        most_recent: typing.Optional[bool] = None,
        name_regex: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param owners: 
        :param executable_users: 
        :param filter: filter block.
        :param most_recent: 
        :param name_regex: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAmiConfig(
            owners=owners,
            executable_users=executable_users,
            filter=filter,
            most_recent=most_recent,
            name_regex=name_regex,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAmi, self, [scope, id, config])

    @jsii.member(jsii_name="blockDeviceMappings")
    def block_device_mappings(self, index: str) -> "DataAwsAmiBlockDeviceMappings":
        """
        :param index: -
        """
        return jsii.invoke(self, "blockDeviceMappings", [index])

    @jsii.member(jsii_name="productCodes")
    def product_codes(self, index: str) -> "DataAwsAmiProductCodes":
        """
        :param index: -
        """
        return jsii.invoke(self, "productCodes", [index])

    @jsii.member(jsii_name="stateReason")
    def state_reason(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "stateReason", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="architecture")
    def architecture(self) -> str:
        return jsii.get(self, "architecture")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="hypervisor")
    def hypervisor(self) -> str:
        return jsii.get(self, "hypervisor")

    @builtins.property
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> str:
        return jsii.get(self, "imageId")

    @builtins.property
    @jsii.member(jsii_name="imageLocation")
    def image_location(self) -> str:
        return jsii.get(self, "imageLocation")

    @builtins.property
    @jsii.member(jsii_name="imageOwnerAlias")
    def image_owner_alias(self) -> str:
        return jsii.get(self, "imageOwnerAlias")

    @builtins.property
    @jsii.member(jsii_name="imageType")
    def image_type(self) -> str:
        return jsii.get(self, "imageType")

    @builtins.property
    @jsii.member(jsii_name="kernelId")
    def kernel_id(self) -> str:
        return jsii.get(self, "kernelId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="platform")
    def platform(self) -> str:
        return jsii.get(self, "platform")

    @builtins.property
    @jsii.member(jsii_name="public")
    def public(self) -> bool:
        return jsii.get(self, "public")

    @builtins.property
    @jsii.member(jsii_name="ramdiskId")
    def ramdisk_id(self) -> str:
        return jsii.get(self, "ramdiskId")

    @builtins.property
    @jsii.member(jsii_name="rootDeviceName")
    def root_device_name(self) -> str:
        return jsii.get(self, "rootDeviceName")

    @builtins.property
    @jsii.member(jsii_name="rootDeviceType")
    def root_device_type(self) -> str:
        return jsii.get(self, "rootDeviceType")

    @builtins.property
    @jsii.member(jsii_name="rootSnapshotId")
    def root_snapshot_id(self) -> str:
        return jsii.get(self, "rootSnapshotId")

    @builtins.property
    @jsii.member(jsii_name="sriovNetSupport")
    def sriov_net_support(self) -> str:
        return jsii.get(self, "sriovNetSupport")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="virtualizationType")
    def virtualization_type(self) -> str:
        return jsii.get(self, "virtualizationType")

    @builtins.property
    @jsii.member(jsii_name="owners")
    def owners(self) -> typing.List[str]:
        return jsii.get(self, "owners")

    @owners.setter
    def owners(self, value: typing.List[str]) -> None:
        jsii.set(self, "owners", value)

    @builtins.property
    @jsii.member(jsii_name="executableUsers")
    def executable_users(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "executableUsers")

    @executable_users.setter
    def executable_users(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "executableUsers", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsAmiFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(self, value: typing.Optional[typing.List["DataAwsAmiFilter"]]) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mostRecent")
    def most_recent(self) -> typing.Optional[bool]:
        return jsii.get(self, "mostRecent")

    @most_recent.setter
    def most_recent(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mostRecent", value)

    @builtins.property
    @jsii.member(jsii_name="nameRegex")
    def name_regex(self) -> typing.Optional[str]:
        return jsii.get(self, "nameRegex")

    @name_regex.setter
    def name_regex(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "nameRegex", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsAmiBlockDeviceMappings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmiBlockDeviceMappings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAmiBlockDeviceMappings,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @builtins.property
    @jsii.member(jsii_name="ebs")
    def ebs(self) -> typing.Any:
        return jsii.get(self, "ebs")

    @builtins.property
    @jsii.member(jsii_name="noDevice")
    def no_device(self) -> str:
        return jsii.get(self, "noDevice")

    @builtins.property
    @jsii.member(jsii_name="virtualName")
    def virtual_name(self) -> str:
        return jsii.get(self, "virtualName")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "owners": "owners",
        "executable_users": "executableUsers",
        "filter": "filter",
        "most_recent": "mostRecent",
        "name_regex": "nameRegex",
        "tags": "tags",
    },
)
class DataAwsAmiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        owners: typing.List[str],
        executable_users: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[typing.List["DataAwsAmiFilter"]] = None,
        most_recent: typing.Optional[bool] = None,
        name_regex: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param owners: 
        :param executable_users: 
        :param filter: filter block.
        :param most_recent: 
        :param name_regex: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "owners": owners,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if executable_users is not None:
            self._values["executable_users"] = executable_users
        if filter is not None:
            self._values["filter"] = filter
        if most_recent is not None:
            self._values["most_recent"] = most_recent
        if name_regex is not None:
            self._values["name_regex"] = name_regex
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def owners(self) -> typing.List[str]:
        return self._values.get("owners")

    @builtins.property
    def executable_users(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("executable_users")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsAmiFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def most_recent(self) -> typing.Optional[bool]:
        return self._values.get("most_recent")

    @builtins.property
    def name_regex(self) -> typing.Optional[str]:
        return self._values.get("name_regex")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAmiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmiFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsAmiFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAmiFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAmiIds(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmiIds",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        owners: typing.List[str],
        executable_users: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[typing.List["DataAwsAmiIdsFilter"]] = None,
        name_regex: typing.Optional[str] = None,
        sort_ascending: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param owners: 
        :param executable_users: 
        :param filter: filter block.
        :param name_regex: 
        :param sort_ascending: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAmiIdsConfig(
            owners=owners,
            executable_users=executable_users,
            filter=filter,
            name_regex=name_regex,
            sort_ascending=sort_ascending,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAmiIds, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="owners")
    def owners(self) -> typing.List[str]:
        return jsii.get(self, "owners")

    @owners.setter
    def owners(self, value: typing.List[str]) -> None:
        jsii.set(self, "owners", value)

    @builtins.property
    @jsii.member(jsii_name="executableUsers")
    def executable_users(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "executableUsers")

    @executable_users.setter
    def executable_users(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "executableUsers", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsAmiIdsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsAmiIdsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="nameRegex")
    def name_regex(self) -> typing.Optional[str]:
        return jsii.get(self, "nameRegex")

    @name_regex.setter
    def name_regex(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "nameRegex", value)

    @builtins.property
    @jsii.member(jsii_name="sortAscending")
    def sort_ascending(self) -> typing.Optional[bool]:
        return jsii.get(self, "sortAscending")

    @sort_ascending.setter
    def sort_ascending(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "sortAscending", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmiIdsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "owners": "owners",
        "executable_users": "executableUsers",
        "filter": "filter",
        "name_regex": "nameRegex",
        "sort_ascending": "sortAscending",
    },
)
class DataAwsAmiIdsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        owners: typing.List[str],
        executable_users: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[typing.List["DataAwsAmiIdsFilter"]] = None,
        name_regex: typing.Optional[str] = None,
        sort_ascending: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param owners: 
        :param executable_users: 
        :param filter: filter block.
        :param name_regex: 
        :param sort_ascending: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "owners": owners,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if executable_users is not None:
            self._values["executable_users"] = executable_users
        if filter is not None:
            self._values["filter"] = filter
        if name_regex is not None:
            self._values["name_regex"] = name_regex
        if sort_ascending is not None:
            self._values["sort_ascending"] = sort_ascending

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def owners(self) -> typing.List[str]:
        return self._values.get("owners")

    @builtins.property
    def executable_users(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("executable_users")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsAmiIdsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def name_regex(self) -> typing.Optional[str]:
        return self._values.get("name_regex")

    @builtins.property
    def sort_ascending(self) -> typing.Optional[bool]:
        return self._values.get("sort_ascending")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAmiIdsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmiIdsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsAmiIdsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAmiIdsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAmiProductCodes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAmiProductCodes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsAmiProductCodes,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="productCodeId")
    def product_code_id(self) -> str:
        return jsii.get(self, "productCodeId")

    @builtins.property
    @jsii.member(jsii_name="productCodeType")
    def product_code_type(self) -> str:
        return jsii.get(self, "productCodeType")


class DataAwsApiGatewayApiKey(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayApiKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id_: str,
        *,
        id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id_: -
        :param id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsApiGatewayApiKeyConfig(
            id=id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsApiGatewayApiKey, self, [scope, id_, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedDate")
    def last_updated_date(self) -> str:
        return jsii.get(self, "lastUpdatedDate")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: str) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayApiKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
        "tags": "tags",
    },
)
class DataAwsApiGatewayApiKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "id": id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsApiGatewayApiKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsApiGatewayResource(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayResource",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        path: str,
        rest_api_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param path: 
        :param rest_api_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsApiGatewayResourceConfig(
            path=path,
            rest_api_id=rest_api_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsApiGatewayResource, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="parentId")
    def parent_id(self) -> str:
        return jsii.get(self, "parentId")

    @builtins.property
    @jsii.member(jsii_name="pathPart")
    def path_part(self) -> str:
        return jsii.get(self, "pathPart")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @path.setter
    def path(self, value: str) -> None:
        jsii.set(self, "path", value)

    @builtins.property
    @jsii.member(jsii_name="restApiId")
    def rest_api_id(self) -> str:
        return jsii.get(self, "restApiId")

    @rest_api_id.setter
    def rest_api_id(self, value: str) -> None:
        jsii.set(self, "restApiId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayResourceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "path": "path",
        "rest_api_id": "restApiId",
    },
)
class DataAwsApiGatewayResourceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        path: str,
        rest_api_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param path: 
        :param rest_api_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "path": path,
            "rest_api_id": rest_api_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def path(self) -> str:
        return self._values.get("path")

    @builtins.property
    def rest_api_id(self) -> str:
        return self._values.get("rest_api_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsApiGatewayResourceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsApiGatewayRestApi(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayRestApi",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsApiGatewayRestApiConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsApiGatewayRestApi, self, [scope, id, config])

    @jsii.member(jsii_name="endpointConfiguration")
    def endpoint_configuration(
        self, index: str
    ) -> "DataAwsApiGatewayRestApiEndpointConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "endpointConfiguration", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiKeySource")
    def api_key_source(self) -> str:
        return jsii.get(self, "apiKeySource")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="binaryMediaTypes")
    def binary_media_types(self) -> typing.List[str]:
        return jsii.get(self, "binaryMediaTypes")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="executionArn")
    def execution_arn(self) -> str:
        return jsii.get(self, "executionArn")

    @builtins.property
    @jsii.member(jsii_name="minimumCompressionSize")
    def minimum_compression_size(self) -> jsii.Number:
        return jsii.get(self, "minimumCompressionSize")

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @builtins.property
    @jsii.member(jsii_name="rootResourceId")
    def root_resource_id(self) -> str:
        return jsii.get(self, "rootResourceId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayRestApiConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsApiGatewayRestApiConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsApiGatewayRestApiConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsApiGatewayRestApiEndpointConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayRestApiEndpointConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsApiGatewayRestApiEndpointConfiguration,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="types")
    def types(self) -> typing.List[str]:
        return jsii.get(self, "types")

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointIds")
    def vpc_endpoint_ids(self) -> typing.List[str]:
        return jsii.get(self, "vpcEndpointIds")


class DataAwsApiGatewayVpcLink(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayVpcLink",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsApiGatewayVpcLinkConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsApiGatewayVpcLink, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> str:
        return jsii.get(self, "statusMessage")

    @builtins.property
    @jsii.member(jsii_name="targetArns")
    def target_arns(self) -> typing.List[str]:
        return jsii.get(self, "targetArns")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsApiGatewayVpcLinkConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsApiGatewayVpcLinkConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsApiGatewayVpcLinkConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsArn(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsArn",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsArnConfig(
            arn=arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsArn, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="account")
    def account(self) -> str:
        return jsii.get(self, "account")

    @builtins.property
    @jsii.member(jsii_name="partition")
    def partition(self) -> str:
        return jsii.get(self, "partition")

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> str:
        return jsii.get(self, "region")

    @builtins.property
    @jsii.member(jsii_name="resource")
    def resource(self) -> str:
        return jsii.get(self, "resource")

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> str:
        return jsii.get(self, "service")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: str) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsArnConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "arn": "arn",
    },
)
class DataAwsArnConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "arn": arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsArnConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAutoscalingGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAutoscalingGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAutoscalingGroupConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAutoscalingGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="defaultCooldown")
    def default_cooldown(self) -> jsii.Number:
        return jsii.get(self, "defaultCooldown")

    @builtins.property
    @jsii.member(jsii_name="desiredCapacity")
    def desired_capacity(self) -> jsii.Number:
        return jsii.get(self, "desiredCapacity")

    @builtins.property
    @jsii.member(jsii_name="healthCheckGracePeriod")
    def health_check_grace_period(self) -> jsii.Number:
        return jsii.get(self, "healthCheckGracePeriod")

    @builtins.property
    @jsii.member(jsii_name="healthCheckType")
    def health_check_type(self) -> str:
        return jsii.get(self, "healthCheckType")

    @builtins.property
    @jsii.member(jsii_name="launchConfiguration")
    def launch_configuration(self) -> str:
        return jsii.get(self, "launchConfiguration")

    @builtins.property
    @jsii.member(jsii_name="loadBalancers")
    def load_balancers(self) -> typing.List[str]:
        return jsii.get(self, "loadBalancers")

    @builtins.property
    @jsii.member(jsii_name="maxSize")
    def max_size(self) -> jsii.Number:
        return jsii.get(self, "maxSize")

    @builtins.property
    @jsii.member(jsii_name="minSize")
    def min_size(self) -> jsii.Number:
        return jsii.get(self, "minSize")

    @builtins.property
    @jsii.member(jsii_name="newInstancesProtectedFromScaleIn")
    def new_instances_protected_from_scale_in(self) -> bool:
        return jsii.get(self, "newInstancesProtectedFromScaleIn")

    @builtins.property
    @jsii.member(jsii_name="placementGroup")
    def placement_group(self) -> str:
        return jsii.get(self, "placementGroup")

    @builtins.property
    @jsii.member(jsii_name="serviceLinkedRoleArn")
    def service_linked_role_arn(self) -> str:
        return jsii.get(self, "serviceLinkedRoleArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="targetGroupArns")
    def target_group_arns(self) -> typing.List[str]:
        return jsii.get(self, "targetGroupArns")

    @builtins.property
    @jsii.member(jsii_name="terminationPolicies")
    def termination_policies(self) -> typing.List[str]:
        return jsii.get(self, "terminationPolicies")

    @builtins.property
    @jsii.member(jsii_name="vpcZoneIdentifier")
    def vpc_zone_identifier(self) -> str:
        return jsii.get(self, "vpcZoneIdentifier")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAutoscalingGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsAutoscalingGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAutoscalingGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAutoscalingGroups(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAutoscalingGroups",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsAutoscalingGroupsFilter"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAutoscalingGroupsConfig(
            filter=filter,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAutoscalingGroups, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arns")
    def arns(self) -> typing.List[str]:
        return jsii.get(self, "arns")

    @builtins.property
    @jsii.member(jsii_name="names")
    def names(self) -> typing.List[str]:
        return jsii.get(self, "names")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsAutoscalingGroupsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsAutoscalingGroupsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAutoscalingGroupsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
    },
)
class DataAwsAutoscalingGroupsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsAutoscalingGroupsFilter"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsAutoscalingGroupsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAutoscalingGroupsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAutoscalingGroupsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsAutoscalingGroupsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAutoscalingGroupsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAvailabilityZone(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAvailabilityZone",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        all_availability_zones: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsAvailabilityZoneFilter"]] = None,
        name: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        zone_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param all_availability_zones: 
        :param filter: filter block.
        :param name: 
        :param state: 
        :param zone_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAvailabilityZoneConfig(
            all_availability_zones=all_availability_zones,
            filter=filter,
            name=name,
            state=state,
            zone_id=zone_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAvailabilityZone, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="groupName")
    def group_name(self) -> str:
        return jsii.get(self, "groupName")

    @builtins.property
    @jsii.member(jsii_name="nameSuffix")
    def name_suffix(self) -> str:
        return jsii.get(self, "nameSuffix")

    @builtins.property
    @jsii.member(jsii_name="networkBorderGroup")
    def network_border_group(self) -> str:
        return jsii.get(self, "networkBorderGroup")

    @builtins.property
    @jsii.member(jsii_name="optInStatus")
    def opt_in_status(self) -> str:
        return jsii.get(self, "optInStatus")

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> str:
        return jsii.get(self, "region")

    @builtins.property
    @jsii.member(jsii_name="allAvailabilityZones")
    def all_availability_zones(self) -> typing.Optional[bool]:
        return jsii.get(self, "allAvailabilityZones")

    @all_availability_zones.setter
    def all_availability_zones(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allAvailabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsAvailabilityZoneFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsAvailabilityZoneFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> typing.Optional[str]:
        return jsii.get(self, "zoneId")

    @zone_id.setter
    def zone_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "zoneId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAvailabilityZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "all_availability_zones": "allAvailabilityZones",
        "filter": "filter",
        "name": "name",
        "state": "state",
        "zone_id": "zoneId",
    },
)
class DataAwsAvailabilityZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        all_availability_zones: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsAvailabilityZoneFilter"]] = None,
        name: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        zone_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param all_availability_zones: 
        :param filter: filter block.
        :param name: 
        :param state: 
        :param zone_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if all_availability_zones is not None:
            self._values["all_availability_zones"] = all_availability_zones
        if filter is not None:
            self._values["filter"] = filter
        if name is not None:
            self._values["name"] = name
        if state is not None:
            self._values["state"] = state
        if zone_id is not None:
            self._values["zone_id"] = zone_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def all_availability_zones(self) -> typing.Optional[bool]:
        return self._values.get("all_availability_zones")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsAvailabilityZoneFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def zone_id(self) -> typing.Optional[str]:
        return self._values.get("zone_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAvailabilityZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAvailabilityZoneFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsAvailabilityZoneFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAvailabilityZoneFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsAvailabilityZones(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAvailabilityZones",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        all_availability_zones: typing.Optional[bool] = None,
        blacklisted_names: typing.Optional[typing.List[str]] = None,
        blacklisted_zone_ids: typing.Optional[typing.List[str]] = None,
        exclude_names: typing.Optional[typing.List[str]] = None,
        exclude_zone_ids: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[typing.List["DataAwsAvailabilityZonesFilter"]] = None,
        group_names: typing.Optional[typing.List[str]] = None,
        state: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param all_availability_zones: 
        :param blacklisted_names: 
        :param blacklisted_zone_ids: 
        :param exclude_names: 
        :param exclude_zone_ids: 
        :param filter: filter block.
        :param group_names: 
        :param state: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsAvailabilityZonesConfig(
            all_availability_zones=all_availability_zones,
            blacklisted_names=blacklisted_names,
            blacklisted_zone_ids=blacklisted_zone_ids,
            exclude_names=exclude_names,
            exclude_zone_ids=exclude_zone_ids,
            filter=filter,
            group_names=group_names,
            state=state,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsAvailabilityZones, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="names")
    def names(self) -> typing.List[str]:
        return jsii.get(self, "names")

    @builtins.property
    @jsii.member(jsii_name="zoneIds")
    def zone_ids(self) -> typing.List[str]:
        return jsii.get(self, "zoneIds")

    @builtins.property
    @jsii.member(jsii_name="allAvailabilityZones")
    def all_availability_zones(self) -> typing.Optional[bool]:
        return jsii.get(self, "allAvailabilityZones")

    @all_availability_zones.setter
    def all_availability_zones(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allAvailabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="blacklistedNames")
    def blacklisted_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "blacklistedNames")

    @blacklisted_names.setter
    def blacklisted_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "blacklistedNames", value)

    @builtins.property
    @jsii.member(jsii_name="blacklistedZoneIds")
    def blacklisted_zone_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "blacklistedZoneIds")

    @blacklisted_zone_ids.setter
    def blacklisted_zone_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "blacklistedZoneIds", value)

    @builtins.property
    @jsii.member(jsii_name="excludeNames")
    def exclude_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "excludeNames")

    @exclude_names.setter
    def exclude_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "excludeNames", value)

    @builtins.property
    @jsii.member(jsii_name="excludeZoneIds")
    def exclude_zone_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "excludeZoneIds")

    @exclude_zone_ids.setter
    def exclude_zone_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "excludeZoneIds", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsAvailabilityZonesFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsAvailabilityZonesFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="groupNames")
    def group_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "groupNames")

    @group_names.setter
    def group_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "groupNames", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAvailabilityZonesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "all_availability_zones": "allAvailabilityZones",
        "blacklisted_names": "blacklistedNames",
        "blacklisted_zone_ids": "blacklistedZoneIds",
        "exclude_names": "excludeNames",
        "exclude_zone_ids": "excludeZoneIds",
        "filter": "filter",
        "group_names": "groupNames",
        "state": "state",
    },
)
class DataAwsAvailabilityZonesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        all_availability_zones: typing.Optional[bool] = None,
        blacklisted_names: typing.Optional[typing.List[str]] = None,
        blacklisted_zone_ids: typing.Optional[typing.List[str]] = None,
        exclude_names: typing.Optional[typing.List[str]] = None,
        exclude_zone_ids: typing.Optional[typing.List[str]] = None,
        filter: typing.Optional[typing.List["DataAwsAvailabilityZonesFilter"]] = None,
        group_names: typing.Optional[typing.List[str]] = None,
        state: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param all_availability_zones: 
        :param blacklisted_names: 
        :param blacklisted_zone_ids: 
        :param exclude_names: 
        :param exclude_zone_ids: 
        :param filter: filter block.
        :param group_names: 
        :param state: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if all_availability_zones is not None:
            self._values["all_availability_zones"] = all_availability_zones
        if blacklisted_names is not None:
            self._values["blacklisted_names"] = blacklisted_names
        if blacklisted_zone_ids is not None:
            self._values["blacklisted_zone_ids"] = blacklisted_zone_ids
        if exclude_names is not None:
            self._values["exclude_names"] = exclude_names
        if exclude_zone_ids is not None:
            self._values["exclude_zone_ids"] = exclude_zone_ids
        if filter is not None:
            self._values["filter"] = filter
        if group_names is not None:
            self._values["group_names"] = group_names
        if state is not None:
            self._values["state"] = state

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def all_availability_zones(self) -> typing.Optional[bool]:
        return self._values.get("all_availability_zones")

    @builtins.property
    def blacklisted_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("blacklisted_names")

    @builtins.property
    def blacklisted_zone_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("blacklisted_zone_ids")

    @builtins.property
    def exclude_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("exclude_names")

    @builtins.property
    def exclude_zone_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("exclude_zone_ids")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsAvailabilityZonesFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def group_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("group_names")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAvailabilityZonesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsAvailabilityZonesFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsAvailabilityZonesFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsAvailabilityZonesFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsBackupPlan(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBackupPlan",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        plan_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param plan_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsBackupPlanConfig(
            plan_id=plan_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsBackupPlan, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="planId")
    def plan_id(self) -> str:
        return jsii.get(self, "planId")

    @plan_id.setter
    def plan_id(self, value: str) -> None:
        jsii.set(self, "planId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBackupPlanConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "plan_id": "planId",
        "tags": "tags",
    },
)
class DataAwsBackupPlanConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        plan_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param plan_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "plan_id": plan_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def plan_id(self) -> str:
        return self._values.get("plan_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsBackupPlanConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsBackupSelection(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBackupSelection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        plan_id: str,
        selection_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param plan_id: 
        :param selection_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsBackupSelectionConfig(
            plan_id=plan_id,
            selection_id=selection_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsBackupSelection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="iamRoleArn")
    def iam_role_arn(self) -> str:
        return jsii.get(self, "iamRoleArn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="resources")
    def resources(self) -> typing.List[str]:
        return jsii.get(self, "resources")

    @builtins.property
    @jsii.member(jsii_name="planId")
    def plan_id(self) -> str:
        return jsii.get(self, "planId")

    @plan_id.setter
    def plan_id(self, value: str) -> None:
        jsii.set(self, "planId", value)

    @builtins.property
    @jsii.member(jsii_name="selectionId")
    def selection_id(self) -> str:
        return jsii.get(self, "selectionId")

    @selection_id.setter
    def selection_id(self, value: str) -> None:
        jsii.set(self, "selectionId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBackupSelectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "plan_id": "planId",
        "selection_id": "selectionId",
    },
)
class DataAwsBackupSelectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        plan_id: str,
        selection_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param plan_id: 
        :param selection_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "plan_id": plan_id,
            "selection_id": selection_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def plan_id(self) -> str:
        return self._values.get("plan_id")

    @builtins.property
    def selection_id(self) -> str:
        return self._values.get("selection_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsBackupSelectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsBackupVault(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBackupVault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsBackupVaultConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsBackupVault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> str:
        return jsii.get(self, "kmsKeyArn")

    @builtins.property
    @jsii.member(jsii_name="recoveryPoints")
    def recovery_points(self) -> jsii.Number:
        return jsii.get(self, "recoveryPoints")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBackupVaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsBackupVaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsBackupVaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsBatchComputeEnvironment(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBatchComputeEnvironment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        compute_environment_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param compute_environment_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsBatchComputeEnvironmentConfig(
            compute_environment_name=compute_environment_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsBatchComputeEnvironment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ecsClusterArn")
    def ecs_cluster_arn(self) -> str:
        return jsii.get(self, "ecsClusterArn")

    @builtins.property
    @jsii.member(jsii_name="serviceRole")
    def service_role(self) -> str:
        return jsii.get(self, "serviceRole")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="statusReason")
    def status_reason(self) -> str:
        return jsii.get(self, "statusReason")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @builtins.property
    @jsii.member(jsii_name="computeEnvironmentName")
    def compute_environment_name(self) -> str:
        return jsii.get(self, "computeEnvironmentName")

    @compute_environment_name.setter
    def compute_environment_name(self, value: str) -> None:
        jsii.set(self, "computeEnvironmentName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBatchComputeEnvironmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "compute_environment_name": "computeEnvironmentName",
    },
)
class DataAwsBatchComputeEnvironmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        compute_environment_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param compute_environment_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "compute_environment_name": compute_environment_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def compute_environment_name(self) -> str:
        return self._values.get("compute_environment_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsBatchComputeEnvironmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsBatchJobQueue(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBatchJobQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsBatchJobQueueConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsBatchJobQueue, self, [scope, id, config])

    @jsii.member(jsii_name="computeEnvironmentOrder")
    def compute_environment_order(
        self, index: str
    ) -> "DataAwsBatchJobQueueComputeEnvironmentOrder":
        """
        :param index: -
        """
        return jsii.invoke(self, "computeEnvironmentOrder", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="statusReason")
    def status_reason(self) -> str:
        return jsii.get(self, "statusReason")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class DataAwsBatchJobQueueComputeEnvironmentOrder(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBatchJobQueueComputeEnvironmentOrder",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsBatchJobQueueComputeEnvironmentOrder,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="computeEnvironment")
    def compute_environment(self) -> str:
        return jsii.get(self, "computeEnvironment")

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> jsii.Number:
        return jsii.get(self, "order")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBatchJobQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsBatchJobQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsBatchJobQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsBillingServiceAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBillingServiceAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsBillingServiceAccountConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsBillingServiceAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsBillingServiceAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsBillingServiceAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsBillingServiceAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCallerIdentity(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCallerIdentity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCallerIdentityConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsCallerIdentity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="userId")
    def user_id(self) -> str:
        return jsii.get(self, "userId")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCallerIdentityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsCallerIdentityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCallerIdentityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCanonicalUserId(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCanonicalUserId",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCanonicalUserIdConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsCanonicalUserId, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> str:
        return jsii.get(self, "displayName")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCanonicalUserIdConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsCanonicalUserIdConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCanonicalUserIdConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCloudformationExport(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudformationExport",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCloudformationExportConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCloudformationExport, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="exportingStackId")
    def exporting_stack_id(self) -> str:
        return jsii.get(self, "exportingStackId")

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudformationExportConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsCloudformationExportConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCloudformationExportConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCloudformationStack(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudformationStack",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCloudformationStackConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCloudformationStack, self, [scope, id, config])

    @jsii.member(jsii_name="outputs")
    def outputs(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "outputs", [key])

    @jsii.member(jsii_name="parameters")
    def parameters(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "parameters", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="capabilities")
    def capabilities(self) -> typing.List[str]:
        return jsii.get(self, "capabilities")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="disableRollback")
    def disable_rollback(self) -> bool:
        return jsii.get(self, "disableRollback")

    @builtins.property
    @jsii.member(jsii_name="iamRoleArn")
    def iam_role_arn(self) -> str:
        return jsii.get(self, "iamRoleArn")

    @builtins.property
    @jsii.member(jsii_name="notificationArns")
    def notification_arns(self) -> typing.List[str]:
        return jsii.get(self, "notificationArns")

    @builtins.property
    @jsii.member(jsii_name="templateBody")
    def template_body(self) -> str:
        return jsii.get(self, "templateBody")

    @builtins.property
    @jsii.member(jsii_name="timeoutInMinutes")
    def timeout_in_minutes(self) -> jsii.Number:
        return jsii.get(self, "timeoutInMinutes")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudformationStackConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsCloudformationStackConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCloudformationStackConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCloudfrontDistribution(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudfrontDistribution",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id_: str,
        *,
        id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id_: -
        :param id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCloudfrontDistributionConfig(
            id=id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCloudfrontDistribution, self, [scope, id_, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="etag")
    def etag(self) -> str:
        return jsii.get(self, "etag")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="inProgressValidationBatches")
    def in_progress_validation_batches(self) -> jsii.Number:
        return jsii.get(self, "inProgressValidationBatches")

    @builtins.property
    @jsii.member(jsii_name="lastModifiedTime")
    def last_modified_time(self) -> str:
        return jsii.get(self, "lastModifiedTime")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: str) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudfrontDistributionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
        "tags": "tags",
    },
)
class DataAwsCloudfrontDistributionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "id": id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCloudfrontDistributionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCloudhsmV2Cluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudhsmV2Cluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_id: str,
        cluster_state: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_id: 
        :param cluster_state: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCloudhsmV2ClusterConfig(
            cluster_id=cluster_id,
            cluster_state=cluster_state,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCloudhsmV2Cluster, self, [scope, id, config])

    @jsii.member(jsii_name="clusterCertificates")
    def cluster_certificates(
        self, index: str
    ) -> "DataAwsCloudhsmV2ClusterClusterCertificates":
        """
        :param index: -
        """
        return jsii.invoke(self, "clusterCertificates", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> str:
        return jsii.get(self, "securityGroupId")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> str:
        return jsii.get(self, "clusterId")

    @cluster_id.setter
    def cluster_id(self, value: str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property
    @jsii.member(jsii_name="clusterState")
    def cluster_state(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterState")

    @cluster_state.setter
    def cluster_state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterState", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class DataAwsCloudhsmV2ClusterClusterCertificates(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudhsmV2ClusterClusterCertificates",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsCloudhsmV2ClusterClusterCertificates,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="awsHardwareCertificate")
    def aws_hardware_certificate(self) -> str:
        return jsii.get(self, "awsHardwareCertificate")

    @builtins.property
    @jsii.member(jsii_name="clusterCertificate")
    def cluster_certificate(self) -> str:
        return jsii.get(self, "clusterCertificate")

    @builtins.property
    @jsii.member(jsii_name="clusterCsr")
    def cluster_csr(self) -> str:
        return jsii.get(self, "clusterCsr")

    @builtins.property
    @jsii.member(jsii_name="hsmCertificate")
    def hsm_certificate(self) -> str:
        return jsii.get(self, "hsmCertificate")

    @builtins.property
    @jsii.member(jsii_name="manufacturerHardwareCertificate")
    def manufacturer_hardware_certificate(self) -> str:
        return jsii.get(self, "manufacturerHardwareCertificate")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudhsmV2ClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "cluster_state": "clusterState",
    },
)
class DataAwsCloudhsmV2ClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: str,
        cluster_state: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: 
        :param cluster_state: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_id": cluster_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cluster_state is not None:
            self._values["cluster_state"] = cluster_state

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_id(self) -> str:
        return self._values.get("cluster_id")

    @builtins.property
    def cluster_state(self) -> typing.Optional[str]:
        return self._values.get("cluster_state")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCloudhsmV2ClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCloudtrailServiceAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudtrailServiceAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        region: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param region: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCloudtrailServiceAccountConfig(
            region=region,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCloudtrailServiceAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudtrailServiceAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "region": "region",
    },
)
class DataAwsCloudtrailServiceAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        region: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param region: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCloudtrailServiceAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCloudwatchLogGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudwatchLogGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCloudwatchLogGroupConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCloudwatchLogGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="creationTime")
    def creation_time(self) -> jsii.Number:
        return jsii.get(self, "creationTime")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="retentionInDays")
    def retention_in_days(self) -> jsii.Number:
        return jsii.get(self, "retentionInDays")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCloudwatchLogGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsCloudwatchLogGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCloudwatchLogGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCodecommitRepository(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCodecommitRepository",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        repository_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param repository_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCodecommitRepositoryConfig(
            repository_name=repository_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCodecommitRepository, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="cloneUrlHttp")
    def clone_url_http(self) -> str:
        return jsii.get(self, "cloneUrlHttp")

    @builtins.property
    @jsii.member(jsii_name="cloneUrlSsh")
    def clone_url_ssh(self) -> str:
        return jsii.get(self, "cloneUrlSsh")

    @builtins.property
    @jsii.member(jsii_name="repositoryId")
    def repository_id(self) -> str:
        return jsii.get(self, "repositoryId")

    @builtins.property
    @jsii.member(jsii_name="repositoryName")
    def repository_name(self) -> str:
        return jsii.get(self, "repositoryName")

    @repository_name.setter
    def repository_name(self, value: str) -> None:
        jsii.set(self, "repositoryName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCodecommitRepositoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "repository_name": "repositoryName",
    },
)
class DataAwsCodecommitRepositoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        repository_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param repository_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "repository_name": repository_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def repository_name(self) -> str:
        return self._values.get("repository_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCodecommitRepositoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCognitoUserPools(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCognitoUserPools",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCognitoUserPoolsConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCognitoUserPools, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arns")
    def arns(self) -> typing.List[str]:
        return jsii.get(self, "arns")

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCognitoUserPoolsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsCognitoUserPoolsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCognitoUserPoolsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCurReportDefinition(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCurReportDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        report_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param report_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCurReportDefinitionConfig(
            report_name=report_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCurReportDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="additionalArtifacts")
    def additional_artifacts(self) -> typing.List[str]:
        return jsii.get(self, "additionalArtifacts")

    @builtins.property
    @jsii.member(jsii_name="additionalSchemaElements")
    def additional_schema_elements(self) -> typing.List[str]:
        return jsii.get(self, "additionalSchemaElements")

    @builtins.property
    @jsii.member(jsii_name="compression")
    def compression(self) -> str:
        return jsii.get(self, "compression")

    @builtins.property
    @jsii.member(jsii_name="format")
    def format(self) -> str:
        return jsii.get(self, "format")

    @builtins.property
    @jsii.member(jsii_name="s3Bucket")
    def s3_bucket(self) -> str:
        return jsii.get(self, "s3Bucket")

    @builtins.property
    @jsii.member(jsii_name="s3Prefix")
    def s3_prefix(self) -> str:
        return jsii.get(self, "s3Prefix")

    @builtins.property
    @jsii.member(jsii_name="s3Region")
    def s3_region(self) -> str:
        return jsii.get(self, "s3Region")

    @builtins.property
    @jsii.member(jsii_name="timeUnit")
    def time_unit(self) -> str:
        return jsii.get(self, "timeUnit")

    @builtins.property
    @jsii.member(jsii_name="reportName")
    def report_name(self) -> str:
        return jsii.get(self, "reportName")

    @report_name.setter
    def report_name(self, value: str) -> None:
        jsii.set(self, "reportName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCurReportDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "report_name": "reportName",
    },
)
class DataAwsCurReportDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        report_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param report_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "report_name": report_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def report_name(self) -> str:
        return self._values.get("report_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCurReportDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsCustomerGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCustomerGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsCustomerGatewayFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsCustomerGatewayConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsCustomerGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsCustomerGatewayFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsCustomerGatewayFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCustomerGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsCustomerGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsCustomerGatewayFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsCustomerGatewayFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCustomerGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsCustomerGatewayFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsCustomerGatewayFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsCustomerGatewayFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDbClusterSnapshot(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbClusterSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_cluster_identifier: typing.Optional[str] = None,
        db_cluster_snapshot_identifier: typing.Optional[str] = None,
        include_public: typing.Optional[bool] = None,
        include_shared: typing.Optional[bool] = None,
        most_recent: typing.Optional[bool] = None,
        snapshot_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param include_public: 
        :param include_shared: 
        :param most_recent: 
        :param snapshot_type: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsDbClusterSnapshotConfig(
            db_cluster_identifier=db_cluster_identifier,
            db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
            include_public=include_public,
            include_shared=include_shared,
            most_recent=most_recent,
            snapshot_type=snapshot_type,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsDbClusterSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> jsii.Number:
        return jsii.get(self, "allocatedStorage")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotArn")
    def db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "dbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="licenseModel")
    def license_model(self) -> str:
        return jsii.get(self, "licenseModel")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="snapshotCreateTime")
    def snapshot_create_time(self) -> str:
        return jsii.get(self, "snapshotCreateTime")

    @builtins.property
    @jsii.member(jsii_name="sourceDbClusterSnapshotArn")
    def source_db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "sourceDbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="dbClusterIdentifier")
    def db_cluster_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "dbClusterIdentifier")

    @db_cluster_identifier.setter
    def db_cluster_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbClusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotIdentifier")
    def db_cluster_snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "dbClusterSnapshotIdentifier")

    @db_cluster_snapshot_identifier.setter
    def db_cluster_snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbClusterSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="includePublic")
    def include_public(self) -> typing.Optional[bool]:
        return jsii.get(self, "includePublic")

    @include_public.setter
    def include_public(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "includePublic", value)

    @builtins.property
    @jsii.member(jsii_name="includeShared")
    def include_shared(self) -> typing.Optional[bool]:
        return jsii.get(self, "includeShared")

    @include_shared.setter
    def include_shared(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "includeShared", value)

    @builtins.property
    @jsii.member(jsii_name="mostRecent")
    def most_recent(self) -> typing.Optional[bool]:
        return jsii.get(self, "mostRecent")

    @most_recent.setter
    def most_recent(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mostRecent", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotType")
    def snapshot_type(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotType")

    @snapshot_type.setter
    def snapshot_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbClusterSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_cluster_identifier": "dbClusterIdentifier",
        "db_cluster_snapshot_identifier": "dbClusterSnapshotIdentifier",
        "include_public": "includePublic",
        "include_shared": "includeShared",
        "most_recent": "mostRecent",
        "snapshot_type": "snapshotType",
        "tags": "tags",
    },
)
class DataAwsDbClusterSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_cluster_identifier: typing.Optional[str] = None,
        db_cluster_snapshot_identifier: typing.Optional[str] = None,
        include_public: typing.Optional[bool] = None,
        include_shared: typing.Optional[bool] = None,
        most_recent: typing.Optional[bool] = None,
        snapshot_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param include_public: 
        :param include_shared: 
        :param most_recent: 
        :param snapshot_type: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if db_cluster_identifier is not None:
            self._values["db_cluster_identifier"] = db_cluster_identifier
        if db_cluster_snapshot_identifier is not None:
            self._values[
                "db_cluster_snapshot_identifier"
            ] = db_cluster_snapshot_identifier
        if include_public is not None:
            self._values["include_public"] = include_public
        if include_shared is not None:
            self._values["include_shared"] = include_shared
        if most_recent is not None:
            self._values["most_recent"] = most_recent
        if snapshot_type is not None:
            self._values["snapshot_type"] = snapshot_type
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_cluster_identifier(self) -> typing.Optional[str]:
        return self._values.get("db_cluster_identifier")

    @builtins.property
    def db_cluster_snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("db_cluster_snapshot_identifier")

    @builtins.property
    def include_public(self) -> typing.Optional[bool]:
        return self._values.get("include_public")

    @builtins.property
    def include_shared(self) -> typing.Optional[bool]:
        return self._values.get("include_shared")

    @builtins.property
    def most_recent(self) -> typing.Optional[bool]:
        return self._values.get("most_recent")

    @builtins.property
    def snapshot_type(self) -> typing.Optional[str]:
        return self._values.get("snapshot_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDbClusterSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDbEventCategories(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbEventCategories",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        source_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param source_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsDbEventCategoriesConfig(
            source_type=source_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsDbEventCategories, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="eventCategories")
    def event_categories(self) -> typing.List[str]:
        return jsii.get(self, "eventCategories")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sourceType")
    def source_type(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceType")

    @source_type.setter
    def source_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbEventCategoriesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "source_type": "sourceType",
    },
)
class DataAwsDbEventCategoriesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        source_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param source_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if source_type is not None:
            self._values["source_type"] = source_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def source_type(self) -> typing.Optional[str]:
        return self._values.get("source_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDbEventCategoriesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDbInstance(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_instance_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_instance_identifier: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsDbInstanceConfig(
            db_instance_identifier=db_instance_identifier,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsDbInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="address")
    def address(self) -> str:
        return jsii.get(self, "address")

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> jsii.Number:
        return jsii.get(self, "allocatedStorage")

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> bool:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="backupRetentionPeriod")
    def backup_retention_period(self) -> jsii.Number:
        return jsii.get(self, "backupRetentionPeriod")

    @builtins.property
    @jsii.member(jsii_name="caCertIdentifier")
    def ca_cert_identifier(self) -> str:
        return jsii.get(self, "caCertIdentifier")

    @builtins.property
    @jsii.member(jsii_name="dbClusterIdentifier")
    def db_cluster_identifier(self) -> str:
        return jsii.get(self, "dbClusterIdentifier")

    @builtins.property
    @jsii.member(jsii_name="dbInstanceArn")
    def db_instance_arn(self) -> str:
        return jsii.get(self, "dbInstanceArn")

    @builtins.property
    @jsii.member(jsii_name="dbInstanceClass")
    def db_instance_class(self) -> str:
        return jsii.get(self, "dbInstanceClass")

    @builtins.property
    @jsii.member(jsii_name="dbInstancePort")
    def db_instance_port(self) -> jsii.Number:
        return jsii.get(self, "dbInstancePort")

    @builtins.property
    @jsii.member(jsii_name="dbName")
    def db_name(self) -> str:
        return jsii.get(self, "dbName")

    @builtins.property
    @jsii.member(jsii_name="dbParameterGroups")
    def db_parameter_groups(self) -> typing.List[str]:
        return jsii.get(self, "dbParameterGroups")

    @builtins.property
    @jsii.member(jsii_name="dbSecurityGroups")
    def db_security_groups(self) -> typing.List[str]:
        return jsii.get(self, "dbSecurityGroups")

    @builtins.property
    @jsii.member(jsii_name="dbSubnetGroup")
    def db_subnet_group(self) -> str:
        return jsii.get(self, "dbSubnetGroup")

    @builtins.property
    @jsii.member(jsii_name="enabledCloudwatchLogsExports")
    def enabled_cloudwatch_logs_exports(self) -> typing.List[str]:
        return jsii.get(self, "enabledCloudwatchLogsExports")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="licenseModel")
    def license_model(self) -> str:
        return jsii.get(self, "licenseModel")

    @builtins.property
    @jsii.member(jsii_name="masterUsername")
    def master_username(self) -> str:
        return jsii.get(self, "masterUsername")

    @builtins.property
    @jsii.member(jsii_name="monitoringInterval")
    def monitoring_interval(self) -> jsii.Number:
        return jsii.get(self, "monitoringInterval")

    @builtins.property
    @jsii.member(jsii_name="monitoringRoleArn")
    def monitoring_role_arn(self) -> str:
        return jsii.get(self, "monitoringRoleArn")

    @builtins.property
    @jsii.member(jsii_name="multiAz")
    def multi_az(self) -> bool:
        return jsii.get(self, "multiAz")

    @builtins.property
    @jsii.member(jsii_name="optionGroupMemberships")
    def option_group_memberships(self) -> typing.List[str]:
        return jsii.get(self, "optionGroupMemberships")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> str:
        return jsii.get(self, "preferredBackupWindow")

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> str:
        return jsii.get(self, "preferredMaintenanceWindow")

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> bool:
        return jsii.get(self, "publiclyAccessible")

    @builtins.property
    @jsii.member(jsii_name="replicateSourceDb")
    def replicate_source_db(self) -> str:
        return jsii.get(self, "replicateSourceDb")

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> str:
        return jsii.get(self, "storageType")

    @builtins.property
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> str:
        return jsii.get(self, "timezone")

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroups")
    def vpc_security_groups(self) -> typing.List[str]:
        return jsii.get(self, "vpcSecurityGroups")

    @builtins.property
    @jsii.member(jsii_name="dbInstanceIdentifier")
    def db_instance_identifier(self) -> str:
        return jsii.get(self, "dbInstanceIdentifier")

    @db_instance_identifier.setter
    def db_instance_identifier(self, value: str) -> None:
        jsii.set(self, "dbInstanceIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_instance_identifier": "dbInstanceIdentifier",
        "tags": "tags",
    },
)
class DataAwsDbInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_instance_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_instance_identifier: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "db_instance_identifier": db_instance_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_instance_identifier(self) -> str:
        return self._values.get("db_instance_identifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDbInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDbSnapshot(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_instance_identifier: typing.Optional[str] = None,
        db_snapshot_identifier: typing.Optional[str] = None,
        include_public: typing.Optional[bool] = None,
        include_shared: typing.Optional[bool] = None,
        most_recent: typing.Optional[bool] = None,
        snapshot_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_instance_identifier: 
        :param db_snapshot_identifier: 
        :param include_public: 
        :param include_shared: 
        :param most_recent: 
        :param snapshot_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsDbSnapshotConfig(
            db_instance_identifier=db_instance_identifier,
            db_snapshot_identifier=db_snapshot_identifier,
            include_public=include_public,
            include_shared=include_shared,
            most_recent=most_recent,
            snapshot_type=snapshot_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsDbSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> jsii.Number:
        return jsii.get(self, "allocatedStorage")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="dbSnapshotArn")
    def db_snapshot_arn(self) -> str:
        return jsii.get(self, "dbSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="licenseModel")
    def license_model(self) -> str:
        return jsii.get(self, "licenseModel")

    @builtins.property
    @jsii.member(jsii_name="optionGroupName")
    def option_group_name(self) -> str:
        return jsii.get(self, "optionGroupName")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="snapshotCreateTime")
    def snapshot_create_time(self) -> str:
        return jsii.get(self, "snapshotCreateTime")

    @builtins.property
    @jsii.member(jsii_name="sourceDbSnapshotIdentifier")
    def source_db_snapshot_identifier(self) -> str:
        return jsii.get(self, "sourceDbSnapshotIdentifier")

    @builtins.property
    @jsii.member(jsii_name="sourceRegion")
    def source_region(self) -> str:
        return jsii.get(self, "sourceRegion")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> str:
        return jsii.get(self, "storageType")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="dbInstanceIdentifier")
    def db_instance_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "dbInstanceIdentifier")

    @db_instance_identifier.setter
    def db_instance_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbInstanceIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="dbSnapshotIdentifier")
    def db_snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "dbSnapshotIdentifier")

    @db_snapshot_identifier.setter
    def db_snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="includePublic")
    def include_public(self) -> typing.Optional[bool]:
        return jsii.get(self, "includePublic")

    @include_public.setter
    def include_public(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "includePublic", value)

    @builtins.property
    @jsii.member(jsii_name="includeShared")
    def include_shared(self) -> typing.Optional[bool]:
        return jsii.get(self, "includeShared")

    @include_shared.setter
    def include_shared(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "includeShared", value)

    @builtins.property
    @jsii.member(jsii_name="mostRecent")
    def most_recent(self) -> typing.Optional[bool]:
        return jsii.get(self, "mostRecent")

    @most_recent.setter
    def most_recent(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mostRecent", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotType")
    def snapshot_type(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotType")

    @snapshot_type.setter
    def snapshot_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDbSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_instance_identifier": "dbInstanceIdentifier",
        "db_snapshot_identifier": "dbSnapshotIdentifier",
        "include_public": "includePublic",
        "include_shared": "includeShared",
        "most_recent": "mostRecent",
        "snapshot_type": "snapshotType",
    },
)
class DataAwsDbSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_instance_identifier: typing.Optional[str] = None,
        db_snapshot_identifier: typing.Optional[str] = None,
        include_public: typing.Optional[bool] = None,
        include_shared: typing.Optional[bool] = None,
        most_recent: typing.Optional[bool] = None,
        snapshot_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_instance_identifier: 
        :param db_snapshot_identifier: 
        :param include_public: 
        :param include_shared: 
        :param most_recent: 
        :param snapshot_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if db_instance_identifier is not None:
            self._values["db_instance_identifier"] = db_instance_identifier
        if db_snapshot_identifier is not None:
            self._values["db_snapshot_identifier"] = db_snapshot_identifier
        if include_public is not None:
            self._values["include_public"] = include_public
        if include_shared is not None:
            self._values["include_shared"] = include_shared
        if most_recent is not None:
            self._values["most_recent"] = most_recent
        if snapshot_type is not None:
            self._values["snapshot_type"] = snapshot_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_instance_identifier(self) -> typing.Optional[str]:
        return self._values.get("db_instance_identifier")

    @builtins.property
    def db_snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("db_snapshot_identifier")

    @builtins.property
    def include_public(self) -> typing.Optional[bool]:
        return self._values.get("include_public")

    @builtins.property
    def include_shared(self) -> typing.Optional[bool]:
        return self._values.get("include_shared")

    @builtins.property
    def most_recent(self) -> typing.Optional[bool]:
        return self._values.get("most_recent")

    @builtins.property
    def snapshot_type(self) -> typing.Optional[str]:
        return self._values.get("snapshot_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDbSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDirectoryServiceDirectory(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDirectoryServiceDirectory",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        directory_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param directory_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsDirectoryServiceDirectoryConfig(
            directory_id=directory_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsDirectoryServiceDirectory, self, [scope, id, config])

    @jsii.member(jsii_name="connectSettings")
    def connect_settings(
        self, index: str
    ) -> "DataAwsDirectoryServiceDirectoryConnectSettings":
        """
        :param index: -
        """
        return jsii.invoke(self, "connectSettings", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="vpcSettings")
    def vpc_settings(self, index: str) -> "DataAwsDirectoryServiceDirectoryVpcSettings":
        """
        :param index: -
        """
        return jsii.invoke(self, "vpcSettings", [index])

    @builtins.property
    @jsii.member(jsii_name="accessUrl")
    def access_url(self) -> str:
        return jsii.get(self, "accessUrl")

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> str:
        return jsii.get(self, "alias")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="dnsIpAddresses")
    def dns_ip_addresses(self) -> typing.List[str]:
        return jsii.get(self, "dnsIpAddresses")

    @builtins.property
    @jsii.member(jsii_name="edition")
    def edition(self) -> str:
        return jsii.get(self, "edition")

    @builtins.property
    @jsii.member(jsii_name="enableSso")
    def enable_sso(self) -> bool:
        return jsii.get(self, "enableSso")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> str:
        return jsii.get(self, "securityGroupId")

    @builtins.property
    @jsii.member(jsii_name="shortName")
    def short_name(self) -> str:
        return jsii.get(self, "shortName")

    @builtins.property
    @jsii.member(jsii_name="size")
    def size(self) -> str:
        return jsii.get(self, "size")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @builtins.property
    @jsii.member(jsii_name="directoryId")
    def directory_id(self) -> str:
        return jsii.get(self, "directoryId")

    @directory_id.setter
    def directory_id(self, value: str) -> None:
        jsii.set(self, "directoryId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDirectoryServiceDirectoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "directory_id": "directoryId",
        "tags": "tags",
    },
)
class DataAwsDirectoryServiceDirectoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        directory_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param directory_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "directory_id": directory_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def directory_id(self) -> str:
        return self._values.get("directory_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDirectoryServiceDirectoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDirectoryServiceDirectoryConnectSettings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDirectoryServiceDirectoryConnectSettings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDirectoryServiceDirectoryConnectSettings,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="connectIps")
    def connect_ips(self) -> typing.List[str]:
        return jsii.get(self, "connectIps")

    @builtins.property
    @jsii.member(jsii_name="customerDnsIps")
    def customer_dns_ips(self) -> typing.List[str]:
        return jsii.get(self, "customerDnsIps")

    @builtins.property
    @jsii.member(jsii_name="customerUsername")
    def customer_username(self) -> str:
        return jsii.get(self, "customerUsername")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")


class DataAwsDirectoryServiceDirectoryVpcSettings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDirectoryServiceDirectoryVpcSettings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDirectoryServiceDirectoryVpcSettings,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")


class DataAwsDxGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDxGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsDxGatewayConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsDxGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="ownerAccountId")
    def owner_account_id(self) -> str:
        return jsii.get(self, "ownerAccountId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDxGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsDxGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDxGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDynamodbTable(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        server_side_encryption: typing.Optional[
            typing.List["DataAwsDynamodbTableServerSideEncryption"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param server_side_encryption: server_side_encryption block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsDynamodbTableConfig(
            name=name,
            server_side_encryption=server_side_encryption,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsDynamodbTable, self, [scope, id, config])

    @jsii.member(jsii_name="attribute")
    def attribute(self, index: str) -> "DataAwsDynamodbTableAttribute":
        """
        :param index: -
        """
        return jsii.invoke(self, "attribute", [index])

    @jsii.member(jsii_name="globalSecondaryIndex")
    def global_secondary_index(
        self, index: str
    ) -> "DataAwsDynamodbTableGlobalSecondaryIndex":
        """
        :param index: -
        """
        return jsii.invoke(self, "globalSecondaryIndex", [index])

    @jsii.member(jsii_name="localSecondaryIndex")
    def local_secondary_index(
        self, index: str
    ) -> "DataAwsDynamodbTableLocalSecondaryIndex":
        """
        :param index: -
        """
        return jsii.invoke(self, "localSecondaryIndex", [index])

    @jsii.member(jsii_name="pointInTimeRecovery")
    def point_in_time_recovery(
        self, index: str
    ) -> "DataAwsDynamodbTablePointInTimeRecovery":
        """
        :param index: -
        """
        return jsii.invoke(self, "pointInTimeRecovery", [index])

    @jsii.member(jsii_name="replica")
    def replica(self, index: str) -> "DataAwsDynamodbTableReplica":
        """
        :param index: -
        """
        return jsii.invoke(self, "replica", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="ttl")
    def ttl(self, index: str) -> "DataAwsDynamodbTableTtl":
        """
        :param index: -
        """
        return jsii.invoke(self, "ttl", [index])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="billingMode")
    def billing_mode(self) -> str:
        return jsii.get(self, "billingMode")

    @builtins.property
    @jsii.member(jsii_name="hashKey")
    def hash_key(self) -> str:
        return jsii.get(self, "hashKey")

    @builtins.property
    @jsii.member(jsii_name="rangeKey")
    def range_key(self) -> str:
        return jsii.get(self, "rangeKey")

    @builtins.property
    @jsii.member(jsii_name="readCapacity")
    def read_capacity(self) -> jsii.Number:
        return jsii.get(self, "readCapacity")

    @builtins.property
    @jsii.member(jsii_name="streamArn")
    def stream_arn(self) -> str:
        return jsii.get(self, "streamArn")

    @builtins.property
    @jsii.member(jsii_name="streamEnabled")
    def stream_enabled(self) -> bool:
        return jsii.get(self, "streamEnabled")

    @builtins.property
    @jsii.member(jsii_name="streamLabel")
    def stream_label(self) -> str:
        return jsii.get(self, "streamLabel")

    @builtins.property
    @jsii.member(jsii_name="streamViewType")
    def stream_view_type(self) -> str:
        return jsii.get(self, "streamViewType")

    @builtins.property
    @jsii.member(jsii_name="writeCapacity")
    def write_capacity(self) -> jsii.Number:
        return jsii.get(self, "writeCapacity")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="serverSideEncryption")
    def server_side_encryption(
        self,
    ) -> typing.Optional[typing.List["DataAwsDynamodbTableServerSideEncryption"]]:
        return jsii.get(self, "serverSideEncryption")

    @server_side_encryption.setter
    def server_side_encryption(
        self,
        value: typing.Optional[typing.List["DataAwsDynamodbTableServerSideEncryption"]],
    ) -> None:
        jsii.set(self, "serverSideEncryption", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsDynamodbTableAttribute(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTableAttribute",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDynamodbTableAttribute,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "server_side_encryption": "serverSideEncryption",
        "tags": "tags",
    },
)
class DataAwsDynamodbTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        server_side_encryption: typing.Optional[
            typing.List["DataAwsDynamodbTableServerSideEncryption"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param server_side_encryption: server_side_encryption block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if server_side_encryption is not None:
            self._values["server_side_encryption"] = server_side_encryption
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def server_side_encryption(
        self,
    ) -> typing.Optional[typing.List["DataAwsDynamodbTableServerSideEncryption"]]:
        """server_side_encryption block."""
        return self._values.get("server_side_encryption")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDynamodbTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDynamodbTableGlobalSecondaryIndex(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTableGlobalSecondaryIndex",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDynamodbTableGlobalSecondaryIndex,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="hashKey")
    def hash_key(self) -> str:
        return jsii.get(self, "hashKey")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="nonKeyAttributes")
    def non_key_attributes(self) -> typing.List[str]:
        return jsii.get(self, "nonKeyAttributes")

    @builtins.property
    @jsii.member(jsii_name="projectionType")
    def projection_type(self) -> str:
        return jsii.get(self, "projectionType")

    @builtins.property
    @jsii.member(jsii_name="rangeKey")
    def range_key(self) -> str:
        return jsii.get(self, "rangeKey")

    @builtins.property
    @jsii.member(jsii_name="readCapacity")
    def read_capacity(self) -> jsii.Number:
        return jsii.get(self, "readCapacity")

    @builtins.property
    @jsii.member(jsii_name="writeCapacity")
    def write_capacity(self) -> jsii.Number:
        return jsii.get(self, "writeCapacity")


class DataAwsDynamodbTableLocalSecondaryIndex(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTableLocalSecondaryIndex",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDynamodbTableLocalSecondaryIndex,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="nonKeyAttributes")
    def non_key_attributes(self) -> typing.List[str]:
        return jsii.get(self, "nonKeyAttributes")

    @builtins.property
    @jsii.member(jsii_name="projectionType")
    def projection_type(self) -> str:
        return jsii.get(self, "projectionType")

    @builtins.property
    @jsii.member(jsii_name="rangeKey")
    def range_key(self) -> str:
        return jsii.get(self, "rangeKey")


class DataAwsDynamodbTablePointInTimeRecovery(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTablePointInTimeRecovery",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDynamodbTablePointInTimeRecovery,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")


class DataAwsDynamodbTableReplica(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTableReplica",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDynamodbTableReplica,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="regionName")
    def region_name(self) -> str:
        return jsii.get(self, "regionName")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTableServerSideEncryption",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataAwsDynamodbTableServerSideEncryption:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsDynamodbTableServerSideEncryption(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsDynamodbTableTtl(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsDynamodbTableTtl",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsDynamodbTableTtl,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="attributeName")
    def attribute_name(self) -> str:
        return jsii.get(self, "attributeName")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")


class DataAwsEbsDefaultKmsKey(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsDefaultKmsKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEbsDefaultKmsKeyConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsEbsDefaultKmsKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="keyArn")
    def key_arn(self) -> str:
        return jsii.get(self, "keyArn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsDefaultKmsKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsEbsDefaultKmsKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsDefaultKmsKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEbsEncryptionByDefault(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsEncryptionByDefault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEbsEncryptionByDefaultConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsEbsEncryptionByDefault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsEncryptionByDefaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsEbsEncryptionByDefaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsEncryptionByDefaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEbsSnapshot(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEbsSnapshotFilter"]] = None,
        most_recent: typing.Optional[bool] = None,
        owners: typing.Optional[typing.List[str]] = None,
        restorable_by_user_ids: typing.Optional[typing.List[str]] = None,
        snapshot_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param most_recent: 
        :param owners: 
        :param restorable_by_user_ids: 
        :param snapshot_ids: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEbsSnapshotConfig(
            filter=filter,
            most_recent=most_recent,
            owners=owners,
            restorable_by_user_ids=restorable_by_user_ids,
            snapshot_ids=snapshot_ids,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEbsSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dataEncryptionKeyId")
    def data_encryption_key_id(self) -> str:
        return jsii.get(self, "dataEncryptionKeyId")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="ownerAlias")
    def owner_alias(self) -> str:
        return jsii.get(self, "ownerAlias")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> str:
        return jsii.get(self, "snapshotId")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsSnapshotFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEbsSnapshotFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mostRecent")
    def most_recent(self) -> typing.Optional[bool]:
        return jsii.get(self, "mostRecent")

    @most_recent.setter
    def most_recent(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mostRecent", value)

    @builtins.property
    @jsii.member(jsii_name="owners")
    def owners(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "owners")

    @owners.setter
    def owners(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "owners", value)

    @builtins.property
    @jsii.member(jsii_name="restorableByUserIds")
    def restorable_by_user_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "restorableByUserIds")

    @restorable_by_user_ids.setter
    def restorable_by_user_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "restorableByUserIds", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotIds")
    def snapshot_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "snapshotIds")

    @snapshot_ids.setter
    def snapshot_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "snapshotIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "most_recent": "mostRecent",
        "owners": "owners",
        "restorable_by_user_ids": "restorableByUserIds",
        "snapshot_ids": "snapshotIds",
        "tags": "tags",
    },
)
class DataAwsEbsSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEbsSnapshotFilter"]] = None,
        most_recent: typing.Optional[bool] = None,
        owners: typing.Optional[typing.List[str]] = None,
        restorable_by_user_ids: typing.Optional[typing.List[str]] = None,
        snapshot_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param most_recent: 
        :param owners: 
        :param restorable_by_user_ids: 
        :param snapshot_ids: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if most_recent is not None:
            self._values["most_recent"] = most_recent
        if owners is not None:
            self._values["owners"] = owners
        if restorable_by_user_ids is not None:
            self._values["restorable_by_user_ids"] = restorable_by_user_ids
        if snapshot_ids is not None:
            self._values["snapshot_ids"] = snapshot_ids
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsSnapshotFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def most_recent(self) -> typing.Optional[bool]:
        return self._values.get("most_recent")

    @builtins.property
    def owners(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("owners")

    @builtins.property
    def restorable_by_user_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("restorable_by_user_ids")

    @builtins.property
    def snapshot_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("snapshot_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsSnapshotFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEbsSnapshotFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsSnapshotFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEbsSnapshotIds(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsSnapshotIds",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEbsSnapshotIdsFilter"]] = None,
        owners: typing.Optional[typing.List[str]] = None,
        restorable_by_user_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param owners: 
        :param restorable_by_user_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEbsSnapshotIdsConfig(
            filter=filter,
            owners=owners,
            restorable_by_user_ids=restorable_by_user_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEbsSnapshotIds, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsSnapshotIdsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEbsSnapshotIdsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="owners")
    def owners(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "owners")

    @owners.setter
    def owners(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "owners", value)

    @builtins.property
    @jsii.member(jsii_name="restorableByUserIds")
    def restorable_by_user_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "restorableByUserIds")

    @restorable_by_user_ids.setter
    def restorable_by_user_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "restorableByUserIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsSnapshotIdsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "owners": "owners",
        "restorable_by_user_ids": "restorableByUserIds",
    },
)
class DataAwsEbsSnapshotIdsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEbsSnapshotIdsFilter"]] = None,
        owners: typing.Optional[typing.List[str]] = None,
        restorable_by_user_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param owners: 
        :param restorable_by_user_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if owners is not None:
            self._values["owners"] = owners
        if restorable_by_user_ids is not None:
            self._values["restorable_by_user_ids"] = restorable_by_user_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsSnapshotIdsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def owners(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("owners")

    @builtins.property
    def restorable_by_user_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("restorable_by_user_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsSnapshotIdsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsSnapshotIdsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEbsSnapshotIdsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsSnapshotIdsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEbsVolume(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsVolume",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEbsVolumeFilter"]] = None,
        most_recent: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param most_recent: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEbsVolumeConfig(
            filter=filter,
            most_recent=most_recent,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEbsVolume, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="multiAttachEnabled")
    def multi_attach_enabled(self) -> bool:
        return jsii.get(self, "multiAttachEnabled")

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="size")
    def size(self) -> jsii.Number:
        return jsii.get(self, "size")

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> str:
        return jsii.get(self, "snapshotId")

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @builtins.property
    @jsii.member(jsii_name="volumeType")
    def volume_type(self) -> str:
        return jsii.get(self, "volumeType")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsVolumeFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEbsVolumeFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mostRecent")
    def most_recent(self) -> typing.Optional[bool]:
        return jsii.get(self, "mostRecent")

    @most_recent.setter
    def most_recent(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mostRecent", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsVolumeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "most_recent": "mostRecent",
        "tags": "tags",
    },
)
class DataAwsEbsVolumeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEbsVolumeFilter"]] = None,
        most_recent: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param most_recent: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if most_recent is not None:
            self._values["most_recent"] = most_recent
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsVolumeFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def most_recent(self) -> typing.Optional[bool]:
        return self._values.get("most_recent")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsVolumeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsVolumeFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEbsVolumeFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsVolumeFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEbsVolumes(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsVolumes",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEbsVolumesFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEbsVolumesConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEbsVolumes, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsVolumesFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEbsVolumesFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsVolumesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEbsVolumesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEbsVolumesFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEbsVolumesFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsVolumesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEbsVolumesFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEbsVolumesFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEbsVolumesFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2CoipPool(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2CoipPool",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEc2CoipPoolFilter"]] = None,
        local_gateway_route_table_id: typing.Optional[str] = None,
        pool_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param local_gateway_route_table_id: 
        :param pool_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2CoipPoolConfig(
            filter=filter,
            local_gateway_route_table_id=local_gateway_route_table_id,
            pool_id=pool_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2CoipPool, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="poolCidrs")
    def pool_cidrs(self) -> typing.List[str]:
        return jsii.get(self, "poolCidrs")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2CoipPoolFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEc2CoipPoolFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="localGatewayRouteTableId")
    def local_gateway_route_table_id(self) -> typing.Optional[str]:
        return jsii.get(self, "localGatewayRouteTableId")

    @local_gateway_route_table_id.setter
    def local_gateway_route_table_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "localGatewayRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="poolId")
    def pool_id(self) -> typing.Optional[str]:
        return jsii.get(self, "poolId")

    @pool_id.setter
    def pool_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "poolId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2CoipPoolConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "local_gateway_route_table_id": "localGatewayRouteTableId",
        "pool_id": "poolId",
        "tags": "tags",
    },
)
class DataAwsEc2CoipPoolConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEc2CoipPoolFilter"]] = None,
        local_gateway_route_table_id: typing.Optional[str] = None,
        pool_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param local_gateway_route_table_id: 
        :param pool_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if local_gateway_route_table_id is not None:
            self._values["local_gateway_route_table_id"] = local_gateway_route_table_id
        if pool_id is not None:
            self._values["pool_id"] = pool_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2CoipPoolFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def local_gateway_route_table_id(self) -> typing.Optional[str]:
        return self._values.get("local_gateway_route_table_id")

    @builtins.property
    def pool_id(self) -> typing.Optional[str]:
        return self._values.get("pool_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2CoipPoolConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2CoipPoolFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2CoipPoolFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2CoipPoolFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2CoipPools(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2CoipPools",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEc2CoipPoolsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2CoipPoolsConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2CoipPools, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="poolIds")
    def pool_ids(self) -> typing.List[str]:
        return jsii.get(self, "poolIds")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2CoipPoolsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEc2CoipPoolsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2CoipPoolsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2CoipPoolsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEc2CoipPoolsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2CoipPoolsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2CoipPoolsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2CoipPoolsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2CoipPoolsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2CoipPoolsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2InstanceTypeOffering(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2InstanceTypeOffering",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2InstanceTypeOfferingFilter"]
        ] = None,
        location_type: typing.Optional[str] = None,
        preferred_instance_types: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param location_type: 
        :param preferred_instance_types: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2InstanceTypeOfferingConfig(
            filter=filter,
            location_type=location_type,
            preferred_instance_types=preferred_instance_types,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2InstanceTypeOffering, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2InstanceTypeOfferingFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[typing.List["DataAwsEc2InstanceTypeOfferingFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="locationType")
    def location_type(self) -> typing.Optional[str]:
        return jsii.get(self, "locationType")

    @location_type.setter
    def location_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "locationType", value)

    @builtins.property
    @jsii.member(jsii_name="preferredInstanceTypes")
    def preferred_instance_types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "preferredInstanceTypes")

    @preferred_instance_types.setter
    def preferred_instance_types(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "preferredInstanceTypes", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2InstanceTypeOfferingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "location_type": "locationType",
        "preferred_instance_types": "preferredInstanceTypes",
    },
)
class DataAwsEc2InstanceTypeOfferingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2InstanceTypeOfferingFilter"]
        ] = None,
        location_type: typing.Optional[str] = None,
        preferred_instance_types: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param location_type: 
        :param preferred_instance_types: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if location_type is not None:
            self._values["location_type"] = location_type
        if preferred_instance_types is not None:
            self._values["preferred_instance_types"] = preferred_instance_types

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2InstanceTypeOfferingFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def location_type(self) -> typing.Optional[str]:
        return self._values.get("location_type")

    @builtins.property
    def preferred_instance_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("preferred_instance_types")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2InstanceTypeOfferingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2InstanceTypeOfferingFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2InstanceTypeOfferingFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2InstanceTypeOfferingFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2InstanceTypeOfferings(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2InstanceTypeOfferings",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2InstanceTypeOfferingsFilter"]
        ] = None,
        location_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param location_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2InstanceTypeOfferingsConfig(
            filter=filter,
            location_type=location_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2InstanceTypeOfferings, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="instanceTypes")
    def instance_types(self) -> typing.List[str]:
        return jsii.get(self, "instanceTypes")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2InstanceTypeOfferingsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[typing.List["DataAwsEc2InstanceTypeOfferingsFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="locationType")
    def location_type(self) -> typing.Optional[str]:
        return jsii.get(self, "locationType")

    @location_type.setter
    def location_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "locationType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2InstanceTypeOfferingsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "location_type": "locationType",
    },
)
class DataAwsEc2InstanceTypeOfferingsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2InstanceTypeOfferingsFilter"]
        ] = None,
        location_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param location_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if location_type is not None:
            self._values["location_type"] = location_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2InstanceTypeOfferingsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def location_type(self) -> typing.Optional[str]:
        return self._values.get("location_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2InstanceTypeOfferingsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2InstanceTypeOfferingsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2InstanceTypeOfferingsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2InstanceTypeOfferingsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2LocalGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEc2LocalGatewayFilter"]] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param state: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2LocalGatewayConfig(
            filter=filter,
            state=state,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2LocalGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEc2LocalGatewayFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "state": "state",
        "tags": "tags",
    },
)
class DataAwsEc2LocalGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEc2LocalGatewayFilter"]] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param state: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2LocalGatewayFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2LocalGatewayRouteTable(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayRouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayRouteTableFilter"]
        ] = None,
        local_gateway_id: typing.Optional[str] = None,
        local_gateway_route_table_id: typing.Optional[str] = None,
        outpost_arn: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param local_gateway_id: 
        :param local_gateway_route_table_id: 
        :param outpost_arn: 
        :param state: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2LocalGatewayRouteTableConfig(
            filter=filter,
            local_gateway_id=local_gateway_id,
            local_gateway_route_table_id=local_gateway_route_table_id,
            outpost_arn=outpost_arn,
            state=state,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2LocalGatewayRouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayRouteTableFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[typing.List["DataAwsEc2LocalGatewayRouteTableFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="localGatewayId")
    def local_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "localGatewayId")

    @local_gateway_id.setter
    def local_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "localGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="localGatewayRouteTableId")
    def local_gateway_route_table_id(self) -> typing.Optional[str]:
        return jsii.get(self, "localGatewayRouteTableId")

    @local_gateway_route_table_id.setter
    def local_gateway_route_table_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "localGatewayRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "outpostArn")

    @outpost_arn.setter
    def outpost_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "outpostArn", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "local_gateway_id": "localGatewayId",
        "local_gateway_route_table_id": "localGatewayRouteTableId",
        "outpost_arn": "outpostArn",
        "state": "state",
        "tags": "tags",
    },
)
class DataAwsEc2LocalGatewayRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayRouteTableFilter"]
        ] = None,
        local_gateway_id: typing.Optional[str] = None,
        local_gateway_route_table_id: typing.Optional[str] = None,
        outpost_arn: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param local_gateway_id: 
        :param local_gateway_route_table_id: 
        :param outpost_arn: 
        :param state: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if local_gateway_id is not None:
            self._values["local_gateway_id"] = local_gateway_id
        if local_gateway_route_table_id is not None:
            self._values["local_gateway_route_table_id"] = local_gateway_route_table_id
        if outpost_arn is not None:
            self._values["outpost_arn"] = outpost_arn
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayRouteTableFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def local_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("local_gateway_id")

    @builtins.property
    def local_gateway_route_table_id(self) -> typing.Optional[str]:
        return self._values.get("local_gateway_route_table_id")

    @builtins.property
    def outpost_arn(self) -> typing.Optional[str]:
        return self._values.get("outpost_arn")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayRouteTableFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2LocalGatewayRouteTableFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayRouteTableFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2LocalGatewayRouteTables(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayRouteTables",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayRouteTablesFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2LocalGatewayRouteTablesConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2LocalGatewayRouteTables, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayRouteTablesFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[typing.List["DataAwsEc2LocalGatewayRouteTablesFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayRouteTablesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2LocalGatewayRouteTablesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayRouteTablesFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayRouteTablesFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayRouteTablesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayRouteTablesFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2LocalGatewayRouteTablesFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayRouteTablesFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2LocalGatewayVirtualInterface(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2LocalGatewayVirtualInterfaceConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2LocalGatewayVirtualInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="localAddress")
    def local_address(self) -> str:
        return jsii.get(self, "localAddress")

    @builtins.property
    @jsii.member(jsii_name="localBgpAsn")
    def local_bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "localBgpAsn")

    @builtins.property
    @jsii.member(jsii_name="localGatewayId")
    def local_gateway_id(self) -> str:
        return jsii.get(self, "localGatewayId")

    @builtins.property
    @jsii.member(jsii_name="localGatewayVirtualInterfaceIds")
    def local_gateway_virtual_interface_ids(self) -> typing.List[str]:
        return jsii.get(self, "localGatewayVirtualInterfaceIds")

    @builtins.property
    @jsii.member(jsii_name="peerAddress")
    def peer_address(self) -> str:
        return jsii.get(self, "peerAddress")

    @builtins.property
    @jsii.member(jsii_name="peerBgpAsn")
    def peer_bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "peerBgpAsn")

    @builtins.property
    @jsii.member(jsii_name="vlan")
    def vlan(self) -> jsii.Number:
        return jsii.get(self, "vlan")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayVirtualInterfaceFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceFilter"]
        ],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2LocalGatewayVirtualInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2LocalGatewayVirtualInterfaceFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayVirtualInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2LocalGatewayVirtualInterfaceFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayVirtualInterfaceFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2LocalGatewayVirtualInterfaceGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter"]
        ] = None,
        local_gateway_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param local_gateway_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2LocalGatewayVirtualInterfaceGroupConfig(
            filter=filter,
            local_gateway_id=local_gateway_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(
            DataAwsEc2LocalGatewayVirtualInterfaceGroup, self, [scope, id, config]
        )

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="localGatewayVirtualInterfaceIds")
    def local_gateway_virtual_interface_ids(self) -> typing.List[str]:
        return jsii.get(self, "localGatewayVirtualInterfaceIds")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter"]
    ]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter"]
        ],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="localGatewayId")
    def local_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "localGatewayId")

    @local_gateway_id.setter
    def local_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "localGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "local_gateway_id": "localGatewayId",
        "tags": "tags",
    },
)
class DataAwsEc2LocalGatewayVirtualInterfaceGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter"]
        ] = None,
        local_gateway_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param local_gateway_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if local_gateway_id is not None:
            self._values["local_gateway_id"] = local_gateway_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter"]
    ]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def local_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("local_gateway_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayVirtualInterfaceGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2LocalGatewayVirtualInterfaceGroups(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceGroups",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2LocalGatewayVirtualInterfaceGroupsConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(
            DataAwsEc2LocalGatewayVirtualInterfaceGroups, self, [scope, id, config]
        )

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="localGatewayVirtualInterfaceIds")
    def local_gateway_virtual_interface_ids(self) -> typing.List[str]:
        return jsii.get(self, "localGatewayVirtualInterfaceIds")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter"]
    ]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter"]
        ],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceGroupsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2LocalGatewayVirtualInterfaceGroupsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter"]
    ]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayVirtualInterfaceGroupsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2LocalGateways(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGateways",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEc2LocalGatewaysFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2LocalGatewaysConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2LocalGateways, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2LocalGatewaysFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEc2LocalGatewaysFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewaysConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2LocalGatewaysConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEc2LocalGatewaysFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2LocalGatewaysFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewaysConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2LocalGatewaysFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2LocalGatewaysFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2LocalGatewaysFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2TransitGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEc2TransitGatewayFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2TransitGatewayConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2TransitGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> jsii.Number:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="associationDefaultRouteTableId")
    def association_default_route_table_id(self) -> str:
        return jsii.get(self, "associationDefaultRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="autoAcceptSharedAttachments")
    def auto_accept_shared_attachments(self) -> str:
        return jsii.get(self, "autoAcceptSharedAttachments")

    @builtins.property
    @jsii.member(jsii_name="defaultRouteTableAssociation")
    def default_route_table_association(self) -> str:
        return jsii.get(self, "defaultRouteTableAssociation")

    @builtins.property
    @jsii.member(jsii_name="defaultRouteTablePropagation")
    def default_route_table_propagation(self) -> str:
        return jsii.get(self, "defaultRouteTablePropagation")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="dnsSupport")
    def dns_support(self) -> str:
        return jsii.get(self, "dnsSupport")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="propagationDefaultRouteTableId")
    def propagation_default_route_table_id(self) -> str:
        return jsii.get(self, "propagationDefaultRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="vpnEcmpSupport")
    def vpn_ecmp_support(self) -> str:
        return jsii.get(self, "vpnEcmpSupport")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsEc2TransitGatewayFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2TransitGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEc2TransitGatewayFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2TransitGatewayDxGatewayAttachment(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayDxGatewayAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dx_gateway_id: typing.Optional[str] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayDxGatewayAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dx_gateway_id: 
        :param filter: filter block.
        :param tags: 
        :param transit_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2TransitGatewayDxGatewayAttachmentConfig(
            dx_gateway_id=dx_gateway_id,
            filter=filter,
            tags=tags,
            transit_gateway_id=transit_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(
            DataAwsEc2TransitGatewayDxGatewayAttachment, self, [scope, id, config]
        )

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dxGatewayId")
    def dx_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "dxGatewayId")

    @dx_gateway_id.setter
    def dx_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dxGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2TransitGatewayDxGatewayAttachmentFilter"]
    ]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayDxGatewayAttachmentFilter"]
        ],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "transitGatewayId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayDxGatewayAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dx_gateway_id": "dxGatewayId",
        "filter": "filter",
        "tags": "tags",
        "transit_gateway_id": "transitGatewayId",
    },
)
class DataAwsEc2TransitGatewayDxGatewayAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dx_gateway_id: typing.Optional[str] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayDxGatewayAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dx_gateway_id: 
        :param filter: filter block.
        :param tags: 
        :param transit_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dx_gateway_id is not None:
            self._values["dx_gateway_id"] = dx_gateway_id
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags
        if transit_gateway_id is not None:
            self._values["transit_gateway_id"] = transit_gateway_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dx_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("dx_gateway_id")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2TransitGatewayDxGatewayAttachmentFilter"]
    ]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def transit_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayDxGatewayAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayDxGatewayAttachmentFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2TransitGatewayDxGatewayAttachmentFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayDxGatewayAttachmentFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2TransitGatewayFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2TransitGatewayPeeringAttachment(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayPeeringAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayPeeringAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2TransitGatewayPeeringAttachmentConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(
            DataAwsEc2TransitGatewayPeeringAttachment, self, [scope, id, config]
        )

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="peerAccountId")
    def peer_account_id(self) -> str:
        return jsii.get(self, "peerAccountId")

    @builtins.property
    @jsii.member(jsii_name="peerRegion")
    def peer_region(self) -> str:
        return jsii.get(self, "peerRegion")

    @builtins.property
    @jsii.member(jsii_name="peerTransitGatewayId")
    def peer_transit_gateway_id(self) -> str:
        return jsii.get(self, "peerTransitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2TransitGatewayPeeringAttachmentFilter"]
    ]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayPeeringAttachmentFilter"]
        ],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayPeeringAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2TransitGatewayPeeringAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayPeeringAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[
        typing.List["DataAwsEc2TransitGatewayPeeringAttachmentFilter"]
    ]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayPeeringAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayPeeringAttachmentFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2TransitGatewayPeeringAttachmentFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayPeeringAttachmentFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2TransitGatewayRouteTable(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayRouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayRouteTableFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2TransitGatewayRouteTableConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2TransitGatewayRouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="defaultAssociationRouteTable")
    def default_association_route_table(self) -> bool:
        return jsii.get(self, "defaultAssociationRouteTable")

    @builtins.property
    @jsii.member(jsii_name="defaultPropagationRouteTable")
    def default_propagation_route_table(self) -> bool:
        return jsii.get(self, "defaultPropagationRouteTable")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayRouteTableFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[typing.List["DataAwsEc2TransitGatewayRouteTableFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2TransitGatewayRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayRouteTableFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayRouteTableFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayRouteTableFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2TransitGatewayRouteTableFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayRouteTableFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2TransitGatewayVpcAttachment(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayVpcAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayVpcAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2TransitGatewayVpcAttachmentConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2TransitGatewayVpcAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dnsSupport")
    def dns_support(self) -> str:
        return jsii.get(self, "dnsSupport")

    @builtins.property
    @jsii.member(jsii_name="ipv6Support")
    def ipv6_support(self) -> str:
        return jsii.get(self, "ipv6Support")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="vpcOwnerId")
    def vpc_owner_id(self) -> str:
        return jsii.get(self, "vpcOwnerId")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayVpcAttachmentFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayVpcAttachmentFilter"]
        ],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayVpcAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsEc2TransitGatewayVpcAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayVpcAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayVpcAttachmentFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayVpcAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayVpcAttachmentFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2TransitGatewayVpcAttachmentFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayVpcAttachmentFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEc2TransitGatewayVpnAttachment(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayVpnAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayVpnAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpn_connection_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param transit_gateway_id: 
        :param vpn_connection_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEc2TransitGatewayVpnAttachmentConfig(
            filter=filter,
            tags=tags,
            transit_gateway_id=transit_gateway_id,
            vpn_connection_id=vpn_connection_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEc2TransitGatewayVpnAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayVpnAttachmentFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayVpnAttachmentFilter"]
        ],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "transitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="vpnConnectionId")
    def vpn_connection_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpnConnectionId")

    @vpn_connection_id.setter
    def vpn_connection_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpnConnectionId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayVpnAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
        "transit_gateway_id": "transitGatewayId",
        "vpn_connection_id": "vpnConnectionId",
    },
)
class DataAwsEc2TransitGatewayVpnAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[
            typing.List["DataAwsEc2TransitGatewayVpnAttachmentFilter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpn_connection_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        :param transit_gateway_id: 
        :param vpn_connection_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags
        if transit_gateway_id is not None:
            self._values["transit_gateway_id"] = transit_gateway_id
        if vpn_connection_id is not None:
            self._values["vpn_connection_id"] = vpn_connection_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsEc2TransitGatewayVpnAttachmentFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def transit_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def vpn_connection_id(self) -> typing.Optional[str]:
        return self._values.get("vpn_connection_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayVpnAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEc2TransitGatewayVpnAttachmentFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEc2TransitGatewayVpnAttachmentFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEc2TransitGatewayVpnAttachmentFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEcrAuthorizationToken(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcrAuthorizationToken",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        registry_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param registry_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEcrAuthorizationTokenConfig(
            registry_id=registry_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEcrAuthorizationToken, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="authorizationToken")
    def authorization_token(self) -> str:
        return jsii.get(self, "authorizationToken")

    @builtins.property
    @jsii.member(jsii_name="expiresAt")
    def expires_at(self) -> str:
        return jsii.get(self, "expiresAt")

    @builtins.property
    @jsii.member(jsii_name="password")
    def password(self) -> str:
        return jsii.get(self, "password")

    @builtins.property
    @jsii.member(jsii_name="proxyEndpoint")
    def proxy_endpoint(self) -> str:
        return jsii.get(self, "proxyEndpoint")

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> str:
        return jsii.get(self, "userName")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> typing.Optional[str]:
        return jsii.get(self, "registryId")

    @registry_id.setter
    def registry_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "registryId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcrAuthorizationTokenConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "registry_id": "registryId",
    },
)
class DataAwsEcrAuthorizationTokenConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        registry_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param registry_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if registry_id is not None:
            self._values["registry_id"] = registry_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def registry_id(self) -> typing.Optional[str]:
        return self._values.get("registry_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEcrAuthorizationTokenConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEcrImage(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcrImage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        repository_name: str,
        image_digest: typing.Optional[str] = None,
        image_tag: typing.Optional[str] = None,
        registry_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param repository_name: 
        :param image_digest: 
        :param image_tag: 
        :param registry_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEcrImageConfig(
            repository_name=repository_name,
            image_digest=image_digest,
            image_tag=image_tag,
            registry_id=registry_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEcrImage, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="imagePushedAt")
    def image_pushed_at(self) -> jsii.Number:
        return jsii.get(self, "imagePushedAt")

    @builtins.property
    @jsii.member(jsii_name="imageSizeInBytes")
    def image_size_in_bytes(self) -> jsii.Number:
        return jsii.get(self, "imageSizeInBytes")

    @builtins.property
    @jsii.member(jsii_name="imageTags")
    def image_tags(self) -> typing.List[str]:
        return jsii.get(self, "imageTags")

    @builtins.property
    @jsii.member(jsii_name="repositoryName")
    def repository_name(self) -> str:
        return jsii.get(self, "repositoryName")

    @repository_name.setter
    def repository_name(self, value: str) -> None:
        jsii.set(self, "repositoryName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="imageDigest")
    def image_digest(self) -> typing.Optional[str]:
        return jsii.get(self, "imageDigest")

    @image_digest.setter
    def image_digest(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "imageDigest", value)

    @builtins.property
    @jsii.member(jsii_name="imageTag")
    def image_tag(self) -> typing.Optional[str]:
        return jsii.get(self, "imageTag")

    @image_tag.setter
    def image_tag(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "imageTag", value)

    @builtins.property
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> typing.Optional[str]:
        return jsii.get(self, "registryId")

    @registry_id.setter
    def registry_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "registryId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcrImageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "repository_name": "repositoryName",
        "image_digest": "imageDigest",
        "image_tag": "imageTag",
        "registry_id": "registryId",
    },
)
class DataAwsEcrImageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        repository_name: str,
        image_digest: typing.Optional[str] = None,
        image_tag: typing.Optional[str] = None,
        registry_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param repository_name: 
        :param image_digest: 
        :param image_tag: 
        :param registry_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "repository_name": repository_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if image_digest is not None:
            self._values["image_digest"] = image_digest
        if image_tag is not None:
            self._values["image_tag"] = image_tag
        if registry_id is not None:
            self._values["registry_id"] = registry_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def repository_name(self) -> str:
        return self._values.get("repository_name")

    @builtins.property
    def image_digest(self) -> typing.Optional[str]:
        return self._values.get("image_digest")

    @builtins.property
    def image_tag(self) -> typing.Optional[str]:
        return self._values.get("image_tag")

    @builtins.property
    def registry_id(self) -> typing.Optional[str]:
        return self._values.get("registry_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEcrImageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEcrRepository(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcrRepository",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEcrRepositoryConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEcrRepository, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> str:
        return jsii.get(self, "registryId")

    @builtins.property
    @jsii.member(jsii_name="repositoryUrl")
    def repository_url(self) -> str:
        return jsii.get(self, "repositoryUrl")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcrRepositoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsEcrRepositoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEcrRepositoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEcsCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEcsClusterConfig(
            cluster_name=cluster_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEcsCluster, self, [scope, id, config])

    @jsii.member(jsii_name="setting")
    def setting(self, index: str) -> "DataAwsEcsClusterSetting":
        """
        :param index: -
        """
        return jsii.invoke(self, "setting", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="pendingTasksCount")
    def pending_tasks_count(self) -> jsii.Number:
        return jsii.get(self, "pendingTasksCount")

    @builtins.property
    @jsii.member(jsii_name="registeredContainerInstancesCount")
    def registered_container_instances_count(self) -> jsii.Number:
        return jsii.get(self, "registeredContainerInstancesCount")

    @builtins.property
    @jsii.member(jsii_name="runningTasksCount")
    def running_tasks_count(self) -> jsii.Number:
        return jsii.get(self, "runningTasksCount")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter
    def cluster_name(self, value: str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_name": "clusterName",
    },
)
class DataAwsEcsClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_name": cluster_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_name(self) -> str:
        return self._values.get("cluster_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEcsClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEcsClusterSetting(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsClusterSetting",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEcsClusterSetting,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")


class DataAwsEcsContainerDefinition(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsContainerDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        container_name: str,
        task_definition: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param container_name: 
        :param task_definition: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEcsContainerDefinitionConfig(
            container_name=container_name,
            task_definition=task_definition,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEcsContainerDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="dockerLabels")
    def docker_labels(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "dockerLabels", [key])

    @jsii.member(jsii_name="environment")
    def environment(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "environment", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cpu")
    def cpu(self) -> jsii.Number:
        return jsii.get(self, "cpu")

    @builtins.property
    @jsii.member(jsii_name="disableNetworking")
    def disable_networking(self) -> bool:
        return jsii.get(self, "disableNetworking")

    @builtins.property
    @jsii.member(jsii_name="image")
    def image(self) -> str:
        return jsii.get(self, "image")

    @builtins.property
    @jsii.member(jsii_name="imageDigest")
    def image_digest(self) -> str:
        return jsii.get(self, "imageDigest")

    @builtins.property
    @jsii.member(jsii_name="memory")
    def memory(self) -> jsii.Number:
        return jsii.get(self, "memory")

    @builtins.property
    @jsii.member(jsii_name="memoryReservation")
    def memory_reservation(self) -> jsii.Number:
        return jsii.get(self, "memoryReservation")

    @builtins.property
    @jsii.member(jsii_name="containerName")
    def container_name(self) -> str:
        return jsii.get(self, "containerName")

    @container_name.setter
    def container_name(self, value: str) -> None:
        jsii.set(self, "containerName", value)

    @builtins.property
    @jsii.member(jsii_name="taskDefinition")
    def task_definition(self) -> str:
        return jsii.get(self, "taskDefinition")

    @task_definition.setter
    def task_definition(self, value: str) -> None:
        jsii.set(self, "taskDefinition", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsContainerDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "container_name": "containerName",
        "task_definition": "taskDefinition",
    },
)
class DataAwsEcsContainerDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        container_name: str,
        task_definition: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param container_name: 
        :param task_definition: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "container_name": container_name,
            "task_definition": task_definition,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def container_name(self) -> str:
        return self._values.get("container_name")

    @builtins.property
    def task_definition(self) -> str:
        return self._values.get("task_definition")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEcsContainerDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEcsService(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_arn: str,
        service_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_arn: 
        :param service_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEcsServiceConfig(
            cluster_arn=cluster_arn,
            service_name=service_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEcsService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="desiredCount")
    def desired_count(self) -> jsii.Number:
        return jsii.get(self, "desiredCount")

    @builtins.property
    @jsii.member(jsii_name="launchType")
    def launch_type(self) -> str:
        return jsii.get(self, "launchType")

    @builtins.property
    @jsii.member(jsii_name="schedulingStrategy")
    def scheduling_strategy(self) -> str:
        return jsii.get(self, "schedulingStrategy")

    @builtins.property
    @jsii.member(jsii_name="taskDefinition")
    def task_definition(self) -> str:
        return jsii.get(self, "taskDefinition")

    @builtins.property
    @jsii.member(jsii_name="clusterArn")
    def cluster_arn(self) -> str:
        return jsii.get(self, "clusterArn")

    @cluster_arn.setter
    def cluster_arn(self, value: str) -> None:
        jsii.set(self, "clusterArn", value)

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> str:
        return jsii.get(self, "serviceName")

    @service_name.setter
    def service_name(self, value: str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_arn": "clusterArn",
        "service_name": "serviceName",
    },
)
class DataAwsEcsServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_arn: str,
        service_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_arn: 
        :param service_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_arn": cluster_arn,
            "service_name": service_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_arn(self) -> str:
        return self._values.get("cluster_arn")

    @builtins.property
    def service_name(self) -> str:
        return self._values.get("service_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEcsServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEcsTaskDefinition(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsTaskDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        task_definition: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param task_definition: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEcsTaskDefinitionConfig(
            task_definition=task_definition,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEcsTaskDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @builtins.property
    @jsii.member(jsii_name="networkMode")
    def network_mode(self) -> str:
        return jsii.get(self, "networkMode")

    @builtins.property
    @jsii.member(jsii_name="revision")
    def revision(self) -> jsii.Number:
        return jsii.get(self, "revision")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="taskRoleArn")
    def task_role_arn(self) -> str:
        return jsii.get(self, "taskRoleArn")

    @builtins.property
    @jsii.member(jsii_name="taskDefinition")
    def task_definition(self) -> str:
        return jsii.get(self, "taskDefinition")

    @task_definition.setter
    def task_definition(self, value: str) -> None:
        jsii.set(self, "taskDefinition", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEcsTaskDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "task_definition": "taskDefinition",
    },
)
class DataAwsEcsTaskDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        task_definition: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param task_definition: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "task_definition": task_definition,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def task_definition(self) -> str:
        return self._values.get("task_definition")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEcsTaskDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEfsAccessPoint(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsAccessPoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        access_point_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param access_point_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEfsAccessPointConfig(
            access_point_id=access_point_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEfsAccessPoint, self, [scope, id, config])

    @jsii.member(jsii_name="posixUser")
    def posix_user(self, index: str) -> "DataAwsEfsAccessPointPosixUser":
        """
        :param index: -
        """
        return jsii.invoke(self, "posixUser", [index])

    @jsii.member(jsii_name="rootDirectory")
    def root_directory(self, index: str) -> "DataAwsEfsAccessPointRootDirectory":
        """
        :param index: -
        """
        return jsii.invoke(self, "rootDirectory", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="fileSystemArn")
    def file_system_arn(self) -> str:
        return jsii.get(self, "fileSystemArn")

    @builtins.property
    @jsii.member(jsii_name="fileSystemId")
    def file_system_id(self) -> str:
        return jsii.get(self, "fileSystemId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="accessPointId")
    def access_point_id(self) -> str:
        return jsii.get(self, "accessPointId")

    @access_point_id.setter
    def access_point_id(self, value: str) -> None:
        jsii.set(self, "accessPointId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsAccessPointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_point_id": "accessPointId",
        "tags": "tags",
    },
)
class DataAwsEfsAccessPointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_point_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_point_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "access_point_id": access_point_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def access_point_id(self) -> str:
        return self._values.get("access_point_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEfsAccessPointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEfsAccessPointPosixUser(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsAccessPointPosixUser",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEfsAccessPointPosixUser,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="gid")
    def gid(self) -> jsii.Number:
        return jsii.get(self, "gid")

    @builtins.property
    @jsii.member(jsii_name="secondaryGids")
    def secondary_gids(self) -> typing.Any:
        return jsii.get(self, "secondaryGids")

    @builtins.property
    @jsii.member(jsii_name="uid")
    def uid(self) -> jsii.Number:
        return jsii.get(self, "uid")


class DataAwsEfsAccessPointRootDirectory(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsAccessPointRootDirectory",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEfsAccessPointRootDirectory,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="creationInfo")
    def creation_info(self) -> typing.Any:
        return jsii.get(self, "creationInfo")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")


class DataAwsEfsAccessPointRootDirectoryCreationInfo(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsAccessPointRootDirectoryCreationInfo",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEfsAccessPointRootDirectoryCreationInfo,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="ownerGid")
    def owner_gid(self) -> jsii.Number:
        return jsii.get(self, "ownerGid")

    @builtins.property
    @jsii.member(jsii_name="ownerUid")
    def owner_uid(self) -> jsii.Number:
        return jsii.get(self, "ownerUid")

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(self) -> str:
        return jsii.get(self, "permissions")


class DataAwsEfsAccessPoints(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsAccessPoints",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        file_system_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param file_system_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEfsAccessPointsConfig(
            file_system_id=file_system_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEfsAccessPoints, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arns")
    def arns(self) -> typing.List[str]:
        return jsii.get(self, "arns")

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="fileSystemId")
    def file_system_id(self) -> str:
        return jsii.get(self, "fileSystemId")

    @file_system_id.setter
    def file_system_id(self, value: str) -> None:
        jsii.set(self, "fileSystemId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsAccessPointsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "file_system_id": "fileSystemId",
    },
)
class DataAwsEfsAccessPointsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        file_system_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param file_system_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "file_system_id": file_system_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def file_system_id(self) -> str:
        return self._values.get("file_system_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEfsAccessPointsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEfsFileSystem(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsFileSystem",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        creation_token: typing.Optional[str] = None,
        file_system_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param creation_token: 
        :param file_system_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEfsFileSystemConfig(
            creation_token=creation_token,
            file_system_id=file_system_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEfsFileSystem, self, [scope, id, config])

    @jsii.member(jsii_name="lifecyclePolicy")
    def lifecycle_policy(self, index: str) -> "DataAwsEfsFileSystemLifecyclePolicy":
        """
        :param index: -
        """
        return jsii.invoke(self, "lifecyclePolicy", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="performanceMode")
    def performance_mode(self) -> str:
        return jsii.get(self, "performanceMode")

    @builtins.property
    @jsii.member(jsii_name="provisionedThroughputInMibps")
    def provisioned_throughput_in_mibps(self) -> jsii.Number:
        return jsii.get(self, "provisionedThroughputInMibps")

    @builtins.property
    @jsii.member(jsii_name="sizeInBytes")
    def size_in_bytes(self) -> jsii.Number:
        return jsii.get(self, "sizeInBytes")

    @builtins.property
    @jsii.member(jsii_name="throughputMode")
    def throughput_mode(self) -> str:
        return jsii.get(self, "throughputMode")

    @builtins.property
    @jsii.member(jsii_name="creationToken")
    def creation_token(self) -> typing.Optional[str]:
        return jsii.get(self, "creationToken")

    @creation_token.setter
    def creation_token(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "creationToken", value)

    @builtins.property
    @jsii.member(jsii_name="fileSystemId")
    def file_system_id(self) -> typing.Optional[str]:
        return jsii.get(self, "fileSystemId")

    @file_system_id.setter
    def file_system_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "fileSystemId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsFileSystemConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "creation_token": "creationToken",
        "file_system_id": "fileSystemId",
        "tags": "tags",
    },
)
class DataAwsEfsFileSystemConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        creation_token: typing.Optional[str] = None,
        file_system_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param creation_token: 
        :param file_system_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if creation_token is not None:
            self._values["creation_token"] = creation_token
        if file_system_id is not None:
            self._values["file_system_id"] = file_system_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def creation_token(self) -> typing.Optional[str]:
        return self._values.get("creation_token")

    @builtins.property
    def file_system_id(self) -> typing.Optional[str]:
        return self._values.get("file_system_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEfsFileSystemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEfsFileSystemLifecyclePolicy(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsFileSystemLifecyclePolicy",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEfsFileSystemLifecyclePolicy,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="transitionToIa")
    def transition_to_ia(self) -> str:
        return jsii.get(self, "transitionToIa")


class DataAwsEfsMountTarget(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsMountTarget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        mount_target_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param mount_target_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEfsMountTargetConfig(
            mount_target_id=mount_target_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEfsMountTarget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> str:
        return jsii.get(self, "availabilityZoneId")

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneName")
    def availability_zone_name(self) -> str:
        return jsii.get(self, "availabilityZoneName")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="fileSystemArn")
    def file_system_arn(self) -> str:
        return jsii.get(self, "fileSystemArn")

    @builtins.property
    @jsii.member(jsii_name="fileSystemId")
    def file_system_id(self) -> str:
        return jsii.get(self, "fileSystemId")

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")

    @builtins.property
    @jsii.member(jsii_name="mountTargetDnsName")
    def mount_target_dns_name(self) -> str:
        return jsii.get(self, "mountTargetDnsName")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @builtins.property
    @jsii.member(jsii_name="mountTargetId")
    def mount_target_id(self) -> str:
        return jsii.get(self, "mountTargetId")

    @mount_target_id.setter
    def mount_target_id(self, value: str) -> None:
        jsii.set(self, "mountTargetId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEfsMountTargetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "mount_target_id": "mountTargetId",
    },
)
class DataAwsEfsMountTargetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        mount_target_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param mount_target_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "mount_target_id": mount_target_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def mount_target_id(self) -> str:
        return self._values.get("mount_target_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEfsMountTargetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEip(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEip",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsEipFilter"]] = None,
        public_ip: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param public_ip: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEipConfig(
            filter=filter,
            public_ip=public_ip,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEip, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="associationId")
    def association_id(self) -> str:
        return jsii.get(self, "associationId")

    @builtins.property
    @jsii.member(jsii_name="customerOwnedIp")
    def customer_owned_ip(self) -> str:
        return jsii.get(self, "customerOwnedIp")

    @builtins.property
    @jsii.member(jsii_name="customerOwnedIpv4Pool")
    def customer_owned_ipv4_pool(self) -> str:
        return jsii.get(self, "customerOwnedIpv4Pool")

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> str:
        return jsii.get(self, "instanceId")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceOwnerId")
    def network_interface_owner_id(self) -> str:
        return jsii.get(self, "networkInterfaceOwnerId")

    @builtins.property
    @jsii.member(jsii_name="privateDns")
    def private_dns(self) -> str:
        return jsii.get(self, "privateDns")

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> str:
        return jsii.get(self, "privateIp")

    @builtins.property
    @jsii.member(jsii_name="publicDns")
    def public_dns(self) -> str:
        return jsii.get(self, "publicDns")

    @builtins.property
    @jsii.member(jsii_name="publicIpv4Pool")
    def public_ipv4_pool(self) -> str:
        return jsii.get(self, "publicIpv4Pool")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsEipFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(self, value: typing.Optional[typing.List["DataAwsEipFilter"]]) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "publicIp")

    @public_ip.setter
    def public_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "publicIp", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEipConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "public_ip": "publicIp",
        "tags": "tags",
    },
)
class DataAwsEipConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsEipFilter"]] = None,
        public_ip: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param public_ip: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if public_ip is not None:
            self._values["public_ip"] = public_ip
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsEipFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def public_ip(self) -> typing.Optional[str]:
        return self._values.get("public_ip")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEipConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEipFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsEipFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEipFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEksCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEksClusterConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEksCluster, self, [scope, id, config])

    @jsii.member(jsii_name="certificateAuthority")
    def certificate_authority(
        self, index: str
    ) -> "DataAwsEksClusterCertificateAuthority":
        """
        :param index: -
        """
        return jsii.invoke(self, "certificateAuthority", [index])

    @jsii.member(jsii_name="identity")
    def identity(self, index: str) -> "DataAwsEksClusterIdentity":
        """
        :param index: -
        """
        return jsii.invoke(self, "identity", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="vpcConfig")
    def vpc_config(self, index: str) -> "DataAwsEksClusterVpcConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "vpcConfig", [index])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> str:
        return jsii.get(self, "createdAt")

    @builtins.property
    @jsii.member(jsii_name="enabledClusterLogTypes")
    def enabled_cluster_log_types(self) -> typing.List[str]:
        return jsii.get(self, "enabledClusterLogTypes")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="platformVersion")
    def platform_version(self) -> str:
        return jsii.get(self, "platformVersion")

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsEksClusterAuth(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksClusterAuth",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsEksClusterAuthConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsEksClusterAuth, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="token")
    def token(self) -> str:
        return jsii.get(self, "token")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksClusterAuthConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsEksClusterAuthConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEksClusterAuthConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEksClusterCertificateAuthority(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksClusterCertificateAuthority",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEksClusterCertificateAuthority,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="data")
    def data(self) -> str:
        return jsii.get(self, "data")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsEksClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsEksClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsEksClusterIdentity(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksClusterIdentity",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEksClusterIdentity,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="oidc")
    def oidc(self) -> typing.Any:
        return jsii.get(self, "oidc")


class DataAwsEksClusterIdentityOidc(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksClusterIdentityOidc",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEksClusterIdentityOidc,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> str:
        return jsii.get(self, "issuer")


class DataAwsEksClusterVpcConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsEksClusterVpcConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsEksClusterVpcConfig,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="clusterSecurityGroupId")
    def cluster_security_group_id(self) -> str:
        return jsii.get(self, "clusterSecurityGroupId")

    @builtins.property
    @jsii.member(jsii_name="endpointPrivateAccess")
    def endpoint_private_access(self) -> bool:
        return jsii.get(self, "endpointPrivateAccess")

    @builtins.property
    @jsii.member(jsii_name="endpointPublicAccess")
    def endpoint_public_access(self) -> bool:
        return jsii.get(self, "endpointPublicAccess")

    @builtins.property
    @jsii.member(jsii_name="publicAccessCidrs")
    def public_access_cidrs(self) -> typing.List[str]:
        return jsii.get(self, "publicAccessCidrs")

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")


class DataAwsElasticBeanstalkApplication(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticBeanstalkApplication",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElasticBeanstalkApplicationConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElasticBeanstalkApplication, self, [scope, id, config])

    @jsii.member(jsii_name="appversionLifecycle")
    def appversion_lifecycle(
        self, index: str
    ) -> "DataAwsElasticBeanstalkApplicationAppversionLifecycle":
        """
        :param index: -
        """
        return jsii.invoke(self, "appversionLifecycle", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class DataAwsElasticBeanstalkApplicationAppversionLifecycle(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticBeanstalkApplicationAppversionLifecycle",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticBeanstalkApplicationAppversionLifecycle,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deleteSourceFromS3")
    def delete_source_from_s3(self) -> bool:
        return jsii.get(self, "deleteSourceFromS3")

    @builtins.property
    @jsii.member(jsii_name="maxAgeInDays")
    def max_age_in_days(self) -> jsii.Number:
        return jsii.get(self, "maxAgeInDays")

    @builtins.property
    @jsii.member(jsii_name="maxCount")
    def max_count(self) -> jsii.Number:
        return jsii.get(self, "maxCount")

    @builtins.property
    @jsii.member(jsii_name="serviceRole")
    def service_role(self) -> str:
        return jsii.get(self, "serviceRole")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticBeanstalkApplicationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsElasticBeanstalkApplicationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElasticBeanstalkApplicationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElasticBeanstalkHostedZone(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticBeanstalkHostedZone",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        region: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param region: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElasticBeanstalkHostedZoneConfig(
            region=region,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElasticBeanstalkHostedZone, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticBeanstalkHostedZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "region": "region",
    },
)
class DataAwsElasticBeanstalkHostedZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        region: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param region: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElasticBeanstalkHostedZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElasticBeanstalkSolutionStack(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticBeanstalkSolutionStack",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name_regex: str,
        most_recent: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name_regex: 
        :param most_recent: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElasticBeanstalkSolutionStackConfig(
            name_regex=name_regex,
            most_recent=most_recent,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElasticBeanstalkSolutionStack, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="nameRegex")
    def name_regex(self) -> str:
        return jsii.get(self, "nameRegex")

    @name_regex.setter
    def name_regex(self, value: str) -> None:
        jsii.set(self, "nameRegex", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mostRecent")
    def most_recent(self) -> typing.Optional[bool]:
        return jsii.get(self, "mostRecent")

    @most_recent.setter
    def most_recent(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mostRecent", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticBeanstalkSolutionStackConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name_regex": "nameRegex",
        "most_recent": "mostRecent",
    },
)
class DataAwsElasticBeanstalkSolutionStackConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name_regex: str,
        most_recent: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name_regex: 
        :param most_recent: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name_regex": name_regex,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if most_recent is not None:
            self._values["most_recent"] = most_recent

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name_regex(self) -> str:
        return self._values.get("name_regex")

    @builtins.property
    def most_recent(self) -> typing.Optional[bool]:
        return self._values.get("most_recent")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElasticBeanstalkSolutionStackConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElasticacheCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticacheCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElasticacheClusterConfig(
            cluster_id=cluster_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElasticacheCluster, self, [scope, id, config])

    @jsii.member(jsii_name="cacheNodes")
    def cache_nodes(self, index: str) -> "DataAwsElasticacheClusterCacheNodes":
        """
        :param index: -
        """
        return jsii.invoke(self, "cacheNodes", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="clusterAddress")
    def cluster_address(self) -> str:
        return jsii.get(self, "clusterAddress")

    @builtins.property
    @jsii.member(jsii_name="configurationEndpoint")
    def configuration_endpoint(self) -> str:
        return jsii.get(self, "configurationEndpoint")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> str:
        return jsii.get(self, "maintenanceWindow")

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> str:
        return jsii.get(self, "nodeType")

    @builtins.property
    @jsii.member(jsii_name="notificationTopicArn")
    def notification_topic_arn(self) -> str:
        return jsii.get(self, "notificationTopicArn")

    @builtins.property
    @jsii.member(jsii_name="numCacheNodes")
    def num_cache_nodes(self) -> jsii.Number:
        return jsii.get(self, "numCacheNodes")

    @builtins.property
    @jsii.member(jsii_name="parameterGroupName")
    def parameter_group_name(self) -> str:
        return jsii.get(self, "parameterGroupName")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="replicationGroupId")
    def replication_group_id(self) -> str:
        return jsii.get(self, "replicationGroupId")

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="securityGroupNames")
    def security_group_names(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupNames")

    @builtins.property
    @jsii.member(jsii_name="snapshotRetentionLimit")
    def snapshot_retention_limit(self) -> jsii.Number:
        return jsii.get(self, "snapshotRetentionLimit")

    @builtins.property
    @jsii.member(jsii_name="snapshotWindow")
    def snapshot_window(self) -> str:
        return jsii.get(self, "snapshotWindow")

    @builtins.property
    @jsii.member(jsii_name="subnetGroupName")
    def subnet_group_name(self) -> str:
        return jsii.get(self, "subnetGroupName")

    @builtins.property
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> str:
        return jsii.get(self, "clusterId")

    @cluster_id.setter
    def cluster_id(self, value: str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsElasticacheClusterCacheNodes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticacheClusterCacheNodes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticacheClusterCacheNodes,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="address")
    def address(self) -> str:
        return jsii.get(self, "address")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticacheClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "tags": "tags",
    },
)
class DataAwsElasticacheClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_id": cluster_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_id(self) -> str:
        return self._values.get("cluster_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElasticacheClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElasticacheReplicationGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticacheReplicationGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        replication_group_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param replication_group_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElasticacheReplicationGroupConfig(
            replication_group_id=replication_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElasticacheReplicationGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="authTokenEnabled")
    def auth_token_enabled(self) -> bool:
        return jsii.get(self, "authTokenEnabled")

    @builtins.property
    @jsii.member(jsii_name="automaticFailoverEnabled")
    def automatic_failover_enabled(self) -> bool:
        return jsii.get(self, "automaticFailoverEnabled")

    @builtins.property
    @jsii.member(jsii_name="configurationEndpointAddress")
    def configuration_endpoint_address(self) -> str:
        return jsii.get(self, "configurationEndpointAddress")

    @builtins.property
    @jsii.member(jsii_name="memberClusters")
    def member_clusters(self) -> typing.List[str]:
        return jsii.get(self, "memberClusters")

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> str:
        return jsii.get(self, "nodeType")

    @builtins.property
    @jsii.member(jsii_name="numberCacheClusters")
    def number_cache_clusters(self) -> jsii.Number:
        return jsii.get(self, "numberCacheClusters")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="primaryEndpointAddress")
    def primary_endpoint_address(self) -> str:
        return jsii.get(self, "primaryEndpointAddress")

    @builtins.property
    @jsii.member(jsii_name="replicationGroupDescription")
    def replication_group_description(self) -> str:
        return jsii.get(self, "replicationGroupDescription")

    @builtins.property
    @jsii.member(jsii_name="snapshotRetentionLimit")
    def snapshot_retention_limit(self) -> jsii.Number:
        return jsii.get(self, "snapshotRetentionLimit")

    @builtins.property
    @jsii.member(jsii_name="snapshotWindow")
    def snapshot_window(self) -> str:
        return jsii.get(self, "snapshotWindow")

    @builtins.property
    @jsii.member(jsii_name="replicationGroupId")
    def replication_group_id(self) -> str:
        return jsii.get(self, "replicationGroupId")

    @replication_group_id.setter
    def replication_group_id(self, value: str) -> None:
        jsii.set(self, "replicationGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticacheReplicationGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "replication_group_id": "replicationGroupId",
    },
)
class DataAwsElasticacheReplicationGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        replication_group_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param replication_group_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "replication_group_id": replication_group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def replication_group_id(self) -> str:
        return self._values.get("replication_group_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElasticacheReplicationGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElasticsearchDomain(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomain",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElasticsearchDomainConfig(
            domain_name=domain_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElasticsearchDomain, self, [scope, id, config])

    @jsii.member(jsii_name="advancedOptions")
    def advanced_options(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "advancedOptions", [key])

    @jsii.member(jsii_name="advancedSecurityOptions")
    def advanced_security_options(
        self, index: str
    ) -> "DataAwsElasticsearchDomainAdvancedSecurityOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "advancedSecurityOptions", [index])

    @jsii.member(jsii_name="clusterConfig")
    def cluster_config(self, index: str) -> "DataAwsElasticsearchDomainClusterConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "clusterConfig", [index])

    @jsii.member(jsii_name="cognitoOptions")
    def cognito_options(self, index: str) -> "DataAwsElasticsearchDomainCognitoOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "cognitoOptions", [index])

    @jsii.member(jsii_name="ebsOptions")
    def ebs_options(self, index: str) -> "DataAwsElasticsearchDomainEbsOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "ebsOptions", [index])

    @jsii.member(jsii_name="encryptionAtRest")
    def encryption_at_rest(
        self, index: str
    ) -> "DataAwsElasticsearchDomainEncryptionAtRest":
        """
        :param index: -
        """
        return jsii.invoke(self, "encryptionAtRest", [index])

    @jsii.member(jsii_name="logPublishingOptions")
    def log_publishing_options(
        self, index: str
    ) -> "DataAwsElasticsearchDomainLogPublishingOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "logPublishingOptions", [index])

    @jsii.member(jsii_name="nodeToNodeEncryption")
    def node_to_node_encryption(
        self, index: str
    ) -> "DataAwsElasticsearchDomainNodeToNodeEncryption":
        """
        :param index: -
        """
        return jsii.invoke(self, "nodeToNodeEncryption", [index])

    @jsii.member(jsii_name="snapshotOptions")
    def snapshot_options(
        self, index: str
    ) -> "DataAwsElasticsearchDomainSnapshotOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "snapshotOptions", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="vpcOptions")
    def vpc_options(self, index: str) -> "DataAwsElasticsearchDomainVpcOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "vpcOptions", [index])

    @builtins.property
    @jsii.member(jsii_name="accessPolicies")
    def access_policies(self) -> str:
        return jsii.get(self, "accessPolicies")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="created")
    def created(self) -> bool:
        return jsii.get(self, "created")

    @builtins.property
    @jsii.member(jsii_name="deleted")
    def deleted(self) -> bool:
        return jsii.get(self, "deleted")

    @builtins.property
    @jsii.member(jsii_name="domainId")
    def domain_id(self) -> str:
        return jsii.get(self, "domainId")

    @builtins.property
    @jsii.member(jsii_name="elasticsearchVersion")
    def elasticsearch_version(self) -> str:
        return jsii.get(self, "elasticsearchVersion")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="kibanaEndpoint")
    def kibana_endpoint(self) -> str:
        return jsii.get(self, "kibanaEndpoint")

    @builtins.property
    @jsii.member(jsii_name="processing")
    def processing(self) -> bool:
        return jsii.get(self, "processing")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsElasticsearchDomainAdvancedSecurityOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainAdvancedSecurityOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainAdvancedSecurityOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="internalUserDatabaseEnabled")
    def internal_user_database_enabled(self) -> bool:
        return jsii.get(self, "internalUserDatabaseEnabled")


class DataAwsElasticsearchDomainClusterConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainClusterConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainClusterConfig,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="dedicatedMasterCount")
    def dedicated_master_count(self) -> jsii.Number:
        return jsii.get(self, "dedicatedMasterCount")

    @builtins.property
    @jsii.member(jsii_name="dedicatedMasterEnabled")
    def dedicated_master_enabled(self) -> bool:
        return jsii.get(self, "dedicatedMasterEnabled")

    @builtins.property
    @jsii.member(jsii_name="dedicatedMasterType")
    def dedicated_master_type(self) -> str:
        return jsii.get(self, "dedicatedMasterType")

    @builtins.property
    @jsii.member(jsii_name="instanceCount")
    def instance_count(self) -> jsii.Number:
        return jsii.get(self, "instanceCount")

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @builtins.property
    @jsii.member(jsii_name="warmCount")
    def warm_count(self) -> jsii.Number:
        return jsii.get(self, "warmCount")

    @builtins.property
    @jsii.member(jsii_name="warmEnabled")
    def warm_enabled(self) -> bool:
        return jsii.get(self, "warmEnabled")

    @builtins.property
    @jsii.member(jsii_name="warmType")
    def warm_type(self) -> str:
        return jsii.get(self, "warmType")

    @builtins.property
    @jsii.member(jsii_name="zoneAwarenessConfig")
    def zone_awareness_config(self) -> typing.Any:
        return jsii.get(self, "zoneAwarenessConfig")

    @builtins.property
    @jsii.member(jsii_name="zoneAwarenessEnabled")
    def zone_awareness_enabled(self) -> bool:
        return jsii.get(self, "zoneAwarenessEnabled")


class DataAwsElasticsearchDomainClusterConfigZoneAwarenessConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainClusterConfigZoneAwarenessConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainClusterConfigZoneAwarenessConfig,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneCount")
    def availability_zone_count(self) -> jsii.Number:
        return jsii.get(self, "availabilityZoneCount")


class DataAwsElasticsearchDomainCognitoOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainCognitoOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainCognitoOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="identityPoolId")
    def identity_pool_id(self) -> str:
        return jsii.get(self, "identityPoolId")

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @builtins.property
    @jsii.member(jsii_name="userPoolId")
    def user_pool_id(self) -> str:
        return jsii.get(self, "userPoolId")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
        "tags": "tags",
    },
)
class DataAwsElasticsearchDomainConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain_name": domain_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElasticsearchDomainConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElasticsearchDomainEbsOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainEbsOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainEbsOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="ebsEnabled")
    def ebs_enabled(self) -> bool:
        return jsii.get(self, "ebsEnabled")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="volumeType")
    def volume_type(self) -> str:
        return jsii.get(self, "volumeType")


class DataAwsElasticsearchDomainEncryptionAtRest(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainEncryptionAtRest",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainEncryptionAtRest,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")


class DataAwsElasticsearchDomainLogPublishingOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainLogPublishingOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainLogPublishingOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="cloudwatchLogGroupArn")
    def cloudwatch_log_group_arn(self) -> str:
        return jsii.get(self, "cloudwatchLogGroupArn")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="logType")
    def log_type(self) -> str:
        return jsii.get(self, "logType")


class DataAwsElasticsearchDomainNodeToNodeEncryption(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainNodeToNodeEncryption",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainNodeToNodeEncryption,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")


class DataAwsElasticsearchDomainSnapshotOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainSnapshotOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainSnapshotOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="automatedSnapshotStartHour")
    def automated_snapshot_start_hour(self) -> jsii.Number:
        return jsii.get(self, "automatedSnapshotStartHour")


class DataAwsElasticsearchDomainVpcOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElasticsearchDomainVpcOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElasticsearchDomainVpcOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")


class DataAwsElb(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElbConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElb, self, [scope, id, config])

    @jsii.member(jsii_name="accessLogs")
    def access_logs(self, index: str) -> "DataAwsElbAccessLogs":
        """
        :param index: -
        """
        return jsii.invoke(self, "accessLogs", [index])

    @jsii.member(jsii_name="healthCheck")
    def health_check(self, index: str) -> "DataAwsElbHealthCheck":
        """
        :param index: -
        """
        return jsii.invoke(self, "healthCheck", [index])

    @jsii.member(jsii_name="listener")
    def listener(self, index: str) -> "DataAwsElbListener":
        """
        :param index: -
        """
        return jsii.invoke(self, "listener", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="connectionDraining")
    def connection_draining(self) -> bool:
        return jsii.get(self, "connectionDraining")

    @builtins.property
    @jsii.member(jsii_name="connectionDrainingTimeout")
    def connection_draining_timeout(self) -> jsii.Number:
        return jsii.get(self, "connectionDrainingTimeout")

    @builtins.property
    @jsii.member(jsii_name="crossZoneLoadBalancing")
    def cross_zone_load_balancing(self) -> bool:
        return jsii.get(self, "crossZoneLoadBalancing")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> jsii.Number:
        return jsii.get(self, "idleTimeout")

    @builtins.property
    @jsii.member(jsii_name="instances")
    def instances(self) -> typing.List[str]:
        return jsii.get(self, "instances")

    @builtins.property
    @jsii.member(jsii_name="internal")
    def internal(self) -> bool:
        return jsii.get(self, "internal")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="sourceSecurityGroup")
    def source_security_group(self) -> str:
        return jsii.get(self, "sourceSecurityGroup")

    @builtins.property
    @jsii.member(jsii_name="sourceSecurityGroupId")
    def source_security_group_id(self) -> str:
        return jsii.get(self, "sourceSecurityGroupId")

    @builtins.property
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.List[str]:
        return jsii.get(self, "subnets")

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsElbAccessLogs(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbAccessLogs",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElbAccessLogs, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @builtins.property
    @jsii.member(jsii_name="bucketPrefix")
    def bucket_prefix(self) -> str:
        return jsii.get(self, "bucketPrefix")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return jsii.get(self, "interval")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsElbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElbHealthCheck(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbHealthCheck",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElbHealthCheck,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return jsii.get(self, "healthyThreshold")

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return jsii.get(self, "interval")

    @builtins.property
    @jsii.member(jsii_name="target")
    def target(self) -> str:
        return jsii.get(self, "target")

    @builtins.property
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return jsii.get(self, "timeout")

    @builtins.property
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return jsii.get(self, "unhealthyThreshold")


class DataAwsElbHostedZoneId(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbHostedZoneId",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        region: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param region: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElbHostedZoneIdConfig(
            region=region,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElbHostedZoneId, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbHostedZoneIdConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "region": "region",
    },
)
class DataAwsElbHostedZoneIdConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        region: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param region: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElbHostedZoneIdConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsElbListener(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbListener",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsElbListener, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="instancePort")
    def instance_port(self) -> jsii.Number:
        return jsii.get(self, "instancePort")

    @builtins.property
    @jsii.member(jsii_name="instanceProtocol")
    def instance_protocol(self) -> str:
        return jsii.get(self, "instanceProtocol")

    @builtins.property
    @jsii.member(jsii_name="lbPort")
    def lb_port(self) -> jsii.Number:
        return jsii.get(self, "lbPort")

    @builtins.property
    @jsii.member(jsii_name="lbProtocol")
    def lb_protocol(self) -> str:
        return jsii.get(self, "lbProtocol")

    @builtins.property
    @jsii.member(jsii_name="sslCertificateId")
    def ssl_certificate_id(self) -> str:
        return jsii.get(self, "sslCertificateId")


class DataAwsElbServiceAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbServiceAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        region: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param region: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsElbServiceAccountConfig(
            region=region,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsElbServiceAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsElbServiceAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "region": "region",
    },
)
class DataAwsElbServiceAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        region: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param region: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsElbServiceAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsGlueScript(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsGlueScript",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dag_edge: typing.List["DataAwsGlueScriptDagEdge"],
        dag_node: typing.List["DataAwsGlueScriptDagNode"],
        language: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dag_edge: dag_edge block.
        :param dag_node: dag_node block.
        :param language: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsGlueScriptConfig(
            dag_edge=dag_edge,
            dag_node=dag_node,
            language=language,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsGlueScript, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="pythonScript")
    def python_script(self) -> str:
        return jsii.get(self, "pythonScript")

    @builtins.property
    @jsii.member(jsii_name="scalaCode")
    def scala_code(self) -> str:
        return jsii.get(self, "scalaCode")

    @builtins.property
    @jsii.member(jsii_name="dagEdge")
    def dag_edge(self) -> typing.List["DataAwsGlueScriptDagEdge"]:
        return jsii.get(self, "dagEdge")

    @dag_edge.setter
    def dag_edge(self, value: typing.List["DataAwsGlueScriptDagEdge"]) -> None:
        jsii.set(self, "dagEdge", value)

    @builtins.property
    @jsii.member(jsii_name="dagNode")
    def dag_node(self) -> typing.List["DataAwsGlueScriptDagNode"]:
        return jsii.get(self, "dagNode")

    @dag_node.setter
    def dag_node(self, value: typing.List["DataAwsGlueScriptDagNode"]) -> None:
        jsii.set(self, "dagNode", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="language")
    def language(self) -> typing.Optional[str]:
        return jsii.get(self, "language")

    @language.setter
    def language(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "language", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsGlueScriptConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dag_edge": "dagEdge",
        "dag_node": "dagNode",
        "language": "language",
    },
)
class DataAwsGlueScriptConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dag_edge: typing.List["DataAwsGlueScriptDagEdge"],
        dag_node: typing.List["DataAwsGlueScriptDagNode"],
        language: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dag_edge: dag_edge block.
        :param dag_node: dag_node block.
        :param language: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "dag_edge": dag_edge,
            "dag_node": dag_node,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if language is not None:
            self._values["language"] = language

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dag_edge(self) -> typing.List["DataAwsGlueScriptDagEdge"]:
        """dag_edge block."""
        return self._values.get("dag_edge")

    @builtins.property
    def dag_node(self) -> typing.List["DataAwsGlueScriptDagNode"]:
        """dag_node block."""
        return self._values.get("dag_node")

    @builtins.property
    def language(self) -> typing.Optional[str]:
        return self._values.get("language")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsGlueScriptConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsGlueScriptDagEdge",
    jsii_struct_bases=[],
    name_mapping={
        "source": "source",
        "target": "target",
        "target_parameter": "targetParameter",
    },
)
class DataAwsGlueScriptDagEdge:
    def __init__(
        self, *, source: str, target: str, target_parameter: typing.Optional[str] = None
    ) -> None:
        """
        :param source: 
        :param target: 
        :param target_parameter: 
        """
        self._values = {
            "source": source,
            "target": target,
        }
        if target_parameter is not None:
            self._values["target_parameter"] = target_parameter

    @builtins.property
    def source(self) -> str:
        return self._values.get("source")

    @builtins.property
    def target(self) -> str:
        return self._values.get("target")

    @builtins.property
    def target_parameter(self) -> typing.Optional[str]:
        return self._values.get("target_parameter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsGlueScriptDagEdge(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsGlueScriptDagNode",
    jsii_struct_bases=[],
    name_mapping={
        "args": "args",
        "id": "id",
        "node_type": "nodeType",
        "line_number": "lineNumber",
    },
)
class DataAwsGlueScriptDagNode:
    def __init__(
        self,
        *,
        args: typing.List["DataAwsGlueScriptDagNodeArgs"],
        id: str,
        node_type: str,
        line_number: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param args: args block.
        :param id: 
        :param node_type: 
        :param line_number: 
        """
        self._values = {
            "args": args,
            "id": id,
            "node_type": node_type,
        }
        if line_number is not None:
            self._values["line_number"] = line_number

    @builtins.property
    def args(self) -> typing.List["DataAwsGlueScriptDagNodeArgs"]:
        """args block."""
        return self._values.get("args")

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    @builtins.property
    def node_type(self) -> str:
        return self._values.get("node_type")

    @builtins.property
    def line_number(self) -> typing.Optional[jsii.Number]:
        return self._values.get("line_number")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsGlueScriptDagNode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsGlueScriptDagNodeArgs",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value", "param": "param"},
)
class DataAwsGlueScriptDagNodeArgs:
    def __init__(
        self, *, name: str, value: str, param: typing.Optional[bool] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        :param param: 
        """
        self._values = {
            "name": name,
            "value": value,
        }
        if param is not None:
            self._values["param"] = param

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def param(self) -> typing.Optional[bool]:
        return self._values.get("param")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsGlueScriptDagNodeArgs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsGuarddutyDetector(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsGuarddutyDetector",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsGuarddutyDetectorConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsGuarddutyDetector, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="findingPublishingFrequency")
    def finding_publishing_frequency(self) -> str:
        return jsii.get(self, "findingPublishingFrequency")

    @builtins.property
    @jsii.member(jsii_name="serviceRoleArn")
    def service_role_arn(self) -> str:
        return jsii.get(self, "serviceRoleArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsGuarddutyDetectorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsGuarddutyDetectorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsGuarddutyDetectorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamAccountAlias(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamAccountAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamAccountAliasConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsIamAccountAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountAlias")
    def account_alias(self) -> str:
        return jsii.get(self, "accountAlias")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamAccountAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsIamAccountAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamAccountAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        group_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamGroupConfig(
            group_name=group_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIamGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="users")
    def users(self, index: str) -> "DataAwsIamGroupUsers":
        """
        :param index: -
        """
        return jsii.invoke(self, "users", [index])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="groupId")
    def group_id(self) -> str:
        return jsii.get(self, "groupId")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="groupName")
    def group_name(self) -> str:
        return jsii.get(self, "groupName")

    @group_name.setter
    def group_name(self, value: str) -> None:
        jsii.set(self, "groupName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group_name": "groupName",
    },
)
class DataAwsIamGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "group_name": group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def group_name(self) -> str:
        return self._values.get("group_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamGroupUsers(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamGroupUsers",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsIamGroupUsers, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="userId")
    def user_id(self) -> str:
        return jsii.get(self, "userId")

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> str:
        return jsii.get(self, "userName")


class DataAwsIamInstanceProfile(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamInstanceProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamInstanceProfileConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIamInstanceProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createDate")
    def create_date(self) -> str:
        return jsii.get(self, "createDate")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @builtins.property
    @jsii.member(jsii_name="roleId")
    def role_id(self) -> str:
        return jsii.get(self, "roleId")

    @builtins.property
    @jsii.member(jsii_name="roleName")
    def role_name(self) -> str:
        return jsii.get(self, "roleName")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamInstanceProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsIamInstanceProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamInstanceProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamPolicy(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamPolicyConfig(
            arn=arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIamPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: str) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "arn": "arn",
    },
)
class DataAwsIamPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "arn": arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamPolicyDocument(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicyDocument",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        override_json: typing.Optional[str] = None,
        policy_id: typing.Optional[str] = None,
        source_json: typing.Optional[str] = None,
        statement: typing.Optional[
            typing.List["DataAwsIamPolicyDocumentStatement"]
        ] = None,
        version: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param override_json: 
        :param policy_id: 
        :param source_json: 
        :param statement: statement block.
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamPolicyDocumentConfig(
            override_json=override_json,
            policy_id=policy_id,
            source_json=source_json,
            statement=statement,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIamPolicyDocument, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="json")
    def json(self) -> str:
        return jsii.get(self, "json")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="overrideJson")
    def override_json(self) -> typing.Optional[str]:
        return jsii.get(self, "overrideJson")

    @override_json.setter
    def override_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "overrideJson", value)

    @builtins.property
    @jsii.member(jsii_name="policyId")
    def policy_id(self) -> typing.Optional[str]:
        return jsii.get(self, "policyId")

    @policy_id.setter
    def policy_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policyId", value)

    @builtins.property
    @jsii.member(jsii_name="sourceJson")
    def source_json(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceJson")

    @source_json.setter
    def source_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceJson", value)

    @builtins.property
    @jsii.member(jsii_name="statement")
    def statement(
        self,
    ) -> typing.Optional[typing.List["DataAwsIamPolicyDocumentStatement"]]:
        return jsii.get(self, "statement")

    @statement.setter
    def statement(
        self, value: typing.Optional[typing.List["DataAwsIamPolicyDocumentStatement"]]
    ) -> None:
        jsii.set(self, "statement", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[str]:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicyDocumentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "override_json": "overrideJson",
        "policy_id": "policyId",
        "source_json": "sourceJson",
        "statement": "statement",
        "version": "version",
    },
)
class DataAwsIamPolicyDocumentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        override_json: typing.Optional[str] = None,
        policy_id: typing.Optional[str] = None,
        source_json: typing.Optional[str] = None,
        statement: typing.Optional[
            typing.List["DataAwsIamPolicyDocumentStatement"]
        ] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param override_json: 
        :param policy_id: 
        :param source_json: 
        :param statement: statement block.
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if override_json is not None:
            self._values["override_json"] = override_json
        if policy_id is not None:
            self._values["policy_id"] = policy_id
        if source_json is not None:
            self._values["source_json"] = source_json
        if statement is not None:
            self._values["statement"] = statement
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def override_json(self) -> typing.Optional[str]:
        return self._values.get("override_json")

    @builtins.property
    def policy_id(self) -> typing.Optional[str]:
        return self._values.get("policy_id")

    @builtins.property
    def source_json(self) -> typing.Optional[str]:
        return self._values.get("source_json")

    @builtins.property
    def statement(
        self,
    ) -> typing.Optional[typing.List["DataAwsIamPolicyDocumentStatement"]]:
        """statement block."""
        return self._values.get("statement")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamPolicyDocumentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicyDocumentStatement",
    jsii_struct_bases=[],
    name_mapping={
        "actions": "actions",
        "condition": "condition",
        "effect": "effect",
        "not_actions": "notActions",
        "not_principals": "notPrincipals",
        "not_resources": "notResources",
        "principals": "principals",
        "resources": "resources",
        "sid": "sid",
    },
)
class DataAwsIamPolicyDocumentStatement:
    def __init__(
        self,
        *,
        actions: typing.Optional[typing.List[str]] = None,
        condition: typing.Optional[
            typing.List["DataAwsIamPolicyDocumentStatementCondition"]
        ] = None,
        effect: typing.Optional[str] = None,
        not_actions: typing.Optional[typing.List[str]] = None,
        not_principals: typing.Optional[
            typing.List["DataAwsIamPolicyDocumentStatementNotPrincipals"]
        ] = None,
        not_resources: typing.Optional[typing.List[str]] = None,
        principals: typing.Optional[
            typing.List["DataAwsIamPolicyDocumentStatementPrincipals"]
        ] = None,
        resources: typing.Optional[typing.List[str]] = None,
        sid: typing.Optional[str] = None,
    ) -> None:
        """
        :param actions: 
        :param condition: condition block.
        :param effect: 
        :param not_actions: 
        :param not_principals: not_principals block.
        :param not_resources: 
        :param principals: principals block.
        :param resources: 
        :param sid: 
        """
        self._values = {}
        if actions is not None:
            self._values["actions"] = actions
        if condition is not None:
            self._values["condition"] = condition
        if effect is not None:
            self._values["effect"] = effect
        if not_actions is not None:
            self._values["not_actions"] = not_actions
        if not_principals is not None:
            self._values["not_principals"] = not_principals
        if not_resources is not None:
            self._values["not_resources"] = not_resources
        if principals is not None:
            self._values["principals"] = principals
        if resources is not None:
            self._values["resources"] = resources
        if sid is not None:
            self._values["sid"] = sid

    @builtins.property
    def actions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("actions")

    @builtins.property
    def condition(
        self,
    ) -> typing.Optional[typing.List["DataAwsIamPolicyDocumentStatementCondition"]]:
        """condition block."""
        return self._values.get("condition")

    @builtins.property
    def effect(self) -> typing.Optional[str]:
        return self._values.get("effect")

    @builtins.property
    def not_actions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("not_actions")

    @builtins.property
    def not_principals(
        self,
    ) -> typing.Optional[typing.List["DataAwsIamPolicyDocumentStatementNotPrincipals"]]:
        """not_principals block."""
        return self._values.get("not_principals")

    @builtins.property
    def not_resources(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("not_resources")

    @builtins.property
    def principals(
        self,
    ) -> typing.Optional[typing.List["DataAwsIamPolicyDocumentStatementPrincipals"]]:
        """principals block."""
        return self._values.get("principals")

    @builtins.property
    def resources(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("resources")

    @builtins.property
    def sid(self) -> typing.Optional[str]:
        return self._values.get("sid")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamPolicyDocumentStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicyDocumentStatementCondition",
    jsii_struct_bases=[],
    name_mapping={"test": "test", "values": "values", "variable": "variable"},
)
class DataAwsIamPolicyDocumentStatementCondition:
    def __init__(self, *, test: str, values: typing.List[str], variable: str) -> None:
        """
        :param test: 
        :param values: 
        :param variable: 
        """
        self._values = {
            "test": test,
            "values": values,
            "variable": variable,
        }

    @builtins.property
    def test(self) -> str:
        return self._values.get("test")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    @builtins.property
    def variable(self) -> str:
        return self._values.get("variable")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamPolicyDocumentStatementCondition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicyDocumentStatementNotPrincipals",
    jsii_struct_bases=[],
    name_mapping={"identifiers": "identifiers", "type": "type"},
)
class DataAwsIamPolicyDocumentStatementNotPrincipals:
    def __init__(self, *, identifiers: typing.List[str], type: str) -> None:
        """
        :param identifiers: 
        :param type: 
        """
        self._values = {
            "identifiers": identifiers,
            "type": type,
        }

    @builtins.property
    def identifiers(self) -> typing.List[str]:
        return self._values.get("identifiers")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamPolicyDocumentStatementNotPrincipals(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamPolicyDocumentStatementPrincipals",
    jsii_struct_bases=[],
    name_mapping={"identifiers": "identifiers", "type": "type"},
)
class DataAwsIamPolicyDocumentStatementPrincipals:
    def __init__(self, *, identifiers: typing.List[str], type: str) -> None:
        """
        :param identifiers: 
        :param type: 
        """
        self._values = {
            "identifiers": identifiers,
            "type": type,
        }

    @builtins.property
    def identifiers(self) -> typing.List[str]:
        return self._values.get("identifiers")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamPolicyDocumentStatementPrincipals(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamRole(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamRole",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        role_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param role_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamRoleConfig(
            name=name,
            role_name=role_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIamRole, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="assumeRolePolicy")
    def assume_role_policy(self) -> str:
        return jsii.get(self, "assumeRolePolicy")

    @builtins.property
    @jsii.member(jsii_name="assumeRolePolicyDocument")
    def assume_role_policy_document(self) -> str:
        return jsii.get(self, "assumeRolePolicyDocument")

    @builtins.property
    @jsii.member(jsii_name="createDate")
    def create_date(self) -> str:
        return jsii.get(self, "createDate")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="maxSessionDuration")
    def max_session_duration(self) -> jsii.Number:
        return jsii.get(self, "maxSessionDuration")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="permissionsBoundary")
    def permissions_boundary(self) -> str:
        return jsii.get(self, "permissionsBoundary")

    @builtins.property
    @jsii.member(jsii_name="roleId")
    def role_id(self) -> str:
        return jsii.get(self, "roleId")

    @builtins.property
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> str:
        return jsii.get(self, "uniqueId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="roleName")
    def role_name(self) -> typing.Optional[str]:
        return jsii.get(self, "roleName")

    @role_name.setter
    def role_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamRoleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "role_name": "roleName",
        "tags": "tags",
    },
)
class DataAwsIamRoleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        role_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param role_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if role_name is not None:
            self._values["role_name"] = role_name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role_name(self) -> typing.Optional[str]:
        return self._values.get("role_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamRoleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamServerCertificate(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamServerCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        latest: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param latest: 
        :param name: 
        :param name_prefix: 
        :param path_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamServerCertificateConfig(
            latest=latest,
            name=name,
            name_prefix=name_prefix,
            path_prefix=path_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIamServerCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="certificateBody")
    def certificate_body(self) -> str:
        return jsii.get(self, "certificateBody")

    @builtins.property
    @jsii.member(jsii_name="certificateChain")
    def certificate_chain(self) -> str:
        return jsii.get(self, "certificateChain")

    @builtins.property
    @jsii.member(jsii_name="expirationDate")
    def expiration_date(self) -> str:
        return jsii.get(self, "expirationDate")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="uploadDate")
    def upload_date(self) -> str:
        return jsii.get(self, "uploadDate")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="latest")
    def latest(self) -> typing.Optional[bool]:
        return jsii.get(self, "latest")

    @latest.setter
    def latest(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "latest", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="pathPrefix")
    def path_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "pathPrefix")

    @path_prefix.setter
    def path_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "pathPrefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamServerCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "latest": "latest",
        "name": "name",
        "name_prefix": "namePrefix",
        "path_prefix": "pathPrefix",
    },
)
class DataAwsIamServerCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        latest: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param latest: 
        :param name: 
        :param name_prefix: 
        :param path_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if latest is not None:
            self._values["latest"] = latest
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if path_prefix is not None:
            self._values["path_prefix"] = path_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def latest(self) -> typing.Optional[bool]:
        return self._values.get("latest")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def path_prefix(self) -> typing.Optional[str]:
        return self._values.get("path_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamServerCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIamUser(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamUser",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        user_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param user_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIamUserConfig(
            user_name=user_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIamUser, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="permissionsBoundary")
    def permissions_boundary(self) -> str:
        return jsii.get(self, "permissionsBoundary")

    @builtins.property
    @jsii.member(jsii_name="userId")
    def user_id(self) -> str:
        return jsii.get(self, "userId")

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> str:
        return jsii.get(self, "userName")

    @user_name.setter
    def user_name(self, value: str) -> None:
        jsii.set(self, "userName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIamUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "user_name": "userName",
    },
)
class DataAwsIamUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        user_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param user_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "user_name": user_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def user_name(self) -> str:
        return self._values.get("user_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIamUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsInspectorRulesPackages(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInspectorRulesPackages",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsInspectorRulesPackagesConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsInspectorRulesPackages, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arns")
    def arns(self) -> typing.List[str]:
        return jsii.get(self, "arns")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInspectorRulesPackagesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsInspectorRulesPackagesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsInspectorRulesPackagesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsInstance(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        fetch_password_data: typing.Optional[bool] = None,
        fetch_user_data: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsInstanceFilter"]] = None,
        instance_id: typing.Optional[str] = None,
        instance_tags: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param fetch_password_data: 
        :param fetch_user_data: 
        :param filter: filter block.
        :param instance_id: 
        :param instance_tags: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsInstanceConfig(
            fetch_password_data=fetch_password_data,
            fetch_user_data=fetch_user_data,
            filter=filter,
            instance_id=instance_id,
            instance_tags=instance_tags,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsInstance, self, [scope, id, config])

    @jsii.member(jsii_name="creditSpecification")
    def credit_specification(self, index: str) -> "DataAwsInstanceCreditSpecification":
        """
        :param index: -
        """
        return jsii.invoke(self, "creditSpecification", [index])

    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(self, index: str) -> "DataAwsInstanceEbsBlockDevice":
        """
        :param index: -
        """
        return jsii.invoke(self, "ebsBlockDevice", [index])

    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self, index: str
    ) -> "DataAwsInstanceEphemeralBlockDevice":
        """
        :param index: -
        """
        return jsii.invoke(self, "ephemeralBlockDevice", [index])

    @jsii.member(jsii_name="metadataOptions")
    def metadata_options(self, index: str) -> "DataAwsInstanceMetadataOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "metadataOptions", [index])

    @jsii.member(jsii_name="rootBlockDevice")
    def root_block_device(self, index: str) -> "DataAwsInstanceRootBlockDevice":
        """
        :param index: -
        """
        return jsii.invoke(self, "rootBlockDevice", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ami")
    def ami(self) -> str:
        return jsii.get(self, "ami")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> bool:
        return jsii.get(self, "associatePublicIpAddress")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="disableApiTermination")
    def disable_api_termination(self) -> bool:
        return jsii.get(self, "disableApiTermination")

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> bool:
        return jsii.get(self, "ebsOptimized")

    @builtins.property
    @jsii.member(jsii_name="hostId")
    def host_id(self) -> str:
        return jsii.get(self, "hostId")

    @builtins.property
    @jsii.member(jsii_name="iamInstanceProfile")
    def iam_instance_profile(self) -> str:
        return jsii.get(self, "iamInstanceProfile")

    @builtins.property
    @jsii.member(jsii_name="instanceState")
    def instance_state(self) -> str:
        return jsii.get(self, "instanceState")

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> str:
        return jsii.get(self, "keyName")

    @builtins.property
    @jsii.member(jsii_name="monitoring")
    def monitoring(self) -> bool:
        return jsii.get(self, "monitoring")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="passwordData")
    def password_data(self) -> str:
        return jsii.get(self, "passwordData")

    @builtins.property
    @jsii.member(jsii_name="placementGroup")
    def placement_group(self) -> str:
        return jsii.get(self, "placementGroup")

    @builtins.property
    @jsii.member(jsii_name="privateDns")
    def private_dns(self) -> str:
        return jsii.get(self, "privateDns")

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> str:
        return jsii.get(self, "privateIp")

    @builtins.property
    @jsii.member(jsii_name="publicDns")
    def public_dns(self) -> str:
        return jsii.get(self, "publicDns")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="sourceDestCheck")
    def source_dest_check(self) -> bool:
        return jsii.get(self, "sourceDestCheck")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @builtins.property
    @jsii.member(jsii_name="tenancy")
    def tenancy(self) -> str:
        return jsii.get(self, "tenancy")

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> str:
        return jsii.get(self, "userData")

    @builtins.property
    @jsii.member(jsii_name="userDataBase64")
    def user_data_base64(self) -> str:
        return jsii.get(self, "userDataBase64")

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="fetchPasswordData")
    def fetch_password_data(self) -> typing.Optional[bool]:
        return jsii.get(self, "fetchPasswordData")

    @fetch_password_data.setter
    def fetch_password_data(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "fetchPasswordData", value)

    @builtins.property
    @jsii.member(jsii_name="fetchUserData")
    def fetch_user_data(self) -> typing.Optional[bool]:
        return jsii.get(self, "fetchUserData")

    @fetch_user_data.setter
    def fetch_user_data(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "fetchUserData", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsInstanceFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsInstanceFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceId")

    @instance_id.setter
    def instance_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property
    @jsii.member(jsii_name="instanceTags")
    def instance_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "instanceTags")

    @instance_tags.setter
    def instance_tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "instanceTags", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "fetch_password_data": "fetchPasswordData",
        "fetch_user_data": "fetchUserData",
        "filter": "filter",
        "instance_id": "instanceId",
        "instance_tags": "instanceTags",
        "tags": "tags",
    },
)
class DataAwsInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        fetch_password_data: typing.Optional[bool] = None,
        fetch_user_data: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsInstanceFilter"]] = None,
        instance_id: typing.Optional[str] = None,
        instance_tags: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param fetch_password_data: 
        :param fetch_user_data: 
        :param filter: filter block.
        :param instance_id: 
        :param instance_tags: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if fetch_password_data is not None:
            self._values["fetch_password_data"] = fetch_password_data
        if fetch_user_data is not None:
            self._values["fetch_user_data"] = fetch_user_data
        if filter is not None:
            self._values["filter"] = filter
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if instance_tags is not None:
            self._values["instance_tags"] = instance_tags
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def fetch_password_data(self) -> typing.Optional[bool]:
        return self._values.get("fetch_password_data")

    @builtins.property
    def fetch_user_data(self) -> typing.Optional[bool]:
        return self._values.get("fetch_user_data")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsInstanceFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def instance_id(self) -> typing.Optional[str]:
        return self._values.get("instance_id")

    @builtins.property
    def instance_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("instance_tags")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsInstanceCreditSpecification(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstanceCreditSpecification",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsInstanceCreditSpecification,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="cpuCredits")
    def cpu_credits(self) -> str:
        return jsii.get(self, "cpuCredits")


class DataAwsInstanceEbsBlockDevice(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstanceEbsBlockDevice",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsInstanceEbsBlockDevice,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deleteOnTermination")
    def delete_on_termination(self) -> bool:
        return jsii.get(self, "deleteOnTermination")

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> str:
        return jsii.get(self, "snapshotId")

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="volumeType")
    def volume_type(self) -> str:
        return jsii.get(self, "volumeType")


class DataAwsInstanceEphemeralBlockDevice(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstanceEphemeralBlockDevice",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsInstanceEphemeralBlockDevice,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @builtins.property
    @jsii.member(jsii_name="noDevice")
    def no_device(self) -> bool:
        return jsii.get(self, "noDevice")

    @builtins.property
    @jsii.member(jsii_name="virtualName")
    def virtual_name(self) -> str:
        return jsii.get(self, "virtualName")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstanceFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsInstanceFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsInstanceFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsInstanceMetadataOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstanceMetadataOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsInstanceMetadataOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="httpEndpoint")
    def http_endpoint(self) -> str:
        return jsii.get(self, "httpEndpoint")

    @builtins.property
    @jsii.member(jsii_name="httpPutResponseHopLimit")
    def http_put_response_hop_limit(self) -> jsii.Number:
        return jsii.get(self, "httpPutResponseHopLimit")

    @builtins.property
    @jsii.member(jsii_name="httpTokens")
    def http_tokens(self) -> str:
        return jsii.get(self, "httpTokens")


class DataAwsInstanceRootBlockDevice(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstanceRootBlockDevice",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsInstanceRootBlockDevice,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deleteOnTermination")
    def delete_on_termination(self) -> bool:
        return jsii.get(self, "deleteOnTermination")

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="volumeType")
    def volume_type(self) -> str:
        return jsii.get(self, "volumeType")


class DataAwsInstances(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstances",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsInstancesFilter"]] = None,
        instance_state_names: typing.Optional[typing.List[str]] = None,
        instance_tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param instance_state_names: 
        :param instance_tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsInstancesConfig(
            filter=filter,
            instance_state_names=instance_state_names,
            instance_tags=instance_tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsInstances, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="privateIps")
    def private_ips(self) -> typing.List[str]:
        return jsii.get(self, "privateIps")

    @builtins.property
    @jsii.member(jsii_name="publicIps")
    def public_ips(self) -> typing.List[str]:
        return jsii.get(self, "publicIps")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsInstancesFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsInstancesFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceStateNames")
    def instance_state_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "instanceStateNames")

    @instance_state_names.setter
    def instance_state_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "instanceStateNames", value)

    @builtins.property
    @jsii.member(jsii_name="instanceTags")
    def instance_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "instanceTags")

    @instance_tags.setter
    def instance_tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "instanceTags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstancesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "instance_state_names": "instanceStateNames",
        "instance_tags": "instanceTags",
    },
)
class DataAwsInstancesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsInstancesFilter"]] = None,
        instance_state_names: typing.Optional[typing.List[str]] = None,
        instance_tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param instance_state_names: 
        :param instance_tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if instance_state_names is not None:
            self._values["instance_state_names"] = instance_state_names
        if instance_tags is not None:
            self._values["instance_tags"] = instance_tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsInstancesFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def instance_state_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("instance_state_names")

    @builtins.property
    def instance_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("instance_tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsInstancesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInstancesFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsInstancesFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsInstancesFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsInternetGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInternetGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsInternetGatewayFilter"]] = None,
        internet_gateway_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param internet_gateway_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsInternetGatewayConfig(
            filter=filter,
            internet_gateway_id=internet_gateway_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsInternetGateway, self, [scope, id, config])

    @jsii.member(jsii_name="attachments")
    def attachments(self, index: str) -> "DataAwsInternetGatewayAttachments":
        """
        :param index: -
        """
        return jsii.invoke(self, "attachments", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsInternetGatewayFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsInternetGatewayFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="internetGatewayId")
    def internet_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "internetGatewayId")

    @internet_gateway_id.setter
    def internet_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "internetGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsInternetGatewayAttachments(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInternetGatewayAttachments",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsInternetGatewayAttachments,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInternetGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "internet_gateway_id": "internetGatewayId",
        "tags": "tags",
    },
)
class DataAwsInternetGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsInternetGatewayFilter"]] = None,
        internet_gateway_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param internet_gateway_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if internet_gateway_id is not None:
            self._values["internet_gateway_id"] = internet_gateway_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsInternetGatewayFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def internet_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("internet_gateway_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsInternetGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsInternetGatewayFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsInternetGatewayFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsInternetGatewayFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIotEndpoint(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIotEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        endpoint_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param endpoint_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIotEndpointConfig(
            endpoint_type=endpoint_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIotEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="endpointAddress")
    def endpoint_address(self) -> str:
        return jsii.get(self, "endpointAddress")

    @builtins.property
    @jsii.member(jsii_name="endpointType")
    def endpoint_type(self) -> typing.Optional[str]:
        return jsii.get(self, "endpointType")

    @endpoint_type.setter
    def endpoint_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endpointType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIotEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "endpoint_type": "endpointType",
    },
)
class DataAwsIotEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        endpoint_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param endpoint_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if endpoint_type is not None:
            self._values["endpoint_type"] = endpoint_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def endpoint_type(self) -> typing.Optional[str]:
        return self._values.get("endpoint_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIotEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsIpRanges(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIpRanges",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        services: typing.List[str],
        regions: typing.Optional[typing.List[str]] = None,
        url: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param services: 
        :param regions: 
        :param url: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsIpRangesConfig(
            services=services,
            regions=regions,
            url=url,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsIpRanges, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cidrBlocks")
    def cidr_blocks(self) -> typing.List[str]:
        return jsii.get(self, "cidrBlocks")

    @builtins.property
    @jsii.member(jsii_name="createDate")
    def create_date(self) -> str:
        return jsii.get(self, "createDate")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlocks")
    def ipv6_cidr_blocks(self) -> typing.List[str]:
        return jsii.get(self, "ipv6CidrBlocks")

    @builtins.property
    @jsii.member(jsii_name="syncToken")
    def sync_token(self) -> jsii.Number:
        return jsii.get(self, "syncToken")

    @builtins.property
    @jsii.member(jsii_name="services")
    def services(self) -> typing.List[str]:
        return jsii.get(self, "services")

    @services.setter
    def services(self, value: typing.List[str]) -> None:
        jsii.set(self, "services", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="regions")
    def regions(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "regions")

    @regions.setter
    def regions(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "regions", value)

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> typing.Optional[str]:
        return jsii.get(self, "url")

    @url.setter
    def url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "url", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsIpRangesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "services": "services",
        "regions": "regions",
        "url": "url",
    },
)
class DataAwsIpRangesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        services: typing.List[str],
        regions: typing.Optional[typing.List[str]] = None,
        url: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param services: 
        :param regions: 
        :param url: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "services": services,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if regions is not None:
            self._values["regions"] = regions
        if url is not None:
            self._values["url"] = url

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def services(self) -> typing.List[str]:
        return self._values.get("services")

    @builtins.property
    def regions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("regions")

    @builtins.property
    def url(self) -> typing.Optional[str]:
        return self._values.get("url")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsIpRangesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsKinesisStream(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKinesisStream",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsKinesisStreamConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsKinesisStream, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="closedShards")
    def closed_shards(self) -> typing.List[str]:
        return jsii.get(self, "closedShards")

    @builtins.property
    @jsii.member(jsii_name="creationTimestamp")
    def creation_timestamp(self) -> jsii.Number:
        return jsii.get(self, "creationTimestamp")

    @builtins.property
    @jsii.member(jsii_name="openShards")
    def open_shards(self) -> typing.List[str]:
        return jsii.get(self, "openShards")

    @builtins.property
    @jsii.member(jsii_name="retentionPeriod")
    def retention_period(self) -> jsii.Number:
        return jsii.get(self, "retentionPeriod")

    @builtins.property
    @jsii.member(jsii_name="shardLevelMetrics")
    def shard_level_metrics(self) -> typing.List[str]:
        return jsii.get(self, "shardLevelMetrics")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKinesisStreamConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsKinesisStreamConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKinesisStreamConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsKmsAlias(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsKmsAliasConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsKmsAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="targetKeyArn")
    def target_key_arn(self) -> str:
        return jsii.get(self, "targetKeyArn")

    @builtins.property
    @jsii.member(jsii_name="targetKeyId")
    def target_key_id(self) -> str:
        return jsii.get(self, "targetKeyId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsKmsAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKmsAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsKmsCiphertext(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsCiphertext",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        key_id: str,
        plaintext: str,
        context: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_id: 
        :param plaintext: 
        :param context: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsKmsCiphertextConfig(
            key_id=key_id,
            plaintext=plaintext,
            context=context,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsKmsCiphertext, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ciphertextBlob")
    def ciphertext_blob(self) -> str:
        return jsii.get(self, "ciphertextBlob")

    @builtins.property
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> str:
        return jsii.get(self, "keyId")

    @key_id.setter
    def key_id(self, value: str) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property
    @jsii.member(jsii_name="plaintext")
    def plaintext(self) -> str:
        return jsii.get(self, "plaintext")

    @plaintext.setter
    def plaintext(self, value: str) -> None:
        jsii.set(self, "plaintext", value)

    @builtins.property
    @jsii.member(jsii_name="context")
    def context(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "context")

    @context.setter
    def context(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "context", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsCiphertextConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_id": "keyId",
        "plaintext": "plaintext",
        "context": "context",
    },
)
class DataAwsKmsCiphertextConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_id: str,
        plaintext: str,
        context: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_id: 
        :param plaintext: 
        :param context: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "key_id": key_id,
            "plaintext": plaintext,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if context is not None:
            self._values["context"] = context

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def key_id(self) -> str:
        return self._values.get("key_id")

    @builtins.property
    def plaintext(self) -> str:
        return self._values.get("plaintext")

    @builtins.property
    def context(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("context")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKmsCiphertextConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsKmsKey(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        key_id: str,
        grant_tokens: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_id: 
        :param grant_tokens: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsKmsKeyConfig(
            key_id=key_id,
            grant_tokens=grant_tokens,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsKmsKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> str:
        return jsii.get(self, "awsAccountId")

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="customerMasterKeySpec")
    def customer_master_key_spec(self) -> str:
        return jsii.get(self, "customerMasterKeySpec")

    @builtins.property
    @jsii.member(jsii_name="deletionDate")
    def deletion_date(self) -> str:
        return jsii.get(self, "deletionDate")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="expirationModel")
    def expiration_model(self) -> str:
        return jsii.get(self, "expirationModel")

    @builtins.property
    @jsii.member(jsii_name="keyManager")
    def key_manager(self) -> str:
        return jsii.get(self, "keyManager")

    @builtins.property
    @jsii.member(jsii_name="keyState")
    def key_state(self) -> str:
        return jsii.get(self, "keyState")

    @builtins.property
    @jsii.member(jsii_name="keyUsage")
    def key_usage(self) -> str:
        return jsii.get(self, "keyUsage")

    @builtins.property
    @jsii.member(jsii_name="origin")
    def origin(self) -> str:
        return jsii.get(self, "origin")

    @builtins.property
    @jsii.member(jsii_name="validTo")
    def valid_to(self) -> str:
        return jsii.get(self, "validTo")

    @builtins.property
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> str:
        return jsii.get(self, "keyId")

    @key_id.setter
    def key_id(self, value: str) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property
    @jsii.member(jsii_name="grantTokens")
    def grant_tokens(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "grantTokens")

    @grant_tokens.setter
    def grant_tokens(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "grantTokens", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_id": "keyId",
        "grant_tokens": "grantTokens",
    },
)
class DataAwsKmsKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_id: str,
        grant_tokens: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_id: 
        :param grant_tokens: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "key_id": key_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if grant_tokens is not None:
            self._values["grant_tokens"] = grant_tokens

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def key_id(self) -> str:
        return self._values.get("key_id")

    @builtins.property
    def grant_tokens(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("grant_tokens")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKmsKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsKmsSecret(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsSecret",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        secret: typing.List["DataAwsKmsSecretSecret"],
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param secret: secret block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsKmsSecretConfig(
            secret=secret,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsKmsSecret, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="secret")
    def secret(self) -> typing.List["DataAwsKmsSecretSecret"]:
        return jsii.get(self, "secret")

    @secret.setter
    def secret(self, value: typing.List["DataAwsKmsSecretSecret"]) -> None:
        jsii.set(self, "secret", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsSecretConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "secret": "secret",
    },
)
class DataAwsKmsSecretConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        secret: typing.List["DataAwsKmsSecretSecret"],
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param secret: secret block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "secret": secret,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def secret(self) -> typing.List["DataAwsKmsSecretSecret"]:
        """secret block."""
        return self._values.get("secret")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKmsSecretConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsSecretSecret",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "payload": "payload",
        "context": "context",
        "grant_tokens": "grantTokens",
    },
)
class DataAwsKmsSecretSecret:
    def __init__(
        self,
        *,
        name: str,
        payload: str,
        context: typing.Optional[typing.Mapping[str, str]] = None,
        grant_tokens: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param name: 
        :param payload: 
        :param context: 
        :param grant_tokens: 
        """
        self._values = {
            "name": name,
            "payload": payload,
        }
        if context is not None:
            self._values["context"] = context
        if grant_tokens is not None:
            self._values["grant_tokens"] = grant_tokens

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def payload(self) -> str:
        return self._values.get("payload")

    @builtins.property
    def context(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("context")

    @builtins.property
    def grant_tokens(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("grant_tokens")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKmsSecretSecret(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsKmsSecrets(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsSecrets",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        secret: typing.List["DataAwsKmsSecretsSecret"],
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param secret: secret block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsKmsSecretsConfig(
            secret=secret,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsKmsSecrets, self, [scope, id, config])

    @jsii.member(jsii_name="plaintext")
    def plaintext(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "plaintext", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="secret")
    def secret(self) -> typing.List["DataAwsKmsSecretsSecret"]:
        return jsii.get(self, "secret")

    @secret.setter
    def secret(self, value: typing.List["DataAwsKmsSecretsSecret"]) -> None:
        jsii.set(self, "secret", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsSecretsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "secret": "secret",
    },
)
class DataAwsKmsSecretsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        secret: typing.List["DataAwsKmsSecretsSecret"],
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param secret: secret block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "secret": secret,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def secret(self) -> typing.List["DataAwsKmsSecretsSecret"]:
        """secret block."""
        return self._values.get("secret")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKmsSecretsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsKmsSecretsSecret",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "payload": "payload",
        "context": "context",
        "grant_tokens": "grantTokens",
    },
)
class DataAwsKmsSecretsSecret:
    def __init__(
        self,
        *,
        name: str,
        payload: str,
        context: typing.Optional[typing.Mapping[str, str]] = None,
        grant_tokens: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param name: 
        :param payload: 
        :param context: 
        :param grant_tokens: 
        """
        self._values = {
            "name": name,
            "payload": payload,
        }
        if context is not None:
            self._values["context"] = context
        if grant_tokens is not None:
            self._values["grant_tokens"] = grant_tokens

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def payload(self) -> str:
        return self._values.get("payload")

    @builtins.property
    def context(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("context")

    @builtins.property
    def grant_tokens(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("grant_tokens")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsKmsSecretsSecret(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLambdaAlias(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        function_name: str,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param function_name: 
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLambdaAliasConfig(
            function_name=function_name,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLambdaAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="functionVersion")
    def function_version(self) -> str:
        return jsii.get(self, "functionVersion")

    @builtins.property
    @jsii.member(jsii_name="invokeArn")
    def invoke_arn(self) -> str:
        return jsii.get(self, "invokeArn")

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_name": "functionName",
        "name": "name",
    },
)
class DataAwsLambdaAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_name: str,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_name: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "function_name": function_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLambdaAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLambdaFunction(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaFunction",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        function_name: str,
        qualifier: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param function_name: 
        :param qualifier: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLambdaFunctionConfig(
            function_name=function_name,
            qualifier=qualifier,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLambdaFunction, self, [scope, id, config])

    @jsii.member(jsii_name="deadLetterConfig")
    def dead_letter_config(self, index: str) -> "DataAwsLambdaFunctionDeadLetterConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "deadLetterConfig", [index])

    @jsii.member(jsii_name="environment")
    def environment(self, index: str) -> "DataAwsLambdaFunctionEnvironment":
        """
        :param index: -
        """
        return jsii.invoke(self, "environment", [index])

    @jsii.member(jsii_name="fileSystemConfig")
    def file_system_config(self, index: str) -> "DataAwsLambdaFunctionFileSystemConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "fileSystemConfig", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tracingConfig")
    def tracing_config(self, index: str) -> "DataAwsLambdaFunctionTracingConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "tracingConfig", [index])

    @jsii.member(jsii_name="vpcConfig")
    def vpc_config(self, index: str) -> "DataAwsLambdaFunctionVpcConfig":
        """
        :param index: -
        """
        return jsii.invoke(self, "vpcConfig", [index])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="handler")
    def handler(self) -> str:
        return jsii.get(self, "handler")

    @builtins.property
    @jsii.member(jsii_name="invokeArn")
    def invoke_arn(self) -> str:
        return jsii.get(self, "invokeArn")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> str:
        return jsii.get(self, "kmsKeyArn")

    @builtins.property
    @jsii.member(jsii_name="lastModified")
    def last_modified(self) -> str:
        return jsii.get(self, "lastModified")

    @builtins.property
    @jsii.member(jsii_name="layers")
    def layers(self) -> typing.List[str]:
        return jsii.get(self, "layers")

    @builtins.property
    @jsii.member(jsii_name="memorySize")
    def memory_size(self) -> jsii.Number:
        return jsii.get(self, "memorySize")

    @builtins.property
    @jsii.member(jsii_name="qualifiedArn")
    def qualified_arn(self) -> str:
        return jsii.get(self, "qualifiedArn")

    @builtins.property
    @jsii.member(jsii_name="reservedConcurrentExecutions")
    def reserved_concurrent_executions(self) -> jsii.Number:
        return jsii.get(self, "reservedConcurrentExecutions")

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> str:
        return jsii.get(self, "role")

    @builtins.property
    @jsii.member(jsii_name="runtime")
    def runtime(self) -> str:
        return jsii.get(self, "runtime")

    @builtins.property
    @jsii.member(jsii_name="sourceCodeHash")
    def source_code_hash(self) -> str:
        return jsii.get(self, "sourceCodeHash")

    @builtins.property
    @jsii.member(jsii_name="sourceCodeSize")
    def source_code_size(self) -> jsii.Number:
        return jsii.get(self, "sourceCodeSize")

    @builtins.property
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return jsii.get(self, "timeout")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="qualifier")
    def qualifier(self) -> typing.Optional[str]:
        return jsii.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "qualifier", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaFunctionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_name": "functionName",
        "qualifier": "qualifier",
        "tags": "tags",
    },
)
class DataAwsLambdaFunctionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_name: str,
        qualifier: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_name: 
        :param qualifier: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "function_name": function_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if qualifier is not None:
            self._values["qualifier"] = qualifier
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def qualifier(self) -> typing.Optional[str]:
        return self._values.get("qualifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLambdaFunctionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLambdaFunctionDeadLetterConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaFunctionDeadLetterConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLambdaFunctionDeadLetterConfig,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="targetArn")
    def target_arn(self) -> str:
        return jsii.get(self, "targetArn")


class DataAwsLambdaFunctionEnvironment(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaFunctionEnvironment",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLambdaFunctionEnvironment,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="variables")
    def variables(self) -> typing.Any:
        return jsii.get(self, "variables")


class DataAwsLambdaFunctionFileSystemConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaFunctionFileSystemConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLambdaFunctionFileSystemConfig,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="localMountPath")
    def local_mount_path(self) -> str:
        return jsii.get(self, "localMountPath")


class DataAwsLambdaFunctionTracingConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaFunctionTracingConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLambdaFunctionTracingConfig,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="mode")
    def mode(self) -> str:
        return jsii.get(self, "mode")


class DataAwsLambdaFunctionVpcConfig(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaFunctionVpcConfig",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLambdaFunctionVpcConfig,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")


class DataAwsLambdaInvocation(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaInvocation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        function_name: str,
        input: str,
        qualifier: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param function_name: 
        :param input: 
        :param qualifier: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLambdaInvocationConfig(
            function_name=function_name,
            input=input,
            qualifier=qualifier,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLambdaInvocation, self, [scope, id, config])

    @jsii.member(jsii_name="resultMap")
    def result_map(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "resultMap", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="result")
    def result(self) -> str:
        return jsii.get(self, "result")

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="input")
    def input(self) -> str:
        return jsii.get(self, "input")

    @input.setter
    def input(self, value: str) -> None:
        jsii.set(self, "input", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="qualifier")
    def qualifier(self) -> typing.Optional[str]:
        return jsii.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "qualifier", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaInvocationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_name": "functionName",
        "input": "input",
        "qualifier": "qualifier",
    },
)
class DataAwsLambdaInvocationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_name: str,
        input: str,
        qualifier: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_name: 
        :param input: 
        :param qualifier: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "function_name": function_name,
            "input": input,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if qualifier is not None:
            self._values["qualifier"] = qualifier

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def input(self) -> str:
        return self._values.get("input")

    @builtins.property
    def qualifier(self) -> typing.Optional[str]:
        return self._values.get("qualifier")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLambdaInvocationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLambdaLayerVersion(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaLayerVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        layer_name: str,
        compatible_runtime: typing.Optional[str] = None,
        version: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param layer_name: 
        :param compatible_runtime: 
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLambdaLayerVersionConfig(
            layer_name=layer_name,
            compatible_runtime=compatible_runtime,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLambdaLayerVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="compatibleRuntimes")
    def compatible_runtimes(self) -> typing.List[str]:
        return jsii.get(self, "compatibleRuntimes")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="layerArn")
    def layer_arn(self) -> str:
        return jsii.get(self, "layerArn")

    @builtins.property
    @jsii.member(jsii_name="licenseInfo")
    def license_info(self) -> str:
        return jsii.get(self, "licenseInfo")

    @builtins.property
    @jsii.member(jsii_name="sourceCodeHash")
    def source_code_hash(self) -> str:
        return jsii.get(self, "sourceCodeHash")

    @builtins.property
    @jsii.member(jsii_name="sourceCodeSize")
    def source_code_size(self) -> jsii.Number:
        return jsii.get(self, "sourceCodeSize")

    @builtins.property
    @jsii.member(jsii_name="layerName")
    def layer_name(self) -> str:
        return jsii.get(self, "layerName")

    @layer_name.setter
    def layer_name(self, value: str) -> None:
        jsii.set(self, "layerName", value)

    @builtins.property
    @jsii.member(jsii_name="compatibleRuntime")
    def compatible_runtime(self) -> typing.Optional[str]:
        return jsii.get(self, "compatibleRuntime")

    @compatible_runtime.setter
    def compatible_runtime(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "compatibleRuntime", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLambdaLayerVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "layer_name": "layerName",
        "compatible_runtime": "compatibleRuntime",
        "version": "version",
    },
)
class DataAwsLambdaLayerVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        layer_name: str,
        compatible_runtime: typing.Optional[str] = None,
        version: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param layer_name: 
        :param compatible_runtime: 
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "layer_name": layer_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if compatible_runtime is not None:
            self._values["compatible_runtime"] = compatible_runtime
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def layer_name(self) -> str:
        return self._values.get("layer_name")

    @builtins.property
    def compatible_runtime(self) -> typing.Optional[str]:
        return self._values.get("compatible_runtime")

    @builtins.property
    def version(self) -> typing.Optional[jsii.Number]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLambdaLayerVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLaunchConfiguration(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLaunchConfigurationConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLaunchConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(
        self, index: str
    ) -> "DataAwsLaunchConfigurationEbsBlockDevice":
        """
        :param index: -
        """
        return jsii.invoke(self, "ebsBlockDevice", [index])

    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self, index: str
    ) -> "DataAwsLaunchConfigurationEphemeralBlockDevice":
        """
        :param index: -
        """
        return jsii.invoke(self, "ephemeralBlockDevice", [index])

    @jsii.member(jsii_name="rootBlockDevice")
    def root_block_device(
        self, index: str
    ) -> "DataAwsLaunchConfigurationRootBlockDevice":
        """
        :param index: -
        """
        return jsii.invoke(self, "rootBlockDevice", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> bool:
        return jsii.get(self, "associatePublicIpAddress")

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> bool:
        return jsii.get(self, "ebsOptimized")

    @builtins.property
    @jsii.member(jsii_name="enableMonitoring")
    def enable_monitoring(self) -> bool:
        return jsii.get(self, "enableMonitoring")

    @builtins.property
    @jsii.member(jsii_name="iamInstanceProfile")
    def iam_instance_profile(self) -> str:
        return jsii.get(self, "iamInstanceProfile")

    @builtins.property
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> str:
        return jsii.get(self, "imageId")

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> str:
        return jsii.get(self, "keyName")

    @builtins.property
    @jsii.member(jsii_name="placementTenancy")
    def placement_tenancy(self) -> str:
        return jsii.get(self, "placementTenancy")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="spotPrice")
    def spot_price(self) -> str:
        return jsii.get(self, "spotPrice")

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> str:
        return jsii.get(self, "userData")

    @builtins.property
    @jsii.member(jsii_name="vpcClassicLinkId")
    def vpc_classic_link_id(self) -> str:
        return jsii.get(self, "vpcClassicLinkId")

    @builtins.property
    @jsii.member(jsii_name="vpcClassicLinkSecurityGroups")
    def vpc_classic_link_security_groups(self) -> typing.List[str]:
        return jsii.get(self, "vpcClassicLinkSecurityGroups")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsLaunchConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLaunchConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLaunchConfigurationEbsBlockDevice(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchConfigurationEbsBlockDevice",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchConfigurationEbsBlockDevice,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deleteOnTermination")
    def delete_on_termination(self) -> bool:
        return jsii.get(self, "deleteOnTermination")

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> str:
        return jsii.get(self, "snapshotId")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="volumeType")
    def volume_type(self) -> str:
        return jsii.get(self, "volumeType")


class DataAwsLaunchConfigurationEphemeralBlockDevice(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchConfigurationEphemeralBlockDevice",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchConfigurationEphemeralBlockDevice,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @builtins.property
    @jsii.member(jsii_name="virtualName")
    def virtual_name(self) -> str:
        return jsii.get(self, "virtualName")


class DataAwsLaunchConfigurationRootBlockDevice(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchConfigurationRootBlockDevice",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchConfigurationRootBlockDevice,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deleteOnTermination")
    def delete_on_termination(self) -> bool:
        return jsii.get(self, "deleteOnTermination")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="volumeType")
    def volume_type(self) -> str:
        return jsii.get(self, "volumeType")


class DataAwsLaunchTemplate(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsLaunchTemplateFilter"]] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLaunchTemplateConfig(
            filter=filter,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLaunchTemplate, self, [scope, id, config])

    @jsii.member(jsii_name="blockDeviceMappings")
    def block_device_mappings(
        self, index: str
    ) -> "DataAwsLaunchTemplateBlockDeviceMappings":
        """
        :param index: -
        """
        return jsii.invoke(self, "blockDeviceMappings", [index])

    @jsii.member(jsii_name="creditSpecification")
    def credit_specification(
        self, index: str
    ) -> "DataAwsLaunchTemplateCreditSpecification":
        """
        :param index: -
        """
        return jsii.invoke(self, "creditSpecification", [index])

    @jsii.member(jsii_name="elasticGpuSpecifications")
    def elastic_gpu_specifications(
        self, index: str
    ) -> "DataAwsLaunchTemplateElasticGpuSpecifications":
        """
        :param index: -
        """
        return jsii.invoke(self, "elasticGpuSpecifications", [index])

    @jsii.member(jsii_name="hibernationOptions")
    def hibernation_options(
        self, index: str
    ) -> "DataAwsLaunchTemplateHibernationOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "hibernationOptions", [index])

    @jsii.member(jsii_name="iamInstanceProfile")
    def iam_instance_profile(
        self, index: str
    ) -> "DataAwsLaunchTemplateIamInstanceProfile":
        """
        :param index: -
        """
        return jsii.invoke(self, "iamInstanceProfile", [index])

    @jsii.member(jsii_name="instanceMarketOptions")
    def instance_market_options(
        self, index: str
    ) -> "DataAwsLaunchTemplateInstanceMarketOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "instanceMarketOptions", [index])

    @jsii.member(jsii_name="metadataOptions")
    def metadata_options(self, index: str) -> "DataAwsLaunchTemplateMetadataOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "metadataOptions", [index])

    @jsii.member(jsii_name="monitoring")
    def monitoring(self, index: str) -> "DataAwsLaunchTemplateMonitoring":
        """
        :param index: -
        """
        return jsii.invoke(self, "monitoring", [index])

    @jsii.member(jsii_name="networkInterfaces")
    def network_interfaces(
        self, index: str
    ) -> "DataAwsLaunchTemplateNetworkInterfaces":
        """
        :param index: -
        """
        return jsii.invoke(self, "networkInterfaces", [index])

    @jsii.member(jsii_name="placement")
    def placement(self, index: str) -> "DataAwsLaunchTemplatePlacement":
        """
        :param index: -
        """
        return jsii.invoke(self, "placement", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tagSpecifications")
    def tag_specifications(
        self, index: str
    ) -> "DataAwsLaunchTemplateTagSpecifications":
        """
        :param index: -
        """
        return jsii.invoke(self, "tagSpecifications", [index])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultVersion")
    def default_version(self) -> jsii.Number:
        return jsii.get(self, "defaultVersion")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="disableApiTermination")
    def disable_api_termination(self) -> bool:
        return jsii.get(self, "disableApiTermination")

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> str:
        return jsii.get(self, "ebsOptimized")

    @builtins.property
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> str:
        return jsii.get(self, "imageId")

    @builtins.property
    @jsii.member(jsii_name="instanceInitiatedShutdownBehavior")
    def instance_initiated_shutdown_behavior(self) -> str:
        return jsii.get(self, "instanceInitiatedShutdownBehavior")

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @builtins.property
    @jsii.member(jsii_name="kernelId")
    def kernel_id(self) -> str:
        return jsii.get(self, "kernelId")

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> str:
        return jsii.get(self, "keyName")

    @builtins.property
    @jsii.member(jsii_name="latestVersion")
    def latest_version(self) -> jsii.Number:
        return jsii.get(self, "latestVersion")

    @builtins.property
    @jsii.member(jsii_name="ramDiskId")
    def ram_disk_id(self) -> str:
        return jsii.get(self, "ramDiskId")

    @builtins.property
    @jsii.member(jsii_name="securityGroupNames")
    def security_group_names(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupNames")

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> str:
        return jsii.get(self, "userData")

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsLaunchTemplateFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsLaunchTemplateFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsLaunchTemplateBlockDeviceMappings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateBlockDeviceMappings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateBlockDeviceMappings,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @builtins.property
    @jsii.member(jsii_name="ebs")
    def ebs(self) -> typing.Any:
        return jsii.get(self, "ebs")

    @builtins.property
    @jsii.member(jsii_name="noDevice")
    def no_device(self) -> str:
        return jsii.get(self, "noDevice")

    @builtins.property
    @jsii.member(jsii_name="virtualName")
    def virtual_name(self) -> str:
        return jsii.get(self, "virtualName")


class DataAwsLaunchTemplateBlockDeviceMappingsEbs(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateBlockDeviceMappingsEbs",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateBlockDeviceMappingsEbs,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="deleteOnTermination")
    def delete_on_termination(self) -> str:
        return jsii.get(self, "deleteOnTermination")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> str:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> str:
        return jsii.get(self, "snapshotId")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="volumeType")
    def volume_type(self) -> str:
        return jsii.get(self, "volumeType")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsLaunchTemplateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsLaunchTemplateFilter"]] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsLaunchTemplateFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLaunchTemplateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLaunchTemplateCreditSpecification(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateCreditSpecification",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateCreditSpecification,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="cpuCredits")
    def cpu_credits(self) -> str:
        return jsii.get(self, "cpuCredits")


class DataAwsLaunchTemplateElasticGpuSpecifications(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateElasticGpuSpecifications",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateElasticGpuSpecifications,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsLaunchTemplateFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLaunchTemplateFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLaunchTemplateHibernationOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateHibernationOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateHibernationOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="configured")
    def configured(self) -> bool:
        return jsii.get(self, "configured")


class DataAwsLaunchTemplateIamInstanceProfile(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateIamInstanceProfile",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateIamInstanceProfile,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")


class DataAwsLaunchTemplateInstanceMarketOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateInstanceMarketOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateInstanceMarketOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="marketType")
    def market_type(self) -> str:
        return jsii.get(self, "marketType")

    @builtins.property
    @jsii.member(jsii_name="spotOptions")
    def spot_options(self) -> typing.Any:
        return jsii.get(self, "spotOptions")


class DataAwsLaunchTemplateInstanceMarketOptionsSpotOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateInstanceMarketOptionsSpotOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateInstanceMarketOptionsSpotOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="blockDurationMinutes")
    def block_duration_minutes(self) -> jsii.Number:
        return jsii.get(self, "blockDurationMinutes")

    @builtins.property
    @jsii.member(jsii_name="instanceInterruptionBehavior")
    def instance_interruption_behavior(self) -> str:
        return jsii.get(self, "instanceInterruptionBehavior")

    @builtins.property
    @jsii.member(jsii_name="maxPrice")
    def max_price(self) -> str:
        return jsii.get(self, "maxPrice")

    @builtins.property
    @jsii.member(jsii_name="spotInstanceType")
    def spot_instance_type(self) -> str:
        return jsii.get(self, "spotInstanceType")

    @builtins.property
    @jsii.member(jsii_name="validUntil")
    def valid_until(self) -> str:
        return jsii.get(self, "validUntil")


class DataAwsLaunchTemplateMetadataOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateMetadataOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateMetadataOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="httpEndpoint")
    def http_endpoint(self) -> str:
        return jsii.get(self, "httpEndpoint")

    @builtins.property
    @jsii.member(jsii_name="httpPutResponseHopLimit")
    def http_put_response_hop_limit(self) -> jsii.Number:
        return jsii.get(self, "httpPutResponseHopLimit")

    @builtins.property
    @jsii.member(jsii_name="httpTokens")
    def http_tokens(self) -> str:
        return jsii.get(self, "httpTokens")


class DataAwsLaunchTemplateMonitoring(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateMonitoring",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateMonitoring,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")


class DataAwsLaunchTemplateNetworkInterfaces(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateNetworkInterfaces",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateNetworkInterfaces,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> str:
        return jsii.get(self, "associatePublicIpAddress")

    @builtins.property
    @jsii.member(jsii_name="deleteOnTermination")
    def delete_on_termination(self) -> bool:
        return jsii.get(self, "deleteOnTermination")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="deviceIndex")
    def device_index(self) -> jsii.Number:
        return jsii.get(self, "deviceIndex")

    @builtins.property
    @jsii.member(jsii_name="ipv4AddressCount")
    def ipv4_address_count(self) -> jsii.Number:
        return jsii.get(self, "ipv4AddressCount")

    @builtins.property
    @jsii.member(jsii_name="ipv4Addresses")
    def ipv4_addresses(self) -> typing.List[str]:
        return jsii.get(self, "ipv4Addresses")

    @builtins.property
    @jsii.member(jsii_name="ipv6AddressCount")
    def ipv6_address_count(self) -> jsii.Number:
        return jsii.get(self, "ipv6AddressCount")

    @builtins.property
    @jsii.member(jsii_name="ipv6Addresses")
    def ipv6_addresses(self) -> typing.List[str]:
        return jsii.get(self, "ipv6Addresses")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")


class DataAwsLaunchTemplatePlacement(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplatePlacement",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplatePlacement,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="affinity")
    def affinity(self) -> str:
        return jsii.get(self, "affinity")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="groupName")
    def group_name(self) -> str:
        return jsii.get(self, "groupName")

    @builtins.property
    @jsii.member(jsii_name="hostId")
    def host_id(self) -> str:
        return jsii.get(self, "hostId")

    @builtins.property
    @jsii.member(jsii_name="partitionNumber")
    def partition_number(self) -> jsii.Number:
        return jsii.get(self, "partitionNumber")

    @builtins.property
    @jsii.member(jsii_name="spreadDomain")
    def spread_domain(self) -> str:
        return jsii.get(self, "spreadDomain")

    @builtins.property
    @jsii.member(jsii_name="tenancy")
    def tenancy(self) -> str:
        return jsii.get(self, "tenancy")


class DataAwsLaunchTemplateTagSpecifications(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLaunchTemplateTagSpecifications",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLaunchTemplateTagSpecifications,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="resourceType")
    def resource_type(self) -> str:
        return jsii.get(self, "resourceType")

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Any:
        return jsii.get(self, "tags")


class DataAwsLb(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLbConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLb, self, [scope, id, config])

    @jsii.member(jsii_name="accessLogs")
    def access_logs(self, index: str) -> "DataAwsLbAccessLogs":
        """
        :param index: -
        """
        return jsii.invoke(self, "accessLogs", [index])

    @jsii.member(jsii_name="subnetMapping")
    def subnet_mapping(self, index: str) -> "DataAwsLbSubnetMapping":
        """
        :param index: -
        """
        return jsii.invoke(self, "subnetMapping", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="dropInvalidHeaderFields")
    def drop_invalid_header_fields(self) -> bool:
        return jsii.get(self, "dropInvalidHeaderFields")

    @builtins.property
    @jsii.member(jsii_name="enableDeletionProtection")
    def enable_deletion_protection(self) -> bool:
        return jsii.get(self, "enableDeletionProtection")

    @builtins.property
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> jsii.Number:
        return jsii.get(self, "idleTimeout")

    @builtins.property
    @jsii.member(jsii_name="internal")
    def internal(self) -> bool:
        return jsii.get(self, "internal")

    @builtins.property
    @jsii.member(jsii_name="ipAddressType")
    def ip_address_type(self) -> str:
        return jsii.get(self, "ipAddressType")

    @builtins.property
    @jsii.member(jsii_name="loadBalancerType")
    def load_balancer_type(self) -> str:
        return jsii.get(self, "loadBalancerType")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.List[str]:
        return jsii.get(self, "subnets")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsLbAccessLogs(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbAccessLogs",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbAccessLogs, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> str:
        return jsii.get(self, "prefix")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsLbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLbListener(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbListener",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        load_balancer_arn: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param load_balancer_arn: 
        :param port: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLbListenerConfig(
            load_balancer_arn=load_balancer_arn,
            port=port,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLbListener, self, [scope, id, config])

    @jsii.member(jsii_name="defaultAction")
    def default_action(self, index: str) -> "DataAwsLbListenerDefaultAction":
        """
        :param index: -
        """
        return jsii.invoke(self, "defaultAction", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> str:
        return jsii.get(self, "certificateArn")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="sslPolicy")
    def ssl_policy(self) -> str:
        return jsii.get(self, "sslPolicy")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerArn")
    def load_balancer_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "loadBalancerArn")

    @load_balancer_arn.setter
    def load_balancer_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "loadBalancerArn", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbListenerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "load_balancer_arn": "loadBalancerArn",
        "port": "port",
    },
)
class DataAwsLbListenerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        load_balancer_arn: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param load_balancer_arn: 
        :param port: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if load_balancer_arn is not None:
            self._values["load_balancer_arn"] = load_balancer_arn
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def load_balancer_arn(self) -> typing.Optional[str]:
        return self._values.get("load_balancer_arn")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLbListenerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLbListenerDefaultAction(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbListenerDefaultAction",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbListenerDefaultAction,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="authenticateCognito")
    def authenticate_cognito(self) -> typing.Any:
        return jsii.get(self, "authenticateCognito")

    @builtins.property
    @jsii.member(jsii_name="authenticateOidc")
    def authenticate_oidc(self) -> typing.Any:
        return jsii.get(self, "authenticateOidc")

    @builtins.property
    @jsii.member(jsii_name="fixedResponse")
    def fixed_response(self) -> typing.Any:
        return jsii.get(self, "fixedResponse")

    @builtins.property
    @jsii.member(jsii_name="order")
    def order(self) -> jsii.Number:
        return jsii.get(self, "order")

    @builtins.property
    @jsii.member(jsii_name="redirect")
    def redirect(self) -> typing.Any:
        return jsii.get(self, "redirect")

    @builtins.property
    @jsii.member(jsii_name="targetGroupArn")
    def target_group_arn(self) -> str:
        return jsii.get(self, "targetGroupArn")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


class DataAwsLbListenerDefaultActionAuthenticateCognito(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbListenerDefaultActionAuthenticateCognito",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbListenerDefaultActionAuthenticateCognito,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="authenticationRequestExtraParams")
    def authentication_request_extra_params(self) -> typing.Any:
        return jsii.get(self, "authenticationRequestExtraParams")

    @builtins.property
    @jsii.member(jsii_name="onUnauthenticatedRequest")
    def on_unauthenticated_request(self) -> str:
        return jsii.get(self, "onUnauthenticatedRequest")

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @builtins.property
    @jsii.member(jsii_name="sessionCookieName")
    def session_cookie_name(self) -> str:
        return jsii.get(self, "sessionCookieName")

    @builtins.property
    @jsii.member(jsii_name="sessionTimeout")
    def session_timeout(self) -> jsii.Number:
        return jsii.get(self, "sessionTimeout")

    @builtins.property
    @jsii.member(jsii_name="userPoolArn")
    def user_pool_arn(self) -> str:
        return jsii.get(self, "userPoolArn")

    @builtins.property
    @jsii.member(jsii_name="userPoolClientId")
    def user_pool_client_id(self) -> str:
        return jsii.get(self, "userPoolClientId")

    @builtins.property
    @jsii.member(jsii_name="userPoolDomain")
    def user_pool_domain(self) -> str:
        return jsii.get(self, "userPoolDomain")


class DataAwsLbListenerDefaultActionAuthenticateOidc(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbListenerDefaultActionAuthenticateOidc",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbListenerDefaultActionAuthenticateOidc,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="authenticationRequestExtraParams")
    def authentication_request_extra_params(self) -> typing.Any:
        return jsii.get(self, "authenticationRequestExtraParams")

    @builtins.property
    @jsii.member(jsii_name="authorizationEndpoint")
    def authorization_endpoint(self) -> str:
        return jsii.get(self, "authorizationEndpoint")

    @builtins.property
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> str:
        return jsii.get(self, "clientId")

    @builtins.property
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> str:
        return jsii.get(self, "clientSecret")

    @builtins.property
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> str:
        return jsii.get(self, "issuer")

    @builtins.property
    @jsii.member(jsii_name="onUnauthenticatedRequest")
    def on_unauthenticated_request(self) -> str:
        return jsii.get(self, "onUnauthenticatedRequest")

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @builtins.property
    @jsii.member(jsii_name="sessionCookieName")
    def session_cookie_name(self) -> str:
        return jsii.get(self, "sessionCookieName")

    @builtins.property
    @jsii.member(jsii_name="sessionTimeout")
    def session_timeout(self) -> jsii.Number:
        return jsii.get(self, "sessionTimeout")

    @builtins.property
    @jsii.member(jsii_name="tokenEndpoint")
    def token_endpoint(self) -> str:
        return jsii.get(self, "tokenEndpoint")

    @builtins.property
    @jsii.member(jsii_name="userInfoEndpoint")
    def user_info_endpoint(self) -> str:
        return jsii.get(self, "userInfoEndpoint")


class DataAwsLbListenerDefaultActionFixedResponse(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbListenerDefaultActionFixedResponse",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbListenerDefaultActionFixedResponse,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> str:
        return jsii.get(self, "contentType")

    @builtins.property
    @jsii.member(jsii_name="messageBody")
    def message_body(self) -> str:
        return jsii.get(self, "messageBody")

    @builtins.property
    @jsii.member(jsii_name="statusCode")
    def status_code(self) -> str:
        return jsii.get(self, "statusCode")


class DataAwsLbListenerDefaultActionRedirect(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbListenerDefaultActionRedirect",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbListenerDefaultActionRedirect,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="host")
    def host(self) -> str:
        return jsii.get(self, "host")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> str:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="query")
    def query(self) -> str:
        return jsii.get(self, "query")

    @builtins.property
    @jsii.member(jsii_name="statusCode")
    def status_code(self) -> str:
        return jsii.get(self, "statusCode")


class DataAwsLbSubnetMapping(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbSubnetMapping",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbSubnetMapping,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="allocationId")
    def allocation_id(self) -> str:
        return jsii.get(self, "allocationId")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")


class DataAwsLbTargetGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbTargetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsLbTargetGroupConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsLbTargetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="healthCheck")
    def health_check(self, index: str) -> "DataAwsLbTargetGroupHealthCheck":
        """
        :param index: -
        """
        return jsii.invoke(self, "healthCheck", [index])

    @jsii.member(jsii_name="stickiness")
    def stickiness(self, index: str) -> "DataAwsLbTargetGroupStickiness":
        """
        :param index: -
        """
        return jsii.invoke(self, "stickiness", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="deregistrationDelay")
    def deregistration_delay(self) -> jsii.Number:
        return jsii.get(self, "deregistrationDelay")

    @builtins.property
    @jsii.member(jsii_name="lambdaMultiValueHeadersEnabled")
    def lambda_multi_value_headers_enabled(self) -> bool:
        return jsii.get(self, "lambdaMultiValueHeadersEnabled")

    @builtins.property
    @jsii.member(jsii_name="loadBalancingAlgorithmType")
    def load_balancing_algorithm_type(self) -> str:
        return jsii.get(self, "loadBalancingAlgorithmType")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="proxyProtocolV2")
    def proxy_protocol_v2(self) -> bool:
        return jsii.get(self, "proxyProtocolV2")

    @builtins.property
    @jsii.member(jsii_name="slowStart")
    def slow_start(self) -> jsii.Number:
        return jsii.get(self, "slowStart")

    @builtins.property
    @jsii.member(jsii_name="targetType")
    def target_type(self) -> str:
        return jsii.get(self, "targetType")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsLbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsLbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsLbTargetGroupHealthCheck(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbTargetGroupHealthCheck",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbTargetGroupHealthCheck,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="healthyThreshold")
    def healthy_threshold(self) -> jsii.Number:
        return jsii.get(self, "healthyThreshold")

    @builtins.property
    @jsii.member(jsii_name="interval")
    def interval(self) -> jsii.Number:
        return jsii.get(self, "interval")

    @builtins.property
    @jsii.member(jsii_name="matcher")
    def matcher(self) -> str:
        return jsii.get(self, "matcher")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> str:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @builtins.property
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> jsii.Number:
        return jsii.get(self, "timeout")

    @builtins.property
    @jsii.member(jsii_name="unhealthyThreshold")
    def unhealthy_threshold(self) -> jsii.Number:
        return jsii.get(self, "unhealthyThreshold")


class DataAwsLbTargetGroupStickiness(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsLbTargetGroupStickiness",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsLbTargetGroupStickiness,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="cookieDuration")
    def cookie_duration(self) -> jsii.Number:
        return jsii.get(self, "cookieDuration")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


class DataAwsMqBroker(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBroker",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        broker_id: typing.Optional[str] = None,
        broker_name: typing.Optional[str] = None,
        logs: typing.Optional[typing.List["DataAwsMqBrokerLogs"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param broker_id: 
        :param broker_name: 
        :param logs: logs block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsMqBrokerConfig(
            broker_id=broker_id,
            broker_name=broker_name,
            logs=logs,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsMqBroker, self, [scope, id, config])

    @jsii.member(jsii_name="configuration")
    def configuration(self, index: str) -> "DataAwsMqBrokerConfiguration":
        """
        :param index: -
        """
        return jsii.invoke(self, "configuration", [index])

    @jsii.member(jsii_name="encryptionOptions")
    def encryption_options(self, index: str) -> "DataAwsMqBrokerEncryptionOptions":
        """
        :param index: -
        """
        return jsii.invoke(self, "encryptionOptions", [index])

    @jsii.member(jsii_name="instances")
    def instances(self, index: str) -> "DataAwsMqBrokerInstances":
        """
        :param index: -
        """
        return jsii.invoke(self, "instances", [index])

    @jsii.member(jsii_name="maintenanceWindowStartTime")
    def maintenance_window_start_time(
        self, index: str
    ) -> "DataAwsMqBrokerMaintenanceWindowStartTime":
        """
        :param index: -
        """
        return jsii.invoke(self, "maintenanceWindowStartTime", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="user")
    def user(self, index: str) -> "DataAwsMqBrokerUser":
        """
        :param index: -
        """
        return jsii.invoke(self, "user", [index])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> bool:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @builtins.property
    @jsii.member(jsii_name="deploymentMode")
    def deployment_mode(self) -> str:
        return jsii.get(self, "deploymentMode")

    @builtins.property
    @jsii.member(jsii_name="engineType")
    def engine_type(self) -> str:
        return jsii.get(self, "engineType")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="hostInstanceType")
    def host_instance_type(self) -> str:
        return jsii.get(self, "hostInstanceType")

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> bool:
        return jsii.get(self, "publiclyAccessible")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="brokerId")
    def broker_id(self) -> typing.Optional[str]:
        return jsii.get(self, "brokerId")

    @broker_id.setter
    def broker_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "brokerId", value)

    @builtins.property
    @jsii.member(jsii_name="brokerName")
    def broker_name(self) -> typing.Optional[str]:
        return jsii.get(self, "brokerName")

    @broker_name.setter
    def broker_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "brokerName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="logs")
    def logs(self) -> typing.Optional[typing.List["DataAwsMqBrokerLogs"]]:
        return jsii.get(self, "logs")

    @logs.setter
    def logs(self, value: typing.Optional[typing.List["DataAwsMqBrokerLogs"]]) -> None:
        jsii.set(self, "logs", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBrokerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "broker_id": "brokerId",
        "broker_name": "brokerName",
        "logs": "logs",
        "tags": "tags",
    },
)
class DataAwsMqBrokerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        broker_id: typing.Optional[str] = None,
        broker_name: typing.Optional[str] = None,
        logs: typing.Optional[typing.List["DataAwsMqBrokerLogs"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param broker_id: 
        :param broker_name: 
        :param logs: logs block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if broker_id is not None:
            self._values["broker_id"] = broker_id
        if broker_name is not None:
            self._values["broker_name"] = broker_name
        if logs is not None:
            self._values["logs"] = logs
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def broker_id(self) -> typing.Optional[str]:
        return self._values.get("broker_id")

    @builtins.property
    def broker_name(self) -> typing.Optional[str]:
        return self._values.get("broker_name")

    @builtins.property
    def logs(self) -> typing.Optional[typing.List["DataAwsMqBrokerLogs"]]:
        """logs block."""
        return self._values.get("logs")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsMqBrokerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsMqBrokerConfiguration(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBrokerConfiguration",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsMqBrokerConfiguration,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="revision")
    def revision(self) -> jsii.Number:
        return jsii.get(self, "revision")


class DataAwsMqBrokerEncryptionOptions(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBrokerEncryptionOptions",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsMqBrokerEncryptionOptions,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="useAwsOwnedKey")
    def use_aws_owned_key(self) -> bool:
        return jsii.get(self, "useAwsOwnedKey")


class DataAwsMqBrokerInstances(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBrokerInstances",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsMqBrokerInstances,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="consoleUrl")
    def console_url(self) -> str:
        return jsii.get(self, "consoleUrl")

    @builtins.property
    @jsii.member(jsii_name="endpoints")
    def endpoints(self) -> typing.List[str]:
        return jsii.get(self, "endpoints")

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBrokerLogs",
    jsii_struct_bases=[],
    name_mapping={},
)
class DataAwsMqBrokerLogs:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsMqBrokerLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsMqBrokerMaintenanceWindowStartTime(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBrokerMaintenanceWindowStartTime",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsMqBrokerMaintenanceWindowStartTime,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="dayOfWeek")
    def day_of_week(self) -> str:
        return jsii.get(self, "dayOfWeek")

    @builtins.property
    @jsii.member(jsii_name="timeOfDay")
    def time_of_day(self) -> str:
        return jsii.get(self, "timeOfDay")

    @builtins.property
    @jsii.member(jsii_name="timeZone")
    def time_zone(self) -> str:
        return jsii.get(self, "timeZone")


class DataAwsMqBrokerUser(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMqBrokerUser",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsMqBrokerUser, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="consoleAccess")
    def console_access(self) -> bool:
        return jsii.get(self, "consoleAccess")

    @builtins.property
    @jsii.member(jsii_name="groups")
    def groups(self) -> typing.List[str]:
        return jsii.get(self, "groups")

    @builtins.property
    @jsii.member(jsii_name="username")
    def username(self) -> str:
        return jsii.get(self, "username")


class DataAwsMskCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMskCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsMskClusterConfig(
            cluster_name=cluster_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsMskCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="bootstrapBrokers")
    def bootstrap_brokers(self) -> str:
        return jsii.get(self, "bootstrapBrokers")

    @builtins.property
    @jsii.member(jsii_name="bootstrapBrokersTls")
    def bootstrap_brokers_tls(self) -> str:
        return jsii.get(self, "bootstrapBrokersTls")

    @builtins.property
    @jsii.member(jsii_name="kafkaVersion")
    def kafka_version(self) -> str:
        return jsii.get(self, "kafkaVersion")

    @builtins.property
    @jsii.member(jsii_name="numberOfBrokerNodes")
    def number_of_broker_nodes(self) -> jsii.Number:
        return jsii.get(self, "numberOfBrokerNodes")

    @builtins.property
    @jsii.member(jsii_name="zookeeperConnectString")
    def zookeeper_connect_string(self) -> str:
        return jsii.get(self, "zookeeperConnectString")

    @builtins.property
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter
    def cluster_name(self, value: str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMskClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_name": "clusterName",
        "tags": "tags",
    },
)
class DataAwsMskClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_name": cluster_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_name(self) -> str:
        return self._values.get("cluster_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsMskClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsMskConfiguration(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMskConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsMskConfigurationConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsMskConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="kafkaVersions")
    def kafka_versions(self) -> typing.List[str]:
        return jsii.get(self, "kafkaVersions")

    @builtins.property
    @jsii.member(jsii_name="latestRevision")
    def latest_revision(self) -> jsii.Number:
        return jsii.get(self, "latestRevision")

    @builtins.property
    @jsii.member(jsii_name="serverProperties")
    def server_properties(self) -> str:
        return jsii.get(self, "serverProperties")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsMskConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsMskConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsMskConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsNatGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNatGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsNatGatewayFilter"]] = None,
        state: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param state: 
        :param subnet_id: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsNatGatewayConfig(
            filter=filter,
            state=state,
            subnet_id=subnet_id,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsNatGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocationId")
    def allocation_id(self) -> str:
        return jsii.get(self, "allocationId")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> str:
        return jsii.get(self, "privateIp")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsNatGatewayFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsNatGatewayFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNatGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "state": "state",
        "subnet_id": "subnetId",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsNatGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsNatGatewayFilter"]] = None,
        state: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param state: 
        :param subnet_id: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if state is not None:
            self._values["state"] = state
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsNatGatewayFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNatGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNatGatewayFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsNatGatewayFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNatGatewayFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsNetworkAcls(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkAcls",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsNetworkAclsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsNetworkAclsConfig(
            filter=filter,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsNetworkAcls, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsNetworkAclsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsNetworkAclsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkAclsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsNetworkAclsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsNetworkAclsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsNetworkAclsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNetworkAclsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkAclsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsNetworkAclsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNetworkAclsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsNetworkInterface(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsNetworkInterfaceFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsNetworkInterfaceConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsNetworkInterface, self, [scope, id, config])

    @jsii.member(jsii_name="association")
    def association(self, index: str) -> "DataAwsNetworkInterfaceAssociation":
        """
        :param index: -
        """
        return jsii.invoke(self, "association", [index])

    @jsii.member(jsii_name="attachment")
    def attachment(self, index: str) -> "DataAwsNetworkInterfaceAttachment":
        """
        :param index: -
        """
        return jsii.invoke(self, "attachment", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="interfaceType")
    def interface_type(self) -> str:
        return jsii.get(self, "interfaceType")

    @builtins.property
    @jsii.member(jsii_name="ipv6Addresses")
    def ipv6_addresses(self) -> typing.List[str]:
        return jsii.get(self, "ipv6Addresses")

    @builtins.property
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> str:
        return jsii.get(self, "macAddress")

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="privateDnsName")
    def private_dns_name(self) -> str:
        return jsii.get(self, "privateDnsName")

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> str:
        return jsii.get(self, "privateIp")

    @builtins.property
    @jsii.member(jsii_name="privateIps")
    def private_ips(self) -> typing.List[str]:
        return jsii.get(self, "privateIps")

    @builtins.property
    @jsii.member(jsii_name="requesterId")
    def requester_id(self) -> str:
        return jsii.get(self, "requesterId")

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsNetworkInterfaceFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsNetworkInterfaceFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsNetworkInterfaceAssociation(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterfaceAssociation",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsNetworkInterfaceAssociation,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="allocationId")
    def allocation_id(self) -> str:
        return jsii.get(self, "allocationId")

    @builtins.property
    @jsii.member(jsii_name="associationId")
    def association_id(self) -> str:
        return jsii.get(self, "associationId")

    @builtins.property
    @jsii.member(jsii_name="ipOwnerId")
    def ip_owner_id(self) -> str:
        return jsii.get(self, "ipOwnerId")

    @builtins.property
    @jsii.member(jsii_name="publicDnsName")
    def public_dns_name(self) -> str:
        return jsii.get(self, "publicDnsName")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")


class DataAwsNetworkInterfaceAttachment(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterfaceAttachment",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsNetworkInterfaceAttachment,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="attachmentId")
    def attachment_id(self) -> str:
        return jsii.get(self, "attachmentId")

    @builtins.property
    @jsii.member(jsii_name="deviceIndex")
    def device_index(self) -> jsii.Number:
        return jsii.get(self, "deviceIndex")

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> str:
        return jsii.get(self, "instanceId")

    @builtins.property
    @jsii.member(jsii_name="instanceOwnerId")
    def instance_owner_id(self) -> str:
        return jsii.get(self, "instanceOwnerId")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsNetworkInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsNetworkInterfaceFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsNetworkInterfaceFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNetworkInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterfaceFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsNetworkInterfaceFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNetworkInterfaceFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsNetworkInterfaces(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterfaces",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsNetworkInterfacesFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsNetworkInterfacesConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsNetworkInterfaces, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsNetworkInterfacesFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsNetworkInterfacesFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterfacesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsNetworkInterfacesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsNetworkInterfacesFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsNetworkInterfacesFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNetworkInterfacesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsNetworkInterfacesFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsNetworkInterfacesFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsNetworkInterfacesFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOrganizationsOrganization(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganization",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOrganizationsOrganizationConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsOrganizationsOrganization, self, [scope, id, config])

    @jsii.member(jsii_name="accounts")
    def accounts(self, index: str) -> "DataAwsOrganizationsOrganizationAccounts":
        """
        :param index: -
        """
        return jsii.invoke(self, "accounts", [index])

    @jsii.member(jsii_name="nonMasterAccounts")
    def non_master_accounts(
        self, index: str
    ) -> "DataAwsOrganizationsOrganizationNonMasterAccounts":
        """
        :param index: -
        """
        return jsii.invoke(self, "nonMasterAccounts", [index])

    @jsii.member(jsii_name="roots")
    def roots(self, index: str) -> "DataAwsOrganizationsOrganizationRoots":
        """
        :param index: -
        """
        return jsii.invoke(self, "roots", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsServiceAccessPrincipals")
    def aws_service_access_principals(self) -> typing.List[str]:
        return jsii.get(self, "awsServiceAccessPrincipals")

    @builtins.property
    @jsii.member(jsii_name="enabledPolicyTypes")
    def enabled_policy_types(self) -> typing.List[str]:
        return jsii.get(self, "enabledPolicyTypes")

    @builtins.property
    @jsii.member(jsii_name="featureSet")
    def feature_set(self) -> str:
        return jsii.get(self, "featureSet")

    @builtins.property
    @jsii.member(jsii_name="masterAccountArn")
    def master_account_arn(self) -> str:
        return jsii.get(self, "masterAccountArn")

    @builtins.property
    @jsii.member(jsii_name="masterAccountEmail")
    def master_account_email(self) -> str:
        return jsii.get(self, "masterAccountEmail")

    @builtins.property
    @jsii.member(jsii_name="masterAccountId")
    def master_account_id(self) -> str:
        return jsii.get(self, "masterAccountId")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class DataAwsOrganizationsOrganizationAccounts(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationAccounts",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsOrganizationsOrganizationAccounts,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsOrganizationsOrganizationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOrganizationsOrganizationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOrganizationsOrganizationNonMasterAccounts(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationNonMasterAccounts",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsOrganizationsOrganizationNonMasterAccounts,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")


class DataAwsOrganizationsOrganizationRoots(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationRoots",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsOrganizationsOrganizationRoots,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="policyTypes")
    def policy_types(self) -> typing.Any:
        return jsii.get(self, "policyTypes")


class DataAwsOrganizationsOrganizationRootsPolicyTypes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationRootsPolicyTypes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsOrganizationsOrganizationRootsPolicyTypes,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


class DataAwsOrganizationsOrganizationalUnits(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationalUnits",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        parent_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param parent_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOrganizationsOrganizationalUnitsConfig(
            parent_id=parent_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsOrganizationsOrganizationalUnits, self, [scope, id, config])

    @jsii.member(jsii_name="children")
    def children(self, index: str) -> "DataAwsOrganizationsOrganizationalUnitsChildren":
        """
        :param index: -
        """
        return jsii.invoke(self, "children", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="parentId")
    def parent_id(self) -> str:
        return jsii.get(self, "parentId")

    @parent_id.setter
    def parent_id(self, value: str) -> None:
        jsii.set(self, "parentId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class DataAwsOrganizationsOrganizationalUnitsChildren(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationalUnitsChildren",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsOrganizationsOrganizationalUnitsChildren,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOrganizationsOrganizationalUnitsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "parent_id": "parentId",
    },
)
class DataAwsOrganizationsOrganizationalUnitsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        parent_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param parent_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "parent_id": parent_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def parent_id(self) -> str:
        return self._values.get("parent_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOrganizationsOrganizationalUnitsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOutpostsOutpost(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutpost",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOutpostsOutpostConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsOutpostsOutpost, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> str:
        return jsii.get(self, "availabilityZoneId")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="siteId")
    def site_id(self) -> str:
        return jsii.get(self, "siteId")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutpostConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsOutpostsOutpostConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOutpostsOutpostConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOutpostsOutpostInstanceType(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutpostInstanceType",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        arn: str,
        instance_type: typing.Optional[str] = None,
        preferred_instance_types: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param arn: 
        :param instance_type: 
        :param preferred_instance_types: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOutpostsOutpostInstanceTypeConfig(
            arn=arn,
            instance_type=instance_type,
            preferred_instance_types=preferred_instance_types,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsOutpostsOutpostInstanceType, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: str) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="preferredInstanceTypes")
    def preferred_instance_types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "preferredInstanceTypes")

    @preferred_instance_types.setter
    def preferred_instance_types(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "preferredInstanceTypes", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutpostInstanceTypeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "arn": "arn",
        "instance_type": "instanceType",
        "preferred_instance_types": "preferredInstanceTypes",
    },
)
class DataAwsOutpostsOutpostInstanceTypeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        arn: str,
        instance_type: typing.Optional[str] = None,
        preferred_instance_types: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param arn: 
        :param instance_type: 
        :param preferred_instance_types: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "arn": arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if preferred_instance_types is not None:
            self._values["preferred_instance_types"] = preferred_instance_types

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def instance_type(self) -> typing.Optional[str]:
        return self._values.get("instance_type")

    @builtins.property
    def preferred_instance_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("preferred_instance_types")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOutpostsOutpostInstanceTypeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOutpostsOutpostInstanceTypes(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutpostInstanceTypes",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOutpostsOutpostInstanceTypesConfig(
            arn=arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsOutpostsOutpostInstanceTypes, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="instanceTypes")
    def instance_types(self) -> typing.List[str]:
        return jsii.get(self, "instanceTypes")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: str) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutpostInstanceTypesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "arn": "arn",
    },
)
class DataAwsOutpostsOutpostInstanceTypesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "arn": arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOutpostsOutpostInstanceTypesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOutpostsOutposts(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutposts",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        availability_zone: typing.Optional[str] = None,
        availability_zone_id: typing.Optional[str] = None,
        site_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param availability_zone: 
        :param availability_zone_id: 
        :param site_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOutpostsOutpostsConfig(
            availability_zone=availability_zone,
            availability_zone_id=availability_zone_id,
            site_id=site_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsOutpostsOutposts, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arns")
    def arns(self) -> typing.List[str]:
        return jsii.get(self, "arns")

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZoneId")

    @availability_zone_id.setter
    def availability_zone_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZoneId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="siteId")
    def site_id(self) -> typing.Optional[str]:
        return jsii.get(self, "siteId")

    @site_id.setter
    def site_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "siteId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsOutpostsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "availability_zone": "availabilityZone",
        "availability_zone_id": "availabilityZoneId",
        "site_id": "siteId",
    },
)
class DataAwsOutpostsOutpostsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        availability_zone: typing.Optional[str] = None,
        availability_zone_id: typing.Optional[str] = None,
        site_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param availability_zone: 
        :param availability_zone_id: 
        :param site_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if availability_zone_id is not None:
            self._values["availability_zone_id"] = availability_zone_id
        if site_id is not None:
            self._values["site_id"] = site_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def availability_zone_id(self) -> typing.Optional[str]:
        return self._values.get("availability_zone_id")

    @builtins.property
    def site_id(self) -> typing.Optional[str]:
        return self._values.get("site_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOutpostsOutpostsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOutpostsSite(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsSite",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOutpostsSiteConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsOutpostsSite, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsSiteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsOutpostsSiteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOutpostsSiteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsOutpostsSites(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsSites",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsOutpostsSitesConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsOutpostsSites, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsOutpostsSitesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsOutpostsSitesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsOutpostsSitesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsPartition(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPartition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsPartitionConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(DataAwsPartition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dnsSuffix")
    def dns_suffix(self) -> str:
        return jsii.get(self, "dnsSuffix")

    @builtins.property
    @jsii.member(jsii_name="partition")
    def partition(self) -> str:
        return jsii.get(self, "partition")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPartitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class DataAwsPartitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsPartitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsPrefixList(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPrefixList",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsPrefixListFilter"]] = None,
        name: typing.Optional[str] = None,
        prefix_list_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param name: 
        :param prefix_list_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsPrefixListConfig(
            filter=filter,
            name=name,
            prefix_list_id=prefix_list_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsPrefixList, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cidrBlocks")
    def cidr_blocks(self) -> typing.List[str]:
        return jsii.get(self, "cidrBlocks")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsPrefixListFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsPrefixListFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="prefixListId")
    def prefix_list_id(self) -> typing.Optional[str]:
        return jsii.get(self, "prefixListId")

    @prefix_list_id.setter
    def prefix_list_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "prefixListId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPrefixListConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "name": "name",
        "prefix_list_id": "prefixListId",
    },
)
class DataAwsPrefixListConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsPrefixListFilter"]] = None,
        name: typing.Optional[str] = None,
        prefix_list_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param name: 
        :param prefix_list_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if name is not None:
            self._values["name"] = name
        if prefix_list_id is not None:
            self._values["prefix_list_id"] = prefix_list_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsPrefixListFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def prefix_list_id(self) -> typing.Optional[str]:
        return self._values.get("prefix_list_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsPrefixListConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPrefixListFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsPrefixListFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsPrefixListFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsPricingProduct(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPricingProduct",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filters: typing.List["DataAwsPricingProductFilters"],
        service_code: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filters: filters block.
        :param service_code: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsPricingProductConfig(
            filters=filters,
            service_code=service_code,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsPricingProduct, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="result")
    def result(self) -> str:
        return jsii.get(self, "result")

    @builtins.property
    @jsii.member(jsii_name="filters")
    def filters(self) -> typing.List["DataAwsPricingProductFilters"]:
        return jsii.get(self, "filters")

    @filters.setter
    def filters(self, value: typing.List["DataAwsPricingProductFilters"]) -> None:
        jsii.set(self, "filters", value)

    @builtins.property
    @jsii.member(jsii_name="serviceCode")
    def service_code(self) -> str:
        return jsii.get(self, "serviceCode")

    @service_code.setter
    def service_code(self, value: str) -> None:
        jsii.set(self, "serviceCode", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPricingProductConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filters": "filters",
        "service_code": "serviceCode",
    },
)
class DataAwsPricingProductConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filters: typing.List["DataAwsPricingProductFilters"],
        service_code: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filters: filters block.
        :param service_code: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "filters": filters,
            "service_code": service_code,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filters(self) -> typing.List["DataAwsPricingProductFilters"]:
        """filters block."""
        return self._values.get("filters")

    @builtins.property
    def service_code(self) -> str:
        return self._values.get("service_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsPricingProductConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsPricingProductFilters",
    jsii_struct_bases=[],
    name_mapping={"field": "field", "value": "value"},
)
class DataAwsPricingProductFilters:
    def __init__(self, *, field: str, value: str) -> None:
        """
        :param field: 
        :param value: 
        """
        self._values = {
            "field": field,
            "value": value,
        }

    @builtins.property
    def field(self) -> str:
        return self._values.get("field")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsPricingProductFilters(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsQldbLedger(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsQldbLedger",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsQldbLedgerConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsQldbLedger, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> bool:
        return jsii.get(self, "deletionProtection")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsQldbLedgerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsQldbLedgerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsQldbLedgerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRamResourceShare(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRamResourceShare",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        resource_owner: str,
        filter: typing.Optional[typing.List["DataAwsRamResourceShareFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_owner: 
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRamResourceShareConfig(
            name=name,
            resource_owner=resource_owner,
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRamResourceShare, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="owningAccountId")
    def owning_account_id(self) -> str:
        return jsii.get(self, "owningAccountId")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resourceOwner")
    def resource_owner(self) -> str:
        return jsii.get(self, "resourceOwner")

    @resource_owner.setter
    def resource_owner(self, value: str) -> None:
        jsii.set(self, "resourceOwner", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsRamResourceShareFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsRamResourceShareFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRamResourceShareConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_owner": "resourceOwner",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsRamResourceShareConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        resource_owner: str,
        filter: typing.Optional[typing.List["DataAwsRamResourceShareFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_owner: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "resource_owner": resource_owner,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def resource_owner(self) -> str:
        return self._values.get("resource_owner")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsRamResourceShareFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRamResourceShareConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRamResourceShareFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsRamResourceShareFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRamResourceShareFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRdsCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRdsCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_identifier: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRdsClusterConfig(
            cluster_identifier=cluster_identifier,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRdsCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="backtrackWindow")
    def backtrack_window(self) -> jsii.Number:
        return jsii.get(self, "backtrackWindow")

    @builtins.property
    @jsii.member(jsii_name="backupRetentionPeriod")
    def backup_retention_period(self) -> jsii.Number:
        return jsii.get(self, "backupRetentionPeriod")

    @builtins.property
    @jsii.member(jsii_name="clusterMembers")
    def cluster_members(self) -> typing.List[str]:
        return jsii.get(self, "clusterMembers")

    @builtins.property
    @jsii.member(jsii_name="clusterResourceId")
    def cluster_resource_id(self) -> str:
        return jsii.get(self, "clusterResourceId")

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> str:
        return jsii.get(self, "databaseName")

    @builtins.property
    @jsii.member(jsii_name="dbClusterParameterGroupName")
    def db_cluster_parameter_group_name(self) -> str:
        return jsii.get(self, "dbClusterParameterGroupName")

    @builtins.property
    @jsii.member(jsii_name="dbSubnetGroupName")
    def db_subnet_group_name(self) -> str:
        return jsii.get(self, "dbSubnetGroupName")

    @builtins.property
    @jsii.member(jsii_name="enabledCloudwatchLogsExports")
    def enabled_cloudwatch_logs_exports(self) -> typing.List[str]:
        return jsii.get(self, "enabledCloudwatchLogsExports")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="finalSnapshotIdentifier")
    def final_snapshot_identifier(self) -> str:
        return jsii.get(self, "finalSnapshotIdentifier")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="iamDatabaseAuthenticationEnabled")
    def iam_database_authentication_enabled(self) -> bool:
        return jsii.get(self, "iamDatabaseAuthenticationEnabled")

    @builtins.property
    @jsii.member(jsii_name="iamRoles")
    def iam_roles(self) -> typing.List[str]:
        return jsii.get(self, "iamRoles")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="masterUsername")
    def master_username(self) -> str:
        return jsii.get(self, "masterUsername")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> str:
        return jsii.get(self, "preferredBackupWindow")

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> str:
        return jsii.get(self, "preferredMaintenanceWindow")

    @builtins.property
    @jsii.member(jsii_name="readerEndpoint")
    def reader_endpoint(self) -> str:
        return jsii.get(self, "readerEndpoint")

    @builtins.property
    @jsii.member(jsii_name="replicationSourceIdentifier")
    def replication_source_identifier(self) -> str:
        return jsii.get(self, "replicationSourceIdentifier")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRdsClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_identifier": "clusterIdentifier",
        "tags": "tags",
    },
)
class DataAwsRdsClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_identifier: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_identifier": cluster_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRdsClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRedshiftCluster(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRedshiftCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_identifier: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRedshiftClusterConfig(
            cluster_identifier=cluster_identifier,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRedshiftCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allowVersionUpgrade")
    def allow_version_upgrade(self) -> bool:
        return jsii.get(self, "allowVersionUpgrade")

    @builtins.property
    @jsii.member(jsii_name="automatedSnapshotRetentionPeriod")
    def automated_snapshot_retention_period(self) -> jsii.Number:
        return jsii.get(self, "automatedSnapshotRetentionPeriod")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="bucketName")
    def bucket_name(self) -> str:
        return jsii.get(self, "bucketName")

    @builtins.property
    @jsii.member(jsii_name="clusterParameterGroupName")
    def cluster_parameter_group_name(self) -> str:
        return jsii.get(self, "clusterParameterGroupName")

    @builtins.property
    @jsii.member(jsii_name="clusterPublicKey")
    def cluster_public_key(self) -> str:
        return jsii.get(self, "clusterPublicKey")

    @builtins.property
    @jsii.member(jsii_name="clusterRevisionNumber")
    def cluster_revision_number(self) -> str:
        return jsii.get(self, "clusterRevisionNumber")

    @builtins.property
    @jsii.member(jsii_name="clusterSecurityGroups")
    def cluster_security_groups(self) -> typing.List[str]:
        return jsii.get(self, "clusterSecurityGroups")

    @builtins.property
    @jsii.member(jsii_name="clusterSubnetGroupName")
    def cluster_subnet_group_name(self) -> str:
        return jsii.get(self, "clusterSubnetGroupName")

    @builtins.property
    @jsii.member(jsii_name="clusterType")
    def cluster_type(self) -> str:
        return jsii.get(self, "clusterType")

    @builtins.property
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> str:
        return jsii.get(self, "clusterVersion")

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> str:
        return jsii.get(self, "databaseName")

    @builtins.property
    @jsii.member(jsii_name="elasticIp")
    def elastic_ip(self) -> str:
        return jsii.get(self, "elasticIp")

    @builtins.property
    @jsii.member(jsii_name="enableLogging")
    def enable_logging(self) -> bool:
        return jsii.get(self, "enableLogging")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="enhancedVpcRouting")
    def enhanced_vpc_routing(self) -> bool:
        return jsii.get(self, "enhancedVpcRouting")

    @builtins.property
    @jsii.member(jsii_name="iamRoles")
    def iam_roles(self) -> typing.List[str]:
        return jsii.get(self, "iamRoles")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="masterUsername")
    def master_username(self) -> str:
        return jsii.get(self, "masterUsername")

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> str:
        return jsii.get(self, "nodeType")

    @builtins.property
    @jsii.member(jsii_name="numberOfNodes")
    def number_of_nodes(self) -> jsii.Number:
        return jsii.get(self, "numberOfNodes")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> str:
        return jsii.get(self, "preferredMaintenanceWindow")

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> bool:
        return jsii.get(self, "publiclyAccessible")

    @builtins.property
    @jsii.member(jsii_name="s3KeyPrefix")
    def s3_key_prefix(self) -> str:
        return jsii.get(self, "s3KeyPrefix")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRedshiftClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_identifier": "clusterIdentifier",
        "tags": "tags",
    },
)
class DataAwsRedshiftClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_identifier: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_identifier": cluster_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRedshiftClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRedshiftServiceAccount(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRedshiftServiceAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        region: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param region: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRedshiftServiceAccountConfig(
            region=region,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRedshiftServiceAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRedshiftServiceAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "region": "region",
    },
)
class DataAwsRedshiftServiceAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        region: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param region: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if region is not None:
            self._values["region"] = region

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRedshiftServiceAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRegion(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRegion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        current: typing.Optional[bool] = None,
        endpoint: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param current: 
        :param endpoint: 
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRegionConfig(
            current=current,
            endpoint=endpoint,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRegion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="current")
    def current(self) -> typing.Optional[bool]:
        return jsii.get(self, "current")

    @current.setter
    def current(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "current", value)

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> typing.Optional[str]:
        return jsii.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRegionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "current": "current",
        "endpoint": "endpoint",
        "name": "name",
    },
)
class DataAwsRegionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        current: typing.Optional[bool] = None,
        endpoint: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param current: 
        :param endpoint: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if current is not None:
            self._values["current"] = current
        if endpoint is not None:
            self._values["endpoint"] = endpoint
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def current(self) -> typing.Optional[bool]:
        return self._values.get("current")

    @builtins.property
    def endpoint(self) -> typing.Optional[str]:
        return self._values.get("endpoint")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRegionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRegions(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRegions",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        all_regions: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsRegionsFilter"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param all_regions: 
        :param filter: filter block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRegionsConfig(
            all_regions=all_regions,
            filter=filter,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRegions, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="names")
    def names(self) -> typing.List[str]:
        return jsii.get(self, "names")

    @builtins.property
    @jsii.member(jsii_name="allRegions")
    def all_regions(self) -> typing.Optional[bool]:
        return jsii.get(self, "allRegions")

    @all_regions.setter
    def all_regions(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allRegions", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsRegionsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsRegionsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRegionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "all_regions": "allRegions",
        "filter": "filter",
    },
)
class DataAwsRegionsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        all_regions: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsRegionsFilter"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param all_regions: 
        :param filter: filter block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if all_regions is not None:
            self._values["all_regions"] = all_regions
        if filter is not None:
            self._values["filter"] = filter

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def all_regions(self) -> typing.Optional[bool]:
        return self._values.get("all_regions")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsRegionsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRegionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRegionsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsRegionsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRegionsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRoute(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        route_table_id: str,
        destination_cidr_block: typing.Optional[str] = None,
        destination_ipv6_cidr_block: typing.Optional[str] = None,
        egress_only_gateway_id: typing.Optional[str] = None,
        gateway_id: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        nat_gateway_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpc_peering_connection_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param route_table_id: 
        :param destination_cidr_block: 
        :param destination_ipv6_cidr_block: 
        :param egress_only_gateway_id: 
        :param gateway_id: 
        :param instance_id: 
        :param nat_gateway_id: 
        :param network_interface_id: 
        :param transit_gateway_id: 
        :param vpc_peering_connection_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRouteConfig(
            route_table_id=route_table_id,
            destination_cidr_block=destination_cidr_block,
            destination_ipv6_cidr_block=destination_ipv6_cidr_block,
            egress_only_gateway_id=egress_only_gateway_id,
            gateway_id=gateway_id,
            instance_id=instance_id,
            nat_gateway_id=nat_gateway_id,
            network_interface_id=network_interface_id,
            transit_gateway_id=transit_gateway_id,
            vpc_peering_connection_id=vpc_peering_connection_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRoute, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> str:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter
    def route_table_id(self, value: str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "destinationCidrBlock")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "destinationCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="destinationIpv6CidrBlock")
    def destination_ipv6_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "destinationIpv6CidrBlock")

    @destination_ipv6_cidr_block.setter
    def destination_ipv6_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "destinationIpv6CidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="egressOnlyGatewayId")
    def egress_only_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "egressOnlyGatewayId")

    @egress_only_gateway_id.setter
    def egress_only_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "egressOnlyGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayId")
    def gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "gatewayId")

    @gateway_id.setter
    def gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "gatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceId")

    @instance_id.setter
    def instance_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property
    @jsii.member(jsii_name="natGatewayId")
    def nat_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "natGatewayId")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "natGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> typing.Optional[str]:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "transitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcPeeringConnectionId")
    def vpc_peering_connection_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcPeeringConnectionId")

    @vpc_peering_connection_id.setter
    def vpc_peering_connection_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcPeeringConnectionId", value)


class DataAwsRoute53DelegationSet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53DelegationSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id_: str,
        *,
        id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id_: -
        :param id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRoute53DelegationSetConfig(
            id=id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRoute53DelegationSet, self, [scope, id_, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="callerReference")
    def caller_reference(self) -> str:
        return jsii.get(self, "callerReference")

    @builtins.property
    @jsii.member(jsii_name="nameServers")
    def name_servers(self) -> typing.List[str]:
        return jsii.get(self, "nameServers")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: str) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53DelegationSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "id": "id",
    },
)
class DataAwsRoute53DelegationSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "id": id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRoute53DelegationSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRoute53ResolverRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53ResolverRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        resolver_endpoint_id: typing.Optional[str] = None,
        resolver_rule_id: typing.Optional[str] = None,
        rule_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param name: 
        :param resolver_endpoint_id: 
        :param resolver_rule_id: 
        :param rule_type: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRoute53ResolverRuleConfig(
            domain_name=domain_name,
            name=name,
            resolver_endpoint_id=resolver_endpoint_id,
            resolver_rule_id=resolver_rule_id,
            rule_type=rule_type,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRoute53ResolverRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="shareStatus")
    def share_status(self) -> str:
        return jsii.get(self, "shareStatus")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> typing.Optional[str]:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resolverEndpointId")
    def resolver_endpoint_id(self) -> typing.Optional[str]:
        return jsii.get(self, "resolverEndpointId")

    @resolver_endpoint_id.setter
    def resolver_endpoint_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resolverEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="resolverRuleId")
    def resolver_rule_id(self) -> typing.Optional[str]:
        return jsii.get(self, "resolverRuleId")

    @resolver_rule_id.setter
    def resolver_rule_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resolverRuleId", value)

    @builtins.property
    @jsii.member(jsii_name="ruleType")
    def rule_type(self) -> typing.Optional[str]:
        return jsii.get(self, "ruleType")

    @rule_type.setter
    def rule_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ruleType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53ResolverRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
        "name": "name",
        "resolver_endpoint_id": "resolverEndpointId",
        "resolver_rule_id": "resolverRuleId",
        "rule_type": "ruleType",
        "tags": "tags",
    },
)
class DataAwsRoute53ResolverRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        resolver_endpoint_id: typing.Optional[str] = None,
        resolver_rule_id: typing.Optional[str] = None,
        rule_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        :param name: 
        :param resolver_endpoint_id: 
        :param resolver_rule_id: 
        :param rule_type: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if domain_name is not None:
            self._values["domain_name"] = domain_name
        if name is not None:
            self._values["name"] = name
        if resolver_endpoint_id is not None:
            self._values["resolver_endpoint_id"] = resolver_endpoint_id
        if resolver_rule_id is not None:
            self._values["resolver_rule_id"] = resolver_rule_id
        if rule_type is not None:
            self._values["rule_type"] = rule_type
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> typing.Optional[str]:
        return self._values.get("domain_name")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def resolver_endpoint_id(self) -> typing.Optional[str]:
        return self._values.get("resolver_endpoint_id")

    @builtins.property
    def resolver_rule_id(self) -> typing.Optional[str]:
        return self._values.get("resolver_rule_id")

    @builtins.property
    def rule_type(self) -> typing.Optional[str]:
        return self._values.get("rule_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRoute53ResolverRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRoute53ResolverRules(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53ResolverRules",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        owner_id: typing.Optional[str] = None,
        resolver_endpoint_id: typing.Optional[str] = None,
        rule_type: typing.Optional[str] = None,
        share_status: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param owner_id: 
        :param resolver_endpoint_id: 
        :param rule_type: 
        :param share_status: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRoute53ResolverRulesConfig(
            owner_id=owner_id,
            resolver_endpoint_id=resolver_endpoint_id,
            rule_type=rule_type,
            share_status=share_status,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRoute53ResolverRules, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resolverRuleIds")
    def resolver_rule_ids(self) -> typing.List[str]:
        return jsii.get(self, "resolverRuleIds")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> typing.Optional[str]:
        return jsii.get(self, "ownerId")

    @owner_id.setter
    def owner_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ownerId", value)

    @builtins.property
    @jsii.member(jsii_name="resolverEndpointId")
    def resolver_endpoint_id(self) -> typing.Optional[str]:
        return jsii.get(self, "resolverEndpointId")

    @resolver_endpoint_id.setter
    def resolver_endpoint_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resolverEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="ruleType")
    def rule_type(self) -> typing.Optional[str]:
        return jsii.get(self, "ruleType")

    @rule_type.setter
    def rule_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ruleType", value)

    @builtins.property
    @jsii.member(jsii_name="shareStatus")
    def share_status(self) -> typing.Optional[str]:
        return jsii.get(self, "shareStatus")

    @share_status.setter
    def share_status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "shareStatus", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53ResolverRulesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "owner_id": "ownerId",
        "resolver_endpoint_id": "resolverEndpointId",
        "rule_type": "ruleType",
        "share_status": "shareStatus",
    },
)
class DataAwsRoute53ResolverRulesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        owner_id: typing.Optional[str] = None,
        resolver_endpoint_id: typing.Optional[str] = None,
        rule_type: typing.Optional[str] = None,
        share_status: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param owner_id: 
        :param resolver_endpoint_id: 
        :param rule_type: 
        :param share_status: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if owner_id is not None:
            self._values["owner_id"] = owner_id
        if resolver_endpoint_id is not None:
            self._values["resolver_endpoint_id"] = resolver_endpoint_id
        if rule_type is not None:
            self._values["rule_type"] = rule_type
        if share_status is not None:
            self._values["share_status"] = share_status

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def owner_id(self) -> typing.Optional[str]:
        return self._values.get("owner_id")

    @builtins.property
    def resolver_endpoint_id(self) -> typing.Optional[str]:
        return self._values.get("resolver_endpoint_id")

    @builtins.property
    def rule_type(self) -> typing.Optional[str]:
        return self._values.get("rule_type")

    @builtins.property
    def share_status(self) -> typing.Optional[str]:
        return self._values.get("share_status")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRoute53ResolverRulesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRoute53Zone(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53Zone",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        private_zone: typing.Optional[bool] = None,
        resource_record_set_count: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        zone_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param private_zone: 
        :param resource_record_set_count: 
        :param tags: 
        :param vpc_id: 
        :param zone_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRoute53ZoneConfig(
            name=name,
            private_zone=private_zone,
            resource_record_set_count=resource_record_set_count,
            tags=tags,
            vpc_id=vpc_id,
            zone_id=zone_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRoute53Zone, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="callerReference")
    def caller_reference(self) -> str:
        return jsii.get(self, "callerReference")

    @builtins.property
    @jsii.member(jsii_name="comment")
    def comment(self) -> str:
        return jsii.get(self, "comment")

    @builtins.property
    @jsii.member(jsii_name="linkedServiceDescription")
    def linked_service_description(self) -> str:
        return jsii.get(self, "linkedServiceDescription")

    @builtins.property
    @jsii.member(jsii_name="linkedServicePrincipal")
    def linked_service_principal(self) -> str:
        return jsii.get(self, "linkedServicePrincipal")

    @builtins.property
    @jsii.member(jsii_name="nameServers")
    def name_servers(self) -> typing.List[str]:
        return jsii.get(self, "nameServers")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="privateZone")
    def private_zone(self) -> typing.Optional[bool]:
        return jsii.get(self, "privateZone")

    @private_zone.setter
    def private_zone(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "privateZone", value)

    @builtins.property
    @jsii.member(jsii_name="resourceRecordSetCount")
    def resource_record_set_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "resourceRecordSetCount")

    @resource_record_set_count.setter
    def resource_record_set_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "resourceRecordSetCount", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> typing.Optional[str]:
        return jsii.get(self, "zoneId")

    @zone_id.setter
    def zone_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "zoneId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRoute53ZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "private_zone": "privateZone",
        "resource_record_set_count": "resourceRecordSetCount",
        "tags": "tags",
        "vpc_id": "vpcId",
        "zone_id": "zoneId",
    },
)
class DataAwsRoute53ZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        private_zone: typing.Optional[bool] = None,
        resource_record_set_count: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        zone_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param private_zone: 
        :param resource_record_set_count: 
        :param tags: 
        :param vpc_id: 
        :param zone_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if private_zone is not None:
            self._values["private_zone"] = private_zone
        if resource_record_set_count is not None:
            self._values["resource_record_set_count"] = resource_record_set_count
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id
        if zone_id is not None:
            self._values["zone_id"] = zone_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def private_zone(self) -> typing.Optional[bool]:
        return self._values.get("private_zone")

    @builtins.property
    def resource_record_set_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("resource_record_set_count")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    @builtins.property
    def zone_id(self) -> typing.Optional[str]:
        return self._values.get("zone_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRoute53ZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "route_table_id": "routeTableId",
        "destination_cidr_block": "destinationCidrBlock",
        "destination_ipv6_cidr_block": "destinationIpv6CidrBlock",
        "egress_only_gateway_id": "egressOnlyGatewayId",
        "gateway_id": "gatewayId",
        "instance_id": "instanceId",
        "nat_gateway_id": "natGatewayId",
        "network_interface_id": "networkInterfaceId",
        "transit_gateway_id": "transitGatewayId",
        "vpc_peering_connection_id": "vpcPeeringConnectionId",
    },
)
class DataAwsRouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        route_table_id: str,
        destination_cidr_block: typing.Optional[str] = None,
        destination_ipv6_cidr_block: typing.Optional[str] = None,
        egress_only_gateway_id: typing.Optional[str] = None,
        gateway_id: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        nat_gateway_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpc_peering_connection_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param route_table_id: 
        :param destination_cidr_block: 
        :param destination_ipv6_cidr_block: 
        :param egress_only_gateway_id: 
        :param gateway_id: 
        :param instance_id: 
        :param nat_gateway_id: 
        :param network_interface_id: 
        :param transit_gateway_id: 
        :param vpc_peering_connection_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "route_table_id": route_table_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if destination_cidr_block is not None:
            self._values["destination_cidr_block"] = destination_cidr_block
        if destination_ipv6_cidr_block is not None:
            self._values["destination_ipv6_cidr_block"] = destination_ipv6_cidr_block
        if egress_only_gateway_id is not None:
            self._values["egress_only_gateway_id"] = egress_only_gateway_id
        if gateway_id is not None:
            self._values["gateway_id"] = gateway_id
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if nat_gateway_id is not None:
            self._values["nat_gateway_id"] = nat_gateway_id
        if network_interface_id is not None:
            self._values["network_interface_id"] = network_interface_id
        if transit_gateway_id is not None:
            self._values["transit_gateway_id"] = transit_gateway_id
        if vpc_peering_connection_id is not None:
            self._values["vpc_peering_connection_id"] = vpc_peering_connection_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def route_table_id(self) -> str:
        return self._values.get("route_table_id")

    @builtins.property
    def destination_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("destination_cidr_block")

    @builtins.property
    def destination_ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("destination_ipv6_cidr_block")

    @builtins.property
    def egress_only_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("egress_only_gateway_id")

    @builtins.property
    def gateway_id(self) -> typing.Optional[str]:
        return self._values.get("gateway_id")

    @builtins.property
    def instance_id(self) -> typing.Optional[str]:
        return self._values.get("instance_id")

    @builtins.property
    def nat_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("nat_gateway_id")

    @builtins.property
    def network_interface_id(self) -> typing.Optional[str]:
        return self._values.get("network_interface_id")

    @builtins.property
    def transit_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def vpc_peering_connection_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_peering_connection_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRouteTable(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsRouteTableFilter"]] = None,
        gateway_id: typing.Optional[str] = None,
        route_table_id: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param gateway_id: 
        :param route_table_id: 
        :param subnet_id: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRouteTableConfig(
            filter=filter,
            gateway_id=gateway_id,
            route_table_id=route_table_id,
            subnet_id=subnet_id,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="associations")
    def associations(self, index: str) -> "DataAwsRouteTableAssociations":
        """
        :param index: -
        """
        return jsii.invoke(self, "associations", [index])

    @jsii.member(jsii_name="routes")
    def routes(self, index: str) -> "DataAwsRouteTableRoutes":
        """
        :param index: -
        """
        return jsii.invoke(self, "routes", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsRouteTableFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsRouteTableFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayId")
    def gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "gatewayId")

    @gateway_id.setter
    def gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "gatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> typing.Optional[str]:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter
    def route_table_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


class DataAwsRouteTableAssociations(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTableAssociations",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsRouteTableAssociations,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="gatewayId")
    def gateway_id(self) -> str:
        return jsii.get(self, "gatewayId")

    @builtins.property
    @jsii.member(jsii_name="main")
    def main(self) -> bool:
        return jsii.get(self, "main")

    @builtins.property
    @jsii.member(jsii_name="routeTableAssociationId")
    def route_table_association_id(self) -> str:
        return jsii.get(self, "routeTableAssociationId")

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> str:
        return jsii.get(self, "routeTableId")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "gateway_id": "gatewayId",
        "route_table_id": "routeTableId",
        "subnet_id": "subnetId",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsRouteTableFilter"]] = None,
        gateway_id: typing.Optional[str] = None,
        route_table_id: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param gateway_id: 
        :param route_table_id: 
        :param subnet_id: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if gateway_id is not None:
            self._values["gateway_id"] = gateway_id
        if route_table_id is not None:
            self._values["route_table_id"] = route_table_id
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsRouteTableFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def gateway_id(self) -> typing.Optional[str]:
        return self._values.get("gateway_id")

    @builtins.property
    def route_table_id(self) -> typing.Optional[str]:
        return self._values.get("route_table_id")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTableFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsRouteTableFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRouteTableFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsRouteTableRoutes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTableRoutes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsRouteTableRoutes,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> str:
        return jsii.get(self, "cidrBlock")

    @builtins.property
    @jsii.member(jsii_name="egressOnlyGatewayId")
    def egress_only_gateway_id(self) -> str:
        return jsii.get(self, "egressOnlyGatewayId")

    @builtins.property
    @jsii.member(jsii_name="gatewayId")
    def gateway_id(self) -> str:
        return jsii.get(self, "gatewayId")

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> str:
        return jsii.get(self, "instanceId")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> str:
        return jsii.get(self, "ipv6CidrBlock")

    @builtins.property
    @jsii.member(jsii_name="natGatewayId")
    def nat_gateway_id(self) -> str:
        return jsii.get(self, "natGatewayId")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="vpcPeeringConnectionId")
    def vpc_peering_connection_id(self) -> str:
        return jsii.get(self, "vpcPeeringConnectionId")


class DataAwsRouteTables(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTables",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsRouteTablesFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsRouteTablesConfig(
            filter=filter,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsRouteTables, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsRouteTablesFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsRouteTablesFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTablesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsRouteTablesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsRouteTablesFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsRouteTablesFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRouteTablesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsRouteTablesFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsRouteTablesFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsRouteTablesFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsS3Bucket(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsS3Bucket",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsS3BucketConfig(
            bucket=bucket,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsS3Bucket, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="bucketDomainName")
    def bucket_domain_name(self) -> str:
        return jsii.get(self, "bucketDomainName")

    @builtins.property
    @jsii.member(jsii_name="bucketRegionalDomainName")
    def bucket_regional_domain_name(self) -> str:
        return jsii.get(self, "bucketRegionalDomainName")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> str:
        return jsii.get(self, "region")

    @builtins.property
    @jsii.member(jsii_name="websiteDomain")
    def website_domain(self) -> str:
        return jsii.get(self, "websiteDomain")

    @builtins.property
    @jsii.member(jsii_name="websiteEndpoint")
    def website_endpoint(self) -> str:
        return jsii.get(self, "websiteEndpoint")

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsS3BucketConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
    },
)
class DataAwsS3BucketConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsS3BucketConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsS3BucketObject(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsS3BucketObject",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        key: str,
        range: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        version_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param key: 
        :param range: 
        :param tags: 
        :param version_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsS3BucketObjectConfig(
            bucket=bucket,
            key=key,
            range=range,
            tags=tags,
            version_id=version_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsS3BucketObject, self, [scope, id, config])

    @jsii.member(jsii_name="metadata")
    def metadata(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "metadata", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="body")
    def body(self) -> str:
        return jsii.get(self, "body")

    @builtins.property
    @jsii.member(jsii_name="cacheControl")
    def cache_control(self) -> str:
        return jsii.get(self, "cacheControl")

    @builtins.property
    @jsii.member(jsii_name="contentDisposition")
    def content_disposition(self) -> str:
        return jsii.get(self, "contentDisposition")

    @builtins.property
    @jsii.member(jsii_name="contentEncoding")
    def content_encoding(self) -> str:
        return jsii.get(self, "contentEncoding")

    @builtins.property
    @jsii.member(jsii_name="contentLanguage")
    def content_language(self) -> str:
        return jsii.get(self, "contentLanguage")

    @builtins.property
    @jsii.member(jsii_name="contentLength")
    def content_length(self) -> jsii.Number:
        return jsii.get(self, "contentLength")

    @builtins.property
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> str:
        return jsii.get(self, "contentType")

    @builtins.property
    @jsii.member(jsii_name="etag")
    def etag(self) -> str:
        return jsii.get(self, "etag")

    @builtins.property
    @jsii.member(jsii_name="expiration")
    def expiration(self) -> str:
        return jsii.get(self, "expiration")

    @builtins.property
    @jsii.member(jsii_name="expires")
    def expires(self) -> str:
        return jsii.get(self, "expires")

    @builtins.property
    @jsii.member(jsii_name="lastModified")
    def last_modified(self) -> str:
        return jsii.get(self, "lastModified")

    @builtins.property
    @jsii.member(jsii_name="objectLockLegalHoldStatus")
    def object_lock_legal_hold_status(self) -> str:
        return jsii.get(self, "objectLockLegalHoldStatus")

    @builtins.property
    @jsii.member(jsii_name="objectLockMode")
    def object_lock_mode(self) -> str:
        return jsii.get(self, "objectLockMode")

    @builtins.property
    @jsii.member(jsii_name="objectLockRetainUntilDate")
    def object_lock_retain_until_date(self) -> str:
        return jsii.get(self, "objectLockRetainUntilDate")

    @builtins.property
    @jsii.member(jsii_name="serverSideEncryption")
    def server_side_encryption(self) -> str:
        return jsii.get(self, "serverSideEncryption")

    @builtins.property
    @jsii.member(jsii_name="sseKmsKeyId")
    def sse_kms_key_id(self) -> str:
        return jsii.get(self, "sseKmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="storageClass")
    def storage_class(self) -> str:
        return jsii.get(self, "storageClass")

    @builtins.property
    @jsii.member(jsii_name="websiteRedirectLocation")
    def website_redirect_location(self) -> str:
        return jsii.get(self, "websiteRedirectLocation")

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="key")
    def key(self) -> str:
        return jsii.get(self, "key")

    @key.setter
    def key(self, value: str) -> None:
        jsii.set(self, "key", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="range")
    def range(self) -> typing.Optional[str]:
        return jsii.get(self, "range")

    @range.setter
    def range(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "range", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="versionId")
    def version_id(self) -> typing.Optional[str]:
        return jsii.get(self, "versionId")

    @version_id.setter
    def version_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "versionId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsS3BucketObjectConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "key": "key",
        "range": "range",
        "tags": "tags",
        "version_id": "versionId",
    },
)
class DataAwsS3BucketObjectConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        key: str,
        range: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        version_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param key: 
        :param range: 
        :param tags: 
        :param version_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "key": key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if range is not None:
            self._values["range"] = range
        if tags is not None:
            self._values["tags"] = tags
        if version_id is not None:
            self._values["version_id"] = version_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def range(self) -> typing.Optional[str]:
        return self._values.get("range")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def version_id(self) -> typing.Optional[str]:
        return self._values.get("version_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsS3BucketObjectConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsS3BucketObjects(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsS3BucketObjects",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        delimiter: typing.Optional[str] = None,
        encoding_type: typing.Optional[str] = None,
        fetch_owner: typing.Optional[bool] = None,
        max_keys: typing.Optional[jsii.Number] = None,
        prefix: typing.Optional[str] = None,
        start_after: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param delimiter: 
        :param encoding_type: 
        :param fetch_owner: 
        :param max_keys: 
        :param prefix: 
        :param start_after: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsS3BucketObjectsConfig(
            bucket=bucket,
            delimiter=delimiter,
            encoding_type=encoding_type,
            fetch_owner=fetch_owner,
            max_keys=max_keys,
            prefix=prefix,
            start_after=start_after,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsS3BucketObjects, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="commonPrefixes")
    def common_prefixes(self) -> typing.List[str]:
        return jsii.get(self, "commonPrefixes")

    @builtins.property
    @jsii.member(jsii_name="keys")
    def keys(self) -> typing.List[str]:
        return jsii.get(self, "keys")

    @builtins.property
    @jsii.member(jsii_name="owners")
    def owners(self) -> typing.List[str]:
        return jsii.get(self, "owners")

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="delimiter")
    def delimiter(self) -> typing.Optional[str]:
        return jsii.get(self, "delimiter")

    @delimiter.setter
    def delimiter(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "delimiter", value)

    @builtins.property
    @jsii.member(jsii_name="encodingType")
    def encoding_type(self) -> typing.Optional[str]:
        return jsii.get(self, "encodingType")

    @encoding_type.setter
    def encoding_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "encodingType", value)

    @builtins.property
    @jsii.member(jsii_name="fetchOwner")
    def fetch_owner(self) -> typing.Optional[bool]:
        return jsii.get(self, "fetchOwner")

    @fetch_owner.setter
    def fetch_owner(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "fetchOwner", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maxKeys")
    def max_keys(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxKeys")

    @max_keys.setter
    def max_keys(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxKeys", value)

    @builtins.property
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "prefix")

    @prefix.setter
    def prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "prefix", value)

    @builtins.property
    @jsii.member(jsii_name="startAfter")
    def start_after(self) -> typing.Optional[str]:
        return jsii.get(self, "startAfter")

    @start_after.setter
    def start_after(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "startAfter", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsS3BucketObjectsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "delimiter": "delimiter",
        "encoding_type": "encodingType",
        "fetch_owner": "fetchOwner",
        "max_keys": "maxKeys",
        "prefix": "prefix",
        "start_after": "startAfter",
    },
)
class DataAwsS3BucketObjectsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        delimiter: typing.Optional[str] = None,
        encoding_type: typing.Optional[str] = None,
        fetch_owner: typing.Optional[bool] = None,
        max_keys: typing.Optional[jsii.Number] = None,
        prefix: typing.Optional[str] = None,
        start_after: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param delimiter: 
        :param encoding_type: 
        :param fetch_owner: 
        :param max_keys: 
        :param prefix: 
        :param start_after: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if delimiter is not None:
            self._values["delimiter"] = delimiter
        if encoding_type is not None:
            self._values["encoding_type"] = encoding_type
        if fetch_owner is not None:
            self._values["fetch_owner"] = fetch_owner
        if max_keys is not None:
            self._values["max_keys"] = max_keys
        if prefix is not None:
            self._values["prefix"] = prefix
        if start_after is not None:
            self._values["start_after"] = start_after

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def delimiter(self) -> typing.Optional[str]:
        return self._values.get("delimiter")

    @builtins.property
    def encoding_type(self) -> typing.Optional[str]:
        return self._values.get("encoding_type")

    @builtins.property
    def fetch_owner(self) -> typing.Optional[bool]:
        return self._values.get("fetch_owner")

    @builtins.property
    def max_keys(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_keys")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def start_after(self) -> typing.Optional[str]:
        return self._values.get("start_after")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsS3BucketObjectsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSecretsmanagerSecret(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecret",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSecretsmanagerSecretConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSecretsmanagerSecret, self, [scope, id, config])

    @jsii.member(jsii_name="rotationRules")
    def rotation_rules(self, index: str) -> "DataAwsSecretsmanagerSecretRotationRules":
        """
        :param index: -
        """
        return jsii.invoke(self, "rotationRules", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="tags")
    def tags(self, key: str) -> str:
        """
        :param key: -
        """
        return jsii.invoke(self, "tags", [key])

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @builtins.property
    @jsii.member(jsii_name="rotationEnabled")
    def rotation_enabled(self) -> bool:
        return jsii.get(self, "rotationEnabled")

    @builtins.property
    @jsii.member(jsii_name="rotationLambdaArn")
    def rotation_lambda_arn(self) -> str:
        return jsii.get(self, "rotationLambdaArn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecretConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsSecretsmanagerSecretConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSecretsmanagerSecretConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSecretsmanagerSecretRotation(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecretRotation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        secret_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param secret_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSecretsmanagerSecretRotationConfig(
            secret_id=secret_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSecretsmanagerSecretRotation, self, [scope, id, config])

    @jsii.member(jsii_name="rotationRules")
    def rotation_rules(
        self, index: str
    ) -> "DataAwsSecretsmanagerSecretRotationRotationRules":
        """
        :param index: -
        """
        return jsii.invoke(self, "rotationRules", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="rotationEnabled")
    def rotation_enabled(self) -> bool:
        return jsii.get(self, "rotationEnabled")

    @builtins.property
    @jsii.member(jsii_name="rotationLambdaArn")
    def rotation_lambda_arn(self) -> str:
        return jsii.get(self, "rotationLambdaArn")

    @builtins.property
    @jsii.member(jsii_name="secretId")
    def secret_id(self) -> str:
        return jsii.get(self, "secretId")

    @secret_id.setter
    def secret_id(self, value: str) -> None:
        jsii.set(self, "secretId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecretRotationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "secret_id": "secretId",
    },
)
class DataAwsSecretsmanagerSecretRotationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        secret_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param secret_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "secret_id": secret_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def secret_id(self) -> str:
        return self._values.get("secret_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSecretsmanagerSecretRotationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSecretsmanagerSecretRotationRotationRules(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecretRotationRotationRules",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsSecretsmanagerSecretRotationRotationRules,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="automaticallyAfterDays")
    def automatically_after_days(self) -> jsii.Number:
        return jsii.get(self, "automaticallyAfterDays")


class DataAwsSecretsmanagerSecretRotationRules(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecretRotationRules",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsSecretsmanagerSecretRotationRules,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="automaticallyAfterDays")
    def automatically_after_days(self) -> jsii.Number:
        return jsii.get(self, "automaticallyAfterDays")


class DataAwsSecretsmanagerSecretVersion(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecretVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        secret_id: str,
        version_id: typing.Optional[str] = None,
        version_stage: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param secret_id: 
        :param version_id: 
        :param version_stage: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSecretsmanagerSecretVersionConfig(
            secret_id=secret_id,
            version_id=version_id,
            version_stage=version_stage,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSecretsmanagerSecretVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="secretBinary")
    def secret_binary(self) -> str:
        return jsii.get(self, "secretBinary")

    @builtins.property
    @jsii.member(jsii_name="secretString")
    def secret_string(self) -> str:
        return jsii.get(self, "secretString")

    @builtins.property
    @jsii.member(jsii_name="versionStages")
    def version_stages(self) -> typing.List[str]:
        return jsii.get(self, "versionStages")

    @builtins.property
    @jsii.member(jsii_name="secretId")
    def secret_id(self) -> str:
        return jsii.get(self, "secretId")

    @secret_id.setter
    def secret_id(self, value: str) -> None:
        jsii.set(self, "secretId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="versionId")
    def version_id(self) -> typing.Optional[str]:
        return jsii.get(self, "versionId")

    @version_id.setter
    def version_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "versionId", value)

    @builtins.property
    @jsii.member(jsii_name="versionStage")
    def version_stage(self) -> typing.Optional[str]:
        return jsii.get(self, "versionStage")

    @version_stage.setter
    def version_stage(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "versionStage", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecretsmanagerSecretVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "secret_id": "secretId",
        "version_id": "versionId",
        "version_stage": "versionStage",
    },
)
class DataAwsSecretsmanagerSecretVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        secret_id: str,
        version_id: typing.Optional[str] = None,
        version_stage: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param secret_id: 
        :param version_id: 
        :param version_stage: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "secret_id": secret_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if version_id is not None:
            self._values["version_id"] = version_id
        if version_stage is not None:
            self._values["version_stage"] = version_stage

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def secret_id(self) -> str:
        return self._values.get("secret_id")

    @builtins.property
    def version_id(self) -> typing.Optional[str]:
        return self._values.get("version_id")

    @builtins.property
    def version_stage(self) -> typing.Optional[str]:
        return self._values.get("version_stage")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSecretsmanagerSecretVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSecurityGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsSecurityGroupFilter"]] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param name: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSecurityGroupConfig(
            filter=filter,
            name=name,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsSecurityGroupFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsSecurityGroupFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "name": "name",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsSecurityGroupFilter"]] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param name: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsSecurityGroupFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecurityGroupFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsSecurityGroupFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSecurityGroupFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSecurityGroups(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecurityGroups",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsSecurityGroupsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSecurityGroupsConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSecurityGroups, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="vpcIds")
    def vpc_ids(self) -> typing.List[str]:
        return jsii.get(self, "vpcIds")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsSecurityGroupsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsSecurityGroupsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecurityGroupsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsSecurityGroupsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsSecurityGroupsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsSecurityGroupsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSecurityGroupsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSecurityGroupsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsSecurityGroupsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSecurityGroupsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsServicequotasService(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsServicequotasService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        service_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param service_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsServicequotasServiceConfig(
            service_name=service_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsServicequotasService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="serviceCode")
    def service_code(self) -> str:
        return jsii.get(self, "serviceCode")

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> str:
        return jsii.get(self, "serviceName")

    @service_name.setter
    def service_name(self, value: str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsServicequotasServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "service_name": "serviceName",
    },
)
class DataAwsServicequotasServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        service_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param service_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "service_name": service_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def service_name(self) -> str:
        return self._values.get("service_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsServicequotasServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsServicequotasServiceQuota(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsServicequotasServiceQuota",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        service_code: str,
        quota_code: typing.Optional[str] = None,
        quota_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param service_code: 
        :param quota_code: 
        :param quota_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsServicequotasServiceQuotaConfig(
            service_code=service_code,
            quota_code=quota_code,
            quota_name=quota_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsServicequotasServiceQuota, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="adjustable")
    def adjustable(self) -> bool:
        return jsii.get(self, "adjustable")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultValue")
    def default_value(self) -> jsii.Number:
        return jsii.get(self, "defaultValue")

    @builtins.property
    @jsii.member(jsii_name="globalQuota")
    def global_quota(self) -> bool:
        return jsii.get(self, "globalQuota")

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> str:
        return jsii.get(self, "serviceName")

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return jsii.get(self, "value")

    @builtins.property
    @jsii.member(jsii_name="serviceCode")
    def service_code(self) -> str:
        return jsii.get(self, "serviceCode")

    @service_code.setter
    def service_code(self, value: str) -> None:
        jsii.set(self, "serviceCode", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="quotaCode")
    def quota_code(self) -> typing.Optional[str]:
        return jsii.get(self, "quotaCode")

    @quota_code.setter
    def quota_code(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "quotaCode", value)

    @builtins.property
    @jsii.member(jsii_name="quotaName")
    def quota_name(self) -> typing.Optional[str]:
        return jsii.get(self, "quotaName")

    @quota_name.setter
    def quota_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "quotaName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsServicequotasServiceQuotaConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "service_code": "serviceCode",
        "quota_code": "quotaCode",
        "quota_name": "quotaName",
    },
)
class DataAwsServicequotasServiceQuotaConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        service_code: str,
        quota_code: typing.Optional[str] = None,
        quota_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param service_code: 
        :param quota_code: 
        :param quota_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "service_code": service_code,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if quota_code is not None:
            self._values["quota_code"] = quota_code
        if quota_name is not None:
            self._values["quota_name"] = quota_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def service_code(self) -> str:
        return self._values.get("service_code")

    @builtins.property
    def quota_code(self) -> typing.Optional[str]:
        return self._values.get("quota_code")

    @builtins.property
    def quota_name(self) -> typing.Optional[str]:
        return self._values.get("quota_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsServicequotasServiceQuotaConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSfnActivity(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSfnActivity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSfnActivityConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSfnActivity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSfnActivityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsSfnActivityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSfnActivityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSfnStateMachine(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSfnStateMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSfnStateMachineConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSfnStateMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(self) -> str:
        return jsii.get(self, "definition")

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSfnStateMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsSfnStateMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSfnStateMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSnsTopic(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSnsTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSnsTopicConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSnsTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSnsTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsSnsTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSnsTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSqsQueue(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSqsQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSqsQueueConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSqsQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> str:
        return jsii.get(self, "url")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSqsQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class DataAwsSqsQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSqsQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSsmDocument(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSsmDocument",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        document_format: typing.Optional[str] = None,
        document_version: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param document_format: 
        :param document_version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSsmDocumentConfig(
            name=name,
            document_format=document_format,
            document_version=document_version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSsmDocument, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="content")
    def content(self) -> str:
        return jsii.get(self, "content")

    @builtins.property
    @jsii.member(jsii_name="documentType")
    def document_type(self) -> str:
        return jsii.get(self, "documentType")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="documentFormat")
    def document_format(self) -> typing.Optional[str]:
        return jsii.get(self, "documentFormat")

    @document_format.setter
    def document_format(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "documentFormat", value)

    @builtins.property
    @jsii.member(jsii_name="documentVersion")
    def document_version(self) -> typing.Optional[str]:
        return jsii.get(self, "documentVersion")

    @document_version.setter
    def document_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "documentVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSsmDocumentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "document_format": "documentFormat",
        "document_version": "documentVersion",
    },
)
class DataAwsSsmDocumentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        document_format: typing.Optional[str] = None,
        document_version: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param document_format: 
        :param document_version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if document_format is not None:
            self._values["document_format"] = document_format
        if document_version is not None:
            self._values["document_version"] = document_version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def document_format(self) -> typing.Optional[str]:
        return self._values.get("document_format")

    @builtins.property
    def document_version(self) -> typing.Optional[str]:
        return self._values.get("document_version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSsmDocumentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSsmParameter(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSsmParameter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        with_decryption: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param with_decryption: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSsmParameterConfig(
            name=name,
            with_decryption=with_decryption,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSsmParameter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> jsii.Number:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="withDecryption")
    def with_decryption(self) -> typing.Optional[bool]:
        return jsii.get(self, "withDecryption")

    @with_decryption.setter
    def with_decryption(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "withDecryption", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSsmParameterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "with_decryption": "withDecryption",
    },
)
class DataAwsSsmParameterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        with_decryption: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param with_decryption: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if with_decryption is not None:
            self._values["with_decryption"] = with_decryption

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def with_decryption(self) -> typing.Optional[bool]:
        return self._values.get("with_decryption")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSsmParameterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSsmPatchBaseline(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSsmPatchBaseline",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        owner: str,
        default_baseline: typing.Optional[bool] = None,
        name_prefix: typing.Optional[str] = None,
        operating_system: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param owner: 
        :param default_baseline: 
        :param name_prefix: 
        :param operating_system: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSsmPatchBaselineConfig(
            owner=owner,
            default_baseline=default_baseline,
            name_prefix=name_prefix,
            operating_system=operating_system,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSsmPatchBaseline, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="owner")
    def owner(self) -> str:
        return jsii.get(self, "owner")

    @owner.setter
    def owner(self, value: str) -> None:
        jsii.set(self, "owner", value)

    @builtins.property
    @jsii.member(jsii_name="defaultBaseline")
    def default_baseline(self) -> typing.Optional[bool]:
        return jsii.get(self, "defaultBaseline")

    @default_baseline.setter
    def default_baseline(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "defaultBaseline", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="operatingSystem")
    def operating_system(self) -> typing.Optional[str]:
        return jsii.get(self, "operatingSystem")

    @operating_system.setter
    def operating_system(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "operatingSystem", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSsmPatchBaselineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "owner": "owner",
        "default_baseline": "defaultBaseline",
        "name_prefix": "namePrefix",
        "operating_system": "operatingSystem",
    },
)
class DataAwsSsmPatchBaselineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        owner: str,
        default_baseline: typing.Optional[bool] = None,
        name_prefix: typing.Optional[str] = None,
        operating_system: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param owner: 
        :param default_baseline: 
        :param name_prefix: 
        :param operating_system: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "owner": owner,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_baseline is not None:
            self._values["default_baseline"] = default_baseline
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if operating_system is not None:
            self._values["operating_system"] = operating_system

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def owner(self) -> str:
        return self._values.get("owner")

    @builtins.property
    def default_baseline(self) -> typing.Optional[bool]:
        return self._values.get("default_baseline")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def operating_system(self) -> typing.Optional[str]:
        return self._values.get("operating_system")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSsmPatchBaselineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsStoragegatewayLocalDisk(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsStoragegatewayLocalDisk",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        gateway_arn: str,
        disk_node: typing.Optional[str] = None,
        disk_path: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gateway_arn: 
        :param disk_node: 
        :param disk_path: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsStoragegatewayLocalDiskConfig(
            gateway_arn=gateway_arn,
            disk_node=disk_node,
            disk_path=disk_path,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsStoragegatewayLocalDisk, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> str:
        return jsii.get(self, "diskId")

    @builtins.property
    @jsii.member(jsii_name="gatewayArn")
    def gateway_arn(self) -> str:
        return jsii.get(self, "gatewayArn")

    @gateway_arn.setter
    def gateway_arn(self, value: str) -> None:
        jsii.set(self, "gatewayArn", value)

    @builtins.property
    @jsii.member(jsii_name="diskNode")
    def disk_node(self) -> typing.Optional[str]:
        return jsii.get(self, "diskNode")

    @disk_node.setter
    def disk_node(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "diskNode", value)

    @builtins.property
    @jsii.member(jsii_name="diskPath")
    def disk_path(self) -> typing.Optional[str]:
        return jsii.get(self, "diskPath")

    @disk_path.setter
    def disk_path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "diskPath", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsStoragegatewayLocalDiskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gateway_arn": "gatewayArn",
        "disk_node": "diskNode",
        "disk_path": "diskPath",
    },
)
class DataAwsStoragegatewayLocalDiskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gateway_arn: str,
        disk_node: typing.Optional[str] = None,
        disk_path: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gateway_arn: 
        :param disk_node: 
        :param disk_path: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "gateway_arn": gateway_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if disk_node is not None:
            self._values["disk_node"] = disk_node
        if disk_path is not None:
            self._values["disk_path"] = disk_path

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def gateway_arn(self) -> str:
        return self._values.get("gateway_arn")

    @builtins.property
    def disk_node(self) -> typing.Optional[str]:
        return self._values.get("disk_node")

    @builtins.property
    def disk_path(self) -> typing.Optional[str]:
        return self._values.get("disk_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsStoragegatewayLocalDiskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSubnet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSubnet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        availability_zone: typing.Optional[str] = None,
        availability_zone_id: typing.Optional[str] = None,
        cidr_block: typing.Optional[str] = None,
        default_for_az: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsSubnetFilter"]] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param availability_zone: 
        :param availability_zone_id: 
        :param cidr_block: 
        :param default_for_az: 
        :param filter: filter block.
        :param ipv6_cidr_block: 
        :param state: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSubnetConfig(
            availability_zone=availability_zone,
            availability_zone_id=availability_zone_id,
            cidr_block=cidr_block,
            default_for_az=default_for_az,
            filter=filter,
            ipv6_cidr_block=ipv6_cidr_block,
            state=state,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSubnet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="assignIpv6AddressOnCreation")
    def assign_ipv6_address_on_creation(self) -> bool:
        return jsii.get(self, "assignIpv6AddressOnCreation")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlockAssociationId")
    def ipv6_cidr_block_association_id(self) -> str:
        return jsii.get(self, "ipv6CidrBlockAssociationId")

    @builtins.property
    @jsii.member(jsii_name="mapPublicIpOnLaunch")
    def map_public_ip_on_launch(self) -> bool:
        return jsii.get(self, "mapPublicIpOnLaunch")

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZoneId")

    @availability_zone_id.setter
    def availability_zone_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZoneId", value)

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "cidrBlock")

    @cidr_block.setter
    def cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="defaultForAz")
    def default_for_az(self) -> typing.Optional[bool]:
        return jsii.get(self, "defaultForAz")

    @default_for_az.setter
    def default_for_az(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "defaultForAz", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsSubnetFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsSubnetFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "ipv6CidrBlock")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipv6CidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSubnetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "availability_zone": "availabilityZone",
        "availability_zone_id": "availabilityZoneId",
        "cidr_block": "cidrBlock",
        "default_for_az": "defaultForAz",
        "filter": "filter",
        "ipv6_cidr_block": "ipv6CidrBlock",
        "state": "state",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsSubnetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        availability_zone: typing.Optional[str] = None,
        availability_zone_id: typing.Optional[str] = None,
        cidr_block: typing.Optional[str] = None,
        default_for_az: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["DataAwsSubnetFilter"]] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param availability_zone: 
        :param availability_zone_id: 
        :param cidr_block: 
        :param default_for_az: 
        :param filter: filter block.
        :param ipv6_cidr_block: 
        :param state: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if availability_zone_id is not None:
            self._values["availability_zone_id"] = availability_zone_id
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if default_for_az is not None:
            self._values["default_for_az"] = default_for_az
        if filter is not None:
            self._values["filter"] = filter
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def availability_zone_id(self) -> typing.Optional[str]:
        return self._values.get("availability_zone_id")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def default_for_az(self) -> typing.Optional[bool]:
        return self._values.get("default_for_az")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsSubnetFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSubnetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSubnetFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsSubnetFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSubnetFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsSubnetIds(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSubnetIds",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_id: str,
        filter: typing.Optional[typing.List["DataAwsSubnetIdsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_id: 
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsSubnetIdsConfig(
            vpc_id=vpc_id,
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsSubnetIds, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsSubnetIdsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsSubnetIdsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSubnetIdsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_id": "vpcId",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsSubnetIdsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_id: str,
        filter: typing.Optional[typing.List["DataAwsSubnetIdsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_id: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsSubnetIdsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSubnetIdsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsSubnetIdsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsSubnetIdsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsSubnetIdsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsTransferServer(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsTransferServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        server_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param server_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsTransferServerConfig(
            server_id=server_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsTransferServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="identityProviderType")
    def identity_provider_type(self) -> str:
        return jsii.get(self, "identityProviderType")

    @builtins.property
    @jsii.member(jsii_name="invocationRole")
    def invocation_role(self) -> str:
        return jsii.get(self, "invocationRole")

    @builtins.property
    @jsii.member(jsii_name="loggingRole")
    def logging_role(self) -> str:
        return jsii.get(self, "loggingRole")

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> str:
        return jsii.get(self, "url")

    @builtins.property
    @jsii.member(jsii_name="serverId")
    def server_id(self) -> str:
        return jsii.get(self, "serverId")

    @server_id.setter
    def server_id(self, value: str) -> None:
        jsii.set(self, "serverId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsTransferServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "server_id": "serverId",
    },
)
class DataAwsTransferServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        server_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param server_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "server_id": server_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def server_id(self) -> str:
        return self._values.get("server_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsTransferServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpc(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpc",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cidr_block: typing.Optional[str] = None,
        default: typing.Optional[bool] = None,
        dhcp_options_id: typing.Optional[str] = None,
        filter: typing.Optional[typing.List["DataAwsVpcFilter"]] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cidr_block: 
        :param default: 
        :param dhcp_options_id: 
        :param filter: filter block.
        :param state: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsVpcConfig(
            cidr_block=cidr_block,
            default=default,
            dhcp_options_id=dhcp_options_id,
            filter=filter,
            state=state,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsVpc, self, [scope, id, config])

    @jsii.member(jsii_name="cidrBlockAssociations")
    def cidr_block_associations(self, index: str) -> "DataAwsVpcCidrBlockAssociations":
        """
        :param index: -
        """
        return jsii.invoke(self, "cidrBlockAssociations", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="enableDnsHostnames")
    def enable_dns_hostnames(self) -> bool:
        return jsii.get(self, "enableDnsHostnames")

    @builtins.property
    @jsii.member(jsii_name="enableDnsSupport")
    def enable_dns_support(self) -> bool:
        return jsii.get(self, "enableDnsSupport")

    @builtins.property
    @jsii.member(jsii_name="instanceTenancy")
    def instance_tenancy(self) -> str:
        return jsii.get(self, "instanceTenancy")

    @builtins.property
    @jsii.member(jsii_name="ipv6AssociationId")
    def ipv6_association_id(self) -> str:
        return jsii.get(self, "ipv6AssociationId")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> str:
        return jsii.get(self, "ipv6CidrBlock")

    @builtins.property
    @jsii.member(jsii_name="mainRouteTableId")
    def main_route_table_id(self) -> str:
        return jsii.get(self, "mainRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "cidrBlock")

    @cidr_block.setter
    def cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="default")
    def default(self) -> typing.Optional[bool]:
        return jsii.get(self, "default")

    @default.setter
    def default(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "default", value)

    @builtins.property
    @jsii.member(jsii_name="dhcpOptionsId")
    def dhcp_options_id(self) -> typing.Optional[str]:
        return jsii.get(self, "dhcpOptionsId")

    @dhcp_options_id.setter
    def dhcp_options_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dhcpOptionsId", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(self, value: typing.Optional[typing.List["DataAwsVpcFilter"]]) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DataAwsVpcCidrBlockAssociations(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcCidrBlockAssociations",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsVpcCidrBlockAssociations,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="associationId")
    def association_id(self) -> str:
        return jsii.get(self, "associationId")

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> str:
        return jsii.get(self, "cidrBlock")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cidr_block": "cidrBlock",
        "default": "default",
        "dhcp_options_id": "dhcpOptionsId",
        "filter": "filter",
        "state": "state",
        "tags": "tags",
    },
)
class DataAwsVpcConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cidr_block: typing.Optional[str] = None,
        default: typing.Optional[bool] = None,
        dhcp_options_id: typing.Optional[str] = None,
        filter: typing.Optional[typing.List["DataAwsVpcFilter"]] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cidr_block: 
        :param default: 
        :param dhcp_options_id: 
        :param filter: filter block.
        :param state: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if default is not None:
            self._values["default"] = default
        if dhcp_options_id is not None:
            self._values["dhcp_options_id"] = dhcp_options_id
        if filter is not None:
            self._values["filter"] = filter
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def default(self) -> typing.Optional[bool]:
        return self._values.get("default")

    @builtins.property
    def dhcp_options_id(self) -> typing.Optional[str]:
        return self._values.get("dhcp_options_id")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpcDhcpOptions(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcDhcpOptions",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dhcp_options_id: typing.Optional[str] = None,
        filter: typing.Optional[typing.List["DataAwsVpcDhcpOptionsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dhcp_options_id: 
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsVpcDhcpOptionsConfig(
            dhcp_options_id=dhcp_options_id,
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsVpcDhcpOptions, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @builtins.property
    @jsii.member(jsii_name="domainNameServers")
    def domain_name_servers(self) -> typing.List[str]:
        return jsii.get(self, "domainNameServers")

    @builtins.property
    @jsii.member(jsii_name="netbiosNameServers")
    def netbios_name_servers(self) -> typing.List[str]:
        return jsii.get(self, "netbiosNameServers")

    @builtins.property
    @jsii.member(jsii_name="netbiosNodeType")
    def netbios_node_type(self) -> str:
        return jsii.get(self, "netbiosNodeType")

    @builtins.property
    @jsii.member(jsii_name="ntpServers")
    def ntp_servers(self) -> typing.List[str]:
        return jsii.get(self, "ntpServers")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="dhcpOptionsId")
    def dhcp_options_id(self) -> typing.Optional[str]:
        return jsii.get(self, "dhcpOptionsId")

    @dhcp_options_id.setter
    def dhcp_options_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dhcpOptionsId", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcDhcpOptionsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsVpcDhcpOptionsFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcDhcpOptionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dhcp_options_id": "dhcpOptionsId",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsVpcDhcpOptionsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dhcp_options_id: typing.Optional[str] = None,
        filter: typing.Optional[typing.List["DataAwsVpcDhcpOptionsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dhcp_options_id: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dhcp_options_id is not None:
            self._values["dhcp_options_id"] = dhcp_options_id
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dhcp_options_id(self) -> typing.Optional[str]:
        return self._values.get("dhcp_options_id")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcDhcpOptionsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcDhcpOptionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcDhcpOptionsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsVpcDhcpOptionsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcDhcpOptionsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpcEndpoint(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsVpcEndpointFilter"]] = None,
        service_name: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param service_name: 
        :param state: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsVpcEndpointConfig(
            filter=filter,
            service_name=service_name,
            state=state,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsVpcEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="dnsEntry")
    def dns_entry(self, index: str) -> "DataAwsVpcEndpointDnsEntry":
        """
        :param index: -
        """
        return jsii.invoke(self, "dnsEntry", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="cidrBlocks")
    def cidr_blocks(self) -> typing.List[str]:
        return jsii.get(self, "cidrBlocks")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceIds")
    def network_interface_ids(self) -> typing.List[str]:
        return jsii.get(self, "networkInterfaceIds")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @builtins.property
    @jsii.member(jsii_name="prefixListId")
    def prefix_list_id(self) -> str:
        return jsii.get(self, "prefixListId")

    @builtins.property
    @jsii.member(jsii_name="privateDnsEnabled")
    def private_dns_enabled(self) -> bool:
        return jsii.get(self, "privateDnsEnabled")

    @builtins.property
    @jsii.member(jsii_name="requesterManaged")
    def requester_managed(self) -> bool:
        return jsii.get(self, "requesterManaged")

    @builtins.property
    @jsii.member(jsii_name="routeTableIds")
    def route_table_ids(self) -> typing.List[str]:
        return jsii.get(self, "routeTableIds")

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupIds")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointType")
    def vpc_endpoint_type(self) -> str:
        return jsii.get(self, "vpcEndpointType")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcEndpointFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsVpcEndpointFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> typing.Optional[str]:
        return jsii.get(self, "serviceName")

    @service_name.setter
    def service_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "service_name": "serviceName",
        "state": "state",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsVpcEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsVpcEndpointFilter"]] = None,
        service_name: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param service_name: 
        :param state: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if service_name is not None:
            self._values["service_name"] = service_name
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcEndpointFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def service_name(self) -> typing.Optional[str]:
        return self._values.get("service_name")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpcEndpointDnsEntry(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcEndpointDnsEntry",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsVpcEndpointDnsEntry,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcEndpointFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsVpcEndpointFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcEndpointFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpcEndpointService(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcEndpointService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsVpcEndpointServiceFilter"]] = None,
        service: typing.Optional[str] = None,
        service_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param service: 
        :param service_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsVpcEndpointServiceConfig(
            filter=filter,
            service=service,
            service_name=service_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsVpcEndpointService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="acceptanceRequired")
    def acceptance_required(self) -> bool:
        return jsii.get(self, "acceptanceRequired")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="baseEndpointDnsNames")
    def base_endpoint_dns_names(self) -> typing.List[str]:
        return jsii.get(self, "baseEndpointDnsNames")

    @builtins.property
    @jsii.member(jsii_name="managesVpcEndpoints")
    def manages_vpc_endpoints(self) -> bool:
        return jsii.get(self, "managesVpcEndpoints")

    @builtins.property
    @jsii.member(jsii_name="owner")
    def owner(self) -> str:
        return jsii.get(self, "owner")

    @builtins.property
    @jsii.member(jsii_name="privateDnsName")
    def private_dns_name(self) -> str:
        return jsii.get(self, "privateDnsName")

    @builtins.property
    @jsii.member(jsii_name="serviceId")
    def service_id(self) -> str:
        return jsii.get(self, "serviceId")

    @builtins.property
    @jsii.member(jsii_name="serviceType")
    def service_type(self) -> str:
        return jsii.get(self, "serviceType")

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointPolicySupported")
    def vpc_endpoint_policy_supported(self) -> bool:
        return jsii.get(self, "vpcEndpointPolicySupported")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcEndpointServiceFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsVpcEndpointServiceFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="service")
    def service(self) -> typing.Optional[str]:
        return jsii.get(self, "service")

    @service.setter
    def service(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "service", value)

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> typing.Optional[str]:
        return jsii.get(self, "serviceName")

    @service_name.setter
    def service_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcEndpointServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "service": "service",
        "service_name": "serviceName",
        "tags": "tags",
    },
)
class DataAwsVpcEndpointServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsVpcEndpointServiceFilter"]] = None,
        service: typing.Optional[str] = None,
        service_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param service: 
        :param service_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if service is not None:
            self._values["service"] = service
        if service_name is not None:
            self._values["service_name"] = service_name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcEndpointServiceFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def service(self) -> typing.Optional[str]:
        return self._values.get("service")

    @builtins.property
    def service_name(self) -> typing.Optional[str]:
        return self._values.get("service_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcEndpointServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcEndpointServiceFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsVpcEndpointServiceFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcEndpointServiceFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsVpcFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpcPeeringConnection(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcPeeringConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cidr_block: typing.Optional[str] = None,
        filter: typing.Optional[
            typing.List["DataAwsVpcPeeringConnectionFilter"]
        ] = None,
        owner_id: typing.Optional[str] = None,
        peer_cidr_block: typing.Optional[str] = None,
        peer_owner_id: typing.Optional[str] = None,
        peer_region: typing.Optional[str] = None,
        peer_vpc_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cidr_block: 
        :param filter: filter block.
        :param owner_id: 
        :param peer_cidr_block: 
        :param peer_owner_id: 
        :param peer_region: 
        :param peer_vpc_id: 
        :param region: 
        :param status: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsVpcPeeringConnectionConfig(
            cidr_block=cidr_block,
            filter=filter,
            owner_id=owner_id,
            peer_cidr_block=peer_cidr_block,
            peer_owner_id=peer_owner_id,
            peer_region=peer_region,
            peer_vpc_id=peer_vpc_id,
            region=region,
            status=status,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsVpcPeeringConnection, self, [scope, id, config])

    @jsii.member(jsii_name="accepter")
    def accepter(self, key: str) -> bool:
        """
        :param key: -
        """
        return jsii.invoke(self, "accepter", [key])

    @jsii.member(jsii_name="requester")
    def requester(self, key: str) -> bool:
        """
        :param key: -
        """
        return jsii.invoke(self, "requester", [key])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "cidrBlock")

    @cidr_block.setter
    def cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsVpcPeeringConnectionFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsVpcPeeringConnectionFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> typing.Optional[str]:
        return jsii.get(self, "ownerId")

    @owner_id.setter
    def owner_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ownerId", value)

    @builtins.property
    @jsii.member(jsii_name="peerCidrBlock")
    def peer_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "peerCidrBlock")

    @peer_cidr_block.setter
    def peer_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "peerCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="peerOwnerId")
    def peer_owner_id(self) -> typing.Optional[str]:
        return jsii.get(self, "peerOwnerId")

    @peer_owner_id.setter
    def peer_owner_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "peerOwnerId", value)

    @builtins.property
    @jsii.member(jsii_name="peerRegion")
    def peer_region(self) -> typing.Optional[str]:
        return jsii.get(self, "peerRegion")

    @peer_region.setter
    def peer_region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "peerRegion", value)

    @builtins.property
    @jsii.member(jsii_name="peerVpcId")
    def peer_vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "peerVpcId")

    @peer_vpc_id.setter
    def peer_vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "peerVpcId", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[str]:
        return jsii.get(self, "status")

    @status.setter
    def status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "status", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcPeeringConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cidr_block": "cidrBlock",
        "filter": "filter",
        "owner_id": "ownerId",
        "peer_cidr_block": "peerCidrBlock",
        "peer_owner_id": "peerOwnerId",
        "peer_region": "peerRegion",
        "peer_vpc_id": "peerVpcId",
        "region": "region",
        "status": "status",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class DataAwsVpcPeeringConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cidr_block: typing.Optional[str] = None,
        filter: typing.Optional[
            typing.List["DataAwsVpcPeeringConnectionFilter"]
        ] = None,
        owner_id: typing.Optional[str] = None,
        peer_cidr_block: typing.Optional[str] = None,
        peer_owner_id: typing.Optional[str] = None,
        peer_region: typing.Optional[str] = None,
        peer_vpc_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cidr_block: 
        :param filter: filter block.
        :param owner_id: 
        :param peer_cidr_block: 
        :param peer_owner_id: 
        :param peer_region: 
        :param peer_vpc_id: 
        :param region: 
        :param status: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if filter is not None:
            self._values["filter"] = filter
        if owner_id is not None:
            self._values["owner_id"] = owner_id
        if peer_cidr_block is not None:
            self._values["peer_cidr_block"] = peer_cidr_block
        if peer_owner_id is not None:
            self._values["peer_owner_id"] = peer_owner_id
        if peer_region is not None:
            self._values["peer_region"] = peer_region
        if peer_vpc_id is not None:
            self._values["peer_vpc_id"] = peer_vpc_id
        if region is not None:
            self._values["region"] = region
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["DataAwsVpcPeeringConnectionFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def owner_id(self) -> typing.Optional[str]:
        return self._values.get("owner_id")

    @builtins.property
    def peer_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("peer_cidr_block")

    @builtins.property
    def peer_owner_id(self) -> typing.Optional[str]:
        return self._values.get("peer_owner_id")

    @builtins.property
    def peer_region(self) -> typing.Optional[str]:
        return self._values.get("peer_region")

    @builtins.property
    def peer_vpc_id(self) -> typing.Optional[str]:
        return self._values.get("peer_vpc_id")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcPeeringConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcPeeringConnectionFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsVpcPeeringConnectionFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcPeeringConnectionFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpcs(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcs",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        filter: typing.Optional[typing.List["DataAwsVpcsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param filter: filter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsVpcsConfig(
            filter=filter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsVpcs, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ids")
    def ids(self) -> typing.List[str]:
        return jsii.get(self, "ids")

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcsFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(self, value: typing.Optional[typing.List["DataAwsVpcsFilter"]]) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "filter": "filter",
        "tags": "tags",
    },
)
class DataAwsVpcsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        filter: typing.Optional[typing.List["DataAwsVpcsFilter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param filter: filter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsVpcsFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpcsFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsVpcsFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpcsFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsVpnGateway(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpnGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        amazon_side_asn: typing.Optional[str] = None,
        attached_vpc_id: typing.Optional[str] = None,
        availability_zone: typing.Optional[str] = None,
        filter: typing.Optional[typing.List["DataAwsVpnGatewayFilter"]] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param amazon_side_asn: 
        :param attached_vpc_id: 
        :param availability_zone: 
        :param filter: filter block.
        :param state: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsVpnGatewayConfig(
            amazon_side_asn=amazon_side_asn,
            attached_vpc_id=attached_vpc_id,
            availability_zone=availability_zone,
            filter=filter,
            state=state,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsVpnGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonSideAsn")

    @amazon_side_asn.setter
    def amazon_side_asn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonSideAsn", value)

    @builtins.property
    @jsii.member(jsii_name="attachedVpcId")
    def attached_vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "attachedVpcId")

    @attached_vpc_id.setter
    def attached_vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "attachedVpcId", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["DataAwsVpnGatewayFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["DataAwsVpnGatewayFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpnGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "amazon_side_asn": "amazonSideAsn",
        "attached_vpc_id": "attachedVpcId",
        "availability_zone": "availabilityZone",
        "filter": "filter",
        "state": "state",
        "tags": "tags",
    },
)
class DataAwsVpnGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        amazon_side_asn: typing.Optional[str] = None,
        attached_vpc_id: typing.Optional[str] = None,
        availability_zone: typing.Optional[str] = None,
        filter: typing.Optional[typing.List["DataAwsVpnGatewayFilter"]] = None,
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param amazon_side_asn: 
        :param attached_vpc_id: 
        :param availability_zone: 
        :param filter: filter block.
        :param state: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_side_asn is not None:
            self._values["amazon_side_asn"] = amazon_side_asn
        if attached_vpc_id is not None:
            self._values["attached_vpc_id"] = attached_vpc_id
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if filter is not None:
            self._values["filter"] = filter
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def amazon_side_asn(self) -> typing.Optional[str]:
        return self._values.get("amazon_side_asn")

    @builtins.property
    def attached_vpc_id(self) -> typing.Optional[str]:
        return self._values.get("attached_vpc_id")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["DataAwsVpnGatewayFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpnGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsVpnGatewayFilter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class DataAwsVpnGatewayFilter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsVpnGatewayFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafIpset(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafIpset",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafIpsetConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafIpset, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafIpsetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafIpsetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafIpsetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafRateBasedRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafRateBasedRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafRateBasedRuleConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafRateBasedRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafRateBasedRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafRateBasedRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafRateBasedRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafRuleConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafWebAcl(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafWebAcl",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafWebAclConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafWebAcl, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafWebAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafWebAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafWebAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafregionalIpset(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalIpset",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafregionalIpsetConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafregionalIpset, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalIpsetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafregionalIpsetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafregionalIpsetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafregionalRateBasedRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalRateBasedRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafregionalRateBasedRuleConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafregionalRateBasedRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalRateBasedRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafregionalRateBasedRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafregionalRateBasedRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafregionalRule(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafregionalRuleConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafregionalRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafregionalRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafregionalRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafregionalWebAcl(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalWebAcl",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafregionalWebAclConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafregionalWebAcl, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafregionalWebAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DataAwsWafregionalWebAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafregionalWebAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafv2IpSet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2IpSet",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        name: str,
        scope: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param scope: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafv2IpSetConfig(
            name=name,
            scope=scope,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafv2IpSet, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="addresses")
    def addresses(self) -> typing.List[str]:
        return jsii.get(self, "addresses")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="ipAddressVersion")
    def ip_address_version(self) -> str:
        return jsii.get(self, "ipAddressVersion")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2IpSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "scope": "scope",
    },
)
class DataAwsWafv2IpSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        scope: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param scope: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafv2IpSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafv2RegexPatternSet(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2RegexPatternSet",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        name: str,
        scope: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param scope: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafv2RegexPatternSetConfig(
            name=name,
            scope=scope,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafv2RegexPatternSet, self, [scope_, id, config])

    @jsii.member(jsii_name="regularExpression")
    def regular_expression(
        self, index: str
    ) -> "DataAwsWafv2RegexPatternSetRegularExpression":
        """
        :param index: -
        """
        return jsii.invoke(self, "regularExpression", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2RegexPatternSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "scope": "scope",
    },
)
class DataAwsWafv2RegexPatternSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        scope: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param scope: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafv2RegexPatternSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafv2RegexPatternSetRegularExpression(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2RegexPatternSetRegularExpression",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsWafv2RegexPatternSetRegularExpression,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="regexString")
    def regex_string(self) -> str:
        return jsii.get(self, "regexString")


class DataAwsWafv2RuleGroup(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2RuleGroup",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        name: str,
        scope: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param scope: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafv2RuleGroupConfig(
            name=name,
            scope=scope,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafv2RuleGroup, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2RuleGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "scope": "scope",
    },
)
class DataAwsWafv2RuleGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        scope: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param scope: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafv2RuleGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWafv2WebAcl(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2WebAcl",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        name: str,
        scope: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param scope: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWafv2WebAclConfig(
            name=name,
            scope=scope,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWafv2WebAcl, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWafv2WebAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "scope": "scope",
    },
)
class DataAwsWafv2WebAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        scope: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param scope: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWafv2WebAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWorkspacesBundle(
    cdktf.TerraformDataSource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWorkspacesBundle",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bundle_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        owner: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bundle_id: 
        :param name: 
        :param owner: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DataAwsWorkspacesBundleConfig(
            bundle_id=bundle_id,
            name=name,
            owner=owner,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DataAwsWorkspacesBundle, self, [scope, id, config])

    @jsii.member(jsii_name="computeType")
    def compute_type(self, index: str) -> "DataAwsWorkspacesBundleComputeType":
        """
        :param index: -
        """
        return jsii.invoke(self, "computeType", [index])

    @jsii.member(jsii_name="rootStorage")
    def root_storage(self, index: str) -> "DataAwsWorkspacesBundleRootStorage":
        """
        :param index: -
        """
        return jsii.invoke(self, "rootStorage", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="userStorage")
    def user_storage(self, index: str) -> "DataAwsWorkspacesBundleUserStorage":
        """
        :param index: -
        """
        return jsii.invoke(self, "userStorage", [index])

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> typing.Optional[str]:
        return jsii.get(self, "bundleId")

    @bundle_id.setter
    def bundle_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bundleId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="owner")
    def owner(self) -> typing.Optional[str]:
        return jsii.get(self, "owner")

    @owner.setter
    def owner(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "owner", value)


class DataAwsWorkspacesBundleComputeType(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWorkspacesBundleComputeType",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsWorkspacesBundleComputeType,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWorkspacesBundleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bundle_id": "bundleId",
        "name": "name",
        "owner": "owner",
    },
)
class DataAwsWorkspacesBundleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bundle_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        owner: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bundle_id: 
        :param name: 
        :param owner: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bundle_id is not None:
            self._values["bundle_id"] = bundle_id
        if name is not None:
            self._values["name"] = name
        if owner is not None:
            self._values["owner"] = owner

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bundle_id(self) -> typing.Optional[str]:
        return self._values.get("bundle_id")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def owner(self) -> typing.Optional[str]:
        return self._values.get("owner")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DataAwsWorkspacesBundleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DataAwsWorkspacesBundleRootStorage(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWorkspacesBundleRootStorage",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsWorkspacesBundleRootStorage,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> str:
        return jsii.get(self, "capacity")


class DataAwsWorkspacesBundleUserStorage(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DataAwsWorkspacesBundleUserStorage",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DataAwsWorkspacesBundleUserStorage,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> str:
        return jsii.get(self, "capacity")


class DatapipelinePipeline(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DatapipelinePipeline",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatapipelinePipelineConfig(
            name=name,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatapipelinePipeline, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatapipelinePipelineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "tags": "tags",
    },
)
class DatapipelinePipelineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatapipelinePipelineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatasyncAgent(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncAgent",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        activation_key: typing.Optional[str] = None,
        ip_address: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DatasyncAgentTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param activation_key: 
        :param ip_address: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatasyncAgentConfig(
            activation_key=activation_key,
            ip_address=ip_address,
            name=name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatasyncAgent, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="activationKey")
    def activation_key(self) -> typing.Optional[str]:
        return jsii.get(self, "activationKey")

    @activation_key.setter
    def activation_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "activationKey", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> typing.Optional[str]:
        return jsii.get(self, "ipAddress")

    @ip_address.setter
    def ip_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DatasyncAgentTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DatasyncAgentTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncAgentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "activation_key": "activationKey",
        "ip_address": "ipAddress",
        "name": "name",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DatasyncAgentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        activation_key: typing.Optional[str] = None,
        ip_address: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DatasyncAgentTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param activation_key: 
        :param ip_address: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DatasyncAgentTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if activation_key is not None:
            self._values["activation_key"] = activation_key
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def activation_key(self) -> typing.Optional[str]:
        return self._values.get("activation_key")

    @builtins.property
    def ip_address(self) -> typing.Optional[str]:
        return self._values.get("ip_address")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DatasyncAgentTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncAgentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncAgentTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class DatasyncAgentTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncAgentTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatasyncLocationEfs(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationEfs",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        ec2_config: typing.List["DatasyncLocationEfsEc2Config"],
        efs_file_system_arn: str,
        subdirectory: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ec2_config: ec2_config block.
        :param efs_file_system_arn: 
        :param subdirectory: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatasyncLocationEfsConfig(
            ec2_config=ec2_config,
            efs_file_system_arn=efs_file_system_arn,
            subdirectory=subdirectory,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatasyncLocationEfs, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="uri")
    def uri(self) -> str:
        return jsii.get(self, "uri")

    @builtins.property
    @jsii.member(jsii_name="ec2Config")
    def ec2_config(self) -> typing.List["DatasyncLocationEfsEc2Config"]:
        return jsii.get(self, "ec2Config")

    @ec2_config.setter
    def ec2_config(self, value: typing.List["DatasyncLocationEfsEc2Config"]) -> None:
        jsii.set(self, "ec2Config", value)

    @builtins.property
    @jsii.member(jsii_name="efsFileSystemArn")
    def efs_file_system_arn(self) -> str:
        return jsii.get(self, "efsFileSystemArn")

    @efs_file_system_arn.setter
    def efs_file_system_arn(self, value: str) -> None:
        jsii.set(self, "efsFileSystemArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="subdirectory")
    def subdirectory(self) -> typing.Optional[str]:
        return jsii.get(self, "subdirectory")

    @subdirectory.setter
    def subdirectory(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subdirectory", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationEfsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ec2_config": "ec2Config",
        "efs_file_system_arn": "efsFileSystemArn",
        "subdirectory": "subdirectory",
        "tags": "tags",
    },
)
class DatasyncLocationEfsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ec2_config: typing.List["DatasyncLocationEfsEc2Config"],
        efs_file_system_arn: str,
        subdirectory: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ec2_config: ec2_config block.
        :param efs_file_system_arn: 
        :param subdirectory: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "ec2_config": ec2_config,
            "efs_file_system_arn": efs_file_system_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if subdirectory is not None:
            self._values["subdirectory"] = subdirectory
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def ec2_config(self) -> typing.List["DatasyncLocationEfsEc2Config"]:
        """ec2_config block."""
        return self._values.get("ec2_config")

    @builtins.property
    def efs_file_system_arn(self) -> str:
        return self._values.get("efs_file_system_arn")

    @builtins.property
    def subdirectory(self) -> typing.Optional[str]:
        return self._values.get("subdirectory")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationEfsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationEfsEc2Config",
    jsii_struct_bases=[],
    name_mapping={
        "security_group_arns": "securityGroupArns",
        "subnet_arn": "subnetArn",
    },
)
class DatasyncLocationEfsEc2Config:
    def __init__(
        self, *, security_group_arns: typing.List[str], subnet_arn: str
    ) -> None:
        """
        :param security_group_arns: 
        :param subnet_arn: 
        """
        self._values = {
            "security_group_arns": security_group_arns,
            "subnet_arn": subnet_arn,
        }

    @builtins.property
    def security_group_arns(self) -> typing.List[str]:
        return self._values.get("security_group_arns")

    @builtins.property
    def subnet_arn(self) -> str:
        return self._values.get("subnet_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationEfsEc2Config(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatasyncLocationNfs(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationNfs",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        on_prem_config: typing.List["DatasyncLocationNfsOnPremConfig"],
        server_hostname: str,
        subdirectory: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param on_prem_config: on_prem_config block.
        :param server_hostname: 
        :param subdirectory: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatasyncLocationNfsConfig(
            on_prem_config=on_prem_config,
            server_hostname=server_hostname,
            subdirectory=subdirectory,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatasyncLocationNfs, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="uri")
    def uri(self) -> str:
        return jsii.get(self, "uri")

    @builtins.property
    @jsii.member(jsii_name="onPremConfig")
    def on_prem_config(self) -> typing.List["DatasyncLocationNfsOnPremConfig"]:
        return jsii.get(self, "onPremConfig")

    @on_prem_config.setter
    def on_prem_config(
        self, value: typing.List["DatasyncLocationNfsOnPremConfig"]
    ) -> None:
        jsii.set(self, "onPremConfig", value)

    @builtins.property
    @jsii.member(jsii_name="serverHostname")
    def server_hostname(self) -> str:
        return jsii.get(self, "serverHostname")

    @server_hostname.setter
    def server_hostname(self, value: str) -> None:
        jsii.set(self, "serverHostname", value)

    @builtins.property
    @jsii.member(jsii_name="subdirectory")
    def subdirectory(self) -> str:
        return jsii.get(self, "subdirectory")

    @subdirectory.setter
    def subdirectory(self, value: str) -> None:
        jsii.set(self, "subdirectory", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationNfsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "on_prem_config": "onPremConfig",
        "server_hostname": "serverHostname",
        "subdirectory": "subdirectory",
        "tags": "tags",
    },
)
class DatasyncLocationNfsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        on_prem_config: typing.List["DatasyncLocationNfsOnPremConfig"],
        server_hostname: str,
        subdirectory: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param on_prem_config: on_prem_config block.
        :param server_hostname: 
        :param subdirectory: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "on_prem_config": on_prem_config,
            "server_hostname": server_hostname,
            "subdirectory": subdirectory,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def on_prem_config(self) -> typing.List["DatasyncLocationNfsOnPremConfig"]:
        """on_prem_config block."""
        return self._values.get("on_prem_config")

    @builtins.property
    def server_hostname(self) -> str:
        return self._values.get("server_hostname")

    @builtins.property
    def subdirectory(self) -> str:
        return self._values.get("subdirectory")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationNfsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationNfsOnPremConfig",
    jsii_struct_bases=[],
    name_mapping={"agent_arns": "agentArns"},
)
class DatasyncLocationNfsOnPremConfig:
    def __init__(self, *, agent_arns: typing.List[str]) -> None:
        """
        :param agent_arns: 
        """
        self._values = {
            "agent_arns": agent_arns,
        }

    @builtins.property
    def agent_arns(self) -> typing.List[str]:
        return self._values.get("agent_arns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationNfsOnPremConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatasyncLocationS3(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationS3",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        s3_bucket_arn: str,
        s3_config: typing.List["DatasyncLocationS3S3Config"],
        subdirectory: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param s3_bucket_arn: 
        :param s3_config: s3_config block.
        :param subdirectory: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatasyncLocationS3Config(
            s3_bucket_arn=s3_bucket_arn,
            s3_config=s3_config,
            subdirectory=subdirectory,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatasyncLocationS3, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="uri")
    def uri(self) -> str:
        return jsii.get(self, "uri")

    @builtins.property
    @jsii.member(jsii_name="s3BucketArn")
    def s3_bucket_arn(self) -> str:
        return jsii.get(self, "s3BucketArn")

    @s3_bucket_arn.setter
    def s3_bucket_arn(self, value: str) -> None:
        jsii.set(self, "s3BucketArn", value)

    @builtins.property
    @jsii.member(jsii_name="s3Config")
    def s3_config(self) -> typing.List["DatasyncLocationS3S3Config"]:
        return jsii.get(self, "s3Config")

    @s3_config.setter
    def s3_config(self, value: typing.List["DatasyncLocationS3S3Config"]) -> None:
        jsii.set(self, "s3Config", value)

    @builtins.property
    @jsii.member(jsii_name="subdirectory")
    def subdirectory(self) -> str:
        return jsii.get(self, "subdirectory")

    @subdirectory.setter
    def subdirectory(self, value: str) -> None:
        jsii.set(self, "subdirectory", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationS3Config",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "s3_bucket_arn": "s3BucketArn",
        "s3_config": "s3Config",
        "subdirectory": "subdirectory",
        "tags": "tags",
    },
)
class DatasyncLocationS3Config(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        s3_bucket_arn: str,
        s3_config: typing.List["DatasyncLocationS3S3Config"],
        subdirectory: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param s3_bucket_arn: 
        :param s3_config: s3_config block.
        :param subdirectory: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "s3_bucket_arn": s3_bucket_arn,
            "s3_config": s3_config,
            "subdirectory": subdirectory,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def s3_bucket_arn(self) -> str:
        return self._values.get("s3_bucket_arn")

    @builtins.property
    def s3_config(self) -> typing.List["DatasyncLocationS3S3Config"]:
        """s3_config block."""
        return self._values.get("s3_config")

    @builtins.property
    def subdirectory(self) -> str:
        return self._values.get("subdirectory")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationS3Config(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationS3S3Config",
    jsii_struct_bases=[],
    name_mapping={"bucket_access_role_arn": "bucketAccessRoleArn"},
)
class DatasyncLocationS3S3Config:
    def __init__(self, *, bucket_access_role_arn: str) -> None:
        """
        :param bucket_access_role_arn: 
        """
        self._values = {
            "bucket_access_role_arn": bucket_access_role_arn,
        }

    @builtins.property
    def bucket_access_role_arn(self) -> str:
        return self._values.get("bucket_access_role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationS3S3Config(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatasyncLocationSmb(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationSmb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        agent_arns: typing.List[str],
        password: str,
        server_hostname: str,
        subdirectory: str,
        user: str,
        domain: typing.Optional[str] = None,
        mount_options: typing.Optional[
            typing.List["DatasyncLocationSmbMountOptions"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param agent_arns: 
        :param password: 
        :param server_hostname: 
        :param subdirectory: 
        :param user: 
        :param domain: 
        :param mount_options: mount_options block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatasyncLocationSmbConfig(
            agent_arns=agent_arns,
            password=password,
            server_hostname=server_hostname,
            subdirectory=subdirectory,
            user=user,
            domain=domain,
            mount_options=mount_options,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatasyncLocationSmb, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="uri")
    def uri(self) -> str:
        return jsii.get(self, "uri")

    @builtins.property
    @jsii.member(jsii_name="agentArns")
    def agent_arns(self) -> typing.List[str]:
        return jsii.get(self, "agentArns")

    @agent_arns.setter
    def agent_arns(self, value: typing.List[str]) -> None:
        jsii.set(self, "agentArns", value)

    @builtins.property
    @jsii.member(jsii_name="password")
    def password(self) -> str:
        return jsii.get(self, "password")

    @password.setter
    def password(self, value: str) -> None:
        jsii.set(self, "password", value)

    @builtins.property
    @jsii.member(jsii_name="serverHostname")
    def server_hostname(self) -> str:
        return jsii.get(self, "serverHostname")

    @server_hostname.setter
    def server_hostname(self, value: str) -> None:
        jsii.set(self, "serverHostname", value)

    @builtins.property
    @jsii.member(jsii_name="subdirectory")
    def subdirectory(self) -> str:
        return jsii.get(self, "subdirectory")

    @subdirectory.setter
    def subdirectory(self, value: str) -> None:
        jsii.set(self, "subdirectory", value)

    @builtins.property
    @jsii.member(jsii_name="user")
    def user(self) -> str:
        return jsii.get(self, "user")

    @user.setter
    def user(self, value: str) -> None:
        jsii.set(self, "user", value)

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> typing.Optional[str]:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mountOptions")
    def mount_options(
        self,
    ) -> typing.Optional[typing.List["DatasyncLocationSmbMountOptions"]]:
        return jsii.get(self, "mountOptions")

    @mount_options.setter
    def mount_options(
        self, value: typing.Optional[typing.List["DatasyncLocationSmbMountOptions"]]
    ) -> None:
        jsii.set(self, "mountOptions", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationSmbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "agent_arns": "agentArns",
        "password": "password",
        "server_hostname": "serverHostname",
        "subdirectory": "subdirectory",
        "user": "user",
        "domain": "domain",
        "mount_options": "mountOptions",
        "tags": "tags",
    },
)
class DatasyncLocationSmbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        agent_arns: typing.List[str],
        password: str,
        server_hostname: str,
        subdirectory: str,
        user: str,
        domain: typing.Optional[str] = None,
        mount_options: typing.Optional[
            typing.List["DatasyncLocationSmbMountOptions"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param agent_arns: 
        :param password: 
        :param server_hostname: 
        :param subdirectory: 
        :param user: 
        :param domain: 
        :param mount_options: mount_options block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "agent_arns": agent_arns,
            "password": password,
            "server_hostname": server_hostname,
            "subdirectory": subdirectory,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if domain is not None:
            self._values["domain"] = domain
        if mount_options is not None:
            self._values["mount_options"] = mount_options
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def agent_arns(self) -> typing.List[str]:
        return self._values.get("agent_arns")

    @builtins.property
    def password(self) -> str:
        return self._values.get("password")

    @builtins.property
    def server_hostname(self) -> str:
        return self._values.get("server_hostname")

    @builtins.property
    def subdirectory(self) -> str:
        return self._values.get("subdirectory")

    @builtins.property
    def user(self) -> str:
        return self._values.get("user")

    @builtins.property
    def domain(self) -> typing.Optional[str]:
        return self._values.get("domain")

    @builtins.property
    def mount_options(
        self,
    ) -> typing.Optional[typing.List["DatasyncLocationSmbMountOptions"]]:
        """mount_options block."""
        return self._values.get("mount_options")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationSmbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncLocationSmbMountOptions",
    jsii_struct_bases=[],
    name_mapping={"version": "version"},
)
class DatasyncLocationSmbMountOptions:
    def __init__(self, *, version: typing.Optional[str] = None) -> None:
        """
        :param version: 
        """
        self._values = {}
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncLocationSmbMountOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DatasyncTask(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncTask",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        destination_location_arn: str,
        source_location_arn: str,
        cloudwatch_log_group_arn: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        options: typing.Optional[typing.List["DatasyncTaskOptions"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DatasyncTaskTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination_location_arn: 
        :param source_location_arn: 
        :param cloudwatch_log_group_arn: 
        :param name: 
        :param options: options block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DatasyncTaskConfig(
            destination_location_arn=destination_location_arn,
            source_location_arn=source_location_arn,
            cloudwatch_log_group_arn=cloudwatch_log_group_arn,
            name=name,
            options=options,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DatasyncTask, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="destinationLocationArn")
    def destination_location_arn(self) -> str:
        return jsii.get(self, "destinationLocationArn")

    @destination_location_arn.setter
    def destination_location_arn(self, value: str) -> None:
        jsii.set(self, "destinationLocationArn", value)

    @builtins.property
    @jsii.member(jsii_name="sourceLocationArn")
    def source_location_arn(self) -> str:
        return jsii.get(self, "sourceLocationArn")

    @source_location_arn.setter
    def source_location_arn(self, value: str) -> None:
        jsii.set(self, "sourceLocationArn", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchLogGroupArn")
    def cloudwatch_log_group_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "cloudwatchLogGroupArn")

    @cloudwatch_log_group_arn.setter
    def cloudwatch_log_group_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cloudwatchLogGroupArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="options")
    def options(self) -> typing.Optional[typing.List["DatasyncTaskOptions"]]:
        return jsii.get(self, "options")

    @options.setter
    def options(
        self, value: typing.Optional[typing.List["DatasyncTaskOptions"]]
    ) -> None:
        jsii.set(self, "options", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DatasyncTaskTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DatasyncTaskTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncTaskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination_location_arn": "destinationLocationArn",
        "source_location_arn": "sourceLocationArn",
        "cloudwatch_log_group_arn": "cloudwatchLogGroupArn",
        "name": "name",
        "options": "options",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DatasyncTaskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination_location_arn: str,
        source_location_arn: str,
        cloudwatch_log_group_arn: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        options: typing.Optional[typing.List["DatasyncTaskOptions"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DatasyncTaskTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination_location_arn: 
        :param source_location_arn: 
        :param cloudwatch_log_group_arn: 
        :param name: 
        :param options: options block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DatasyncTaskTimeouts(**timeouts)
        self._values = {
            "destination_location_arn": destination_location_arn,
            "source_location_arn": source_location_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloudwatch_log_group_arn is not None:
            self._values["cloudwatch_log_group_arn"] = cloudwatch_log_group_arn
        if name is not None:
            self._values["name"] = name
        if options is not None:
            self._values["options"] = options
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def destination_location_arn(self) -> str:
        return self._values.get("destination_location_arn")

    @builtins.property
    def source_location_arn(self) -> str:
        return self._values.get("source_location_arn")

    @builtins.property
    def cloudwatch_log_group_arn(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_log_group_arn")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def options(self) -> typing.Optional[typing.List["DatasyncTaskOptions"]]:
        """options block."""
        return self._values.get("options")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DatasyncTaskTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncTaskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncTaskOptions",
    jsii_struct_bases=[],
    name_mapping={
        "atime": "atime",
        "bytes_per_second": "bytesPerSecond",
        "gid": "gid",
        "mtime": "mtime",
        "posix_permissions": "posixPermissions",
        "preserve_deleted_files": "preserveDeletedFiles",
        "preserve_devices": "preserveDevices",
        "uid": "uid",
        "verify_mode": "verifyMode",
    },
)
class DatasyncTaskOptions:
    def __init__(
        self,
        *,
        atime: typing.Optional[str] = None,
        bytes_per_second: typing.Optional[jsii.Number] = None,
        gid: typing.Optional[str] = None,
        mtime: typing.Optional[str] = None,
        posix_permissions: typing.Optional[str] = None,
        preserve_deleted_files: typing.Optional[str] = None,
        preserve_devices: typing.Optional[str] = None,
        uid: typing.Optional[str] = None,
        verify_mode: typing.Optional[str] = None,
    ) -> None:
        """
        :param atime: 
        :param bytes_per_second: 
        :param gid: 
        :param mtime: 
        :param posix_permissions: 
        :param preserve_deleted_files: 
        :param preserve_devices: 
        :param uid: 
        :param verify_mode: 
        """
        self._values = {}
        if atime is not None:
            self._values["atime"] = atime
        if bytes_per_second is not None:
            self._values["bytes_per_second"] = bytes_per_second
        if gid is not None:
            self._values["gid"] = gid
        if mtime is not None:
            self._values["mtime"] = mtime
        if posix_permissions is not None:
            self._values["posix_permissions"] = posix_permissions
        if preserve_deleted_files is not None:
            self._values["preserve_deleted_files"] = preserve_deleted_files
        if preserve_devices is not None:
            self._values["preserve_devices"] = preserve_devices
        if uid is not None:
            self._values["uid"] = uid
        if verify_mode is not None:
            self._values["verify_mode"] = verify_mode

    @builtins.property
    def atime(self) -> typing.Optional[str]:
        return self._values.get("atime")

    @builtins.property
    def bytes_per_second(self) -> typing.Optional[jsii.Number]:
        return self._values.get("bytes_per_second")

    @builtins.property
    def gid(self) -> typing.Optional[str]:
        return self._values.get("gid")

    @builtins.property
    def mtime(self) -> typing.Optional[str]:
        return self._values.get("mtime")

    @builtins.property
    def posix_permissions(self) -> typing.Optional[str]:
        return self._values.get("posix_permissions")

    @builtins.property
    def preserve_deleted_files(self) -> typing.Optional[str]:
        return self._values.get("preserve_deleted_files")

    @builtins.property
    def preserve_devices(self) -> typing.Optional[str]:
        return self._values.get("preserve_devices")

    @builtins.property
    def uid(self) -> typing.Optional[str]:
        return self._values.get("uid")

    @builtins.property
    def verify_mode(self) -> typing.Optional[str]:
        return self._values.get("verify_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncTaskOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DatasyncTaskTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class DatasyncTaskTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DatasyncTaskTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DaxCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DaxCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_name: str,
        iam_role_arn: str,
        node_type: str,
        replication_factor: jsii.Number,
        availability_zones: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        notification_topic_arn: typing.Optional[str] = None,
        parameter_group_name: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        server_side_encryption: typing.Optional[
            typing.List["DaxClusterServerSideEncryption"]
        ] = None,
        subnet_group_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DaxClusterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_name: 
        :param iam_role_arn: 
        :param node_type: 
        :param replication_factor: 
        :param availability_zones: 
        :param description: 
        :param maintenance_window: 
        :param notification_topic_arn: 
        :param parameter_group_name: 
        :param security_group_ids: 
        :param server_side_encryption: server_side_encryption block.
        :param subnet_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DaxClusterConfig(
            cluster_name=cluster_name,
            iam_role_arn=iam_role_arn,
            node_type=node_type,
            replication_factor=replication_factor,
            availability_zones=availability_zones,
            description=description,
            maintenance_window=maintenance_window,
            notification_topic_arn=notification_topic_arn,
            parameter_group_name=parameter_group_name,
            security_group_ids=security_group_ids,
            server_side_encryption=server_side_encryption,
            subnet_group_name=subnet_group_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DaxCluster, self, [scope, id, config])

    @jsii.member(jsii_name="nodes")
    def nodes(self, index: str) -> "DaxClusterNodes":
        """
        :param index: -
        """
        return jsii.invoke(self, "nodes", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="clusterAddress")
    def cluster_address(self) -> str:
        return jsii.get(self, "clusterAddress")

    @builtins.property
    @jsii.member(jsii_name="configurationEndpoint")
    def configuration_endpoint(self) -> str:
        return jsii.get(self, "configurationEndpoint")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter
    def cluster_name(self, value: str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property
    @jsii.member(jsii_name="iamRoleArn")
    def iam_role_arn(self) -> str:
        return jsii.get(self, "iamRoleArn")

    @iam_role_arn.setter
    def iam_role_arn(self, value: str) -> None:
        jsii.set(self, "iamRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> str:
        return jsii.get(self, "nodeType")

    @node_type.setter
    def node_type(self, value: str) -> None:
        jsii.set(self, "nodeType", value)

    @builtins.property
    @jsii.member(jsii_name="replicationFactor")
    def replication_factor(self) -> jsii.Number:
        return jsii.get(self, "replicationFactor")

    @replication_factor.setter
    def replication_factor(self, value: jsii.Number) -> None:
        jsii.set(self, "replicationFactor", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "maintenanceWindow")

    @maintenance_window.setter
    def maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="notificationTopicArn")
    def notification_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "notificationTopicArn")

    @notification_topic_arn.setter
    def notification_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "notificationTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="parameterGroupName")
    def parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "parameterGroupName")

    @parameter_group_name.setter
    def parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "parameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="serverSideEncryption")
    def server_side_encryption(
        self,
    ) -> typing.Optional[typing.List["DaxClusterServerSideEncryption"]]:
        return jsii.get(self, "serverSideEncryption")

    @server_side_encryption.setter
    def server_side_encryption(
        self, value: typing.Optional[typing.List["DaxClusterServerSideEncryption"]]
    ) -> None:
        jsii.set(self, "serverSideEncryption", value)

    @builtins.property
    @jsii.member(jsii_name="subnetGroupName")
    def subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetGroupName")

    @subnet_group_name.setter
    def subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DaxClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DaxClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DaxClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_name": "clusterName",
        "iam_role_arn": "iamRoleArn",
        "node_type": "nodeType",
        "replication_factor": "replicationFactor",
        "availability_zones": "availabilityZones",
        "description": "description",
        "maintenance_window": "maintenanceWindow",
        "notification_topic_arn": "notificationTopicArn",
        "parameter_group_name": "parameterGroupName",
        "security_group_ids": "securityGroupIds",
        "server_side_encryption": "serverSideEncryption",
        "subnet_group_name": "subnetGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DaxClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_name: str,
        iam_role_arn: str,
        node_type: str,
        replication_factor: jsii.Number,
        availability_zones: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        notification_topic_arn: typing.Optional[str] = None,
        parameter_group_name: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        server_side_encryption: typing.Optional[
            typing.List["DaxClusterServerSideEncryption"]
        ] = None,
        subnet_group_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DaxClusterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_name: 
        :param iam_role_arn: 
        :param node_type: 
        :param replication_factor: 
        :param availability_zones: 
        :param description: 
        :param maintenance_window: 
        :param notification_topic_arn: 
        :param parameter_group_name: 
        :param security_group_ids: 
        :param server_side_encryption: server_side_encryption block.
        :param subnet_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DaxClusterTimeouts(**timeouts)
        self._values = {
            "cluster_name": cluster_name,
            "iam_role_arn": iam_role_arn,
            "node_type": node_type,
            "replication_factor": replication_factor,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if description is not None:
            self._values["description"] = description
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if notification_topic_arn is not None:
            self._values["notification_topic_arn"] = notification_topic_arn
        if parameter_group_name is not None:
            self._values["parameter_group_name"] = parameter_group_name
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if server_side_encryption is not None:
            self._values["server_side_encryption"] = server_side_encryption
        if subnet_group_name is not None:
            self._values["subnet_group_name"] = subnet_group_name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_name(self) -> str:
        return self._values.get("cluster_name")

    @builtins.property
    def iam_role_arn(self) -> str:
        return self._values.get("iam_role_arn")

    @builtins.property
    def node_type(self) -> str:
        return self._values.get("node_type")

    @builtins.property
    def replication_factor(self) -> jsii.Number:
        return self._values.get("replication_factor")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("maintenance_window")

    @builtins.property
    def notification_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("notification_topic_arn")

    @builtins.property
    def parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("parameter_group_name")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def server_side_encryption(
        self,
    ) -> typing.Optional[typing.List["DaxClusterServerSideEncryption"]]:
        """server_side_encryption block."""
        return self._values.get("server_side_encryption")

    @builtins.property
    def subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("subnet_group_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DaxClusterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaxClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DaxClusterNodes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DaxClusterNodes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            DaxClusterNodes, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="address")
    def address(self) -> str:
        return jsii.get(self, "address")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DaxClusterServerSideEncryption",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class DaxClusterServerSideEncryption:
    def __init__(self, *, enabled: typing.Optional[bool] = None) -> None:
        """
        :param enabled: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaxClusterServerSideEncryption(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DaxClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DaxClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaxClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DaxParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DaxParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        parameters: typing.Optional[typing.List["DaxParameterGroupParameters"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param parameters: parameters block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DaxParameterGroupConfig(
            name=name,
            description=description,
            parameters=parameters,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DaxParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.List["DaxParameterGroupParameters"]]:
        return jsii.get(self, "parameters")

    @parameters.setter
    def parameters(
        self, value: typing.Optional[typing.List["DaxParameterGroupParameters"]]
    ) -> None:
        jsii.set(self, "parameters", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DaxParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "parameters": "parameters",
    },
)
class DaxParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        parameters: typing.Optional[typing.List["DaxParameterGroupParameters"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param parameters: parameters block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.List["DaxParameterGroupParameters"]]:
        """parameters block."""
        return self._values.get("parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaxParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DaxParameterGroupParameters",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class DaxParameterGroupParameters:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaxParameterGroupParameters(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DaxSubnetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DaxSubnetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param subnet_ids: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DaxSubnetGroupConfig(
            name=name,
            subnet_ids=subnet_ids,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DaxSubnetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DaxSubnetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "subnet_ids": "subnetIds",
        "description": "description",
    },
)
class DaxSubnetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param subnet_ids: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DaxSubnetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbClusterSnapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbClusterSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_cluster_identifier: str,
        db_cluster_snapshot_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbClusterSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbClusterSnapshotConfig(
            db_cluster_identifier=db_cluster_identifier,
            db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbClusterSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> jsii.Number:
        return jsii.get(self, "allocatedStorage")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotArn")
    def db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "dbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="licenseModel")
    def license_model(self) -> str:
        return jsii.get(self, "licenseModel")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="snapshotType")
    def snapshot_type(self) -> str:
        return jsii.get(self, "snapshotType")

    @builtins.property
    @jsii.member(jsii_name="sourceDbClusterSnapshotArn")
    def source_db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "sourceDbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="dbClusterIdentifier")
    def db_cluster_identifier(self) -> str:
        return jsii.get(self, "dbClusterIdentifier")

    @db_cluster_identifier.setter
    def db_cluster_identifier(self, value: str) -> None:
        jsii.set(self, "dbClusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotIdentifier")
    def db_cluster_snapshot_identifier(self) -> str:
        return jsii.get(self, "dbClusterSnapshotIdentifier")

    @db_cluster_snapshot_identifier.setter
    def db_cluster_snapshot_identifier(self, value: str) -> None:
        jsii.set(self, "dbClusterSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DbClusterSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DbClusterSnapshotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbClusterSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_cluster_identifier": "dbClusterIdentifier",
        "db_cluster_snapshot_identifier": "dbClusterSnapshotIdentifier",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DbClusterSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_cluster_identifier: str,
        db_cluster_snapshot_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbClusterSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DbClusterSnapshotTimeouts(**timeouts)
        self._values = {
            "db_cluster_identifier": db_cluster_identifier,
            "db_cluster_snapshot_identifier": db_cluster_snapshot_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_cluster_identifier(self) -> str:
        return self._values.get("db_cluster_identifier")

    @builtins.property
    def db_cluster_snapshot_identifier(self) -> str:
        return self._values.get("db_cluster_snapshot_identifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DbClusterSnapshotTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbClusterSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbClusterSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class DbClusterSnapshotTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbClusterSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbEventSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbEventSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        sns_topic: str,
        enabled: typing.Optional[bool] = None,
        event_categories: typing.Optional[typing.List[str]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbEventSubscriptionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param sns_topic: 
        :param enabled: 
        :param event_categories: 
        :param name: 
        :param name_prefix: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbEventSubscriptionConfig(
            sns_topic=sns_topic,
            enabled=enabled,
            event_categories=event_categories,
            name=name,
            name_prefix=name_prefix,
            source_ids=source_ids,
            source_type=source_type,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbEventSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="customerAwsId")
    def customer_aws_id(self) -> str:
        return jsii.get(self, "customerAwsId")

    @builtins.property
    @jsii.member(jsii_name="snsTopic")
    def sns_topic(self) -> str:
        return jsii.get(self, "snsTopic")

    @sns_topic.setter
    def sns_topic(self, value: str) -> None:
        jsii.set(self, "snsTopic", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="eventCategories")
    def event_categories(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "eventCategories")

    @event_categories.setter
    def event_categories(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "eventCategories", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="sourceIds")
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "sourceIds")

    @source_ids.setter
    def source_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "sourceIds", value)

    @builtins.property
    @jsii.member(jsii_name="sourceType")
    def source_type(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceType")

    @source_type.setter
    def source_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DbEventSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DbEventSubscriptionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbEventSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "sns_topic": "snsTopic",
        "enabled": "enabled",
        "event_categories": "eventCategories",
        "name": "name",
        "name_prefix": "namePrefix",
        "source_ids": "sourceIds",
        "source_type": "sourceType",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DbEventSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        sns_topic: str,
        enabled: typing.Optional[bool] = None,
        event_categories: typing.Optional[typing.List[str]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbEventSubscriptionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param sns_topic: 
        :param enabled: 
        :param event_categories: 
        :param name: 
        :param name_prefix: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DbEventSubscriptionTimeouts(**timeouts)
        self._values = {
            "sns_topic": sns_topic,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if event_categories is not None:
            self._values["event_categories"] = event_categories
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if source_ids is not None:
            self._values["source_ids"] = source_ids
        if source_type is not None:
            self._values["source_type"] = source_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def sns_topic(self) -> str:
        return self._values.get("sns_topic")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def event_categories(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("event_categories")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("source_ids")

    @builtins.property
    def source_type(self) -> typing.Optional[str]:
        return self._values.get("source_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DbEventSubscriptionTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbEventSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbEventSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DbEventSubscriptionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbEventSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        instance_class: str,
        allocated_storage: typing.Optional[jsii.Number] = None,
        allow_major_version_upgrade: typing.Optional[bool] = None,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        backup_window: typing.Optional[str] = None,
        ca_cert_identifier: typing.Optional[str] = None,
        character_set_name: typing.Optional[str] = None,
        copy_tags_to_snapshot: typing.Optional[bool] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        delete_automated_backups: typing.Optional[bool] = None,
        deletion_protection: typing.Optional[bool] = None,
        domain: typing.Optional[str] = None,
        domain_iam_role_name: typing.Optional[str] = None,
        enabled_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        iam_database_authentication_enabled: typing.Optional[bool] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        license_model: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        max_allocated_storage: typing.Optional[jsii.Number] = None,
        monitoring_interval: typing.Optional[jsii.Number] = None,
        monitoring_role_arn: typing.Optional[str] = None,
        multi_az: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        option_group_name: typing.Optional[str] = None,
        parameter_group_name: typing.Optional[str] = None,
        password: typing.Optional[str] = None,
        performance_insights_enabled: typing.Optional[bool] = None,
        performance_insights_kms_key_id: typing.Optional[str] = None,
        performance_insights_retention_period: typing.Optional[jsii.Number] = None,
        port: typing.Optional[jsii.Number] = None,
        publicly_accessible: typing.Optional[bool] = None,
        replicate_source_db: typing.Optional[str] = None,
        s3_import: typing.Optional[typing.List["DbInstanceS3Import"]] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        storage_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbInstanceTimeouts"] = None,
        timezone: typing.Optional[str] = None,
        username: typing.Optional[str] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param instance_class: 
        :param allocated_storage: 
        :param allow_major_version_upgrade: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param backup_retention_period: 
        :param backup_window: 
        :param ca_cert_identifier: 
        :param character_set_name: 
        :param copy_tags_to_snapshot: 
        :param db_subnet_group_name: 
        :param delete_automated_backups: 
        :param deletion_protection: 
        :param domain: 
        :param domain_iam_role_name: 
        :param enabled_cloudwatch_logs_exports: 
        :param engine: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param iam_database_authentication_enabled: 
        :param identifier: 
        :param identifier_prefix: 
        :param iops: 
        :param kms_key_id: 
        :param license_model: 
        :param maintenance_window: 
        :param max_allocated_storage: 
        :param monitoring_interval: 
        :param monitoring_role_arn: 
        :param multi_az: 
        :param name: 
        :param option_group_name: 
        :param parameter_group_name: 
        :param password: 
        :param performance_insights_enabled: 
        :param performance_insights_kms_key_id: 
        :param performance_insights_retention_period: 
        :param port: 
        :param publicly_accessible: 
        :param replicate_source_db: 
        :param s3_import: s3_import block.
        :param security_group_names: 
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param storage_encrypted: 
        :param storage_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param username: 
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbInstanceConfig(
            instance_class=instance_class,
            allocated_storage=allocated_storage,
            allow_major_version_upgrade=allow_major_version_upgrade,
            apply_immediately=apply_immediately,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
            availability_zone=availability_zone,
            backup_retention_period=backup_retention_period,
            backup_window=backup_window,
            ca_cert_identifier=ca_cert_identifier,
            character_set_name=character_set_name,
            copy_tags_to_snapshot=copy_tags_to_snapshot,
            db_subnet_group_name=db_subnet_group_name,
            delete_automated_backups=delete_automated_backups,
            deletion_protection=deletion_protection,
            domain=domain,
            domain_iam_role_name=domain_iam_role_name,
            enabled_cloudwatch_logs_exports=enabled_cloudwatch_logs_exports,
            engine=engine,
            engine_version=engine_version,
            final_snapshot_identifier=final_snapshot_identifier,
            iam_database_authentication_enabled=iam_database_authentication_enabled,
            identifier=identifier,
            identifier_prefix=identifier_prefix,
            iops=iops,
            kms_key_id=kms_key_id,
            license_model=license_model,
            maintenance_window=maintenance_window,
            max_allocated_storage=max_allocated_storage,
            monitoring_interval=monitoring_interval,
            monitoring_role_arn=monitoring_role_arn,
            multi_az=multi_az,
            name=name,
            option_group_name=option_group_name,
            parameter_group_name=parameter_group_name,
            password=password,
            performance_insights_enabled=performance_insights_enabled,
            performance_insights_kms_key_id=performance_insights_kms_key_id,
            performance_insights_retention_period=performance_insights_retention_period,
            port=port,
            publicly_accessible=publicly_accessible,
            replicate_source_db=replicate_source_db,
            s3_import=s3_import,
            security_group_names=security_group_names,
            skip_final_snapshot=skip_final_snapshot,
            snapshot_identifier=snapshot_identifier,
            storage_encrypted=storage_encrypted,
            storage_type=storage_type,
            tags=tags,
            timeouts=timeouts,
            timezone=timezone,
            username=username,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="address")
    def address(self) -> str:
        return jsii.get(self, "address")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="replicas")
    def replicas(self) -> typing.List[str]:
        return jsii.get(self, "replicas")

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="instanceClass")
    def instance_class(self) -> str:
        return jsii.get(self, "instanceClass")

    @instance_class.setter
    def instance_class(self, value: str) -> None:
        jsii.set(self, "instanceClass", value)

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "allocatedStorage")

    @allocated_storage.setter
    def allocated_storage(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "allocatedStorage", value)

    @builtins.property
    @jsii.member(jsii_name="allowMajorVersionUpgrade")
    def allow_major_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowMajorVersionUpgrade")

    @allow_major_version_upgrade.setter
    def allow_major_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowMajorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoMinorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="backupRetentionPeriod")
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "backupRetentionPeriod")

    @backup_retention_period.setter
    def backup_retention_period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "backupRetentionPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="backupWindow")
    def backup_window(self) -> typing.Optional[str]:
        return jsii.get(self, "backupWindow")

    @backup_window.setter
    def backup_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "backupWindow", value)

    @builtins.property
    @jsii.member(jsii_name="caCertIdentifier")
    def ca_cert_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "caCertIdentifier")

    @ca_cert_identifier.setter
    def ca_cert_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "caCertIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="characterSetName")
    def character_set_name(self) -> typing.Optional[str]:
        return jsii.get(self, "characterSetName")

    @character_set_name.setter
    def character_set_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "characterSetName", value)

    @builtins.property
    @jsii.member(jsii_name="copyTagsToSnapshot")
    def copy_tags_to_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "copyTagsToSnapshot")

    @copy_tags_to_snapshot.setter
    def copy_tags_to_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "copyTagsToSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="dbSubnetGroupName")
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dbSubnetGroupName")

    @db_subnet_group_name.setter
    def db_subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbSubnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="deleteAutomatedBackups")
    def delete_automated_backups(self) -> typing.Optional[bool]:
        return jsii.get(self, "deleteAutomatedBackups")

    @delete_automated_backups.setter
    def delete_automated_backups(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deleteAutomatedBackups", value)

    @builtins.property
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "deletionProtection")

    @deletion_protection.setter
    def deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> typing.Optional[str]:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="domainIamRoleName")
    def domain_iam_role_name(self) -> typing.Optional[str]:
        return jsii.get(self, "domainIamRoleName")

    @domain_iam_role_name.setter
    def domain_iam_role_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "domainIamRoleName", value)

    @builtins.property
    @jsii.member(jsii_name="enabledCloudwatchLogsExports")
    def enabled_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "enabledCloudwatchLogsExports")

    @enabled_cloudwatch_logs_exports.setter
    def enabled_cloudwatch_logs_exports(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "enabledCloudwatchLogsExports", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="finalSnapshotIdentifier")
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "finalSnapshotIdentifier")

    @final_snapshot_identifier.setter
    def final_snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "finalSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="iamDatabaseAuthenticationEnabled")
    def iam_database_authentication_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "iamDatabaseAuthenticationEnabled")

    @iam_database_authentication_enabled.setter
    def iam_database_authentication_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "iamDatabaseAuthenticationEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property
    @jsii.member(jsii_name="identifierPrefix")
    def identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "identifierPrefix")

    @identifier_prefix.setter
    def identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "iops")

    @iops.setter
    def iops(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "iops", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="licenseModel")
    def license_model(self) -> typing.Optional[str]:
        return jsii.get(self, "licenseModel")

    @license_model.setter
    def license_model(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "licenseModel", value)

    @builtins.property
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "maintenanceWindow")

    @maintenance_window.setter
    def maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="maxAllocatedStorage")
    def max_allocated_storage(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxAllocatedStorage")

    @max_allocated_storage.setter
    def max_allocated_storage(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxAllocatedStorage", value)

    @builtins.property
    @jsii.member(jsii_name="monitoringInterval")
    def monitoring_interval(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "monitoringInterval")

    @monitoring_interval.setter
    def monitoring_interval(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "monitoringInterval", value)

    @builtins.property
    @jsii.member(jsii_name="monitoringRoleArn")
    def monitoring_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "monitoringRoleArn")

    @monitoring_role_arn.setter
    def monitoring_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "monitoringRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="multiAz")
    def multi_az(self) -> typing.Optional[bool]:
        return jsii.get(self, "multiAz")

    @multi_az.setter
    def multi_az(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "multiAz", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="optionGroupName")
    def option_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "optionGroupName")

    @option_group_name.setter
    def option_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "optionGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="parameterGroupName")
    def parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "parameterGroupName")

    @parameter_group_name.setter
    def parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "parameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="password")
    def password(self) -> typing.Optional[str]:
        return jsii.get(self, "password")

    @password.setter
    def password(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "password", value)

    @builtins.property
    @jsii.member(jsii_name="performanceInsightsEnabled")
    def performance_insights_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "performanceInsightsEnabled")

    @performance_insights_enabled.setter
    def performance_insights_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "performanceInsightsEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="performanceInsightsKmsKeyId")
    def performance_insights_kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "performanceInsightsKmsKeyId")

    @performance_insights_kms_key_id.setter
    def performance_insights_kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "performanceInsightsKmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="performanceInsightsRetentionPeriod")
    def performance_insights_retention_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "performanceInsightsRetentionPeriod")

    @performance_insights_retention_period.setter
    def performance_insights_retention_period(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "performanceInsightsRetentionPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> typing.Optional[bool]:
        return jsii.get(self, "publiclyAccessible")

    @publicly_accessible.setter
    def publicly_accessible(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "publiclyAccessible", value)

    @builtins.property
    @jsii.member(jsii_name="replicateSourceDb")
    def replicate_source_db(self) -> typing.Optional[str]:
        return jsii.get(self, "replicateSourceDb")

    @replicate_source_db.setter
    def replicate_source_db(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "replicateSourceDb", value)

    @builtins.property
    @jsii.member(jsii_name="s3Import")
    def s3_import(self) -> typing.Optional[typing.List["DbInstanceS3Import"]]:
        return jsii.get(self, "s3Import")

    @s3_import.setter
    def s3_import(
        self, value: typing.Optional[typing.List["DbInstanceS3Import"]]
    ) -> None:
        jsii.set(self, "s3Import", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupNames")
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupNames")

    @security_group_names.setter
    def security_group_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupNames", value)

    @builtins.property
    @jsii.member(jsii_name="skipFinalSnapshot")
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipFinalSnapshot")

    @skip_final_snapshot.setter
    def skip_final_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipFinalSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotIdentifier")
    def snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotIdentifier")

    @snapshot_identifier.setter
    def snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "storageEncrypted")

    @storage_encrypted.setter
    def storage_encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "storageEncrypted", value)

    @builtins.property
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> typing.Optional[str]:
        return jsii.get(self, "storageType")

    @storage_type.setter
    def storage_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "storageType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DbInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DbInstanceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="timezone")
    def timezone(self) -> typing.Optional[str]:
        return jsii.get(self, "timezone")

    @timezone.setter
    def timezone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "timezone", value)

    @builtins.property
    @jsii.member(jsii_name="username")
    def username(self) -> typing.Optional[str]:
        return jsii.get(self, "username")

    @username.setter
    def username(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "username", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "instance_class": "instanceClass",
        "allocated_storage": "allocatedStorage",
        "allow_major_version_upgrade": "allowMajorVersionUpgrade",
        "apply_immediately": "applyImmediately",
        "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
        "availability_zone": "availabilityZone",
        "backup_retention_period": "backupRetentionPeriod",
        "backup_window": "backupWindow",
        "ca_cert_identifier": "caCertIdentifier",
        "character_set_name": "characterSetName",
        "copy_tags_to_snapshot": "copyTagsToSnapshot",
        "db_subnet_group_name": "dbSubnetGroupName",
        "delete_automated_backups": "deleteAutomatedBackups",
        "deletion_protection": "deletionProtection",
        "domain": "domain",
        "domain_iam_role_name": "domainIamRoleName",
        "enabled_cloudwatch_logs_exports": "enabledCloudwatchLogsExports",
        "engine": "engine",
        "engine_version": "engineVersion",
        "final_snapshot_identifier": "finalSnapshotIdentifier",
        "iam_database_authentication_enabled": "iamDatabaseAuthenticationEnabled",
        "identifier": "identifier",
        "identifier_prefix": "identifierPrefix",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "license_model": "licenseModel",
        "maintenance_window": "maintenanceWindow",
        "max_allocated_storage": "maxAllocatedStorage",
        "monitoring_interval": "monitoringInterval",
        "monitoring_role_arn": "monitoringRoleArn",
        "multi_az": "multiAz",
        "name": "name",
        "option_group_name": "optionGroupName",
        "parameter_group_name": "parameterGroupName",
        "password": "password",
        "performance_insights_enabled": "performanceInsightsEnabled",
        "performance_insights_kms_key_id": "performanceInsightsKmsKeyId",
        "performance_insights_retention_period": "performanceInsightsRetentionPeriod",
        "port": "port",
        "publicly_accessible": "publiclyAccessible",
        "replicate_source_db": "replicateSourceDb",
        "s3_import": "s3Import",
        "security_group_names": "securityGroupNames",
        "skip_final_snapshot": "skipFinalSnapshot",
        "snapshot_identifier": "snapshotIdentifier",
        "storage_encrypted": "storageEncrypted",
        "storage_type": "storageType",
        "tags": "tags",
        "timeouts": "timeouts",
        "timezone": "timezone",
        "username": "username",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class DbInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        instance_class: str,
        allocated_storage: typing.Optional[jsii.Number] = None,
        allow_major_version_upgrade: typing.Optional[bool] = None,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        backup_window: typing.Optional[str] = None,
        ca_cert_identifier: typing.Optional[str] = None,
        character_set_name: typing.Optional[str] = None,
        copy_tags_to_snapshot: typing.Optional[bool] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        delete_automated_backups: typing.Optional[bool] = None,
        deletion_protection: typing.Optional[bool] = None,
        domain: typing.Optional[str] = None,
        domain_iam_role_name: typing.Optional[str] = None,
        enabled_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        iam_database_authentication_enabled: typing.Optional[bool] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        license_model: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        max_allocated_storage: typing.Optional[jsii.Number] = None,
        monitoring_interval: typing.Optional[jsii.Number] = None,
        monitoring_role_arn: typing.Optional[str] = None,
        multi_az: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        option_group_name: typing.Optional[str] = None,
        parameter_group_name: typing.Optional[str] = None,
        password: typing.Optional[str] = None,
        performance_insights_enabled: typing.Optional[bool] = None,
        performance_insights_kms_key_id: typing.Optional[str] = None,
        performance_insights_retention_period: typing.Optional[jsii.Number] = None,
        port: typing.Optional[jsii.Number] = None,
        publicly_accessible: typing.Optional[bool] = None,
        replicate_source_db: typing.Optional[str] = None,
        s3_import: typing.Optional[typing.List["DbInstanceS3Import"]] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        storage_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbInstanceTimeouts"] = None,
        timezone: typing.Optional[str] = None,
        username: typing.Optional[str] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param instance_class: 
        :param allocated_storage: 
        :param allow_major_version_upgrade: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param backup_retention_period: 
        :param backup_window: 
        :param ca_cert_identifier: 
        :param character_set_name: 
        :param copy_tags_to_snapshot: 
        :param db_subnet_group_name: 
        :param delete_automated_backups: 
        :param deletion_protection: 
        :param domain: 
        :param domain_iam_role_name: 
        :param enabled_cloudwatch_logs_exports: 
        :param engine: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param iam_database_authentication_enabled: 
        :param identifier: 
        :param identifier_prefix: 
        :param iops: 
        :param kms_key_id: 
        :param license_model: 
        :param maintenance_window: 
        :param max_allocated_storage: 
        :param monitoring_interval: 
        :param monitoring_role_arn: 
        :param multi_az: 
        :param name: 
        :param option_group_name: 
        :param parameter_group_name: 
        :param password: 
        :param performance_insights_enabled: 
        :param performance_insights_kms_key_id: 
        :param performance_insights_retention_period: 
        :param port: 
        :param publicly_accessible: 
        :param replicate_source_db: 
        :param s3_import: s3_import block.
        :param security_group_names: 
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param storage_encrypted: 
        :param storage_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param timezone: 
        :param username: 
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DbInstanceTimeouts(**timeouts)
        self._values = {
            "instance_class": instance_class,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocated_storage is not None:
            self._values["allocated_storage"] = allocated_storage
        if allow_major_version_upgrade is not None:
            self._values["allow_major_version_upgrade"] = allow_major_version_upgrade
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if auto_minor_version_upgrade is not None:
            self._values["auto_minor_version_upgrade"] = auto_minor_version_upgrade
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if backup_retention_period is not None:
            self._values["backup_retention_period"] = backup_retention_period
        if backup_window is not None:
            self._values["backup_window"] = backup_window
        if ca_cert_identifier is not None:
            self._values["ca_cert_identifier"] = ca_cert_identifier
        if character_set_name is not None:
            self._values["character_set_name"] = character_set_name
        if copy_tags_to_snapshot is not None:
            self._values["copy_tags_to_snapshot"] = copy_tags_to_snapshot
        if db_subnet_group_name is not None:
            self._values["db_subnet_group_name"] = db_subnet_group_name
        if delete_automated_backups is not None:
            self._values["delete_automated_backups"] = delete_automated_backups
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if domain is not None:
            self._values["domain"] = domain
        if domain_iam_role_name is not None:
            self._values["domain_iam_role_name"] = domain_iam_role_name
        if enabled_cloudwatch_logs_exports is not None:
            self._values[
                "enabled_cloudwatch_logs_exports"
            ] = enabled_cloudwatch_logs_exports
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if final_snapshot_identifier is not None:
            self._values["final_snapshot_identifier"] = final_snapshot_identifier
        if iam_database_authentication_enabled is not None:
            self._values[
                "iam_database_authentication_enabled"
            ] = iam_database_authentication_enabled
        if identifier is not None:
            self._values["identifier"] = identifier
        if identifier_prefix is not None:
            self._values["identifier_prefix"] = identifier_prefix
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if license_model is not None:
            self._values["license_model"] = license_model
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if max_allocated_storage is not None:
            self._values["max_allocated_storage"] = max_allocated_storage
        if monitoring_interval is not None:
            self._values["monitoring_interval"] = monitoring_interval
        if monitoring_role_arn is not None:
            self._values["monitoring_role_arn"] = monitoring_role_arn
        if multi_az is not None:
            self._values["multi_az"] = multi_az
        if name is not None:
            self._values["name"] = name
        if option_group_name is not None:
            self._values["option_group_name"] = option_group_name
        if parameter_group_name is not None:
            self._values["parameter_group_name"] = parameter_group_name
        if password is not None:
            self._values["password"] = password
        if performance_insights_enabled is not None:
            self._values["performance_insights_enabled"] = performance_insights_enabled
        if performance_insights_kms_key_id is not None:
            self._values[
                "performance_insights_kms_key_id"
            ] = performance_insights_kms_key_id
        if performance_insights_retention_period is not None:
            self._values[
                "performance_insights_retention_period"
            ] = performance_insights_retention_period
        if port is not None:
            self._values["port"] = port
        if publicly_accessible is not None:
            self._values["publicly_accessible"] = publicly_accessible
        if replicate_source_db is not None:
            self._values["replicate_source_db"] = replicate_source_db
        if s3_import is not None:
            self._values["s3_import"] = s3_import
        if security_group_names is not None:
            self._values["security_group_names"] = security_group_names
        if skip_final_snapshot is not None:
            self._values["skip_final_snapshot"] = skip_final_snapshot
        if snapshot_identifier is not None:
            self._values["snapshot_identifier"] = snapshot_identifier
        if storage_encrypted is not None:
            self._values["storage_encrypted"] = storage_encrypted
        if storage_type is not None:
            self._values["storage_type"] = storage_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if timezone is not None:
            self._values["timezone"] = timezone
        if username is not None:
            self._values["username"] = username
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def instance_class(self) -> str:
        return self._values.get("instance_class")

    @builtins.property
    def allocated_storage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("allocated_storage")

    @builtins.property
    def allow_major_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("allow_major_version_upgrade")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("auto_minor_version_upgrade")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("backup_retention_period")

    @builtins.property
    def backup_window(self) -> typing.Optional[str]:
        return self._values.get("backup_window")

    @builtins.property
    def ca_cert_identifier(self) -> typing.Optional[str]:
        return self._values.get("ca_cert_identifier")

    @builtins.property
    def character_set_name(self) -> typing.Optional[str]:
        return self._values.get("character_set_name")

    @builtins.property
    def copy_tags_to_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("copy_tags_to_snapshot")

    @builtins.property
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("db_subnet_group_name")

    @builtins.property
    def delete_automated_backups(self) -> typing.Optional[bool]:
        return self._values.get("delete_automated_backups")

    @builtins.property
    def deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("deletion_protection")

    @builtins.property
    def domain(self) -> typing.Optional[str]:
        return self._values.get("domain")

    @builtins.property
    def domain_iam_role_name(self) -> typing.Optional[str]:
        return self._values.get("domain_iam_role_name")

    @builtins.property
    def enabled_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("enabled_cloudwatch_logs_exports")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("final_snapshot_identifier")

    @builtins.property
    def iam_database_authentication_enabled(self) -> typing.Optional[bool]:
        return self._values.get("iam_database_authentication_enabled")

    @builtins.property
    def identifier(self) -> typing.Optional[str]:
        return self._values.get("identifier")

    @builtins.property
    def identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("identifier_prefix")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def license_model(self) -> typing.Optional[str]:
        return self._values.get("license_model")

    @builtins.property
    def maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("maintenance_window")

    @builtins.property
    def max_allocated_storage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_allocated_storage")

    @builtins.property
    def monitoring_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("monitoring_interval")

    @builtins.property
    def monitoring_role_arn(self) -> typing.Optional[str]:
        return self._values.get("monitoring_role_arn")

    @builtins.property
    def multi_az(self) -> typing.Optional[bool]:
        return self._values.get("multi_az")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def option_group_name(self) -> typing.Optional[str]:
        return self._values.get("option_group_name")

    @builtins.property
    def parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("parameter_group_name")

    @builtins.property
    def password(self) -> typing.Optional[str]:
        return self._values.get("password")

    @builtins.property
    def performance_insights_enabled(self) -> typing.Optional[bool]:
        return self._values.get("performance_insights_enabled")

    @builtins.property
    def performance_insights_kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("performance_insights_kms_key_id")

    @builtins.property
    def performance_insights_retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("performance_insights_retention_period")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def publicly_accessible(self) -> typing.Optional[bool]:
        return self._values.get("publicly_accessible")

    @builtins.property
    def replicate_source_db(self) -> typing.Optional[str]:
        return self._values.get("replicate_source_db")

    @builtins.property
    def s3_import(self) -> typing.Optional[typing.List["DbInstanceS3Import"]]:
        """s3_import block."""
        return self._values.get("s3_import")

    @builtins.property
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_names")

    @builtins.property
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("skip_final_snapshot")

    @builtins.property
    def snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("snapshot_identifier")

    @builtins.property
    def storage_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("storage_encrypted")

    @builtins.property
    def storage_type(self) -> typing.Optional[str]:
        return self._values.get("storage_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DbInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def timezone(self) -> typing.Optional[str]:
        return self._values.get("timezone")

    @builtins.property
    def username(self) -> typing.Optional[str]:
        return self._values.get("username")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbInstanceRoleAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbInstanceRoleAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_instance_identifier: str,
        feature_name: str,
        role_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_instance_identifier: 
        :param feature_name: 
        :param role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbInstanceRoleAssociationConfig(
            db_instance_identifier=db_instance_identifier,
            feature_name=feature_name,
            role_arn=role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbInstanceRoleAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dbInstanceIdentifier")
    def db_instance_identifier(self) -> str:
        return jsii.get(self, "dbInstanceIdentifier")

    @db_instance_identifier.setter
    def db_instance_identifier(self, value: str) -> None:
        jsii.set(self, "dbInstanceIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="featureName")
    def feature_name(self) -> str:
        return jsii.get(self, "featureName")

    @feature_name.setter
    def feature_name(self, value: str) -> None:
        jsii.set(self, "featureName", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbInstanceRoleAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_instance_identifier": "dbInstanceIdentifier",
        "feature_name": "featureName",
        "role_arn": "roleArn",
    },
)
class DbInstanceRoleAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_instance_identifier: str,
        feature_name: str,
        role_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_instance_identifier: 
        :param feature_name: 
        :param role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "db_instance_identifier": db_instance_identifier,
            "feature_name": feature_name,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_instance_identifier(self) -> str:
        return self._values.get("db_instance_identifier")

    @builtins.property
    def feature_name(self) -> str:
        return self._values.get("feature_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbInstanceRoleAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbInstanceS3Import",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_name": "bucketName",
        "ingestion_role": "ingestionRole",
        "source_engine": "sourceEngine",
        "source_engine_version": "sourceEngineVersion",
        "bucket_prefix": "bucketPrefix",
    },
)
class DbInstanceS3Import:
    def __init__(
        self,
        *,
        bucket_name: str,
        ingestion_role: str,
        source_engine: str,
        source_engine_version: str,
        bucket_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_name: 
        :param ingestion_role: 
        :param source_engine: 
        :param source_engine_version: 
        :param bucket_prefix: 
        """
        self._values = {
            "bucket_name": bucket_name,
            "ingestion_role": ingestion_role,
            "source_engine": source_engine,
            "source_engine_version": source_engine_version,
        }
        if bucket_prefix is not None:
            self._values["bucket_prefix"] = bucket_prefix

    @builtins.property
    def bucket_name(self) -> str:
        return self._values.get("bucket_name")

    @builtins.property
    def ingestion_role(self) -> str:
        return self._values.get("ingestion_role")

    @builtins.property
    def source_engine(self) -> str:
        return self._values.get("source_engine")

    @builtins.property
    def source_engine_version(self) -> str:
        return self._values.get("source_engine_version")

    @builtins.property
    def bucket_prefix(self) -> typing.Optional[str]:
        return self._values.get("bucket_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbInstanceS3Import(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DbInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbOptionGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbOptionGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        engine_name: str,
        major_engine_version: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        option: typing.Optional[typing.List["DbOptionGroupOption"]] = None,
        option_group_description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbOptionGroupTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param engine_name: 
        :param major_engine_version: 
        :param name: 
        :param name_prefix: 
        :param option: option block.
        :param option_group_description: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbOptionGroupConfig(
            engine_name=engine_name,
            major_engine_version=major_engine_version,
            name=name,
            name_prefix=name_prefix,
            option=option,
            option_group_description=option_group_description,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbOptionGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="engineName")
    def engine_name(self) -> str:
        return jsii.get(self, "engineName")

    @engine_name.setter
    def engine_name(self, value: str) -> None:
        jsii.set(self, "engineName", value)

    @builtins.property
    @jsii.member(jsii_name="majorEngineVersion")
    def major_engine_version(self) -> str:
        return jsii.get(self, "majorEngineVersion")

    @major_engine_version.setter
    def major_engine_version(self, value: str) -> None:
        jsii.set(self, "majorEngineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="option")
    def option(self) -> typing.Optional[typing.List["DbOptionGroupOption"]]:
        return jsii.get(self, "option")

    @option.setter
    def option(
        self, value: typing.Optional[typing.List["DbOptionGroupOption"]]
    ) -> None:
        jsii.set(self, "option", value)

    @builtins.property
    @jsii.member(jsii_name="optionGroupDescription")
    def option_group_description(self) -> typing.Optional[str]:
        return jsii.get(self, "optionGroupDescription")

    @option_group_description.setter
    def option_group_description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "optionGroupDescription", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DbOptionGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DbOptionGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbOptionGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "engine_name": "engineName",
        "major_engine_version": "majorEngineVersion",
        "name": "name",
        "name_prefix": "namePrefix",
        "option": "option",
        "option_group_description": "optionGroupDescription",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DbOptionGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        engine_name: str,
        major_engine_version: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        option: typing.Optional[typing.List["DbOptionGroupOption"]] = None,
        option_group_description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbOptionGroupTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param engine_name: 
        :param major_engine_version: 
        :param name: 
        :param name_prefix: 
        :param option: option block.
        :param option_group_description: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DbOptionGroupTimeouts(**timeouts)
        self._values = {
            "engine_name": engine_name,
            "major_engine_version": major_engine_version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if option is not None:
            self._values["option"] = option
        if option_group_description is not None:
            self._values["option_group_description"] = option_group_description
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def engine_name(self) -> str:
        return self._values.get("engine_name")

    @builtins.property
    def major_engine_version(self) -> str:
        return self._values.get("major_engine_version")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def option(self) -> typing.Optional[typing.List["DbOptionGroupOption"]]:
        """option block."""
        return self._values.get("option")

    @builtins.property
    def option_group_description(self) -> typing.Optional[str]:
        return self._values.get("option_group_description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DbOptionGroupTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbOptionGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbOptionGroupOption",
    jsii_struct_bases=[],
    name_mapping={
        "option_name": "optionName",
        "db_security_group_memberships": "dbSecurityGroupMemberships",
        "option_settings": "optionSettings",
        "port": "port",
        "version": "version",
        "vpc_security_group_memberships": "vpcSecurityGroupMemberships",
    },
)
class DbOptionGroupOption:
    def __init__(
        self,
        *,
        option_name: str,
        db_security_group_memberships: typing.Optional[typing.List[str]] = None,
        option_settings: typing.Optional[
            typing.List["DbOptionGroupOptionOptionSettings"]
        ] = None,
        port: typing.Optional[jsii.Number] = None,
        version: typing.Optional[str] = None,
        vpc_security_group_memberships: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param option_name: 
        :param db_security_group_memberships: 
        :param option_settings: option_settings block.
        :param port: 
        :param version: 
        :param vpc_security_group_memberships: 
        """
        self._values = {
            "option_name": option_name,
        }
        if db_security_group_memberships is not None:
            self._values[
                "db_security_group_memberships"
            ] = db_security_group_memberships
        if option_settings is not None:
            self._values["option_settings"] = option_settings
        if port is not None:
            self._values["port"] = port
        if version is not None:
            self._values["version"] = version
        if vpc_security_group_memberships is not None:
            self._values[
                "vpc_security_group_memberships"
            ] = vpc_security_group_memberships

    @builtins.property
    def option_name(self) -> str:
        return self._values.get("option_name")

    @builtins.property
    def db_security_group_memberships(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("db_security_group_memberships")

    @builtins.property
    def option_settings(
        self,
    ) -> typing.Optional[typing.List["DbOptionGroupOptionOptionSettings"]]:
        """option_settings block."""
        return self._values.get("option_settings")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    @builtins.property
    def vpc_security_group_memberships(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_memberships")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbOptionGroupOption(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbOptionGroupOptionOptionSettings",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class DbOptionGroupOptionOptionSettings:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbOptionGroupOptionOptionSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbOptionGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"delete": "delete"},
)
class DbOptionGroupTimeouts:
    def __init__(self, *, delete: typing.Optional[str] = None) -> None:
        """
        :param delete: 
        """
        self._values = {}
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbOptionGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[typing.List["DbParameterGroupParameter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbParameterGroupConfig(
            family=family,
            description=description,
            name=name,
            name_prefix=name_prefix,
            parameter=parameter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="parameter")
    def parameter(self) -> typing.Optional[typing.List["DbParameterGroupParameter"]]:
        return jsii.get(self, "parameter")

    @parameter.setter
    def parameter(
        self, value: typing.Optional[typing.List["DbParameterGroupParameter"]]
    ) -> None:
        jsii.set(self, "parameter", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "parameter": "parameter",
        "tags": "tags",
    },
)
class DbParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[typing.List["DbParameterGroupParameter"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "family": family,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if parameter is not None:
            self._values["parameter"] = parameter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def parameter(self) -> typing.Optional[typing.List["DbParameterGroupParameter"]]:
        """parameter block."""
        return self._values.get("parameter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbParameterGroupParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value", "apply_method": "applyMethod"},
)
class DbParameterGroupParameter:
    def __init__(
        self, *, name: str, value: str, apply_method: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        :param apply_method: 
        """
        self._values = {
            "name": name,
            "value": value,
        }
        if apply_method is not None:
            self._values["apply_method"] = apply_method

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def apply_method(self) -> typing.Optional[str]:
        return self._values.get("apply_method")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbParameterGroupParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        ingress: typing.List["DbSecurityGroupIngress"],
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ingress: ingress block.
        :param name: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbSecurityGroupConfig(
            ingress=ingress,
            name=name,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> typing.List["DbSecurityGroupIngress"]:
        return jsii.get(self, "ingress")

    @ingress.setter
    def ingress(self, value: typing.List["DbSecurityGroupIngress"]) -> None:
        jsii.set(self, "ingress", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ingress": "ingress",
        "name": "name",
        "description": "description",
        "tags": "tags",
    },
)
class DbSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ingress: typing.List["DbSecurityGroupIngress"],
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ingress: ingress block.
        :param name: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "ingress": ingress,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def ingress(self) -> typing.List["DbSecurityGroupIngress"]:
        """ingress block."""
        return self._values.get("ingress")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbSecurityGroupIngress",
    jsii_struct_bases=[],
    name_mapping={
        "cidr": "cidr",
        "security_group_id": "securityGroupId",
        "security_group_name": "securityGroupName",
        "security_group_owner_id": "securityGroupOwnerId",
    },
)
class DbSecurityGroupIngress:
    def __init__(
        self,
        *,
        cidr: typing.Optional[str] = None,
        security_group_id: typing.Optional[str] = None,
        security_group_name: typing.Optional[str] = None,
        security_group_owner_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param cidr: 
        :param security_group_id: 
        :param security_group_name: 
        :param security_group_owner_id: 
        """
        self._values = {}
        if cidr is not None:
            self._values["cidr"] = cidr
        if security_group_id is not None:
            self._values["security_group_id"] = security_group_id
        if security_group_name is not None:
            self._values["security_group_name"] = security_group_name
        if security_group_owner_id is not None:
            self._values["security_group_owner_id"] = security_group_owner_id

    @builtins.property
    def cidr(self) -> typing.Optional[str]:
        return self._values.get("cidr")

    @builtins.property
    def security_group_id(self) -> typing.Optional[str]:
        return self._values.get("security_group_id")

    @builtins.property
    def security_group_name(self) -> typing.Optional[str]:
        return self._values.get("security_group_name")

    @builtins.property
    def security_group_owner_id(self) -> typing.Optional[str]:
        return self._values.get("security_group_owner_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbSecurityGroupIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbSnapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_instance_identifier: str,
        db_snapshot_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_instance_identifier: 
        :param db_snapshot_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbSnapshotConfig(
            db_instance_identifier=db_instance_identifier,
            db_snapshot_identifier=db_snapshot_identifier,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> jsii.Number:
        return jsii.get(self, "allocatedStorage")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="dbSnapshotArn")
    def db_snapshot_arn(self) -> str:
        return jsii.get(self, "dbSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> jsii.Number:
        return jsii.get(self, "iops")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="licenseModel")
    def license_model(self) -> str:
        return jsii.get(self, "licenseModel")

    @builtins.property
    @jsii.member(jsii_name="optionGroupName")
    def option_group_name(self) -> str:
        return jsii.get(self, "optionGroupName")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="snapshotType")
    def snapshot_type(self) -> str:
        return jsii.get(self, "snapshotType")

    @builtins.property
    @jsii.member(jsii_name="sourceDbSnapshotIdentifier")
    def source_db_snapshot_identifier(self) -> str:
        return jsii.get(self, "sourceDbSnapshotIdentifier")

    @builtins.property
    @jsii.member(jsii_name="sourceRegion")
    def source_region(self) -> str:
        return jsii.get(self, "sourceRegion")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="storageType")
    def storage_type(self) -> str:
        return jsii.get(self, "storageType")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="dbInstanceIdentifier")
    def db_instance_identifier(self) -> str:
        return jsii.get(self, "dbInstanceIdentifier")

    @db_instance_identifier.setter
    def db_instance_identifier(self, value: str) -> None:
        jsii.set(self, "dbInstanceIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="dbSnapshotIdentifier")
    def db_snapshot_identifier(self) -> str:
        return jsii.get(self, "dbSnapshotIdentifier")

    @db_snapshot_identifier.setter
    def db_snapshot_identifier(self, value: str) -> None:
        jsii.set(self, "dbSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DbSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DbSnapshotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_instance_identifier": "dbInstanceIdentifier",
        "db_snapshot_identifier": "dbSnapshotIdentifier",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DbSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_instance_identifier: str,
        db_snapshot_identifier: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DbSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_instance_identifier: 
        :param db_snapshot_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DbSnapshotTimeouts(**timeouts)
        self._values = {
            "db_instance_identifier": db_instance_identifier,
            "db_snapshot_identifier": db_snapshot_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_instance_identifier(self) -> str:
        return self._values.get("db_instance_identifier")

    @builtins.property
    def db_snapshot_identifier(self) -> str:
        return self._values.get("db_snapshot_identifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DbSnapshotTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class DbSnapshotTimeouts:
    def __init__(self, *, read: typing.Optional[str] = None) -> None:
        """
        :param read: 
        """
        self._values = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[str]:
        return self._values.get("read")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DbSubnetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DbSubnetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param subnet_ids: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DbSubnetGroupConfig(
            subnet_ids=subnet_ids,
            description=description,
            name=name,
            name_prefix=name_prefix,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DbSubnetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DbSubnetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "subnet_ids": "subnetIds",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "tags": "tags",
    },
)
class DbSubnetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param subnet_ids: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DbSubnetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DefaultNetworkAcl(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultNetworkAcl",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_network_acl_id: str,
        egress: typing.Optional[typing.List["DefaultNetworkAclEgress"]] = None,
        ingress: typing.Optional[typing.List["DefaultNetworkAclIngress"]] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_network_acl_id: 
        :param egress: egress block.
        :param ingress: ingress block.
        :param subnet_ids: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DefaultNetworkAclConfig(
            default_network_acl_id=default_network_acl_id,
            egress=egress,
            ingress=ingress,
            subnet_ids=subnet_ids,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DefaultNetworkAcl, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="defaultNetworkAclId")
    def default_network_acl_id(self) -> str:
        return jsii.get(self, "defaultNetworkAclId")

    @default_network_acl_id.setter
    def default_network_acl_id(self, value: str) -> None:
        jsii.set(self, "defaultNetworkAclId", value)

    @builtins.property
    @jsii.member(jsii_name="egress")
    def egress(self) -> typing.Optional[typing.List["DefaultNetworkAclEgress"]]:
        return jsii.get(self, "egress")

    @egress.setter
    def egress(
        self, value: typing.Optional[typing.List["DefaultNetworkAclEgress"]]
    ) -> None:
        jsii.set(self, "egress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> typing.Optional[typing.List["DefaultNetworkAclIngress"]]:
        return jsii.get(self, "ingress")

    @ingress.setter
    def ingress(
        self, value: typing.Optional[typing.List["DefaultNetworkAclIngress"]]
    ) -> None:
        jsii.set(self, "ingress", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultNetworkAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_network_acl_id": "defaultNetworkAclId",
        "egress": "egress",
        "ingress": "ingress",
        "subnet_ids": "subnetIds",
        "tags": "tags",
    },
)
class DefaultNetworkAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_network_acl_id: str,
        egress: typing.Optional[typing.List["DefaultNetworkAclEgress"]] = None,
        ingress: typing.Optional[typing.List["DefaultNetworkAclIngress"]] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_network_acl_id: 
        :param egress: egress block.
        :param ingress: ingress block.
        :param subnet_ids: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "default_network_acl_id": default_network_acl_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if egress is not None:
            self._values["egress"] = egress
        if ingress is not None:
            self._values["ingress"] = ingress
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_network_acl_id(self) -> str:
        return self._values.get("default_network_acl_id")

    @builtins.property
    def egress(self) -> typing.Optional[typing.List["DefaultNetworkAclEgress"]]:
        """egress block."""
        return self._values.get("egress")

    @builtins.property
    def ingress(self) -> typing.Optional[typing.List["DefaultNetworkAclIngress"]]:
        """ingress block."""
        return self._values.get("ingress")

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultNetworkAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultNetworkAclEgress",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "from_port": "fromPort",
        "protocol": "protocol",
        "rule_no": "ruleNo",
        "to_port": "toPort",
        "cidr_block": "cidrBlock",
        "icmp_code": "icmpCode",
        "icmp_type": "icmpType",
        "ipv6_cidr_block": "ipv6CidrBlock",
    },
)
class DefaultNetworkAclEgress:
    def __init__(
        self,
        *,
        action: str,
        from_port: jsii.Number,
        protocol: str,
        rule_no: jsii.Number,
        to_port: jsii.Number,
        cidr_block: typing.Optional[str] = None,
        icmp_code: typing.Optional[jsii.Number] = None,
        icmp_type: typing.Optional[jsii.Number] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
    ) -> None:
        """
        :param action: 
        :param from_port: 
        :param protocol: 
        :param rule_no: 
        :param to_port: 
        :param cidr_block: 
        :param icmp_code: 
        :param icmp_type: 
        :param ipv6_cidr_block: 
        """
        self._values = {
            "action": action,
            "from_port": from_port,
            "protocol": protocol,
            "rule_no": rule_no,
            "to_port": to_port,
        }
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if icmp_code is not None:
            self._values["icmp_code"] = icmp_code
        if icmp_type is not None:
            self._values["icmp_type"] = icmp_type
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block

    @builtins.property
    def action(self) -> str:
        return self._values.get("action")

    @builtins.property
    def from_port(self) -> jsii.Number:
        return self._values.get("from_port")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def rule_no(self) -> jsii.Number:
        return self._values.get("rule_no")

    @builtins.property
    def to_port(self) -> jsii.Number:
        return self._values.get("to_port")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def icmp_code(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_code")

    @builtins.property
    def icmp_type(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_type")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultNetworkAclEgress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultNetworkAclIngress",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "from_port": "fromPort",
        "protocol": "protocol",
        "rule_no": "ruleNo",
        "to_port": "toPort",
        "cidr_block": "cidrBlock",
        "icmp_code": "icmpCode",
        "icmp_type": "icmpType",
        "ipv6_cidr_block": "ipv6CidrBlock",
    },
)
class DefaultNetworkAclIngress:
    def __init__(
        self,
        *,
        action: str,
        from_port: jsii.Number,
        protocol: str,
        rule_no: jsii.Number,
        to_port: jsii.Number,
        cidr_block: typing.Optional[str] = None,
        icmp_code: typing.Optional[jsii.Number] = None,
        icmp_type: typing.Optional[jsii.Number] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
    ) -> None:
        """
        :param action: 
        :param from_port: 
        :param protocol: 
        :param rule_no: 
        :param to_port: 
        :param cidr_block: 
        :param icmp_code: 
        :param icmp_type: 
        :param ipv6_cidr_block: 
        """
        self._values = {
            "action": action,
            "from_port": from_port,
            "protocol": protocol,
            "rule_no": rule_no,
            "to_port": to_port,
        }
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if icmp_code is not None:
            self._values["icmp_code"] = icmp_code
        if icmp_type is not None:
            self._values["icmp_type"] = icmp_type
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block

    @builtins.property
    def action(self) -> str:
        return self._values.get("action")

    @builtins.property
    def from_port(self) -> jsii.Number:
        return self._values.get("from_port")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def rule_no(self) -> jsii.Number:
        return self._values.get("rule_no")

    @builtins.property
    def to_port(self) -> jsii.Number:
        return self._values.get("to_port")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def icmp_code(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_code")

    @builtins.property
    def icmp_type(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_type")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultNetworkAclIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DefaultRouteTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultRouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_route_table_id: str,
        propagating_vgws: typing.Optional[typing.List[str]] = None,
        route: typing.Optional[typing.List["DefaultRouteTableRoute"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_route_table_id: 
        :param propagating_vgws: 
        :param route: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DefaultRouteTableConfig(
            default_route_table_id=default_route_table_id,
            propagating_vgws=propagating_vgws,
            route=route,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DefaultRouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="defaultRouteTableId")
    def default_route_table_id(self) -> str:
        return jsii.get(self, "defaultRouteTableId")

    @default_route_table_id.setter
    def default_route_table_id(self, value: str) -> None:
        jsii.set(self, "defaultRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="propagatingVgws")
    def propagating_vgws(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "propagatingVgws")

    @propagating_vgws.setter
    def propagating_vgws(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "propagatingVgws", value)

    @builtins.property
    @jsii.member(jsii_name="route")
    def route(self) -> typing.Optional[typing.List["DefaultRouteTableRoute"]]:
        return jsii.get(self, "route")

    @route.setter
    def route(
        self, value: typing.Optional[typing.List["DefaultRouteTableRoute"]]
    ) -> None:
        jsii.set(self, "route", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_route_table_id": "defaultRouteTableId",
        "propagating_vgws": "propagatingVgws",
        "route": "route",
        "tags": "tags",
    },
)
class DefaultRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_route_table_id: str,
        propagating_vgws: typing.Optional[typing.List[str]] = None,
        route: typing.Optional[typing.List["DefaultRouteTableRoute"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_route_table_id: 
        :param propagating_vgws: 
        :param route: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "default_route_table_id": default_route_table_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if propagating_vgws is not None:
            self._values["propagating_vgws"] = propagating_vgws
        if route is not None:
            self._values["route"] = route
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_route_table_id(self) -> str:
        return self._values.get("default_route_table_id")

    @builtins.property
    def propagating_vgws(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("propagating_vgws")

    @builtins.property
    def route(self) -> typing.Optional[typing.List["DefaultRouteTableRoute"]]:
        return self._values.get("route")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultRouteTableRoute",
    jsii_struct_bases=[],
    name_mapping={
        "cidr_block": "cidrBlock",
        "egress_only_gateway_id": "egressOnlyGatewayId",
        "gateway_id": "gatewayId",
        "instance_id": "instanceId",
        "ipv6_cidr_block": "ipv6CidrBlock",
        "nat_gateway_id": "natGatewayId",
        "network_interface_id": "networkInterfaceId",
        "transit_gateway_id": "transitGatewayId",
        "vpc_peering_connection_id": "vpcPeeringConnectionId",
    },
)
class DefaultRouteTableRoute:
    def __init__(
        self,
        *,
        cidr_block: typing.Optional[str] = None,
        egress_only_gateway_id: typing.Optional[str] = None,
        gateway_id: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        nat_gateway_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpc_peering_connection_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param cidr_block: 
        :param egress_only_gateway_id: 
        :param gateway_id: 
        :param instance_id: 
        :param ipv6_cidr_block: 
        :param nat_gateway_id: 
        :param network_interface_id: 
        :param transit_gateway_id: 
        :param vpc_peering_connection_id: 
        """
        self._values = {}
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if egress_only_gateway_id is not None:
            self._values["egress_only_gateway_id"] = egress_only_gateway_id
        if gateway_id is not None:
            self._values["gateway_id"] = gateway_id
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block
        if nat_gateway_id is not None:
            self._values["nat_gateway_id"] = nat_gateway_id
        if network_interface_id is not None:
            self._values["network_interface_id"] = network_interface_id
        if transit_gateway_id is not None:
            self._values["transit_gateway_id"] = transit_gateway_id
        if vpc_peering_connection_id is not None:
            self._values["vpc_peering_connection_id"] = vpc_peering_connection_id

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def egress_only_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("egress_only_gateway_id")

    @builtins.property
    def gateway_id(self) -> typing.Optional[str]:
        return self._values.get("gateway_id")

    @builtins.property
    def instance_id(self) -> typing.Optional[str]:
        return self._values.get("instance_id")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    @builtins.property
    def nat_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("nat_gateway_id")

    @builtins.property
    def network_interface_id(self) -> typing.Optional[str]:
        return self._values.get("network_interface_id")

    @builtins.property
    def transit_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def vpc_peering_connection_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_peering_connection_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultRouteTableRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DefaultSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        egress: typing.Optional[typing.List["DefaultSecurityGroupEgress"]] = None,
        ingress: typing.Optional[typing.List["DefaultSecurityGroupIngress"]] = None,
        revoke_rules_on_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DefaultSecurityGroupTimeouts"] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param egress: 
        :param ingress: 
        :param revoke_rules_on_delete: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DefaultSecurityGroupConfig(
            egress=egress,
            ingress=ingress,
            revoke_rules_on_delete=revoke_rules_on_delete,
            tags=tags,
            timeouts=timeouts,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DefaultSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="egress")
    def egress(self) -> typing.Optional[typing.List["DefaultSecurityGroupEgress"]]:
        return jsii.get(self, "egress")

    @egress.setter
    def egress(
        self, value: typing.Optional[typing.List["DefaultSecurityGroupEgress"]]
    ) -> None:
        jsii.set(self, "egress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> typing.Optional[typing.List["DefaultSecurityGroupIngress"]]:
        return jsii.get(self, "ingress")

    @ingress.setter
    def ingress(
        self, value: typing.Optional[typing.List["DefaultSecurityGroupIngress"]]
    ) -> None:
        jsii.set(self, "ingress", value)

    @builtins.property
    @jsii.member(jsii_name="revokeRulesOnDelete")
    def revoke_rules_on_delete(self) -> typing.Optional[bool]:
        return jsii.get(self, "revokeRulesOnDelete")

    @revoke_rules_on_delete.setter
    def revoke_rules_on_delete(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "revokeRulesOnDelete", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DefaultSecurityGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DefaultSecurityGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "egress": "egress",
        "ingress": "ingress",
        "revoke_rules_on_delete": "revokeRulesOnDelete",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_id": "vpcId",
    },
)
class DefaultSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        egress: typing.Optional[typing.List["DefaultSecurityGroupEgress"]] = None,
        ingress: typing.Optional[typing.List["DefaultSecurityGroupIngress"]] = None,
        revoke_rules_on_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DefaultSecurityGroupTimeouts"] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param egress: 
        :param ingress: 
        :param revoke_rules_on_delete: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DefaultSecurityGroupTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if egress is not None:
            self._values["egress"] = egress
        if ingress is not None:
            self._values["ingress"] = ingress
        if revoke_rules_on_delete is not None:
            self._values["revoke_rules_on_delete"] = revoke_rules_on_delete
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def egress(self) -> typing.Optional[typing.List["DefaultSecurityGroupEgress"]]:
        return self._values.get("egress")

    @builtins.property
    def ingress(self) -> typing.Optional[typing.List["DefaultSecurityGroupIngress"]]:
        return self._values.get("ingress")

    @builtins.property
    def revoke_rules_on_delete(self) -> typing.Optional[bool]:
        return self._values.get("revoke_rules_on_delete")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DefaultSecurityGroupTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSecurityGroupEgress",
    jsii_struct_bases=[],
    name_mapping={
        "cidr_blocks": "cidrBlocks",
        "description": "description",
        "from_port": "fromPort",
        "ipv6_cidr_blocks": "ipv6CidrBlocks",
        "prefix_list_ids": "prefixListIds",
        "protocol": "protocol",
        "security_groups": "securityGroups",
        "self_attribute": "selfAttribute",
        "to_port": "toPort",
    },
)
class DefaultSecurityGroupEgress:
    def __init__(
        self,
        *,
        cidr_blocks: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        ipv6_cidr_blocks: typing.Optional[typing.List[str]] = None,
        prefix_list_ids: typing.Optional[typing.List[str]] = None,
        protocol: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        self_attribute: typing.Optional[bool] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param cidr_blocks: 
        :param description: 
        :param from_port: 
        :param ipv6_cidr_blocks: 
        :param prefix_list_ids: 
        :param protocol: 
        :param security_groups: 
        :param self_attribute: 
        :param to_port: 
        """
        self._values = {}
        if cidr_blocks is not None:
            self._values["cidr_blocks"] = cidr_blocks
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if ipv6_cidr_blocks is not None:
            self._values["ipv6_cidr_blocks"] = ipv6_cidr_blocks
        if prefix_list_ids is not None:
            self._values["prefix_list_ids"] = prefix_list_ids
        if protocol is not None:
            self._values["protocol"] = protocol
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if self_attribute is not None:
            self._values["self_attribute"] = self_attribute
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cidr_blocks")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def ipv6_cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_cidr_blocks")

    @builtins.property
    def prefix_list_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("prefix_list_ids")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def self_attribute(self) -> typing.Optional[bool]:
        return self._values.get("self_attribute")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultSecurityGroupEgress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSecurityGroupIngress",
    jsii_struct_bases=[],
    name_mapping={
        "cidr_blocks": "cidrBlocks",
        "description": "description",
        "from_port": "fromPort",
        "ipv6_cidr_blocks": "ipv6CidrBlocks",
        "prefix_list_ids": "prefixListIds",
        "protocol": "protocol",
        "security_groups": "securityGroups",
        "self_attribute": "selfAttribute",
        "to_port": "toPort",
    },
)
class DefaultSecurityGroupIngress:
    def __init__(
        self,
        *,
        cidr_blocks: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        ipv6_cidr_blocks: typing.Optional[typing.List[str]] = None,
        prefix_list_ids: typing.Optional[typing.List[str]] = None,
        protocol: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        self_attribute: typing.Optional[bool] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param cidr_blocks: 
        :param description: 
        :param from_port: 
        :param ipv6_cidr_blocks: 
        :param prefix_list_ids: 
        :param protocol: 
        :param security_groups: 
        :param self_attribute: 
        :param to_port: 
        """
        self._values = {}
        if cidr_blocks is not None:
            self._values["cidr_blocks"] = cidr_blocks
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if ipv6_cidr_blocks is not None:
            self._values["ipv6_cidr_blocks"] = ipv6_cidr_blocks
        if prefix_list_ids is not None:
            self._values["prefix_list_ids"] = prefix_list_ids
        if protocol is not None:
            self._values["protocol"] = protocol
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if self_attribute is not None:
            self._values["self_attribute"] = self_attribute
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cidr_blocks")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def ipv6_cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_cidr_blocks")

    @builtins.property
    def prefix_list_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("prefix_list_ids")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def self_attribute(self) -> typing.Optional[bool]:
        return self._values.get("self_attribute")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultSecurityGroupIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DefaultSecurityGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultSecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DefaultSubnet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSubnet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        availability_zone: str,
        map_public_ip_on_launch: typing.Optional[bool] = None,
        outpost_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DefaultSubnetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param availability_zone: 
        :param map_public_ip_on_launch: 
        :param outpost_arn: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DefaultSubnetConfig(
            availability_zone=availability_zone,
            map_public_ip_on_launch=map_public_ip_on_launch,
            outpost_arn=outpost_arn,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DefaultSubnet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="assignIpv6AddressOnCreation")
    def assign_ipv6_address_on_creation(self) -> bool:
        return jsii.get(self, "assignIpv6AddressOnCreation")

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> str:
        return jsii.get(self, "availabilityZoneId")

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> str:
        return jsii.get(self, "cidrBlock")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> str:
        return jsii.get(self, "ipv6CidrBlock")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlockAssociationId")
    def ipv6_cidr_block_association_id(self) -> str:
        return jsii.get(self, "ipv6CidrBlockAssociationId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: str) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mapPublicIpOnLaunch")
    def map_public_ip_on_launch(self) -> typing.Optional[bool]:
        return jsii.get(self, "mapPublicIpOnLaunch")

    @map_public_ip_on_launch.setter
    def map_public_ip_on_launch(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mapPublicIpOnLaunch", value)

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "outpostArn")

    @outpost_arn.setter
    def outpost_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "outpostArn", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DefaultSubnetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DefaultSubnetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSubnetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "availability_zone": "availabilityZone",
        "map_public_ip_on_launch": "mapPublicIpOnLaunch",
        "outpost_arn": "outpostArn",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DefaultSubnetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        availability_zone: str,
        map_public_ip_on_launch: typing.Optional[bool] = None,
        outpost_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DefaultSubnetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param availability_zone: 
        :param map_public_ip_on_launch: 
        :param outpost_arn: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DefaultSubnetTimeouts(**timeouts)
        self._values = {
            "availability_zone": availability_zone,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if map_public_ip_on_launch is not None:
            self._values["map_public_ip_on_launch"] = map_public_ip_on_launch
        if outpost_arn is not None:
            self._values["outpost_arn"] = outpost_arn
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def availability_zone(self) -> str:
        return self._values.get("availability_zone")

    @builtins.property
    def map_public_ip_on_launch(self) -> typing.Optional[bool]:
        return self._values.get("map_public_ip_on_launch")

    @builtins.property
    def outpost_arn(self) -> typing.Optional[str]:
        return self._values.get("outpost_arn")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DefaultSubnetTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultSubnetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultSubnetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DefaultSubnetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultSubnetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DefaultVpc(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultVpc",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        enable_classiclink: typing.Optional[bool] = None,
        enable_classiclink_dns_support: typing.Optional[bool] = None,
        enable_dns_hostnames: typing.Optional[bool] = None,
        enable_dns_support: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enable_classiclink: 
        :param enable_classiclink_dns_support: 
        :param enable_dns_hostnames: 
        :param enable_dns_support: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DefaultVpcConfig(
            enable_classiclink=enable_classiclink,
            enable_classiclink_dns_support=enable_classiclink_dns_support,
            enable_dns_hostnames=enable_dns_hostnames,
            enable_dns_support=enable_dns_support,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DefaultVpc, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="assignGeneratedIpv6CidrBlock")
    def assign_generated_ipv6_cidr_block(self) -> bool:
        return jsii.get(self, "assignGeneratedIpv6CidrBlock")

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> str:
        return jsii.get(self, "cidrBlock")

    @builtins.property
    @jsii.member(jsii_name="defaultNetworkAclId")
    def default_network_acl_id(self) -> str:
        return jsii.get(self, "defaultNetworkAclId")

    @builtins.property
    @jsii.member(jsii_name="defaultRouteTableId")
    def default_route_table_id(self) -> str:
        return jsii.get(self, "defaultRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="defaultSecurityGroupId")
    def default_security_group_id(self) -> str:
        return jsii.get(self, "defaultSecurityGroupId")

    @builtins.property
    @jsii.member(jsii_name="dhcpOptionsId")
    def dhcp_options_id(self) -> str:
        return jsii.get(self, "dhcpOptionsId")

    @builtins.property
    @jsii.member(jsii_name="instanceTenancy")
    def instance_tenancy(self) -> str:
        return jsii.get(self, "instanceTenancy")

    @builtins.property
    @jsii.member(jsii_name="ipv6AssociationId")
    def ipv6_association_id(self) -> str:
        return jsii.get(self, "ipv6AssociationId")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> str:
        return jsii.get(self, "ipv6CidrBlock")

    @builtins.property
    @jsii.member(jsii_name="mainRouteTableId")
    def main_route_table_id(self) -> str:
        return jsii.get(self, "mainRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="enableClassiclink")
    def enable_classiclink(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableClassiclink")

    @enable_classiclink.setter
    def enable_classiclink(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableClassiclink", value)

    @builtins.property
    @jsii.member(jsii_name="enableClassiclinkDnsSupport")
    def enable_classiclink_dns_support(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableClassiclinkDnsSupport")

    @enable_classiclink_dns_support.setter
    def enable_classiclink_dns_support(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableClassiclinkDnsSupport", value)

    @builtins.property
    @jsii.member(jsii_name="enableDnsHostnames")
    def enable_dns_hostnames(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableDnsHostnames")

    @enable_dns_hostnames.setter
    def enable_dns_hostnames(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableDnsHostnames", value)

    @builtins.property
    @jsii.member(jsii_name="enableDnsSupport")
    def enable_dns_support(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableDnsSupport")

    @enable_dns_support.setter
    def enable_dns_support(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableDnsSupport", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultVpcConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enable_classiclink": "enableClassiclink",
        "enable_classiclink_dns_support": "enableClassiclinkDnsSupport",
        "enable_dns_hostnames": "enableDnsHostnames",
        "enable_dns_support": "enableDnsSupport",
        "tags": "tags",
    },
)
class DefaultVpcConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enable_classiclink: typing.Optional[bool] = None,
        enable_classiclink_dns_support: typing.Optional[bool] = None,
        enable_dns_hostnames: typing.Optional[bool] = None,
        enable_dns_support: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enable_classiclink: 
        :param enable_classiclink_dns_support: 
        :param enable_dns_hostnames: 
        :param enable_dns_support: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enable_classiclink is not None:
            self._values["enable_classiclink"] = enable_classiclink
        if enable_classiclink_dns_support is not None:
            self._values[
                "enable_classiclink_dns_support"
            ] = enable_classiclink_dns_support
        if enable_dns_hostnames is not None:
            self._values["enable_dns_hostnames"] = enable_dns_hostnames
        if enable_dns_support is not None:
            self._values["enable_dns_support"] = enable_dns_support
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def enable_classiclink(self) -> typing.Optional[bool]:
        return self._values.get("enable_classiclink")

    @builtins.property
    def enable_classiclink_dns_support(self) -> typing.Optional[bool]:
        return self._values.get("enable_classiclink_dns_support")

    @builtins.property
    def enable_dns_hostnames(self) -> typing.Optional[bool]:
        return self._values.get("enable_dns_hostnames")

    @builtins.property
    def enable_dns_support(self) -> typing.Optional[bool]:
        return self._values.get("enable_dns_support")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultVpcConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DefaultVpcDhcpOptions(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultVpcDhcpOptions",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        netbios_name_servers: typing.Optional[typing.List[str]] = None,
        netbios_node_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param netbios_name_servers: 
        :param netbios_node_type: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DefaultVpcDhcpOptionsConfig(
            netbios_name_servers=netbios_name_servers,
            netbios_node_type=netbios_node_type,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DefaultVpcDhcpOptions, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @builtins.property
    @jsii.member(jsii_name="domainNameServers")
    def domain_name_servers(self) -> str:
        return jsii.get(self, "domainNameServers")

    @builtins.property
    @jsii.member(jsii_name="ntpServers")
    def ntp_servers(self) -> str:
        return jsii.get(self, "ntpServers")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="netbiosNameServers")
    def netbios_name_servers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "netbiosNameServers")

    @netbios_name_servers.setter
    def netbios_name_servers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "netbiosNameServers", value)

    @builtins.property
    @jsii.member(jsii_name="netbiosNodeType")
    def netbios_node_type(self) -> typing.Optional[str]:
        return jsii.get(self, "netbiosNodeType")

    @netbios_node_type.setter
    def netbios_node_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "netbiosNodeType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DefaultVpcDhcpOptionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "netbios_name_servers": "netbiosNameServers",
        "netbios_node_type": "netbiosNodeType",
        "tags": "tags",
    },
)
class DefaultVpcDhcpOptionsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        netbios_name_servers: typing.Optional[typing.List[str]] = None,
        netbios_node_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param netbios_name_servers: 
        :param netbios_node_type: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if netbios_name_servers is not None:
            self._values["netbios_name_servers"] = netbios_name_servers
        if netbios_node_type is not None:
            self._values["netbios_node_type"] = netbios_node_type
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def netbios_name_servers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("netbios_name_servers")

    @builtins.property
    def netbios_node_type(self) -> typing.Optional[str]:
        return self._values.get("netbios_node_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DefaultVpcDhcpOptionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DevicefarmProject(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DevicefarmProject",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DevicefarmProjectConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DevicefarmProject, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DevicefarmProjectConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class DevicefarmProjectConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DevicefarmProjectConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DirectoryServiceConditionalForwarder(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceConditionalForwarder",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        directory_id: str,
        dns_ips: typing.List[str],
        remote_domain_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param directory_id: 
        :param dns_ips: 
        :param remote_domain_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DirectoryServiceConditionalForwarderConfig(
            directory_id=directory_id,
            dns_ips=dns_ips,
            remote_domain_name=remote_domain_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DirectoryServiceConditionalForwarder, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="directoryId")
    def directory_id(self) -> str:
        return jsii.get(self, "directoryId")

    @directory_id.setter
    def directory_id(self, value: str) -> None:
        jsii.set(self, "directoryId", value)

    @builtins.property
    @jsii.member(jsii_name="dnsIps")
    def dns_ips(self) -> typing.List[str]:
        return jsii.get(self, "dnsIps")

    @dns_ips.setter
    def dns_ips(self, value: typing.List[str]) -> None:
        jsii.set(self, "dnsIps", value)

    @builtins.property
    @jsii.member(jsii_name="remoteDomainName")
    def remote_domain_name(self) -> str:
        return jsii.get(self, "remoteDomainName")

    @remote_domain_name.setter
    def remote_domain_name(self, value: str) -> None:
        jsii.set(self, "remoteDomainName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceConditionalForwarderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "directory_id": "directoryId",
        "dns_ips": "dnsIps",
        "remote_domain_name": "remoteDomainName",
    },
)
class DirectoryServiceConditionalForwarderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        directory_id: str,
        dns_ips: typing.List[str],
        remote_domain_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param directory_id: 
        :param dns_ips: 
        :param remote_domain_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "directory_id": directory_id,
            "dns_ips": dns_ips,
            "remote_domain_name": remote_domain_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def directory_id(self) -> str:
        return self._values.get("directory_id")

    @builtins.property
    def dns_ips(self) -> typing.List[str]:
        return self._values.get("dns_ips")

    @builtins.property
    def remote_domain_name(self) -> str:
        return self._values.get("remote_domain_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DirectoryServiceConditionalForwarderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DirectoryServiceDirectory(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceDirectory",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        password: str,
        alias: typing.Optional[str] = None,
        connect_settings: typing.Optional[
            typing.List["DirectoryServiceDirectoryConnectSettings"]
        ] = None,
        description: typing.Optional[str] = None,
        edition: typing.Optional[str] = None,
        enable_sso: typing.Optional[bool] = None,
        short_name: typing.Optional[str] = None,
        size: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        type: typing.Optional[str] = None,
        vpc_settings: typing.Optional[
            typing.List["DirectoryServiceDirectoryVpcSettings"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param password: 
        :param alias: 
        :param connect_settings: connect_settings block.
        :param description: 
        :param edition: 
        :param enable_sso: 
        :param short_name: 
        :param size: 
        :param tags: 
        :param type: 
        :param vpc_settings: vpc_settings block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DirectoryServiceDirectoryConfig(
            name=name,
            password=password,
            alias=alias,
            connect_settings=connect_settings,
            description=description,
            edition=edition,
            enable_sso=enable_sso,
            short_name=short_name,
            size=size,
            tags=tags,
            type=type,
            vpc_settings=vpc_settings,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DirectoryServiceDirectory, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accessUrl")
    def access_url(self) -> str:
        return jsii.get(self, "accessUrl")

    @builtins.property
    @jsii.member(jsii_name="dnsIpAddresses")
    def dns_ip_addresses(self) -> typing.List[str]:
        return jsii.get(self, "dnsIpAddresses")

    @builtins.property
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> str:
        return jsii.get(self, "securityGroupId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="password")
    def password(self) -> str:
        return jsii.get(self, "password")

    @password.setter
    def password(self, value: str) -> None:
        jsii.set(self, "password", value)

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> typing.Optional[str]:
        return jsii.get(self, "alias")

    @alias.setter
    def alias(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "alias", value)

    @builtins.property
    @jsii.member(jsii_name="connectSettings")
    def connect_settings(
        self,
    ) -> typing.Optional[typing.List["DirectoryServiceDirectoryConnectSettings"]]:
        return jsii.get(self, "connectSettings")

    @connect_settings.setter
    def connect_settings(
        self,
        value: typing.Optional[typing.List["DirectoryServiceDirectoryConnectSettings"]],
    ) -> None:
        jsii.set(self, "connectSettings", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="edition")
    def edition(self) -> typing.Optional[str]:
        return jsii.get(self, "edition")

    @edition.setter
    def edition(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "edition", value)

    @builtins.property
    @jsii.member(jsii_name="enableSso")
    def enable_sso(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableSso")

    @enable_sso.setter
    def enable_sso(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableSso", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="shortName")
    def short_name(self) -> typing.Optional[str]:
        return jsii.get(self, "shortName")

    @short_name.setter
    def short_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "shortName", value)

    @builtins.property
    @jsii.member(jsii_name="size")
    def size(self) -> typing.Optional[str]:
        return jsii.get(self, "size")

    @size.setter
    def size(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "size", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSettings")
    def vpc_settings(
        self,
    ) -> typing.Optional[typing.List["DirectoryServiceDirectoryVpcSettings"]]:
        return jsii.get(self, "vpcSettings")

    @vpc_settings.setter
    def vpc_settings(
        self,
        value: typing.Optional[typing.List["DirectoryServiceDirectoryVpcSettings"]],
    ) -> None:
        jsii.set(self, "vpcSettings", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceDirectoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "password": "password",
        "alias": "alias",
        "connect_settings": "connectSettings",
        "description": "description",
        "edition": "edition",
        "enable_sso": "enableSso",
        "short_name": "shortName",
        "size": "size",
        "tags": "tags",
        "type": "type",
        "vpc_settings": "vpcSettings",
    },
)
class DirectoryServiceDirectoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        password: str,
        alias: typing.Optional[str] = None,
        connect_settings: typing.Optional[
            typing.List["DirectoryServiceDirectoryConnectSettings"]
        ] = None,
        description: typing.Optional[str] = None,
        edition: typing.Optional[str] = None,
        enable_sso: typing.Optional[bool] = None,
        short_name: typing.Optional[str] = None,
        size: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        type: typing.Optional[str] = None,
        vpc_settings: typing.Optional[
            typing.List["DirectoryServiceDirectoryVpcSettings"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param password: 
        :param alias: 
        :param connect_settings: connect_settings block.
        :param description: 
        :param edition: 
        :param enable_sso: 
        :param short_name: 
        :param size: 
        :param tags: 
        :param type: 
        :param vpc_settings: vpc_settings block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "password": password,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if alias is not None:
            self._values["alias"] = alias
        if connect_settings is not None:
            self._values["connect_settings"] = connect_settings
        if description is not None:
            self._values["description"] = description
        if edition is not None:
            self._values["edition"] = edition
        if enable_sso is not None:
            self._values["enable_sso"] = enable_sso
        if short_name is not None:
            self._values["short_name"] = short_name
        if size is not None:
            self._values["size"] = size
        if tags is not None:
            self._values["tags"] = tags
        if type is not None:
            self._values["type"] = type
        if vpc_settings is not None:
            self._values["vpc_settings"] = vpc_settings

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def password(self) -> str:
        return self._values.get("password")

    @builtins.property
    def alias(self) -> typing.Optional[str]:
        return self._values.get("alias")

    @builtins.property
    def connect_settings(
        self,
    ) -> typing.Optional[typing.List["DirectoryServiceDirectoryConnectSettings"]]:
        """connect_settings block."""
        return self._values.get("connect_settings")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def edition(self) -> typing.Optional[str]:
        return self._values.get("edition")

    @builtins.property
    def enable_sso(self) -> typing.Optional[bool]:
        return self._values.get("enable_sso")

    @builtins.property
    def short_name(self) -> typing.Optional[str]:
        return self._values.get("short_name")

    @builtins.property
    def size(self) -> typing.Optional[str]:
        return self._values.get("size")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    @builtins.property
    def vpc_settings(
        self,
    ) -> typing.Optional[typing.List["DirectoryServiceDirectoryVpcSettings"]]:
        """vpc_settings block."""
        return self._values.get("vpc_settings")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DirectoryServiceDirectoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceDirectoryConnectSettings",
    jsii_struct_bases=[],
    name_mapping={
        "customer_dns_ips": "customerDnsIps",
        "customer_username": "customerUsername",
        "subnet_ids": "subnetIds",
        "vpc_id": "vpcId",
    },
)
class DirectoryServiceDirectoryConnectSettings:
    def __init__(
        self,
        *,
        customer_dns_ips: typing.List[str],
        customer_username: str,
        subnet_ids: typing.List[str],
        vpc_id: str,
    ) -> None:
        """
        :param customer_dns_ips: 
        :param customer_username: 
        :param subnet_ids: 
        :param vpc_id: 
        """
        self._values = {
            "customer_dns_ips": customer_dns_ips,
            "customer_username": customer_username,
            "subnet_ids": subnet_ids,
            "vpc_id": vpc_id,
        }

    @builtins.property
    def customer_dns_ips(self) -> typing.List[str]:
        return self._values.get("customer_dns_ips")

    @builtins.property
    def customer_username(self) -> str:
        return self._values.get("customer_username")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DirectoryServiceDirectoryConnectSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceDirectoryVpcSettings",
    jsii_struct_bases=[],
    name_mapping={"subnet_ids": "subnetIds", "vpc_id": "vpcId"},
)
class DirectoryServiceDirectoryVpcSettings:
    def __init__(self, *, subnet_ids: typing.List[str], vpc_id: str) -> None:
        """
        :param subnet_ids: 
        :param vpc_id: 
        """
        self._values = {
            "subnet_ids": subnet_ids,
            "vpc_id": vpc_id,
        }

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DirectoryServiceDirectoryVpcSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DirectoryServiceLogSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceLogSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        directory_id: str,
        log_group_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param directory_id: 
        :param log_group_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DirectoryServiceLogSubscriptionConfig(
            directory_id=directory_id,
            log_group_name=log_group_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DirectoryServiceLogSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="directoryId")
    def directory_id(self) -> str:
        return jsii.get(self, "directoryId")

    @directory_id.setter
    def directory_id(self, value: str) -> None:
        jsii.set(self, "directoryId", value)

    @builtins.property
    @jsii.member(jsii_name="logGroupName")
    def log_group_name(self) -> str:
        return jsii.get(self, "logGroupName")

    @log_group_name.setter
    def log_group_name(self, value: str) -> None:
        jsii.set(self, "logGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DirectoryServiceLogSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "directory_id": "directoryId",
        "log_group_name": "logGroupName",
    },
)
class DirectoryServiceLogSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        directory_id: str,
        log_group_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param directory_id: 
        :param log_group_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "directory_id": directory_id,
            "log_group_name": log_group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def directory_id(self) -> str:
        return self._values.get("directory_id")

    @builtins.property
    def log_group_name(self) -> str:
        return self._values.get("log_group_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DirectoryServiceLogSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DlmLifecyclePolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DlmLifecyclePolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        description: str,
        execution_role_arn: str,
        policy_details: typing.List["DlmLifecyclePolicyPolicyDetails"],
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param description: 
        :param execution_role_arn: 
        :param policy_details: policy_details block.
        :param state: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DlmLifecyclePolicyConfig(
            description=description,
            execution_role_arn=execution_role_arn,
            policy_details=policy_details,
            state=state,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DlmLifecyclePolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: str) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="executionRoleArn")
    def execution_role_arn(self) -> str:
        return jsii.get(self, "executionRoleArn")

    @execution_role_arn.setter
    def execution_role_arn(self, value: str) -> None:
        jsii.set(self, "executionRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="policyDetails")
    def policy_details(self) -> typing.List["DlmLifecyclePolicyPolicyDetails"]:
        return jsii.get(self, "policyDetails")

    @policy_details.setter
    def policy_details(
        self, value: typing.List["DlmLifecyclePolicyPolicyDetails"]
    ) -> None:
        jsii.set(self, "policyDetails", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DlmLifecyclePolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "execution_role_arn": "executionRoleArn",
        "policy_details": "policyDetails",
        "state": "state",
        "tags": "tags",
    },
)
class DlmLifecyclePolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: str,
        execution_role_arn: str,
        policy_details: typing.List["DlmLifecyclePolicyPolicyDetails"],
        state: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: 
        :param execution_role_arn: 
        :param policy_details: policy_details block.
        :param state: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "description": description,
            "execution_role_arn": execution_role_arn,
            "policy_details": policy_details,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if state is not None:
            self._values["state"] = state
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def description(self) -> str:
        return self._values.get("description")

    @builtins.property
    def execution_role_arn(self) -> str:
        return self._values.get("execution_role_arn")

    @builtins.property
    def policy_details(self) -> typing.List["DlmLifecyclePolicyPolicyDetails"]:
        """policy_details block."""
        return self._values.get("policy_details")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DlmLifecyclePolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DlmLifecyclePolicyPolicyDetails",
    jsii_struct_bases=[],
    name_mapping={
        "resource_types": "resourceTypes",
        "schedule": "schedule",
        "target_tags": "targetTags",
    },
)
class DlmLifecyclePolicyPolicyDetails:
    def __init__(
        self,
        *,
        resource_types: typing.List[str],
        schedule: typing.List["DlmLifecyclePolicyPolicyDetailsSchedule"],
        target_tags: typing.Mapping[str, str],
    ) -> None:
        """
        :param resource_types: 
        :param schedule: schedule block.
        :param target_tags: 
        """
        self._values = {
            "resource_types": resource_types,
            "schedule": schedule,
            "target_tags": target_tags,
        }

    @builtins.property
    def resource_types(self) -> typing.List[str]:
        return self._values.get("resource_types")

    @builtins.property
    def schedule(self) -> typing.List["DlmLifecyclePolicyPolicyDetailsSchedule"]:
        """schedule block."""
        return self._values.get("schedule")

    @builtins.property
    def target_tags(self) -> typing.Mapping[str, str]:
        return self._values.get("target_tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DlmLifecyclePolicyPolicyDetails(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DlmLifecyclePolicyPolicyDetailsSchedule",
    jsii_struct_bases=[],
    name_mapping={
        "create_rule": "createRule",
        "name": "name",
        "retain_rule": "retainRule",
        "copy_tags": "copyTags",
        "tags_to_add": "tagsToAdd",
    },
)
class DlmLifecyclePolicyPolicyDetailsSchedule:
    def __init__(
        self,
        *,
        create_rule: typing.List["DlmLifecyclePolicyPolicyDetailsScheduleCreateRule"],
        name: str,
        retain_rule: typing.List["DlmLifecyclePolicyPolicyDetailsScheduleRetainRule"],
        copy_tags: typing.Optional[bool] = None,
        tags_to_add: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param create_rule: create_rule block.
        :param name: 
        :param retain_rule: retain_rule block.
        :param copy_tags: 
        :param tags_to_add: 
        """
        self._values = {
            "create_rule": create_rule,
            "name": name,
            "retain_rule": retain_rule,
        }
        if copy_tags is not None:
            self._values["copy_tags"] = copy_tags
        if tags_to_add is not None:
            self._values["tags_to_add"] = tags_to_add

    @builtins.property
    def create_rule(
        self,
    ) -> typing.List["DlmLifecyclePolicyPolicyDetailsScheduleCreateRule"]:
        """create_rule block."""
        return self._values.get("create_rule")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def retain_rule(
        self,
    ) -> typing.List["DlmLifecyclePolicyPolicyDetailsScheduleRetainRule"]:
        """retain_rule block."""
        return self._values.get("retain_rule")

    @builtins.property
    def copy_tags(self) -> typing.Optional[bool]:
        return self._values.get("copy_tags")

    @builtins.property
    def tags_to_add(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags_to_add")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DlmLifecyclePolicyPolicyDetailsSchedule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DlmLifecyclePolicyPolicyDetailsScheduleCreateRule",
    jsii_struct_bases=[],
    name_mapping={
        "interval": "interval",
        "interval_unit": "intervalUnit",
        "times": "times",
    },
)
class DlmLifecyclePolicyPolicyDetailsScheduleCreateRule:
    def __init__(
        self,
        *,
        interval: jsii.Number,
        interval_unit: typing.Optional[str] = None,
        times: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param interval: 
        :param interval_unit: 
        :param times: 
        """
        self._values = {
            "interval": interval,
        }
        if interval_unit is not None:
            self._values["interval_unit"] = interval_unit
        if times is not None:
            self._values["times"] = times

    @builtins.property
    def interval(self) -> jsii.Number:
        return self._values.get("interval")

    @builtins.property
    def interval_unit(self) -> typing.Optional[str]:
        return self._values.get("interval_unit")

    @builtins.property
    def times(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("times")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DlmLifecyclePolicyPolicyDetailsScheduleCreateRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DlmLifecyclePolicyPolicyDetailsScheduleRetainRule",
    jsii_struct_bases=[],
    name_mapping={"count": "count"},
)
class DlmLifecyclePolicyPolicyDetailsScheduleRetainRule:
    def __init__(self, *, count: jsii.Number) -> None:
        """
        :param count: 
        """
        self._values = {
            "count": count,
        }

    @builtins.property
    def count(self) -> jsii.Number:
        return self._values.get("count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DlmLifecyclePolicyPolicyDetailsScheduleRetainRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DmsCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DmsCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate_id: str,
        certificate_pem: typing.Optional[str] = None,
        certificate_wallet: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_id: 
        :param certificate_pem: 
        :param certificate_wallet: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DmsCertificateConfig(
            certificate_id=certificate_id,
            certificate_pem=certificate_pem,
            certificate_wallet=certificate_wallet,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DmsCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> str:
        return jsii.get(self, "certificateArn")

    @builtins.property
    @jsii.member(jsii_name="certificateId")
    def certificate_id(self) -> str:
        return jsii.get(self, "certificateId")

    @certificate_id.setter
    def certificate_id(self, value: str) -> None:
        jsii.set(self, "certificateId", value)

    @builtins.property
    @jsii.member(jsii_name="certificatePem")
    def certificate_pem(self) -> typing.Optional[str]:
        return jsii.get(self, "certificatePem")

    @certificate_pem.setter
    def certificate_pem(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificatePem", value)

    @builtins.property
    @jsii.member(jsii_name="certificateWallet")
    def certificate_wallet(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateWallet")

    @certificate_wallet.setter
    def certificate_wallet(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateWallet", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_id": "certificateId",
        "certificate_pem": "certificatePem",
        "certificate_wallet": "certificateWallet",
    },
)
class DmsCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_id: str,
        certificate_pem: typing.Optional[str] = None,
        certificate_wallet: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_id: 
        :param certificate_pem: 
        :param certificate_wallet: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "certificate_id": certificate_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_pem is not None:
            self._values["certificate_pem"] = certificate_pem
        if certificate_wallet is not None:
            self._values["certificate_wallet"] = certificate_wallet

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate_id(self) -> str:
        return self._values.get("certificate_id")

    @builtins.property
    def certificate_pem(self) -> typing.Optional[str]:
        return self._values.get("certificate_pem")

    @builtins.property
    def certificate_wallet(self) -> typing.Optional[str]:
        return self._values.get("certificate_wallet")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DmsEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        endpoint_id: str,
        endpoint_type: str,
        engine_name: str,
        certificate_arn: typing.Optional[str] = None,
        database_name: typing.Optional[str] = None,
        elasticsearch_settings: typing.Optional[
            typing.List["DmsEndpointElasticsearchSettings"]
        ] = None,
        extra_connection_attributes: typing.Optional[str] = None,
        kafka_settings: typing.Optional[typing.List["DmsEndpointKafkaSettings"]] = None,
        kinesis_settings: typing.Optional[
            typing.List["DmsEndpointKinesisSettings"]
        ] = None,
        kms_key_arn: typing.Optional[str] = None,
        mongodb_settings: typing.Optional[
            typing.List["DmsEndpointMongodbSettings"]
        ] = None,
        password: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        s3_settings: typing.Optional[typing.List["DmsEndpointS3Settings"]] = None,
        server_name: typing.Optional[str] = None,
        service_access_role: typing.Optional[str] = None,
        ssl_mode: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        username: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param endpoint_id: 
        :param endpoint_type: 
        :param engine_name: 
        :param certificate_arn: 
        :param database_name: 
        :param elasticsearch_settings: elasticsearch_settings block.
        :param extra_connection_attributes: 
        :param kafka_settings: kafka_settings block.
        :param kinesis_settings: kinesis_settings block.
        :param kms_key_arn: 
        :param mongodb_settings: mongodb_settings block.
        :param password: 
        :param port: 
        :param s3_settings: s3_settings block.
        :param server_name: 
        :param service_access_role: 
        :param ssl_mode: 
        :param tags: 
        :param username: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DmsEndpointConfig(
            endpoint_id=endpoint_id,
            endpoint_type=endpoint_type,
            engine_name=engine_name,
            certificate_arn=certificate_arn,
            database_name=database_name,
            elasticsearch_settings=elasticsearch_settings,
            extra_connection_attributes=extra_connection_attributes,
            kafka_settings=kafka_settings,
            kinesis_settings=kinesis_settings,
            kms_key_arn=kms_key_arn,
            mongodb_settings=mongodb_settings,
            password=password,
            port=port,
            s3_settings=s3_settings,
            server_name=server_name,
            service_access_role=service_access_role,
            ssl_mode=ssl_mode,
            tags=tags,
            username=username,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DmsEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="endpointArn")
    def endpoint_arn(self) -> str:
        return jsii.get(self, "endpointArn")

    @builtins.property
    @jsii.member(jsii_name="endpointId")
    def endpoint_id(self) -> str:
        return jsii.get(self, "endpointId")

    @endpoint_id.setter
    def endpoint_id(self, value: str) -> None:
        jsii.set(self, "endpointId", value)

    @builtins.property
    @jsii.member(jsii_name="endpointType")
    def endpoint_type(self) -> str:
        return jsii.get(self, "endpointType")

    @endpoint_type.setter
    def endpoint_type(self, value: str) -> None:
        jsii.set(self, "endpointType", value)

    @builtins.property
    @jsii.member(jsii_name="engineName")
    def engine_name(self) -> str:
        return jsii.get(self, "engineName")

    @engine_name.setter
    def engine_name(self, value: str) -> None:
        jsii.set(self, "engineName", value)

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> typing.Optional[str]:
        return jsii.get(self, "databaseName")

    @database_name.setter
    def database_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property
    @jsii.member(jsii_name="elasticsearchSettings")
    def elasticsearch_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointElasticsearchSettings"]]:
        return jsii.get(self, "elasticsearchSettings")

    @elasticsearch_settings.setter
    def elasticsearch_settings(
        self, value: typing.Optional[typing.List["DmsEndpointElasticsearchSettings"]]
    ) -> None:
        jsii.set(self, "elasticsearchSettings", value)

    @builtins.property
    @jsii.member(jsii_name="extraConnectionAttributes")
    def extra_connection_attributes(self) -> typing.Optional[str]:
        return jsii.get(self, "extraConnectionAttributes")

    @extra_connection_attributes.setter
    def extra_connection_attributes(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "extraConnectionAttributes", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kafkaSettings")
    def kafka_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointKafkaSettings"]]:
        return jsii.get(self, "kafkaSettings")

    @kafka_settings.setter
    def kafka_settings(
        self, value: typing.Optional[typing.List["DmsEndpointKafkaSettings"]]
    ) -> None:
        jsii.set(self, "kafkaSettings", value)

    @builtins.property
    @jsii.member(jsii_name="kinesisSettings")
    def kinesis_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointKinesisSettings"]]:
        return jsii.get(self, "kinesisSettings")

    @kinesis_settings.setter
    def kinesis_settings(
        self, value: typing.Optional[typing.List["DmsEndpointKinesisSettings"]]
    ) -> None:
        jsii.set(self, "kinesisSettings", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="mongodbSettings")
    def mongodb_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointMongodbSettings"]]:
        return jsii.get(self, "mongodbSettings")

    @mongodb_settings.setter
    def mongodb_settings(
        self, value: typing.Optional[typing.List["DmsEndpointMongodbSettings"]]
    ) -> None:
        jsii.set(self, "mongodbSettings", value)

    @builtins.property
    @jsii.member(jsii_name="password")
    def password(self) -> typing.Optional[str]:
        return jsii.get(self, "password")

    @password.setter
    def password(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "password", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="s3Settings")
    def s3_settings(self) -> typing.Optional[typing.List["DmsEndpointS3Settings"]]:
        return jsii.get(self, "s3Settings")

    @s3_settings.setter
    def s3_settings(
        self, value: typing.Optional[typing.List["DmsEndpointS3Settings"]]
    ) -> None:
        jsii.set(self, "s3Settings", value)

    @builtins.property
    @jsii.member(jsii_name="serverName")
    def server_name(self) -> typing.Optional[str]:
        return jsii.get(self, "serverName")

    @server_name.setter
    def server_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "serverName", value)

    @builtins.property
    @jsii.member(jsii_name="serviceAccessRole")
    def service_access_role(self) -> typing.Optional[str]:
        return jsii.get(self, "serviceAccessRole")

    @service_access_role.setter
    def service_access_role(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "serviceAccessRole", value)

    @builtins.property
    @jsii.member(jsii_name="sslMode")
    def ssl_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "sslMode")

    @ssl_mode.setter
    def ssl_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sslMode", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="username")
    def username(self) -> typing.Optional[str]:
        return jsii.get(self, "username")

    @username.setter
    def username(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "username", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "endpoint_id": "endpointId",
        "endpoint_type": "endpointType",
        "engine_name": "engineName",
        "certificate_arn": "certificateArn",
        "database_name": "databaseName",
        "elasticsearch_settings": "elasticsearchSettings",
        "extra_connection_attributes": "extraConnectionAttributes",
        "kafka_settings": "kafkaSettings",
        "kinesis_settings": "kinesisSettings",
        "kms_key_arn": "kmsKeyArn",
        "mongodb_settings": "mongodbSettings",
        "password": "password",
        "port": "port",
        "s3_settings": "s3Settings",
        "server_name": "serverName",
        "service_access_role": "serviceAccessRole",
        "ssl_mode": "sslMode",
        "tags": "tags",
        "username": "username",
    },
)
class DmsEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        endpoint_id: str,
        endpoint_type: str,
        engine_name: str,
        certificate_arn: typing.Optional[str] = None,
        database_name: typing.Optional[str] = None,
        elasticsearch_settings: typing.Optional[
            typing.List["DmsEndpointElasticsearchSettings"]
        ] = None,
        extra_connection_attributes: typing.Optional[str] = None,
        kafka_settings: typing.Optional[typing.List["DmsEndpointKafkaSettings"]] = None,
        kinesis_settings: typing.Optional[
            typing.List["DmsEndpointKinesisSettings"]
        ] = None,
        kms_key_arn: typing.Optional[str] = None,
        mongodb_settings: typing.Optional[
            typing.List["DmsEndpointMongodbSettings"]
        ] = None,
        password: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        s3_settings: typing.Optional[typing.List["DmsEndpointS3Settings"]] = None,
        server_name: typing.Optional[str] = None,
        service_access_role: typing.Optional[str] = None,
        ssl_mode: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        username: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param endpoint_id: 
        :param endpoint_type: 
        :param engine_name: 
        :param certificate_arn: 
        :param database_name: 
        :param elasticsearch_settings: elasticsearch_settings block.
        :param extra_connection_attributes: 
        :param kafka_settings: kafka_settings block.
        :param kinesis_settings: kinesis_settings block.
        :param kms_key_arn: 
        :param mongodb_settings: mongodb_settings block.
        :param password: 
        :param port: 
        :param s3_settings: s3_settings block.
        :param server_name: 
        :param service_access_role: 
        :param ssl_mode: 
        :param tags: 
        :param username: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "endpoint_id": endpoint_id,
            "endpoint_type": endpoint_type,
            "engine_name": engine_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_arn is not None:
            self._values["certificate_arn"] = certificate_arn
        if database_name is not None:
            self._values["database_name"] = database_name
        if elasticsearch_settings is not None:
            self._values["elasticsearch_settings"] = elasticsearch_settings
        if extra_connection_attributes is not None:
            self._values["extra_connection_attributes"] = extra_connection_attributes
        if kafka_settings is not None:
            self._values["kafka_settings"] = kafka_settings
        if kinesis_settings is not None:
            self._values["kinesis_settings"] = kinesis_settings
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if mongodb_settings is not None:
            self._values["mongodb_settings"] = mongodb_settings
        if password is not None:
            self._values["password"] = password
        if port is not None:
            self._values["port"] = port
        if s3_settings is not None:
            self._values["s3_settings"] = s3_settings
        if server_name is not None:
            self._values["server_name"] = server_name
        if service_access_role is not None:
            self._values["service_access_role"] = service_access_role
        if ssl_mode is not None:
            self._values["ssl_mode"] = ssl_mode
        if tags is not None:
            self._values["tags"] = tags
        if username is not None:
            self._values["username"] = username

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def endpoint_id(self) -> str:
        return self._values.get("endpoint_id")

    @builtins.property
    def endpoint_type(self) -> str:
        return self._values.get("endpoint_type")

    @builtins.property
    def engine_name(self) -> str:
        return self._values.get("engine_name")

    @builtins.property
    def certificate_arn(self) -> typing.Optional[str]:
        return self._values.get("certificate_arn")

    @builtins.property
    def database_name(self) -> typing.Optional[str]:
        return self._values.get("database_name")

    @builtins.property
    def elasticsearch_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointElasticsearchSettings"]]:
        """elasticsearch_settings block."""
        return self._values.get("elasticsearch_settings")

    @builtins.property
    def extra_connection_attributes(self) -> typing.Optional[str]:
        return self._values.get("extra_connection_attributes")

    @builtins.property
    def kafka_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointKafkaSettings"]]:
        """kafka_settings block."""
        return self._values.get("kafka_settings")

    @builtins.property
    def kinesis_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointKinesisSettings"]]:
        """kinesis_settings block."""
        return self._values.get("kinesis_settings")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def mongodb_settings(
        self,
    ) -> typing.Optional[typing.List["DmsEndpointMongodbSettings"]]:
        """mongodb_settings block."""
        return self._values.get("mongodb_settings")

    @builtins.property
    def password(self) -> typing.Optional[str]:
        return self._values.get("password")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def s3_settings(self) -> typing.Optional[typing.List["DmsEndpointS3Settings"]]:
        """s3_settings block."""
        return self._values.get("s3_settings")

    @builtins.property
    def server_name(self) -> typing.Optional[str]:
        return self._values.get("server_name")

    @builtins.property
    def service_access_role(self) -> typing.Optional[str]:
        return self._values.get("service_access_role")

    @builtins.property
    def ssl_mode(self) -> typing.Optional[str]:
        return self._values.get("ssl_mode")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def username(self) -> typing.Optional[str]:
        return self._values.get("username")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEndpointElasticsearchSettings",
    jsii_struct_bases=[],
    name_mapping={
        "endpoint_uri": "endpointUri",
        "service_access_role_arn": "serviceAccessRoleArn",
        "error_retry_duration": "errorRetryDuration",
        "full_load_error_percentage": "fullLoadErrorPercentage",
    },
)
class DmsEndpointElasticsearchSettings:
    def __init__(
        self,
        *,
        endpoint_uri: str,
        service_access_role_arn: str,
        error_retry_duration: typing.Optional[jsii.Number] = None,
        full_load_error_percentage: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param endpoint_uri: 
        :param service_access_role_arn: 
        :param error_retry_duration: 
        :param full_load_error_percentage: 
        """
        self._values = {
            "endpoint_uri": endpoint_uri,
            "service_access_role_arn": service_access_role_arn,
        }
        if error_retry_duration is not None:
            self._values["error_retry_duration"] = error_retry_duration
        if full_load_error_percentage is not None:
            self._values["full_load_error_percentage"] = full_load_error_percentage

    @builtins.property
    def endpoint_uri(self) -> str:
        return self._values.get("endpoint_uri")

    @builtins.property
    def service_access_role_arn(self) -> str:
        return self._values.get("service_access_role_arn")

    @builtins.property
    def error_retry_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("error_retry_duration")

    @builtins.property
    def full_load_error_percentage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("full_load_error_percentage")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEndpointElasticsearchSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEndpointKafkaSettings",
    jsii_struct_bases=[],
    name_mapping={"broker": "broker", "topic": "topic"},
)
class DmsEndpointKafkaSettings:
    def __init__(self, *, broker: str, topic: typing.Optional[str] = None) -> None:
        """
        :param broker: 
        :param topic: 
        """
        self._values = {
            "broker": broker,
        }
        if topic is not None:
            self._values["topic"] = topic

    @builtins.property
    def broker(self) -> str:
        return self._values.get("broker")

    @builtins.property
    def topic(self) -> typing.Optional[str]:
        return self._values.get("topic")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEndpointKafkaSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEndpointKinesisSettings",
    jsii_struct_bases=[],
    name_mapping={
        "message_format": "messageFormat",
        "service_access_role_arn": "serviceAccessRoleArn",
        "stream_arn": "streamArn",
    },
)
class DmsEndpointKinesisSettings:
    def __init__(
        self,
        *,
        message_format: typing.Optional[str] = None,
        service_access_role_arn: typing.Optional[str] = None,
        stream_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param message_format: 
        :param service_access_role_arn: 
        :param stream_arn: 
        """
        self._values = {}
        if message_format is not None:
            self._values["message_format"] = message_format
        if service_access_role_arn is not None:
            self._values["service_access_role_arn"] = service_access_role_arn
        if stream_arn is not None:
            self._values["stream_arn"] = stream_arn

    @builtins.property
    def message_format(self) -> typing.Optional[str]:
        return self._values.get("message_format")

    @builtins.property
    def service_access_role_arn(self) -> typing.Optional[str]:
        return self._values.get("service_access_role_arn")

    @builtins.property
    def stream_arn(self) -> typing.Optional[str]:
        return self._values.get("stream_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEndpointKinesisSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEndpointMongodbSettings",
    jsii_struct_bases=[],
    name_mapping={
        "auth_mechanism": "authMechanism",
        "auth_source": "authSource",
        "auth_type": "authType",
        "docs_to_investigate": "docsToInvestigate",
        "extract_doc_id": "extractDocId",
        "nesting_level": "nestingLevel",
    },
)
class DmsEndpointMongodbSettings:
    def __init__(
        self,
        *,
        auth_mechanism: typing.Optional[str] = None,
        auth_source: typing.Optional[str] = None,
        auth_type: typing.Optional[str] = None,
        docs_to_investigate: typing.Optional[str] = None,
        extract_doc_id: typing.Optional[str] = None,
        nesting_level: typing.Optional[str] = None,
    ) -> None:
        """
        :param auth_mechanism: 
        :param auth_source: 
        :param auth_type: 
        :param docs_to_investigate: 
        :param extract_doc_id: 
        :param nesting_level: 
        """
        self._values = {}
        if auth_mechanism is not None:
            self._values["auth_mechanism"] = auth_mechanism
        if auth_source is not None:
            self._values["auth_source"] = auth_source
        if auth_type is not None:
            self._values["auth_type"] = auth_type
        if docs_to_investigate is not None:
            self._values["docs_to_investigate"] = docs_to_investigate
        if extract_doc_id is not None:
            self._values["extract_doc_id"] = extract_doc_id
        if nesting_level is not None:
            self._values["nesting_level"] = nesting_level

    @builtins.property
    def auth_mechanism(self) -> typing.Optional[str]:
        return self._values.get("auth_mechanism")

    @builtins.property
    def auth_source(self) -> typing.Optional[str]:
        return self._values.get("auth_source")

    @builtins.property
    def auth_type(self) -> typing.Optional[str]:
        return self._values.get("auth_type")

    @builtins.property
    def docs_to_investigate(self) -> typing.Optional[str]:
        return self._values.get("docs_to_investigate")

    @builtins.property
    def extract_doc_id(self) -> typing.Optional[str]:
        return self._values.get("extract_doc_id")

    @builtins.property
    def nesting_level(self) -> typing.Optional[str]:
        return self._values.get("nesting_level")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEndpointMongodbSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEndpointS3Settings",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_folder": "bucketFolder",
        "bucket_name": "bucketName",
        "compression_type": "compressionType",
        "csv_delimiter": "csvDelimiter",
        "csv_row_delimiter": "csvRowDelimiter",
        "external_table_definition": "externalTableDefinition",
        "service_access_role_arn": "serviceAccessRoleArn",
    },
)
class DmsEndpointS3Settings:
    def __init__(
        self,
        *,
        bucket_folder: typing.Optional[str] = None,
        bucket_name: typing.Optional[str] = None,
        compression_type: typing.Optional[str] = None,
        csv_delimiter: typing.Optional[str] = None,
        csv_row_delimiter: typing.Optional[str] = None,
        external_table_definition: typing.Optional[str] = None,
        service_access_role_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_folder: 
        :param bucket_name: 
        :param compression_type: 
        :param csv_delimiter: 
        :param csv_row_delimiter: 
        :param external_table_definition: 
        :param service_access_role_arn: 
        """
        self._values = {}
        if bucket_folder is not None:
            self._values["bucket_folder"] = bucket_folder
        if bucket_name is not None:
            self._values["bucket_name"] = bucket_name
        if compression_type is not None:
            self._values["compression_type"] = compression_type
        if csv_delimiter is not None:
            self._values["csv_delimiter"] = csv_delimiter
        if csv_row_delimiter is not None:
            self._values["csv_row_delimiter"] = csv_row_delimiter
        if external_table_definition is not None:
            self._values["external_table_definition"] = external_table_definition
        if service_access_role_arn is not None:
            self._values["service_access_role_arn"] = service_access_role_arn

    @builtins.property
    def bucket_folder(self) -> typing.Optional[str]:
        return self._values.get("bucket_folder")

    @builtins.property
    def bucket_name(self) -> typing.Optional[str]:
        return self._values.get("bucket_name")

    @builtins.property
    def compression_type(self) -> typing.Optional[str]:
        return self._values.get("compression_type")

    @builtins.property
    def csv_delimiter(self) -> typing.Optional[str]:
        return self._values.get("csv_delimiter")

    @builtins.property
    def csv_row_delimiter(self) -> typing.Optional[str]:
        return self._values.get("csv_row_delimiter")

    @builtins.property
    def external_table_definition(self) -> typing.Optional[str]:
        return self._values.get("external_table_definition")

    @builtins.property
    def service_access_role_arn(self) -> typing.Optional[str]:
        return self._values.get("service_access_role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEndpointS3Settings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DmsEventSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEventSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        event_categories: typing.List[str],
        name: str,
        sns_topic_arn: str,
        enabled: typing.Optional[bool] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DmsEventSubscriptionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param event_categories: 
        :param name: 
        :param sns_topic_arn: 
        :param enabled: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DmsEventSubscriptionConfig(
            event_categories=event_categories,
            name=name,
            sns_topic_arn=sns_topic_arn,
            enabled=enabled,
            source_ids=source_ids,
            source_type=source_type,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DmsEventSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="eventCategories")
    def event_categories(self) -> typing.List[str]:
        return jsii.get(self, "eventCategories")

    @event_categories.setter
    def event_categories(self, value: typing.List[str]) -> None:
        jsii.set(self, "eventCategories", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="snsTopicArn")
    def sns_topic_arn(self) -> str:
        return jsii.get(self, "snsTopicArn")

    @sns_topic_arn.setter
    def sns_topic_arn(self, value: str) -> None:
        jsii.set(self, "snsTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sourceIds")
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "sourceIds")

    @source_ids.setter
    def source_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "sourceIds", value)

    @builtins.property
    @jsii.member(jsii_name="sourceType")
    def source_type(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceType")

    @source_type.setter
    def source_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DmsEventSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DmsEventSubscriptionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEventSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "event_categories": "eventCategories",
        "name": "name",
        "sns_topic_arn": "snsTopicArn",
        "enabled": "enabled",
        "source_ids": "sourceIds",
        "source_type": "sourceType",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DmsEventSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        event_categories: typing.List[str],
        name: str,
        sns_topic_arn: str,
        enabled: typing.Optional[bool] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DmsEventSubscriptionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param event_categories: 
        :param name: 
        :param sns_topic_arn: 
        :param enabled: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DmsEventSubscriptionTimeouts(**timeouts)
        self._values = {
            "event_categories": event_categories,
            "name": name,
            "sns_topic_arn": sns_topic_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if source_ids is not None:
            self._values["source_ids"] = source_ids
        if source_type is not None:
            self._values["source_type"] = source_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def event_categories(self) -> typing.List[str]:
        return self._values.get("event_categories")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def sns_topic_arn(self) -> str:
        return self._values.get("sns_topic_arn")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("source_ids")

    @builtins.property
    def source_type(self) -> typing.Optional[str]:
        return self._values.get("source_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DmsEventSubscriptionTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEventSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsEventSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DmsEventSubscriptionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsEventSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DmsReplicationInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DmsReplicationInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        replication_instance_class: str,
        replication_instance_id: str,
        allocated_storage: typing.Optional[jsii.Number] = None,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
        multi_az: typing.Optional[bool] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        publicly_accessible: typing.Optional[bool] = None,
        replication_subnet_group_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DmsReplicationInstanceTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param replication_instance_class: 
        :param replication_instance_id: 
        :param allocated_storage: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param engine_version: 
        :param kms_key_arn: 
        :param multi_az: 
        :param preferred_maintenance_window: 
        :param publicly_accessible: 
        :param replication_subnet_group_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DmsReplicationInstanceConfig(
            replication_instance_class=replication_instance_class,
            replication_instance_id=replication_instance_id,
            allocated_storage=allocated_storage,
            apply_immediately=apply_immediately,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
            availability_zone=availability_zone,
            engine_version=engine_version,
            kms_key_arn=kms_key_arn,
            multi_az=multi_az,
            preferred_maintenance_window=preferred_maintenance_window,
            publicly_accessible=publicly_accessible,
            replication_subnet_group_id=replication_subnet_group_id,
            tags=tags,
            timeouts=timeouts,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DmsReplicationInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="replicationInstanceArn")
    def replication_instance_arn(self) -> str:
        return jsii.get(self, "replicationInstanceArn")

    @builtins.property
    @jsii.member(jsii_name="replicationInstancePrivateIps")
    def replication_instance_private_ips(self) -> typing.List[str]:
        return jsii.get(self, "replicationInstancePrivateIps")

    @builtins.property
    @jsii.member(jsii_name="replicationInstancePublicIps")
    def replication_instance_public_ips(self) -> typing.List[str]:
        return jsii.get(self, "replicationInstancePublicIps")

    @builtins.property
    @jsii.member(jsii_name="replicationInstanceClass")
    def replication_instance_class(self) -> str:
        return jsii.get(self, "replicationInstanceClass")

    @replication_instance_class.setter
    def replication_instance_class(self, value: str) -> None:
        jsii.set(self, "replicationInstanceClass", value)

    @builtins.property
    @jsii.member(jsii_name="replicationInstanceId")
    def replication_instance_id(self) -> str:
        return jsii.get(self, "replicationInstanceId")

    @replication_instance_id.setter
    def replication_instance_id(self, value: str) -> None:
        jsii.set(self, "replicationInstanceId", value)

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "allocatedStorage")

    @allocated_storage.setter
    def allocated_storage(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "allocatedStorage", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoMinorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="multiAz")
    def multi_az(self) -> typing.Optional[bool]:
        return jsii.get(self, "multiAz")

    @multi_az.setter
    def multi_az(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "multiAz", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> typing.Optional[bool]:
        return jsii.get(self, "publiclyAccessible")

    @publicly_accessible.setter
    def publicly_accessible(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "publiclyAccessible", value)

    @builtins.property
    @jsii.member(jsii_name="replicationSubnetGroupId")
    def replication_subnet_group_id(self) -> typing.Optional[str]:
        return jsii.get(self, "replicationSubnetGroupId")

    @replication_subnet_group_id.setter
    def replication_subnet_group_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "replicationSubnetGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DmsReplicationInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DmsReplicationInstanceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsReplicationInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "replication_instance_class": "replicationInstanceClass",
        "replication_instance_id": "replicationInstanceId",
        "allocated_storage": "allocatedStorage",
        "apply_immediately": "applyImmediately",
        "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
        "availability_zone": "availabilityZone",
        "engine_version": "engineVersion",
        "kms_key_arn": "kmsKeyArn",
        "multi_az": "multiAz",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "publicly_accessible": "publiclyAccessible",
        "replication_subnet_group_id": "replicationSubnetGroupId",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class DmsReplicationInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        replication_instance_class: str,
        replication_instance_id: str,
        allocated_storage: typing.Optional[jsii.Number] = None,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
        multi_az: typing.Optional[bool] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        publicly_accessible: typing.Optional[bool] = None,
        replication_subnet_group_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DmsReplicationInstanceTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param replication_instance_class: 
        :param replication_instance_id: 
        :param allocated_storage: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param engine_version: 
        :param kms_key_arn: 
        :param multi_az: 
        :param preferred_maintenance_window: 
        :param publicly_accessible: 
        :param replication_subnet_group_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DmsReplicationInstanceTimeouts(**timeouts)
        self._values = {
            "replication_instance_class": replication_instance_class,
            "replication_instance_id": replication_instance_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocated_storage is not None:
            self._values["allocated_storage"] = allocated_storage
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if auto_minor_version_upgrade is not None:
            self._values["auto_minor_version_upgrade"] = auto_minor_version_upgrade
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if multi_az is not None:
            self._values["multi_az"] = multi_az
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if publicly_accessible is not None:
            self._values["publicly_accessible"] = publicly_accessible
        if replication_subnet_group_id is not None:
            self._values["replication_subnet_group_id"] = replication_subnet_group_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def replication_instance_class(self) -> str:
        return self._values.get("replication_instance_class")

    @builtins.property
    def replication_instance_id(self) -> str:
        return self._values.get("replication_instance_id")

    @builtins.property
    def allocated_storage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("allocated_storage")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("auto_minor_version_upgrade")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def multi_az(self) -> typing.Optional[bool]:
        return self._values.get("multi_az")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def publicly_accessible(self) -> typing.Optional[bool]:
        return self._values.get("publicly_accessible")

    @builtins.property
    def replication_subnet_group_id(self) -> typing.Optional[str]:
        return self._values.get("replication_subnet_group_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DmsReplicationInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsReplicationInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsReplicationInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DmsReplicationInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsReplicationInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DmsReplicationSubnetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DmsReplicationSubnetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        replication_subnet_group_description: str,
        replication_subnet_group_id: str,
        subnet_ids: typing.List[str],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param replication_subnet_group_description: 
        :param replication_subnet_group_id: 
        :param subnet_ids: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DmsReplicationSubnetGroupConfig(
            replication_subnet_group_description=replication_subnet_group_description,
            replication_subnet_group_id=replication_subnet_group_id,
            subnet_ids=subnet_ids,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DmsReplicationSubnetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="replicationSubnetGroupArn")
    def replication_subnet_group_arn(self) -> str:
        return jsii.get(self, "replicationSubnetGroupArn")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="replicationSubnetGroupDescription")
    def replication_subnet_group_description(self) -> str:
        return jsii.get(self, "replicationSubnetGroupDescription")

    @replication_subnet_group_description.setter
    def replication_subnet_group_description(self, value: str) -> None:
        jsii.set(self, "replicationSubnetGroupDescription", value)

    @builtins.property
    @jsii.member(jsii_name="replicationSubnetGroupId")
    def replication_subnet_group_id(self) -> str:
        return jsii.get(self, "replicationSubnetGroupId")

    @replication_subnet_group_id.setter
    def replication_subnet_group_id(self, value: str) -> None:
        jsii.set(self, "replicationSubnetGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsReplicationSubnetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "replication_subnet_group_description": "replicationSubnetGroupDescription",
        "replication_subnet_group_id": "replicationSubnetGroupId",
        "subnet_ids": "subnetIds",
        "tags": "tags",
    },
)
class DmsReplicationSubnetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        replication_subnet_group_description: str,
        replication_subnet_group_id: str,
        subnet_ids: typing.List[str],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param replication_subnet_group_description: 
        :param replication_subnet_group_id: 
        :param subnet_ids: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "replication_subnet_group_description": replication_subnet_group_description,
            "replication_subnet_group_id": replication_subnet_group_id,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def replication_subnet_group_description(self) -> str:
        return self._values.get("replication_subnet_group_description")

    @builtins.property
    def replication_subnet_group_id(self) -> str:
        return self._values.get("replication_subnet_group_id")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsReplicationSubnetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DmsReplicationTask(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DmsReplicationTask",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        migration_type: str,
        replication_instance_arn: str,
        replication_task_id: str,
        source_endpoint_arn: str,
        table_mappings: str,
        target_endpoint_arn: str,
        cdc_start_time: typing.Optional[str] = None,
        replication_task_settings: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param migration_type: 
        :param replication_instance_arn: 
        :param replication_task_id: 
        :param source_endpoint_arn: 
        :param table_mappings: 
        :param target_endpoint_arn: 
        :param cdc_start_time: 
        :param replication_task_settings: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DmsReplicationTaskConfig(
            migration_type=migration_type,
            replication_instance_arn=replication_instance_arn,
            replication_task_id=replication_task_id,
            source_endpoint_arn=source_endpoint_arn,
            table_mappings=table_mappings,
            target_endpoint_arn=target_endpoint_arn,
            cdc_start_time=cdc_start_time,
            replication_task_settings=replication_task_settings,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DmsReplicationTask, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="replicationTaskArn")
    def replication_task_arn(self) -> str:
        return jsii.get(self, "replicationTaskArn")

    @builtins.property
    @jsii.member(jsii_name="migrationType")
    def migration_type(self) -> str:
        return jsii.get(self, "migrationType")

    @migration_type.setter
    def migration_type(self, value: str) -> None:
        jsii.set(self, "migrationType", value)

    @builtins.property
    @jsii.member(jsii_name="replicationInstanceArn")
    def replication_instance_arn(self) -> str:
        return jsii.get(self, "replicationInstanceArn")

    @replication_instance_arn.setter
    def replication_instance_arn(self, value: str) -> None:
        jsii.set(self, "replicationInstanceArn", value)

    @builtins.property
    @jsii.member(jsii_name="replicationTaskId")
    def replication_task_id(self) -> str:
        return jsii.get(self, "replicationTaskId")

    @replication_task_id.setter
    def replication_task_id(self, value: str) -> None:
        jsii.set(self, "replicationTaskId", value)

    @builtins.property
    @jsii.member(jsii_name="sourceEndpointArn")
    def source_endpoint_arn(self) -> str:
        return jsii.get(self, "sourceEndpointArn")

    @source_endpoint_arn.setter
    def source_endpoint_arn(self, value: str) -> None:
        jsii.set(self, "sourceEndpointArn", value)

    @builtins.property
    @jsii.member(jsii_name="tableMappings")
    def table_mappings(self) -> str:
        return jsii.get(self, "tableMappings")

    @table_mappings.setter
    def table_mappings(self, value: str) -> None:
        jsii.set(self, "tableMappings", value)

    @builtins.property
    @jsii.member(jsii_name="targetEndpointArn")
    def target_endpoint_arn(self) -> str:
        return jsii.get(self, "targetEndpointArn")

    @target_endpoint_arn.setter
    def target_endpoint_arn(self, value: str) -> None:
        jsii.set(self, "targetEndpointArn", value)

    @builtins.property
    @jsii.member(jsii_name="cdcStartTime")
    def cdc_start_time(self) -> typing.Optional[str]:
        return jsii.get(self, "cdcStartTime")

    @cdc_start_time.setter
    def cdc_start_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cdcStartTime", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="replicationTaskSettings")
    def replication_task_settings(self) -> typing.Optional[str]:
        return jsii.get(self, "replicationTaskSettings")

    @replication_task_settings.setter
    def replication_task_settings(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "replicationTaskSettings", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DmsReplicationTaskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "migration_type": "migrationType",
        "replication_instance_arn": "replicationInstanceArn",
        "replication_task_id": "replicationTaskId",
        "source_endpoint_arn": "sourceEndpointArn",
        "table_mappings": "tableMappings",
        "target_endpoint_arn": "targetEndpointArn",
        "cdc_start_time": "cdcStartTime",
        "replication_task_settings": "replicationTaskSettings",
        "tags": "tags",
    },
)
class DmsReplicationTaskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        migration_type: str,
        replication_instance_arn: str,
        replication_task_id: str,
        source_endpoint_arn: str,
        table_mappings: str,
        target_endpoint_arn: str,
        cdc_start_time: typing.Optional[str] = None,
        replication_task_settings: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param migration_type: 
        :param replication_instance_arn: 
        :param replication_task_id: 
        :param source_endpoint_arn: 
        :param table_mappings: 
        :param target_endpoint_arn: 
        :param cdc_start_time: 
        :param replication_task_settings: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "migration_type": migration_type,
            "replication_instance_arn": replication_instance_arn,
            "replication_task_id": replication_task_id,
            "source_endpoint_arn": source_endpoint_arn,
            "table_mappings": table_mappings,
            "target_endpoint_arn": target_endpoint_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cdc_start_time is not None:
            self._values["cdc_start_time"] = cdc_start_time
        if replication_task_settings is not None:
            self._values["replication_task_settings"] = replication_task_settings
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def migration_type(self) -> str:
        return self._values.get("migration_type")

    @builtins.property
    def replication_instance_arn(self) -> str:
        return self._values.get("replication_instance_arn")

    @builtins.property
    def replication_task_id(self) -> str:
        return self._values.get("replication_task_id")

    @builtins.property
    def source_endpoint_arn(self) -> str:
        return self._values.get("source_endpoint_arn")

    @builtins.property
    def table_mappings(self) -> str:
        return self._values.get("table_mappings")

    @builtins.property
    def target_endpoint_arn(self) -> str:
        return self._values.get("target_endpoint_arn")

    @builtins.property
    def cdc_start_time(self) -> typing.Optional[str]:
        return self._values.get("cdc_start_time")

    @builtins.property
    def replication_task_settings(self) -> typing.Optional[str]:
        return self._values.get("replication_task_settings")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DmsReplicationTaskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DocdbCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        apply_immediately: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        cluster_identifier: typing.Optional[str] = None,
        cluster_identifier_prefix: typing.Optional[str] = None,
        cluster_members: typing.Optional[typing.List[str]] = None,
        db_cluster_parameter_group_name: typing.Optional[str] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        enabled_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        master_password: typing.Optional[str] = None,
        master_username: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DocdbClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param apply_immediately: 
        :param availability_zones: 
        :param backup_retention_period: 
        :param cluster_identifier: 
        :param cluster_identifier_prefix: 
        :param cluster_members: 
        :param db_cluster_parameter_group_name: 
        :param db_subnet_group_name: 
        :param deletion_protection: 
        :param enabled_cloudwatch_logs_exports: 
        :param engine: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param kms_key_id: 
        :param master_password: 
        :param master_username: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param storage_encrypted: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DocdbClusterConfig(
            apply_immediately=apply_immediately,
            availability_zones=availability_zones,
            backup_retention_period=backup_retention_period,
            cluster_identifier=cluster_identifier,
            cluster_identifier_prefix=cluster_identifier_prefix,
            cluster_members=cluster_members,
            db_cluster_parameter_group_name=db_cluster_parameter_group_name,
            db_subnet_group_name=db_subnet_group_name,
            deletion_protection=deletion_protection,
            enabled_cloudwatch_logs_exports=enabled_cloudwatch_logs_exports,
            engine=engine,
            engine_version=engine_version,
            final_snapshot_identifier=final_snapshot_identifier,
            kms_key_id=kms_key_id,
            master_password=master_password,
            master_username=master_username,
            port=port,
            preferred_backup_window=preferred_backup_window,
            preferred_maintenance_window=preferred_maintenance_window,
            skip_final_snapshot=skip_final_snapshot,
            snapshot_identifier=snapshot_identifier,
            storage_encrypted=storage_encrypted,
            tags=tags,
            timeouts=timeouts,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DocdbCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="clusterResourceId")
    def cluster_resource_id(self) -> str:
        return jsii.get(self, "clusterResourceId")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="readerEndpoint")
    def reader_endpoint(self) -> str:
        return jsii.get(self, "readerEndpoint")

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="backupRetentionPeriod")
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "backupRetentionPeriod")

    @backup_retention_period.setter
    def backup_retention_period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "backupRetentionPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifierPrefix")
    def cluster_identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterIdentifierPrefix")

    @cluster_identifier_prefix.setter
    def cluster_identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterIdentifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="clusterMembers")
    def cluster_members(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "clusterMembers")

    @cluster_members.setter
    def cluster_members(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "clusterMembers", value)

    @builtins.property
    @jsii.member(jsii_name="dbClusterParameterGroupName")
    def db_cluster_parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dbClusterParameterGroupName")

    @db_cluster_parameter_group_name.setter
    def db_cluster_parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbClusterParameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="dbSubnetGroupName")
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dbSubnetGroupName")

    @db_subnet_group_name.setter
    def db_subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbSubnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "deletionProtection")

    @deletion_protection.setter
    def deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="enabledCloudwatchLogsExports")
    def enabled_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "enabledCloudwatchLogsExports")

    @enabled_cloudwatch_logs_exports.setter
    def enabled_cloudwatch_logs_exports(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "enabledCloudwatchLogsExports", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="finalSnapshotIdentifier")
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "finalSnapshotIdentifier")

    @final_snapshot_identifier.setter
    def final_snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "finalSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="masterPassword")
    def master_password(self) -> typing.Optional[str]:
        return jsii.get(self, "masterPassword")

    @master_password.setter
    def master_password(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "masterPassword", value)

    @builtins.property
    @jsii.member(jsii_name="masterUsername")
    def master_username(self) -> typing.Optional[str]:
        return jsii.get(self, "masterUsername")

    @master_username.setter
    def master_username(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "masterUsername", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredBackupWindow")

    @preferred_backup_window.setter
    def preferred_backup_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredBackupWindow", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="skipFinalSnapshot")
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipFinalSnapshot")

    @skip_final_snapshot.setter
    def skip_final_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipFinalSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotIdentifier")
    def snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotIdentifier")

    @snapshot_identifier.setter
    def snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "storageEncrypted")

    @storage_encrypted.setter
    def storage_encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "storageEncrypted", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DocdbClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DocdbClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "apply_immediately": "applyImmediately",
        "availability_zones": "availabilityZones",
        "backup_retention_period": "backupRetentionPeriod",
        "cluster_identifier": "clusterIdentifier",
        "cluster_identifier_prefix": "clusterIdentifierPrefix",
        "cluster_members": "clusterMembers",
        "db_cluster_parameter_group_name": "dbClusterParameterGroupName",
        "db_subnet_group_name": "dbSubnetGroupName",
        "deletion_protection": "deletionProtection",
        "enabled_cloudwatch_logs_exports": "enabledCloudwatchLogsExports",
        "engine": "engine",
        "engine_version": "engineVersion",
        "final_snapshot_identifier": "finalSnapshotIdentifier",
        "kms_key_id": "kmsKeyId",
        "master_password": "masterPassword",
        "master_username": "masterUsername",
        "port": "port",
        "preferred_backup_window": "preferredBackupWindow",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "skip_final_snapshot": "skipFinalSnapshot",
        "snapshot_identifier": "snapshotIdentifier",
        "storage_encrypted": "storageEncrypted",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class DocdbClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        apply_immediately: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        cluster_identifier: typing.Optional[str] = None,
        cluster_identifier_prefix: typing.Optional[str] = None,
        cluster_members: typing.Optional[typing.List[str]] = None,
        db_cluster_parameter_group_name: typing.Optional[str] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        enabled_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        master_password: typing.Optional[str] = None,
        master_username: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DocdbClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param apply_immediately: 
        :param availability_zones: 
        :param backup_retention_period: 
        :param cluster_identifier: 
        :param cluster_identifier_prefix: 
        :param cluster_members: 
        :param db_cluster_parameter_group_name: 
        :param db_subnet_group_name: 
        :param deletion_protection: 
        :param enabled_cloudwatch_logs_exports: 
        :param engine: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param kms_key_id: 
        :param master_password: 
        :param master_username: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param storage_encrypted: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DocdbClusterTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if backup_retention_period is not None:
            self._values["backup_retention_period"] = backup_retention_period
        if cluster_identifier is not None:
            self._values["cluster_identifier"] = cluster_identifier
        if cluster_identifier_prefix is not None:
            self._values["cluster_identifier_prefix"] = cluster_identifier_prefix
        if cluster_members is not None:
            self._values["cluster_members"] = cluster_members
        if db_cluster_parameter_group_name is not None:
            self._values[
                "db_cluster_parameter_group_name"
            ] = db_cluster_parameter_group_name
        if db_subnet_group_name is not None:
            self._values["db_subnet_group_name"] = db_subnet_group_name
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if enabled_cloudwatch_logs_exports is not None:
            self._values[
                "enabled_cloudwatch_logs_exports"
            ] = enabled_cloudwatch_logs_exports
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if final_snapshot_identifier is not None:
            self._values["final_snapshot_identifier"] = final_snapshot_identifier
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if master_password is not None:
            self._values["master_password"] = master_password
        if master_username is not None:
            self._values["master_username"] = master_username
        if port is not None:
            self._values["port"] = port
        if preferred_backup_window is not None:
            self._values["preferred_backup_window"] = preferred_backup_window
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if skip_final_snapshot is not None:
            self._values["skip_final_snapshot"] = skip_final_snapshot
        if snapshot_identifier is not None:
            self._values["snapshot_identifier"] = snapshot_identifier
        if storage_encrypted is not None:
            self._values["storage_encrypted"] = storage_encrypted
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("backup_retention_period")

    @builtins.property
    def cluster_identifier(self) -> typing.Optional[str]:
        return self._values.get("cluster_identifier")

    @builtins.property
    def cluster_identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("cluster_identifier_prefix")

    @builtins.property
    def cluster_members(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cluster_members")

    @builtins.property
    def db_cluster_parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("db_cluster_parameter_group_name")

    @builtins.property
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("db_subnet_group_name")

    @builtins.property
    def deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("deletion_protection")

    @builtins.property
    def enabled_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("enabled_cloudwatch_logs_exports")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("final_snapshot_identifier")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def master_password(self) -> typing.Optional[str]:
        return self._values.get("master_password")

    @builtins.property
    def master_username(self) -> typing.Optional[str]:
        return self._values.get("master_username")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def preferred_backup_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_backup_window")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("skip_final_snapshot")

    @builtins.property
    def snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("snapshot_identifier")

    @builtins.property
    def storage_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("storage_encrypted")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DocdbClusterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DocdbClusterInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_identifier: str,
        instance_class: str,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        ca_cert_identifier: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        promotion_tier: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DocdbClusterInstanceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_identifier: 
        :param instance_class: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param ca_cert_identifier: 
        :param engine: 
        :param identifier: 
        :param identifier_prefix: 
        :param preferred_maintenance_window: 
        :param promotion_tier: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DocdbClusterInstanceConfig(
            cluster_identifier=cluster_identifier,
            instance_class=instance_class,
            apply_immediately=apply_immediately,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
            availability_zone=availability_zone,
            ca_cert_identifier=ca_cert_identifier,
            engine=engine,
            identifier=identifier,
            identifier_prefix=identifier_prefix,
            preferred_maintenance_window=preferred_maintenance_window,
            promotion_tier=promotion_tier,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DocdbClusterInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dbiResourceId")
    def dbi_resource_id(self) -> str:
        return jsii.get(self, "dbiResourceId")

    @builtins.property
    @jsii.member(jsii_name="dbSubnetGroupName")
    def db_subnet_group_name(self) -> str:
        return jsii.get(self, "dbSubnetGroupName")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> str:
        return jsii.get(self, "preferredBackupWindow")

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> bool:
        return jsii.get(self, "publiclyAccessible")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="writer")
    def writer(self) -> bool:
        return jsii.get(self, "writer")

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="instanceClass")
    def instance_class(self) -> str:
        return jsii.get(self, "instanceClass")

    @instance_class.setter
    def instance_class(self, value: str) -> None:
        jsii.set(self, "instanceClass", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoMinorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="caCertIdentifier")
    def ca_cert_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "caCertIdentifier")

    @ca_cert_identifier.setter
    def ca_cert_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "caCertIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property
    @jsii.member(jsii_name="identifierPrefix")
    def identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "identifierPrefix")

    @identifier_prefix.setter
    def identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="promotionTier")
    def promotion_tier(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "promotionTier")

    @promotion_tier.setter
    def promotion_tier(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "promotionTier", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DocdbClusterInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DocdbClusterInstanceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_identifier": "clusterIdentifier",
        "instance_class": "instanceClass",
        "apply_immediately": "applyImmediately",
        "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
        "availability_zone": "availabilityZone",
        "ca_cert_identifier": "caCertIdentifier",
        "engine": "engine",
        "identifier": "identifier",
        "identifier_prefix": "identifierPrefix",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "promotion_tier": "promotionTier",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DocdbClusterInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_identifier: str,
        instance_class: str,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        ca_cert_identifier: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        promotion_tier: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DocdbClusterInstanceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_identifier: 
        :param instance_class: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param ca_cert_identifier: 
        :param engine: 
        :param identifier: 
        :param identifier_prefix: 
        :param preferred_maintenance_window: 
        :param promotion_tier: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DocdbClusterInstanceTimeouts(**timeouts)
        self._values = {
            "cluster_identifier": cluster_identifier,
            "instance_class": instance_class,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if auto_minor_version_upgrade is not None:
            self._values["auto_minor_version_upgrade"] = auto_minor_version_upgrade
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if ca_cert_identifier is not None:
            self._values["ca_cert_identifier"] = ca_cert_identifier
        if engine is not None:
            self._values["engine"] = engine
        if identifier is not None:
            self._values["identifier"] = identifier
        if identifier_prefix is not None:
            self._values["identifier_prefix"] = identifier_prefix
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if promotion_tier is not None:
            self._values["promotion_tier"] = promotion_tier
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def instance_class(self) -> str:
        return self._values.get("instance_class")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("auto_minor_version_upgrade")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def ca_cert_identifier(self) -> typing.Optional[str]:
        return self._values.get("ca_cert_identifier")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def identifier(self) -> typing.Optional[str]:
        return self._values.get("identifier")

    @builtins.property
    def identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("identifier_prefix")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def promotion_tier(self) -> typing.Optional[jsii.Number]:
        return self._values.get("promotion_tier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DocdbClusterInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DocdbClusterInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DocdbClusterParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["DocdbClusterParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DocdbClusterParameterGroupConfig(
            family=family,
            description=description,
            name=name,
            name_prefix=name_prefix,
            parameter=parameter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DocdbClusterParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="parameter")
    def parameter(
        self,
    ) -> typing.Optional[typing.List["DocdbClusterParameterGroupParameter"]]:
        return jsii.get(self, "parameter")

    @parameter.setter
    def parameter(
        self, value: typing.Optional[typing.List["DocdbClusterParameterGroupParameter"]]
    ) -> None:
        jsii.set(self, "parameter", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "parameter": "parameter",
        "tags": "tags",
    },
)
class DocdbClusterParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["DocdbClusterParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "family": family,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if parameter is not None:
            self._values["parameter"] = parameter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[typing.List["DocdbClusterParameterGroupParameter"]]:
        """parameter block."""
        return self._values.get("parameter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterParameterGroupParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value", "apply_method": "applyMethod"},
)
class DocdbClusterParameterGroupParameter:
    def __init__(
        self, *, name: str, value: str, apply_method: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        :param apply_method: 
        """
        self._values = {
            "name": name,
            "value": value,
        }
        if apply_method is not None:
            self._values["apply_method"] = apply_method

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def apply_method(self) -> typing.Optional[str]:
        return self._values.get("apply_method")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterParameterGroupParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DocdbClusterSnapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_cluster_identifier: str,
        db_cluster_snapshot_identifier: str,
        timeouts: typing.Optional["DocdbClusterSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DocdbClusterSnapshotConfig(
            db_cluster_identifier=db_cluster_identifier,
            db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DocdbClusterSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotArn")
    def db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "dbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="snapshotType")
    def snapshot_type(self) -> str:
        return jsii.get(self, "snapshotType")

    @builtins.property
    @jsii.member(jsii_name="sourceDbClusterSnapshotArn")
    def source_db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "sourceDbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="dbClusterIdentifier")
    def db_cluster_identifier(self) -> str:
        return jsii.get(self, "dbClusterIdentifier")

    @db_cluster_identifier.setter
    def db_cluster_identifier(self, value: str) -> None:
        jsii.set(self, "dbClusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotIdentifier")
    def db_cluster_snapshot_identifier(self) -> str:
        return jsii.get(self, "dbClusterSnapshotIdentifier")

    @db_cluster_snapshot_identifier.setter
    def db_cluster_snapshot_identifier(self, value: str) -> None:
        jsii.set(self, "dbClusterSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DocdbClusterSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DocdbClusterSnapshotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_cluster_identifier": "dbClusterIdentifier",
        "db_cluster_snapshot_identifier": "dbClusterSnapshotIdentifier",
        "timeouts": "timeouts",
    },
)
class DocdbClusterSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_cluster_identifier: str,
        db_cluster_snapshot_identifier: str,
        timeouts: typing.Optional["DocdbClusterSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DocdbClusterSnapshotTimeouts(**timeouts)
        self._values = {
            "db_cluster_identifier": db_cluster_identifier,
            "db_cluster_snapshot_identifier": db_cluster_snapshot_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_cluster_identifier(self) -> str:
        return self._values.get("db_cluster_identifier")

    @builtins.property
    def db_cluster_snapshot_identifier(self) -> str:
        return self._values.get("db_cluster_snapshot_identifier")

    @builtins.property
    def timeouts(self) -> typing.Optional["DocdbClusterSnapshotTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class DocdbClusterSnapshotTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DocdbClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DocdbSubnetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbSubnetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param subnet_ids: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DocdbSubnetGroupConfig(
            subnet_ids=subnet_ids,
            description=description,
            name=name,
            name_prefix=name_prefix,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DocdbSubnetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DocdbSubnetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "subnet_ids": "subnetIds",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "tags": "tags",
    },
)
class DocdbSubnetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param subnet_ids: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DocdbSubnetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxBgpPeer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxBgpPeer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        address_family: str,
        bgp_asn: jsii.Number,
        virtual_interface_id: str,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        timeouts: typing.Optional["DxBgpPeerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_family: 
        :param bgp_asn: 
        :param virtual_interface_id: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxBgpPeerConfig(
            address_family=address_family,
            bgp_asn=bgp_asn,
            virtual_interface_id=virtual_interface_id,
            amazon_address=amazon_address,
            bgp_auth_key=bgp_auth_key,
            customer_address=customer_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxBgpPeer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="bgpPeerId")
    def bgp_peer_id(self) -> str:
        return jsii.get(self, "bgpPeerId")

    @builtins.property
    @jsii.member(jsii_name="bgpStatus")
    def bgp_status(self) -> str:
        return jsii.get(self, "bgpStatus")

    @builtins.property
    @jsii.member(jsii_name="addressFamily")
    def address_family(self) -> str:
        return jsii.get(self, "addressFamily")

    @address_family.setter
    def address_family(self, value: str) -> None:
        jsii.set(self, "addressFamily", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: jsii.Number) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="virtualInterfaceId")
    def virtual_interface_id(self) -> str:
        return jsii.get(self, "virtualInterfaceId")

    @virtual_interface_id.setter
    def virtual_interface_id(self, value: str) -> None:
        jsii.set(self, "virtualInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="amazonAddress")
    def amazon_address(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonAddress")

    @amazon_address.setter
    def amazon_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonAddress", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAuthKey")
    def bgp_auth_key(self) -> typing.Optional[str]:
        return jsii.get(self, "bgpAuthKey")

    @bgp_auth_key.setter
    def bgp_auth_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bgpAuthKey", value)

    @builtins.property
    @jsii.member(jsii_name="customerAddress")
    def customer_address(self) -> typing.Optional[str]:
        return jsii.get(self, "customerAddress")

    @customer_address.setter
    def customer_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerAddress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxBgpPeerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DxBgpPeerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxBgpPeerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_family": "addressFamily",
        "bgp_asn": "bgpAsn",
        "virtual_interface_id": "virtualInterfaceId",
        "amazon_address": "amazonAddress",
        "bgp_auth_key": "bgpAuthKey",
        "customer_address": "customerAddress",
        "timeouts": "timeouts",
    },
)
class DxBgpPeerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_family: str,
        bgp_asn: jsii.Number,
        virtual_interface_id: str,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        timeouts: typing.Optional["DxBgpPeerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_family: 
        :param bgp_asn: 
        :param virtual_interface_id: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxBgpPeerTimeouts(**timeouts)
        self._values = {
            "address_family": address_family,
            "bgp_asn": bgp_asn,
            "virtual_interface_id": virtual_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_address is not None:
            self._values["amazon_address"] = amazon_address
        if bgp_auth_key is not None:
            self._values["bgp_auth_key"] = bgp_auth_key
        if customer_address is not None:
            self._values["customer_address"] = customer_address
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def address_family(self) -> str:
        return self._values.get("address_family")

    @builtins.property
    def bgp_asn(self) -> jsii.Number:
        return self._values.get("bgp_asn")

    @builtins.property
    def virtual_interface_id(self) -> str:
        return self._values.get("virtual_interface_id")

    @builtins.property
    def amazon_address(self) -> typing.Optional[str]:
        return self._values.get("amazon_address")

    @builtins.property
    def bgp_auth_key(self) -> typing.Optional[str]:
        return self._values.get("bgp_auth_key")

    @builtins.property
    def customer_address(self) -> typing.Optional[str]:
        return self._values.get("customer_address")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxBgpPeerTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxBgpPeerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxBgpPeerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DxBgpPeerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxBgpPeerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bandwidth: str,
        location: str,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bandwidth: 
        :param location: 
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxConnectionConfig(
            bandwidth=bandwidth,
            location=location,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="hasLogicalRedundancy")
    def has_logical_redundancy(self) -> str:
        return jsii.get(self, "hasLogicalRedundancy")

    @builtins.property
    @jsii.member(jsii_name="jumboFrameCapable")
    def jumbo_frame_capable(self) -> bool:
        return jsii.get(self, "jumboFrameCapable")

    @builtins.property
    @jsii.member(jsii_name="bandwidth")
    def bandwidth(self) -> str:
        return jsii.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: str) -> None:
        jsii.set(self, "bandwidth", value)

    @builtins.property
    @jsii.member(jsii_name="location")
    def location(self) -> str:
        return jsii.get(self, "location")

    @location.setter
    def location(self, value: str) -> None:
        jsii.set(self, "location", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class DxConnectionAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxConnectionAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        connection_id: str,
        lag_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_id: 
        :param lag_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxConnectionAssociationConfig(
            connection_id=connection_id,
            lag_id=lag_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxConnectionAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> str:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: str) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="lagId")
    def lag_id(self) -> str:
        return jsii.get(self, "lagId")

    @lag_id.setter
    def lag_id(self, value: str) -> None:
        jsii.set(self, "lagId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxConnectionAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_id": "connectionId",
        "lag_id": "lagId",
    },
)
class DxConnectionAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_id: str,
        lag_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_id: 
        :param lag_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "connection_id": connection_id,
            "lag_id": lag_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def connection_id(self) -> str:
        return self._values.get("connection_id")

    @builtins.property
    def lag_id(self) -> str:
        return self._values.get("lag_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxConnectionAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bandwidth": "bandwidth",
        "location": "location",
        "name": "name",
        "tags": "tags",
    },
)
class DxConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bandwidth: str,
        location: str,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bandwidth: 
        :param location: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bandwidth": bandwidth,
            "location": location,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bandwidth(self) -> str:
        return self._values.get("bandwidth")

    @builtins.property
    def location(self) -> str:
        return self._values.get("location")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        amazon_side_asn: str,
        name: str,
        timeouts: typing.Optional["DxGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param amazon_side_asn: 
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxGatewayConfig(
            amazon_side_asn=amazon_side_asn,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ownerAccountId")
    def owner_account_id(self) -> str:
        return jsii.get(self, "ownerAccountId")

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @amazon_side_asn.setter
    def amazon_side_asn(self, value: str) -> None:
        jsii.set(self, "amazonSideAsn", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DxGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class DxGatewayAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxGatewayAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dx_gateway_id: str,
        allowed_prefixes: typing.Optional[typing.List[str]] = None,
        associated_gateway_id: typing.Optional[str] = None,
        associated_gateway_owner_account_id: typing.Optional[str] = None,
        proposal_id: typing.Optional[str] = None,
        timeouts: typing.Optional["DxGatewayAssociationTimeouts"] = None,
        vpn_gateway_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dx_gateway_id: 
        :param allowed_prefixes: 
        :param associated_gateway_id: 
        :param associated_gateway_owner_account_id: 
        :param proposal_id: 
        :param timeouts: timeouts block.
        :param vpn_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxGatewayAssociationConfig(
            dx_gateway_id=dx_gateway_id,
            allowed_prefixes=allowed_prefixes,
            associated_gateway_id=associated_gateway_id,
            associated_gateway_owner_account_id=associated_gateway_owner_account_id,
            proposal_id=proposal_id,
            timeouts=timeouts,
            vpn_gateway_id=vpn_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxGatewayAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="associatedGatewayType")
    def associated_gateway_type(self) -> str:
        return jsii.get(self, "associatedGatewayType")

    @builtins.property
    @jsii.member(jsii_name="dxGatewayAssociationId")
    def dx_gateway_association_id(self) -> str:
        return jsii.get(self, "dxGatewayAssociationId")

    @builtins.property
    @jsii.member(jsii_name="dxGatewayOwnerAccountId")
    def dx_gateway_owner_account_id(self) -> str:
        return jsii.get(self, "dxGatewayOwnerAccountId")

    @builtins.property
    @jsii.member(jsii_name="dxGatewayId")
    def dx_gateway_id(self) -> str:
        return jsii.get(self, "dxGatewayId")

    @dx_gateway_id.setter
    def dx_gateway_id(self, value: str) -> None:
        jsii.set(self, "dxGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="allowedPrefixes")
    def allowed_prefixes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "allowedPrefixes")

    @allowed_prefixes.setter
    def allowed_prefixes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "allowedPrefixes", value)

    @builtins.property
    @jsii.member(jsii_name="associatedGatewayId")
    def associated_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "associatedGatewayId")

    @associated_gateway_id.setter
    def associated_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "associatedGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="associatedGatewayOwnerAccountId")
    def associated_gateway_owner_account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "associatedGatewayOwnerAccountId")

    @associated_gateway_owner_account_id.setter
    def associated_gateway_owner_account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "associatedGatewayOwnerAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="proposalId")
    def proposal_id(self) -> typing.Optional[str]:
        return jsii.get(self, "proposalId")

    @proposal_id.setter
    def proposal_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "proposalId", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxGatewayAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DxGatewayAssociationTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpnGatewayId")
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpnGatewayId")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpnGatewayId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxGatewayAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dx_gateway_id": "dxGatewayId",
        "allowed_prefixes": "allowedPrefixes",
        "associated_gateway_id": "associatedGatewayId",
        "associated_gateway_owner_account_id": "associatedGatewayOwnerAccountId",
        "proposal_id": "proposalId",
        "timeouts": "timeouts",
        "vpn_gateway_id": "vpnGatewayId",
    },
)
class DxGatewayAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dx_gateway_id: str,
        allowed_prefixes: typing.Optional[typing.List[str]] = None,
        associated_gateway_id: typing.Optional[str] = None,
        associated_gateway_owner_account_id: typing.Optional[str] = None,
        proposal_id: typing.Optional[str] = None,
        timeouts: typing.Optional["DxGatewayAssociationTimeouts"] = None,
        vpn_gateway_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dx_gateway_id: 
        :param allowed_prefixes: 
        :param associated_gateway_id: 
        :param associated_gateway_owner_account_id: 
        :param proposal_id: 
        :param timeouts: timeouts block.
        :param vpn_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxGatewayAssociationTimeouts(**timeouts)
        self._values = {
            "dx_gateway_id": dx_gateway_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allowed_prefixes is not None:
            self._values["allowed_prefixes"] = allowed_prefixes
        if associated_gateway_id is not None:
            self._values["associated_gateway_id"] = associated_gateway_id
        if associated_gateway_owner_account_id is not None:
            self._values[
                "associated_gateway_owner_account_id"
            ] = associated_gateway_owner_account_id
        if proposal_id is not None:
            self._values["proposal_id"] = proposal_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpn_gateway_id is not None:
            self._values["vpn_gateway_id"] = vpn_gateway_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dx_gateway_id(self) -> str:
        return self._values.get("dx_gateway_id")

    @builtins.property
    def allowed_prefixes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allowed_prefixes")

    @builtins.property
    def associated_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("associated_gateway_id")

    @builtins.property
    def associated_gateway_owner_account_id(self) -> typing.Optional[str]:
        return self._values.get("associated_gateway_owner_account_id")

    @builtins.property
    def proposal_id(self) -> typing.Optional[str]:
        return self._values.get("proposal_id")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxGatewayAssociationTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("vpn_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxGatewayAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxGatewayAssociationProposal(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxGatewayAssociationProposal",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dx_gateway_id: str,
        dx_gateway_owner_account_id: str,
        allowed_prefixes: typing.Optional[typing.List[str]] = None,
        associated_gateway_id: typing.Optional[str] = None,
        vpn_gateway_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dx_gateway_id: 
        :param dx_gateway_owner_account_id: 
        :param allowed_prefixes: 
        :param associated_gateway_id: 
        :param vpn_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxGatewayAssociationProposalConfig(
            dx_gateway_id=dx_gateway_id,
            dx_gateway_owner_account_id=dx_gateway_owner_account_id,
            allowed_prefixes=allowed_prefixes,
            associated_gateway_id=associated_gateway_id,
            vpn_gateway_id=vpn_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxGatewayAssociationProposal, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="associatedGatewayOwnerAccountId")
    def associated_gateway_owner_account_id(self) -> str:
        return jsii.get(self, "associatedGatewayOwnerAccountId")

    @builtins.property
    @jsii.member(jsii_name="associatedGatewayType")
    def associated_gateway_type(self) -> str:
        return jsii.get(self, "associatedGatewayType")

    @builtins.property
    @jsii.member(jsii_name="dxGatewayId")
    def dx_gateway_id(self) -> str:
        return jsii.get(self, "dxGatewayId")

    @dx_gateway_id.setter
    def dx_gateway_id(self, value: str) -> None:
        jsii.set(self, "dxGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="dxGatewayOwnerAccountId")
    def dx_gateway_owner_account_id(self) -> str:
        return jsii.get(self, "dxGatewayOwnerAccountId")

    @dx_gateway_owner_account_id.setter
    def dx_gateway_owner_account_id(self, value: str) -> None:
        jsii.set(self, "dxGatewayOwnerAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="allowedPrefixes")
    def allowed_prefixes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "allowedPrefixes")

    @allowed_prefixes.setter
    def allowed_prefixes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "allowedPrefixes", value)

    @builtins.property
    @jsii.member(jsii_name="associatedGatewayId")
    def associated_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "associatedGatewayId")

    @associated_gateway_id.setter
    def associated_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "associatedGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="vpnGatewayId")
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpnGatewayId")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpnGatewayId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxGatewayAssociationProposalConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dx_gateway_id": "dxGatewayId",
        "dx_gateway_owner_account_id": "dxGatewayOwnerAccountId",
        "allowed_prefixes": "allowedPrefixes",
        "associated_gateway_id": "associatedGatewayId",
        "vpn_gateway_id": "vpnGatewayId",
    },
)
class DxGatewayAssociationProposalConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dx_gateway_id: str,
        dx_gateway_owner_account_id: str,
        allowed_prefixes: typing.Optional[typing.List[str]] = None,
        associated_gateway_id: typing.Optional[str] = None,
        vpn_gateway_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dx_gateway_id: 
        :param dx_gateway_owner_account_id: 
        :param allowed_prefixes: 
        :param associated_gateway_id: 
        :param vpn_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "dx_gateway_id": dx_gateway_id,
            "dx_gateway_owner_account_id": dx_gateway_owner_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allowed_prefixes is not None:
            self._values["allowed_prefixes"] = allowed_prefixes
        if associated_gateway_id is not None:
            self._values["associated_gateway_id"] = associated_gateway_id
        if vpn_gateway_id is not None:
            self._values["vpn_gateway_id"] = vpn_gateway_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dx_gateway_id(self) -> str:
        return self._values.get("dx_gateway_id")

    @builtins.property
    def dx_gateway_owner_account_id(self) -> str:
        return self._values.get("dx_gateway_owner_account_id")

    @builtins.property
    def allowed_prefixes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allowed_prefixes")

    @builtins.property
    def associated_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("associated_gateway_id")

    @builtins.property
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("vpn_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxGatewayAssociationProposalConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxGatewayAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DxGatewayAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxGatewayAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "amazon_side_asn": "amazonSideAsn",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class DxGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        amazon_side_asn: str,
        name: str,
        timeouts: typing.Optional["DxGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param amazon_side_asn: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxGatewayTimeouts(**timeouts)
        self._values = {
            "amazon_side_asn": amazon_side_asn,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def amazon_side_asn(self) -> str:
        return self._values.get("amazon_side_asn")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxGatewayTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DxGatewayTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxHostedPrivateVirtualInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPrivateVirtualInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        owner_account_id: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["DxHostedPrivateVirtualInterfaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param owner_account_id: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param mtu: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxHostedPrivateVirtualInterfaceConfig(
            address_family=address_family,
            bgp_asn=bgp_asn,
            connection_id=connection_id,
            name=name,
            owner_account_id=owner_account_id,
            vlan=vlan,
            amazon_address=amazon_address,
            bgp_auth_key=bgp_auth_key,
            customer_address=customer_address,
            mtu=mtu,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxHostedPrivateVirtualInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="jumboFrameCapable")
    def jumbo_frame_capable(self) -> bool:
        return jsii.get(self, "jumboFrameCapable")

    @builtins.property
    @jsii.member(jsii_name="addressFamily")
    def address_family(self) -> str:
        return jsii.get(self, "addressFamily")

    @address_family.setter
    def address_family(self, value: str) -> None:
        jsii.set(self, "addressFamily", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: jsii.Number) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> str:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: str) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="ownerAccountId")
    def owner_account_id(self) -> str:
        return jsii.get(self, "ownerAccountId")

    @owner_account_id.setter
    def owner_account_id(self, value: str) -> None:
        jsii.set(self, "ownerAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="vlan")
    def vlan(self) -> jsii.Number:
        return jsii.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: jsii.Number) -> None:
        jsii.set(self, "vlan", value)

    @builtins.property
    @jsii.member(jsii_name="amazonAddress")
    def amazon_address(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonAddress")

    @amazon_address.setter
    def amazon_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonAddress", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAuthKey")
    def bgp_auth_key(self) -> typing.Optional[str]:
        return jsii.get(self, "bgpAuthKey")

    @bgp_auth_key.setter
    def bgp_auth_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bgpAuthKey", value)

    @builtins.property
    @jsii.member(jsii_name="customerAddress")
    def customer_address(self) -> typing.Optional[str]:
        return jsii.get(self, "customerAddress")

    @customer_address.setter
    def customer_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerAddress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mtu")
    def mtu(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "mtu", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxHostedPrivateVirtualInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxHostedPrivateVirtualInterfaceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


class DxHostedPrivateVirtualInterfaceAccepter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPrivateVirtualInterfaceAccepter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        virtual_interface_id: str,
        dx_gateway_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional[
            "DxHostedPrivateVirtualInterfaceAccepterTimeouts"
        ] = None,
        vpn_gateway_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param virtual_interface_id: 
        :param dx_gateway_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxHostedPrivateVirtualInterfaceAccepterConfig(
            virtual_interface_id=virtual_interface_id,
            dx_gateway_id=dx_gateway_id,
            tags=tags,
            timeouts=timeouts,
            vpn_gateway_id=vpn_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxHostedPrivateVirtualInterfaceAccepter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="virtualInterfaceId")
    def virtual_interface_id(self) -> str:
        return jsii.get(self, "virtualInterfaceId")

    @virtual_interface_id.setter
    def virtual_interface_id(self, value: str) -> None:
        jsii.set(self, "virtualInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="dxGatewayId")
    def dx_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "dxGatewayId")

    @dx_gateway_id.setter
    def dx_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dxGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DxHostedPrivateVirtualInterfaceAccepterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxHostedPrivateVirtualInterfaceAccepterTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpnGatewayId")
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpnGatewayId")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpnGatewayId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPrivateVirtualInterfaceAccepterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "virtual_interface_id": "virtualInterfaceId",
        "dx_gateway_id": "dxGatewayId",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpn_gateway_id": "vpnGatewayId",
    },
)
class DxHostedPrivateVirtualInterfaceAccepterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        virtual_interface_id: str,
        dx_gateway_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional[
            "DxHostedPrivateVirtualInterfaceAccepterTimeouts"
        ] = None,
        vpn_gateway_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param virtual_interface_id: 
        :param dx_gateway_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxHostedPrivateVirtualInterfaceAccepterTimeouts(**timeouts)
        self._values = {
            "virtual_interface_id": virtual_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dx_gateway_id is not None:
            self._values["dx_gateway_id"] = dx_gateway_id
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpn_gateway_id is not None:
            self._values["vpn_gateway_id"] = vpn_gateway_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def virtual_interface_id(self) -> str:
        return self._values.get("virtual_interface_id")

    @builtins.property
    def dx_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("dx_gateway_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DxHostedPrivateVirtualInterfaceAccepterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("vpn_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPrivateVirtualInterfaceAccepterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPrivateVirtualInterfaceAccepterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DxHostedPrivateVirtualInterfaceAccepterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPrivateVirtualInterfaceAccepterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPrivateVirtualInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_family": "addressFamily",
        "bgp_asn": "bgpAsn",
        "connection_id": "connectionId",
        "name": "name",
        "owner_account_id": "ownerAccountId",
        "vlan": "vlan",
        "amazon_address": "amazonAddress",
        "bgp_auth_key": "bgpAuthKey",
        "customer_address": "customerAddress",
        "mtu": "mtu",
        "timeouts": "timeouts",
    },
)
class DxHostedPrivateVirtualInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        owner_account_id: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["DxHostedPrivateVirtualInterfaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param owner_account_id: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param mtu: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxHostedPrivateVirtualInterfaceTimeouts(**timeouts)
        self._values = {
            "address_family": address_family,
            "bgp_asn": bgp_asn,
            "connection_id": connection_id,
            "name": name,
            "owner_account_id": owner_account_id,
            "vlan": vlan,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_address is not None:
            self._values["amazon_address"] = amazon_address
        if bgp_auth_key is not None:
            self._values["bgp_auth_key"] = bgp_auth_key
        if customer_address is not None:
            self._values["customer_address"] = customer_address
        if mtu is not None:
            self._values["mtu"] = mtu
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def address_family(self) -> str:
        return self._values.get("address_family")

    @builtins.property
    def bgp_asn(self) -> jsii.Number:
        return self._values.get("bgp_asn")

    @builtins.property
    def connection_id(self) -> str:
        return self._values.get("connection_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def owner_account_id(self) -> str:
        return self._values.get("owner_account_id")

    @builtins.property
    def vlan(self) -> jsii.Number:
        return self._values.get("vlan")

    @builtins.property
    def amazon_address(self) -> typing.Optional[str]:
        return self._values.get("amazon_address")

    @builtins.property
    def bgp_auth_key(self) -> typing.Optional[str]:
        return self._values.get("bgp_auth_key")

    @builtins.property
    def customer_address(self) -> typing.Optional[str]:
        return self._values.get("customer_address")

    @builtins.property
    def mtu(self) -> typing.Optional[jsii.Number]:
        return self._values.get("mtu")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxHostedPrivateVirtualInterfaceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPrivateVirtualInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPrivateVirtualInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DxHostedPrivateVirtualInterfaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPrivateVirtualInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxHostedPublicVirtualInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPublicVirtualInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        owner_account_id: str,
        route_filter_prefixes: typing.List[str],
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        timeouts: typing.Optional["DxHostedPublicVirtualInterfaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param owner_account_id: 
        :param route_filter_prefixes: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxHostedPublicVirtualInterfaceConfig(
            address_family=address_family,
            bgp_asn=bgp_asn,
            connection_id=connection_id,
            name=name,
            owner_account_id=owner_account_id,
            route_filter_prefixes=route_filter_prefixes,
            vlan=vlan,
            amazon_address=amazon_address,
            bgp_auth_key=bgp_auth_key,
            customer_address=customer_address,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxHostedPublicVirtualInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="addressFamily")
    def address_family(self) -> str:
        return jsii.get(self, "addressFamily")

    @address_family.setter
    def address_family(self, value: str) -> None:
        jsii.set(self, "addressFamily", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: jsii.Number) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> str:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: str) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="ownerAccountId")
    def owner_account_id(self) -> str:
        return jsii.get(self, "ownerAccountId")

    @owner_account_id.setter
    def owner_account_id(self, value: str) -> None:
        jsii.set(self, "ownerAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="routeFilterPrefixes")
    def route_filter_prefixes(self) -> typing.List[str]:
        return jsii.get(self, "routeFilterPrefixes")

    @route_filter_prefixes.setter
    def route_filter_prefixes(self, value: typing.List[str]) -> None:
        jsii.set(self, "routeFilterPrefixes", value)

    @builtins.property
    @jsii.member(jsii_name="vlan")
    def vlan(self) -> jsii.Number:
        return jsii.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: jsii.Number) -> None:
        jsii.set(self, "vlan", value)

    @builtins.property
    @jsii.member(jsii_name="amazonAddress")
    def amazon_address(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonAddress")

    @amazon_address.setter
    def amazon_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonAddress", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAuthKey")
    def bgp_auth_key(self) -> typing.Optional[str]:
        return jsii.get(self, "bgpAuthKey")

    @bgp_auth_key.setter
    def bgp_auth_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bgpAuthKey", value)

    @builtins.property
    @jsii.member(jsii_name="customerAddress")
    def customer_address(self) -> typing.Optional[str]:
        return jsii.get(self, "customerAddress")

    @customer_address.setter
    def customer_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerAddress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxHostedPublicVirtualInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxHostedPublicVirtualInterfaceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


class DxHostedPublicVirtualInterfaceAccepter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPublicVirtualInterfaceAccepter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        virtual_interface_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional[
            "DxHostedPublicVirtualInterfaceAccepterTimeouts"
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param virtual_interface_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxHostedPublicVirtualInterfaceAccepterConfig(
            virtual_interface_id=virtual_interface_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxHostedPublicVirtualInterfaceAccepter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="virtualInterfaceId")
    def virtual_interface_id(self) -> str:
        return jsii.get(self, "virtualInterfaceId")

    @virtual_interface_id.setter
    def virtual_interface_id(self, value: str) -> None:
        jsii.set(self, "virtualInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DxHostedPublicVirtualInterfaceAccepterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxHostedPublicVirtualInterfaceAccepterTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPublicVirtualInterfaceAccepterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "virtual_interface_id": "virtualInterfaceId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DxHostedPublicVirtualInterfaceAccepterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        virtual_interface_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional[
            "DxHostedPublicVirtualInterfaceAccepterTimeouts"
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param virtual_interface_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxHostedPublicVirtualInterfaceAccepterTimeouts(**timeouts)
        self._values = {
            "virtual_interface_id": virtual_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def virtual_interface_id(self) -> str:
        return self._values.get("virtual_interface_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DxHostedPublicVirtualInterfaceAccepterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPublicVirtualInterfaceAccepterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPublicVirtualInterfaceAccepterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DxHostedPublicVirtualInterfaceAccepterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPublicVirtualInterfaceAccepterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPublicVirtualInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_family": "addressFamily",
        "bgp_asn": "bgpAsn",
        "connection_id": "connectionId",
        "name": "name",
        "owner_account_id": "ownerAccountId",
        "route_filter_prefixes": "routeFilterPrefixes",
        "vlan": "vlan",
        "amazon_address": "amazonAddress",
        "bgp_auth_key": "bgpAuthKey",
        "customer_address": "customerAddress",
        "timeouts": "timeouts",
    },
)
class DxHostedPublicVirtualInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        owner_account_id: str,
        route_filter_prefixes: typing.List[str],
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        timeouts: typing.Optional["DxHostedPublicVirtualInterfaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param owner_account_id: 
        :param route_filter_prefixes: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxHostedPublicVirtualInterfaceTimeouts(**timeouts)
        self._values = {
            "address_family": address_family,
            "bgp_asn": bgp_asn,
            "connection_id": connection_id,
            "name": name,
            "owner_account_id": owner_account_id,
            "route_filter_prefixes": route_filter_prefixes,
            "vlan": vlan,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_address is not None:
            self._values["amazon_address"] = amazon_address
        if bgp_auth_key is not None:
            self._values["bgp_auth_key"] = bgp_auth_key
        if customer_address is not None:
            self._values["customer_address"] = customer_address
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def address_family(self) -> str:
        return self._values.get("address_family")

    @builtins.property
    def bgp_asn(self) -> jsii.Number:
        return self._values.get("bgp_asn")

    @builtins.property
    def connection_id(self) -> str:
        return self._values.get("connection_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def owner_account_id(self) -> str:
        return self._values.get("owner_account_id")

    @builtins.property
    def route_filter_prefixes(self) -> typing.List[str]:
        return self._values.get("route_filter_prefixes")

    @builtins.property
    def vlan(self) -> jsii.Number:
        return self._values.get("vlan")

    @builtins.property
    def amazon_address(self) -> typing.Optional[str]:
        return self._values.get("amazon_address")

    @builtins.property
    def bgp_auth_key(self) -> typing.Optional[str]:
        return self._values.get("bgp_auth_key")

    @builtins.property
    def customer_address(self) -> typing.Optional[str]:
        return self._values.get("customer_address")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxHostedPublicVirtualInterfaceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPublicVirtualInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedPublicVirtualInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DxHostedPublicVirtualInterfaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedPublicVirtualInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxHostedTransitVirtualInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedTransitVirtualInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        owner_account_id: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["DxHostedTransitVirtualInterfaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param owner_account_id: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param mtu: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxHostedTransitVirtualInterfaceConfig(
            address_family=address_family,
            bgp_asn=bgp_asn,
            connection_id=connection_id,
            name=name,
            owner_account_id=owner_account_id,
            vlan=vlan,
            amazon_address=amazon_address,
            bgp_auth_key=bgp_auth_key,
            customer_address=customer_address,
            mtu=mtu,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxHostedTransitVirtualInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="jumboFrameCapable")
    def jumbo_frame_capable(self) -> bool:
        return jsii.get(self, "jumboFrameCapable")

    @builtins.property
    @jsii.member(jsii_name="addressFamily")
    def address_family(self) -> str:
        return jsii.get(self, "addressFamily")

    @address_family.setter
    def address_family(self, value: str) -> None:
        jsii.set(self, "addressFamily", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: jsii.Number) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> str:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: str) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="ownerAccountId")
    def owner_account_id(self) -> str:
        return jsii.get(self, "ownerAccountId")

    @owner_account_id.setter
    def owner_account_id(self, value: str) -> None:
        jsii.set(self, "ownerAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="vlan")
    def vlan(self) -> jsii.Number:
        return jsii.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: jsii.Number) -> None:
        jsii.set(self, "vlan", value)

    @builtins.property
    @jsii.member(jsii_name="amazonAddress")
    def amazon_address(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonAddress")

    @amazon_address.setter
    def amazon_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonAddress", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAuthKey")
    def bgp_auth_key(self) -> typing.Optional[str]:
        return jsii.get(self, "bgpAuthKey")

    @bgp_auth_key.setter
    def bgp_auth_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bgpAuthKey", value)

    @builtins.property
    @jsii.member(jsii_name="customerAddress")
    def customer_address(self) -> typing.Optional[str]:
        return jsii.get(self, "customerAddress")

    @customer_address.setter
    def customer_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerAddress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mtu")
    def mtu(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "mtu", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxHostedTransitVirtualInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxHostedTransitVirtualInterfaceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


class DxHostedTransitVirtualInterfaceAccepter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedTransitVirtualInterfaceAccepter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dx_gateway_id: str,
        virtual_interface_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional[
            "DxHostedTransitVirtualInterfaceAccepterTimeouts"
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dx_gateway_id: 
        :param virtual_interface_id: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxHostedTransitVirtualInterfaceAccepterConfig(
            dx_gateway_id=dx_gateway_id,
            virtual_interface_id=virtual_interface_id,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxHostedTransitVirtualInterfaceAccepter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dxGatewayId")
    def dx_gateway_id(self) -> str:
        return jsii.get(self, "dxGatewayId")

    @dx_gateway_id.setter
    def dx_gateway_id(self, value: str) -> None:
        jsii.set(self, "dxGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="virtualInterfaceId")
    def virtual_interface_id(self) -> str:
        return jsii.get(self, "virtualInterfaceId")

    @virtual_interface_id.setter
    def virtual_interface_id(self, value: str) -> None:
        jsii.set(self, "virtualInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(
        self,
    ) -> typing.Optional["DxHostedTransitVirtualInterfaceAccepterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxHostedTransitVirtualInterfaceAccepterTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedTransitVirtualInterfaceAccepterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dx_gateway_id": "dxGatewayId",
        "virtual_interface_id": "virtualInterfaceId",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DxHostedTransitVirtualInterfaceAccepterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dx_gateway_id: str,
        virtual_interface_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional[
            "DxHostedTransitVirtualInterfaceAccepterTimeouts"
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dx_gateway_id: 
        :param virtual_interface_id: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxHostedTransitVirtualInterfaceAccepterTimeouts(**timeouts)
        self._values = {
            "dx_gateway_id": dx_gateway_id,
            "virtual_interface_id": virtual_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dx_gateway_id(self) -> str:
        return self._values.get("dx_gateway_id")

    @builtins.property
    def virtual_interface_id(self) -> str:
        return self._values.get("virtual_interface_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(
        self,
    ) -> typing.Optional["DxHostedTransitVirtualInterfaceAccepterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedTransitVirtualInterfaceAccepterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedTransitVirtualInterfaceAccepterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DxHostedTransitVirtualInterfaceAccepterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedTransitVirtualInterfaceAccepterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedTransitVirtualInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_family": "addressFamily",
        "bgp_asn": "bgpAsn",
        "connection_id": "connectionId",
        "name": "name",
        "owner_account_id": "ownerAccountId",
        "vlan": "vlan",
        "amazon_address": "amazonAddress",
        "bgp_auth_key": "bgpAuthKey",
        "customer_address": "customerAddress",
        "mtu": "mtu",
        "timeouts": "timeouts",
    },
)
class DxHostedTransitVirtualInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        owner_account_id: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["DxHostedTransitVirtualInterfaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param owner_account_id: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param mtu: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxHostedTransitVirtualInterfaceTimeouts(**timeouts)
        self._values = {
            "address_family": address_family,
            "bgp_asn": bgp_asn,
            "connection_id": connection_id,
            "name": name,
            "owner_account_id": owner_account_id,
            "vlan": vlan,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_address is not None:
            self._values["amazon_address"] = amazon_address
        if bgp_auth_key is not None:
            self._values["bgp_auth_key"] = bgp_auth_key
        if customer_address is not None:
            self._values["customer_address"] = customer_address
        if mtu is not None:
            self._values["mtu"] = mtu
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def address_family(self) -> str:
        return self._values.get("address_family")

    @builtins.property
    def bgp_asn(self) -> jsii.Number:
        return self._values.get("bgp_asn")

    @builtins.property
    def connection_id(self) -> str:
        return self._values.get("connection_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def owner_account_id(self) -> str:
        return self._values.get("owner_account_id")

    @builtins.property
    def vlan(self) -> jsii.Number:
        return self._values.get("vlan")

    @builtins.property
    def amazon_address(self) -> typing.Optional[str]:
        return self._values.get("amazon_address")

    @builtins.property
    def bgp_auth_key(self) -> typing.Optional[str]:
        return self._values.get("bgp_auth_key")

    @builtins.property
    def customer_address(self) -> typing.Optional[str]:
        return self._values.get("customer_address")

    @builtins.property
    def mtu(self) -> typing.Optional[jsii.Number]:
        return self._values.get("mtu")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxHostedTransitVirtualInterfaceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedTransitVirtualInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxHostedTransitVirtualInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DxHostedTransitVirtualInterfaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxHostedTransitVirtualInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxLag(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxLag",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        connections_bandwidth: str,
        location: str,
        name: str,
        force_destroy: typing.Optional[bool] = None,
        number_of_connections: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connections_bandwidth: 
        :param location: 
        :param name: 
        :param force_destroy: 
        :param number_of_connections: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxLagConfig(
            connections_bandwidth=connections_bandwidth,
            location=location,
            name=name,
            force_destroy=force_destroy,
            number_of_connections=number_of_connections,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxLag, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="hasLogicalRedundancy")
    def has_logical_redundancy(self) -> str:
        return jsii.get(self, "hasLogicalRedundancy")

    @builtins.property
    @jsii.member(jsii_name="jumboFrameCapable")
    def jumbo_frame_capable(self) -> bool:
        return jsii.get(self, "jumboFrameCapable")

    @builtins.property
    @jsii.member(jsii_name="connectionsBandwidth")
    def connections_bandwidth(self) -> str:
        return jsii.get(self, "connectionsBandwidth")

    @connections_bandwidth.setter
    def connections_bandwidth(self, value: str) -> None:
        jsii.set(self, "connectionsBandwidth", value)

    @builtins.property
    @jsii.member(jsii_name="location")
    def location(self) -> str:
        return jsii.get(self, "location")

    @location.setter
    def location(self, value: str) -> None:
        jsii.set(self, "location", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="numberOfConnections")
    def number_of_connections(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "numberOfConnections")

    @number_of_connections.setter
    def number_of_connections(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "numberOfConnections", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxLagConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connections_bandwidth": "connectionsBandwidth",
        "location": "location",
        "name": "name",
        "force_destroy": "forceDestroy",
        "number_of_connections": "numberOfConnections",
        "tags": "tags",
    },
)
class DxLagConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connections_bandwidth: str,
        location: str,
        name: str,
        force_destroy: typing.Optional[bool] = None,
        number_of_connections: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connections_bandwidth: 
        :param location: 
        :param name: 
        :param force_destroy: 
        :param number_of_connections: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "connections_bandwidth": connections_bandwidth,
            "location": location,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if number_of_connections is not None:
            self._values["number_of_connections"] = number_of_connections
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def connections_bandwidth(self) -> str:
        return self._values.get("connections_bandwidth")

    @builtins.property
    def location(self) -> str:
        return self._values.get("location")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    @builtins.property
    def number_of_connections(self) -> typing.Optional[jsii.Number]:
        return self._values.get("number_of_connections")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxLagConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxPrivateVirtualInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxPrivateVirtualInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        dx_gateway_id: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DxPrivateVirtualInterfaceTimeouts"] = None,
        vpn_gateway_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param dx_gateway_id: 
        :param mtu: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxPrivateVirtualInterfaceConfig(
            address_family=address_family,
            bgp_asn=bgp_asn,
            connection_id=connection_id,
            name=name,
            vlan=vlan,
            amazon_address=amazon_address,
            bgp_auth_key=bgp_auth_key,
            customer_address=customer_address,
            dx_gateway_id=dx_gateway_id,
            mtu=mtu,
            tags=tags,
            timeouts=timeouts,
            vpn_gateway_id=vpn_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxPrivateVirtualInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="jumboFrameCapable")
    def jumbo_frame_capable(self) -> bool:
        return jsii.get(self, "jumboFrameCapable")

    @builtins.property
    @jsii.member(jsii_name="addressFamily")
    def address_family(self) -> str:
        return jsii.get(self, "addressFamily")

    @address_family.setter
    def address_family(self, value: str) -> None:
        jsii.set(self, "addressFamily", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: jsii.Number) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> str:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: str) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="vlan")
    def vlan(self) -> jsii.Number:
        return jsii.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: jsii.Number) -> None:
        jsii.set(self, "vlan", value)

    @builtins.property
    @jsii.member(jsii_name="amazonAddress")
    def amazon_address(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonAddress")

    @amazon_address.setter
    def amazon_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonAddress", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAuthKey")
    def bgp_auth_key(self) -> typing.Optional[str]:
        return jsii.get(self, "bgpAuthKey")

    @bgp_auth_key.setter
    def bgp_auth_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bgpAuthKey", value)

    @builtins.property
    @jsii.member(jsii_name="customerAddress")
    def customer_address(self) -> typing.Optional[str]:
        return jsii.get(self, "customerAddress")

    @customer_address.setter
    def customer_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerAddress", value)

    @builtins.property
    @jsii.member(jsii_name="dxGatewayId")
    def dx_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "dxGatewayId")

    @dx_gateway_id.setter
    def dx_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dxGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mtu")
    def mtu(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "mtu", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxPrivateVirtualInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxPrivateVirtualInterfaceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpnGatewayId")
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpnGatewayId")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpnGatewayId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxPrivateVirtualInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_family": "addressFamily",
        "bgp_asn": "bgpAsn",
        "connection_id": "connectionId",
        "name": "name",
        "vlan": "vlan",
        "amazon_address": "amazonAddress",
        "bgp_auth_key": "bgpAuthKey",
        "customer_address": "customerAddress",
        "dx_gateway_id": "dxGatewayId",
        "mtu": "mtu",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpn_gateway_id": "vpnGatewayId",
    },
)
class DxPrivateVirtualInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        dx_gateway_id: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DxPrivateVirtualInterfaceTimeouts"] = None,
        vpn_gateway_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param dx_gateway_id: 
        :param mtu: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpn_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxPrivateVirtualInterfaceTimeouts(**timeouts)
        self._values = {
            "address_family": address_family,
            "bgp_asn": bgp_asn,
            "connection_id": connection_id,
            "name": name,
            "vlan": vlan,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_address is not None:
            self._values["amazon_address"] = amazon_address
        if bgp_auth_key is not None:
            self._values["bgp_auth_key"] = bgp_auth_key
        if customer_address is not None:
            self._values["customer_address"] = customer_address
        if dx_gateway_id is not None:
            self._values["dx_gateway_id"] = dx_gateway_id
        if mtu is not None:
            self._values["mtu"] = mtu
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpn_gateway_id is not None:
            self._values["vpn_gateway_id"] = vpn_gateway_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def address_family(self) -> str:
        return self._values.get("address_family")

    @builtins.property
    def bgp_asn(self) -> jsii.Number:
        return self._values.get("bgp_asn")

    @builtins.property
    def connection_id(self) -> str:
        return self._values.get("connection_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def vlan(self) -> jsii.Number:
        return self._values.get("vlan")

    @builtins.property
    def amazon_address(self) -> typing.Optional[str]:
        return self._values.get("amazon_address")

    @builtins.property
    def bgp_auth_key(self) -> typing.Optional[str]:
        return self._values.get("bgp_auth_key")

    @builtins.property
    def customer_address(self) -> typing.Optional[str]:
        return self._values.get("customer_address")

    @builtins.property
    def dx_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("dx_gateway_id")

    @builtins.property
    def mtu(self) -> typing.Optional[jsii.Number]:
        return self._values.get("mtu")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxPrivateVirtualInterfaceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("vpn_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxPrivateVirtualInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxPrivateVirtualInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DxPrivateVirtualInterfaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxPrivateVirtualInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxPublicVirtualInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxPublicVirtualInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        route_filter_prefixes: typing.List[str],
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DxPublicVirtualInterfaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param route_filter_prefixes: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxPublicVirtualInterfaceConfig(
            address_family=address_family,
            bgp_asn=bgp_asn,
            connection_id=connection_id,
            name=name,
            route_filter_prefixes=route_filter_prefixes,
            vlan=vlan,
            amazon_address=amazon_address,
            bgp_auth_key=bgp_auth_key,
            customer_address=customer_address,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxPublicVirtualInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="addressFamily")
    def address_family(self) -> str:
        return jsii.get(self, "addressFamily")

    @address_family.setter
    def address_family(self, value: str) -> None:
        jsii.set(self, "addressFamily", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: jsii.Number) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> str:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: str) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="routeFilterPrefixes")
    def route_filter_prefixes(self) -> typing.List[str]:
        return jsii.get(self, "routeFilterPrefixes")

    @route_filter_prefixes.setter
    def route_filter_prefixes(self, value: typing.List[str]) -> None:
        jsii.set(self, "routeFilterPrefixes", value)

    @builtins.property
    @jsii.member(jsii_name="vlan")
    def vlan(self) -> jsii.Number:
        return jsii.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: jsii.Number) -> None:
        jsii.set(self, "vlan", value)

    @builtins.property
    @jsii.member(jsii_name="amazonAddress")
    def amazon_address(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonAddress")

    @amazon_address.setter
    def amazon_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonAddress", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAuthKey")
    def bgp_auth_key(self) -> typing.Optional[str]:
        return jsii.get(self, "bgpAuthKey")

    @bgp_auth_key.setter
    def bgp_auth_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bgpAuthKey", value)

    @builtins.property
    @jsii.member(jsii_name="customerAddress")
    def customer_address(self) -> typing.Optional[str]:
        return jsii.get(self, "customerAddress")

    @customer_address.setter
    def customer_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerAddress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxPublicVirtualInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxPublicVirtualInterfaceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxPublicVirtualInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_family": "addressFamily",
        "bgp_asn": "bgpAsn",
        "connection_id": "connectionId",
        "name": "name",
        "route_filter_prefixes": "routeFilterPrefixes",
        "vlan": "vlan",
        "amazon_address": "amazonAddress",
        "bgp_auth_key": "bgpAuthKey",
        "customer_address": "customerAddress",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DxPublicVirtualInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        name: str,
        route_filter_prefixes: typing.List[str],
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DxPublicVirtualInterfaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param name: 
        :param route_filter_prefixes: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxPublicVirtualInterfaceTimeouts(**timeouts)
        self._values = {
            "address_family": address_family,
            "bgp_asn": bgp_asn,
            "connection_id": connection_id,
            "name": name,
            "route_filter_prefixes": route_filter_prefixes,
            "vlan": vlan,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_address is not None:
            self._values["amazon_address"] = amazon_address
        if bgp_auth_key is not None:
            self._values["bgp_auth_key"] = bgp_auth_key
        if customer_address is not None:
            self._values["customer_address"] = customer_address
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def address_family(self) -> str:
        return self._values.get("address_family")

    @builtins.property
    def bgp_asn(self) -> jsii.Number:
        return self._values.get("bgp_asn")

    @builtins.property
    def connection_id(self) -> str:
        return self._values.get("connection_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def route_filter_prefixes(self) -> typing.List[str]:
        return self._values.get("route_filter_prefixes")

    @builtins.property
    def vlan(self) -> jsii.Number:
        return self._values.get("vlan")

    @builtins.property
    def amazon_address(self) -> typing.Optional[str]:
        return self._values.get("amazon_address")

    @builtins.property
    def bgp_auth_key(self) -> typing.Optional[str]:
        return self._values.get("bgp_auth_key")

    @builtins.property
    def customer_address(self) -> typing.Optional[str]:
        return self._values.get("customer_address")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxPublicVirtualInterfaceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxPublicVirtualInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxPublicVirtualInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class DxPublicVirtualInterfaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxPublicVirtualInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DxTransitVirtualInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DxTransitVirtualInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        dx_gateway_id: str,
        name: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DxTransitVirtualInterfaceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param dx_gateway_id: 
        :param name: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param mtu: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DxTransitVirtualInterfaceConfig(
            address_family=address_family,
            bgp_asn=bgp_asn,
            connection_id=connection_id,
            dx_gateway_id=dx_gateway_id,
            name=name,
            vlan=vlan,
            amazon_address=amazon_address,
            bgp_auth_key=bgp_auth_key,
            customer_address=customer_address,
            mtu=mtu,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DxTransitVirtualInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> str:
        return jsii.get(self, "amazonSideAsn")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="awsDevice")
    def aws_device(self) -> str:
        return jsii.get(self, "awsDevice")

    @builtins.property
    @jsii.member(jsii_name="jumboFrameCapable")
    def jumbo_frame_capable(self) -> bool:
        return jsii.get(self, "jumboFrameCapable")

    @builtins.property
    @jsii.member(jsii_name="addressFamily")
    def address_family(self) -> str:
        return jsii.get(self, "addressFamily")

    @address_family.setter
    def address_family(self, value: str) -> None:
        jsii.set(self, "addressFamily", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAsn")
    def bgp_asn(self) -> jsii.Number:
        return jsii.get(self, "bgpAsn")

    @bgp_asn.setter
    def bgp_asn(self, value: jsii.Number) -> None:
        jsii.set(self, "bgpAsn", value)

    @builtins.property
    @jsii.member(jsii_name="connectionId")
    def connection_id(self) -> str:
        return jsii.get(self, "connectionId")

    @connection_id.setter
    def connection_id(self, value: str) -> None:
        jsii.set(self, "connectionId", value)

    @builtins.property
    @jsii.member(jsii_name="dxGatewayId")
    def dx_gateway_id(self) -> str:
        return jsii.get(self, "dxGatewayId")

    @dx_gateway_id.setter
    def dx_gateway_id(self, value: str) -> None:
        jsii.set(self, "dxGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="vlan")
    def vlan(self) -> jsii.Number:
        return jsii.get(self, "vlan")

    @vlan.setter
    def vlan(self, value: jsii.Number) -> None:
        jsii.set(self, "vlan", value)

    @builtins.property
    @jsii.member(jsii_name="amazonAddress")
    def amazon_address(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonAddress")

    @amazon_address.setter
    def amazon_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonAddress", value)

    @builtins.property
    @jsii.member(jsii_name="bgpAuthKey")
    def bgp_auth_key(self) -> typing.Optional[str]:
        return jsii.get(self, "bgpAuthKey")

    @bgp_auth_key.setter
    def bgp_auth_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bgpAuthKey", value)

    @builtins.property
    @jsii.member(jsii_name="customerAddress")
    def customer_address(self) -> typing.Optional[str]:
        return jsii.get(self, "customerAddress")

    @customer_address.setter
    def customer_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerAddress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mtu")
    def mtu(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "mtu")

    @mtu.setter
    def mtu(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "mtu", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DxTransitVirtualInterfaceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["DxTransitVirtualInterfaceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxTransitVirtualInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "address_family": "addressFamily",
        "bgp_asn": "bgpAsn",
        "connection_id": "connectionId",
        "dx_gateway_id": "dxGatewayId",
        "name": "name",
        "vlan": "vlan",
        "amazon_address": "amazonAddress",
        "bgp_auth_key": "bgpAuthKey",
        "customer_address": "customerAddress",
        "mtu": "mtu",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class DxTransitVirtualInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        address_family: str,
        bgp_asn: jsii.Number,
        connection_id: str,
        dx_gateway_id: str,
        name: str,
        vlan: jsii.Number,
        amazon_address: typing.Optional[str] = None,
        bgp_auth_key: typing.Optional[str] = None,
        customer_address: typing.Optional[str] = None,
        mtu: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DxTransitVirtualInterfaceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param address_family: 
        :param bgp_asn: 
        :param connection_id: 
        :param dx_gateway_id: 
        :param name: 
        :param vlan: 
        :param amazon_address: 
        :param bgp_auth_key: 
        :param customer_address: 
        :param mtu: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DxTransitVirtualInterfaceTimeouts(**timeouts)
        self._values = {
            "address_family": address_family,
            "bgp_asn": bgp_asn,
            "connection_id": connection_id,
            "dx_gateway_id": dx_gateway_id,
            "name": name,
            "vlan": vlan,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_address is not None:
            self._values["amazon_address"] = amazon_address
        if bgp_auth_key is not None:
            self._values["bgp_auth_key"] = bgp_auth_key
        if customer_address is not None:
            self._values["customer_address"] = customer_address
        if mtu is not None:
            self._values["mtu"] = mtu
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def address_family(self) -> str:
        return self._values.get("address_family")

    @builtins.property
    def bgp_asn(self) -> jsii.Number:
        return self._values.get("bgp_asn")

    @builtins.property
    def connection_id(self) -> str:
        return self._values.get("connection_id")

    @builtins.property
    def dx_gateway_id(self) -> str:
        return self._values.get("dx_gateway_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def vlan(self) -> jsii.Number:
        return self._values.get("vlan")

    @builtins.property
    def amazon_address(self) -> typing.Optional[str]:
        return self._values.get("amazon_address")

    @builtins.property
    def bgp_auth_key(self) -> typing.Optional[str]:
        return self._values.get("bgp_auth_key")

    @builtins.property
    def customer_address(self) -> typing.Optional[str]:
        return self._values.get("customer_address")

    @builtins.property
    def mtu(self) -> typing.Optional[jsii.Number]:
        return self._values.get("mtu")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DxTransitVirtualInterfaceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxTransitVirtualInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DxTransitVirtualInterfaceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DxTransitVirtualInterfaceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DxTransitVirtualInterfaceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DynamodbGlobalTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbGlobalTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        replica: typing.List["DynamodbGlobalTableReplica"],
        timeouts: typing.Optional["DynamodbGlobalTableTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param replica: replica block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DynamodbGlobalTableConfig(
            name=name,
            replica=replica,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DynamodbGlobalTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="replica")
    def replica(self) -> typing.List["DynamodbGlobalTableReplica"]:
        return jsii.get(self, "replica")

    @replica.setter
    def replica(self, value: typing.List["DynamodbGlobalTableReplica"]) -> None:
        jsii.set(self, "replica", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DynamodbGlobalTableTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DynamodbGlobalTableTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbGlobalTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "replica": "replica",
        "timeouts": "timeouts",
    },
)
class DynamodbGlobalTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        replica: typing.List["DynamodbGlobalTableReplica"],
        timeouts: typing.Optional["DynamodbGlobalTableTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param replica: replica block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DynamodbGlobalTableTimeouts(**timeouts)
        self._values = {
            "name": name,
            "replica": replica,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def replica(self) -> typing.List["DynamodbGlobalTableReplica"]:
        """replica block."""
        return self._values.get("replica")

    @builtins.property
    def timeouts(self) -> typing.Optional["DynamodbGlobalTableTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbGlobalTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbGlobalTableReplica",
    jsii_struct_bases=[],
    name_mapping={"region_name": "regionName"},
)
class DynamodbGlobalTableReplica:
    def __init__(self, *, region_name: str) -> None:
        """
        :param region_name: 
        """
        self._values = {
            "region_name": region_name,
        }

    @builtins.property
    def region_name(self) -> str:
        return self._values.get("region_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbGlobalTableReplica(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbGlobalTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DynamodbGlobalTableTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbGlobalTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DynamodbTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        attribute: typing.List["DynamodbTableAttribute"],
        hash_key: str,
        name: str,
        billing_mode: typing.Optional[str] = None,
        global_secondary_index: typing.Optional[
            typing.List["DynamodbTableGlobalSecondaryIndex"]
        ] = None,
        local_secondary_index: typing.Optional[
            typing.List["DynamodbTableLocalSecondaryIndex"]
        ] = None,
        point_in_time_recovery: typing.Optional[
            typing.List["DynamodbTablePointInTimeRecovery"]
        ] = None,
        range_key: typing.Optional[str] = None,
        read_capacity: typing.Optional[jsii.Number] = None,
        replica: typing.Optional[typing.List["DynamodbTableReplica"]] = None,
        server_side_encryption: typing.Optional[
            typing.List["DynamodbTableServerSideEncryption"]
        ] = None,
        stream_enabled: typing.Optional[bool] = None,
        stream_view_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DynamodbTableTimeouts"] = None,
        ttl: typing.Optional[typing.List["DynamodbTableTtl"]] = None,
        write_capacity: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param attribute: attribute block.
        :param hash_key: 
        :param name: 
        :param billing_mode: 
        :param global_secondary_index: global_secondary_index block.
        :param local_secondary_index: local_secondary_index block.
        :param point_in_time_recovery: point_in_time_recovery block.
        :param range_key: 
        :param read_capacity: 
        :param replica: replica block.
        :param server_side_encryption: server_side_encryption block.
        :param stream_enabled: 
        :param stream_view_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param ttl: ttl block.
        :param write_capacity: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DynamodbTableConfig(
            attribute=attribute,
            hash_key=hash_key,
            name=name,
            billing_mode=billing_mode,
            global_secondary_index=global_secondary_index,
            local_secondary_index=local_secondary_index,
            point_in_time_recovery=point_in_time_recovery,
            range_key=range_key,
            read_capacity=read_capacity,
            replica=replica,
            server_side_encryption=server_side_encryption,
            stream_enabled=stream_enabled,
            stream_view_type=stream_view_type,
            tags=tags,
            timeouts=timeouts,
            ttl=ttl,
            write_capacity=write_capacity,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DynamodbTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="streamArn")
    def stream_arn(self) -> str:
        return jsii.get(self, "streamArn")

    @builtins.property
    @jsii.member(jsii_name="streamLabel")
    def stream_label(self) -> str:
        return jsii.get(self, "streamLabel")

    @builtins.property
    @jsii.member(jsii_name="attribute")
    def attribute(self) -> typing.List["DynamodbTableAttribute"]:
        return jsii.get(self, "attribute")

    @attribute.setter
    def attribute(self, value: typing.List["DynamodbTableAttribute"]) -> None:
        jsii.set(self, "attribute", value)

    @builtins.property
    @jsii.member(jsii_name="hashKey")
    def hash_key(self) -> str:
        return jsii.get(self, "hashKey")

    @hash_key.setter
    def hash_key(self, value: str) -> None:
        jsii.set(self, "hashKey", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="billingMode")
    def billing_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "billingMode")

    @billing_mode.setter
    def billing_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "billingMode", value)

    @builtins.property
    @jsii.member(jsii_name="globalSecondaryIndex")
    def global_secondary_index(
        self,
    ) -> typing.Optional[typing.List["DynamodbTableGlobalSecondaryIndex"]]:
        return jsii.get(self, "globalSecondaryIndex")

    @global_secondary_index.setter
    def global_secondary_index(
        self, value: typing.Optional[typing.List["DynamodbTableGlobalSecondaryIndex"]]
    ) -> None:
        jsii.set(self, "globalSecondaryIndex", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="localSecondaryIndex")
    def local_secondary_index(
        self,
    ) -> typing.Optional[typing.List["DynamodbTableLocalSecondaryIndex"]]:
        return jsii.get(self, "localSecondaryIndex")

    @local_secondary_index.setter
    def local_secondary_index(
        self, value: typing.Optional[typing.List["DynamodbTableLocalSecondaryIndex"]]
    ) -> None:
        jsii.set(self, "localSecondaryIndex", value)

    @builtins.property
    @jsii.member(jsii_name="pointInTimeRecovery")
    def point_in_time_recovery(
        self,
    ) -> typing.Optional[typing.List["DynamodbTablePointInTimeRecovery"]]:
        return jsii.get(self, "pointInTimeRecovery")

    @point_in_time_recovery.setter
    def point_in_time_recovery(
        self, value: typing.Optional[typing.List["DynamodbTablePointInTimeRecovery"]]
    ) -> None:
        jsii.set(self, "pointInTimeRecovery", value)

    @builtins.property
    @jsii.member(jsii_name="rangeKey")
    def range_key(self) -> typing.Optional[str]:
        return jsii.get(self, "rangeKey")

    @range_key.setter
    def range_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rangeKey", value)

    @builtins.property
    @jsii.member(jsii_name="readCapacity")
    def read_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "readCapacity")

    @read_capacity.setter
    def read_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "readCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="replica")
    def replica(self) -> typing.Optional[typing.List["DynamodbTableReplica"]]:
        return jsii.get(self, "replica")

    @replica.setter
    def replica(
        self, value: typing.Optional[typing.List["DynamodbTableReplica"]]
    ) -> None:
        jsii.set(self, "replica", value)

    @builtins.property
    @jsii.member(jsii_name="serverSideEncryption")
    def server_side_encryption(
        self,
    ) -> typing.Optional[typing.List["DynamodbTableServerSideEncryption"]]:
        return jsii.get(self, "serverSideEncryption")

    @server_side_encryption.setter
    def server_side_encryption(
        self, value: typing.Optional[typing.List["DynamodbTableServerSideEncryption"]]
    ) -> None:
        jsii.set(self, "serverSideEncryption", value)

    @builtins.property
    @jsii.member(jsii_name="streamEnabled")
    def stream_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "streamEnabled")

    @stream_enabled.setter
    def stream_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "streamEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="streamViewType")
    def stream_view_type(self) -> typing.Optional[str]:
        return jsii.get(self, "streamViewType")

    @stream_view_type.setter
    def stream_view_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "streamViewType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["DynamodbTableTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["DynamodbTableTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> typing.Optional[typing.List["DynamodbTableTtl"]]:
        return jsii.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: typing.Optional[typing.List["DynamodbTableTtl"]]) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property
    @jsii.member(jsii_name="writeCapacity")
    def write_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "writeCapacity")

    @write_capacity.setter
    def write_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "writeCapacity", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableAttribute",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "type": "type"},
)
class DynamodbTableAttribute:
    def __init__(self, *, name: str, type: str) -> None:
        """
        :param name: 
        :param type: 
        """
        self._values = {
            "name": name,
            "type": type,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableAttribute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "attribute": "attribute",
        "hash_key": "hashKey",
        "name": "name",
        "billing_mode": "billingMode",
        "global_secondary_index": "globalSecondaryIndex",
        "local_secondary_index": "localSecondaryIndex",
        "point_in_time_recovery": "pointInTimeRecovery",
        "range_key": "rangeKey",
        "read_capacity": "readCapacity",
        "replica": "replica",
        "server_side_encryption": "serverSideEncryption",
        "stream_enabled": "streamEnabled",
        "stream_view_type": "streamViewType",
        "tags": "tags",
        "timeouts": "timeouts",
        "ttl": "ttl",
        "write_capacity": "writeCapacity",
    },
)
class DynamodbTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        attribute: typing.List["DynamodbTableAttribute"],
        hash_key: str,
        name: str,
        billing_mode: typing.Optional[str] = None,
        global_secondary_index: typing.Optional[
            typing.List["DynamodbTableGlobalSecondaryIndex"]
        ] = None,
        local_secondary_index: typing.Optional[
            typing.List["DynamodbTableLocalSecondaryIndex"]
        ] = None,
        point_in_time_recovery: typing.Optional[
            typing.List["DynamodbTablePointInTimeRecovery"]
        ] = None,
        range_key: typing.Optional[str] = None,
        read_capacity: typing.Optional[jsii.Number] = None,
        replica: typing.Optional[typing.List["DynamodbTableReplica"]] = None,
        server_side_encryption: typing.Optional[
            typing.List["DynamodbTableServerSideEncryption"]
        ] = None,
        stream_enabled: typing.Optional[bool] = None,
        stream_view_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["DynamodbTableTimeouts"] = None,
        ttl: typing.Optional[typing.List["DynamodbTableTtl"]] = None,
        write_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param attribute: attribute block.
        :param hash_key: 
        :param name: 
        :param billing_mode: 
        :param global_secondary_index: global_secondary_index block.
        :param local_secondary_index: local_secondary_index block.
        :param point_in_time_recovery: point_in_time_recovery block.
        :param range_key: 
        :param read_capacity: 
        :param replica: replica block.
        :param server_side_encryption: server_side_encryption block.
        :param stream_enabled: 
        :param stream_view_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param ttl: ttl block.
        :param write_capacity: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = DynamodbTableTimeouts(**timeouts)
        self._values = {
            "attribute": attribute,
            "hash_key": hash_key,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if billing_mode is not None:
            self._values["billing_mode"] = billing_mode
        if global_secondary_index is not None:
            self._values["global_secondary_index"] = global_secondary_index
        if local_secondary_index is not None:
            self._values["local_secondary_index"] = local_secondary_index
        if point_in_time_recovery is not None:
            self._values["point_in_time_recovery"] = point_in_time_recovery
        if range_key is not None:
            self._values["range_key"] = range_key
        if read_capacity is not None:
            self._values["read_capacity"] = read_capacity
        if replica is not None:
            self._values["replica"] = replica
        if server_side_encryption is not None:
            self._values["server_side_encryption"] = server_side_encryption
        if stream_enabled is not None:
            self._values["stream_enabled"] = stream_enabled
        if stream_view_type is not None:
            self._values["stream_view_type"] = stream_view_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if ttl is not None:
            self._values["ttl"] = ttl
        if write_capacity is not None:
            self._values["write_capacity"] = write_capacity

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def attribute(self) -> typing.List["DynamodbTableAttribute"]:
        """attribute block."""
        return self._values.get("attribute")

    @builtins.property
    def hash_key(self) -> str:
        return self._values.get("hash_key")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def billing_mode(self) -> typing.Optional[str]:
        return self._values.get("billing_mode")

    @builtins.property
    def global_secondary_index(
        self,
    ) -> typing.Optional[typing.List["DynamodbTableGlobalSecondaryIndex"]]:
        """global_secondary_index block."""
        return self._values.get("global_secondary_index")

    @builtins.property
    def local_secondary_index(
        self,
    ) -> typing.Optional[typing.List["DynamodbTableLocalSecondaryIndex"]]:
        """local_secondary_index block."""
        return self._values.get("local_secondary_index")

    @builtins.property
    def point_in_time_recovery(
        self,
    ) -> typing.Optional[typing.List["DynamodbTablePointInTimeRecovery"]]:
        """point_in_time_recovery block."""
        return self._values.get("point_in_time_recovery")

    @builtins.property
    def range_key(self) -> typing.Optional[str]:
        return self._values.get("range_key")

    @builtins.property
    def read_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("read_capacity")

    @builtins.property
    def replica(self) -> typing.Optional[typing.List["DynamodbTableReplica"]]:
        """replica block."""
        return self._values.get("replica")

    @builtins.property
    def server_side_encryption(
        self,
    ) -> typing.Optional[typing.List["DynamodbTableServerSideEncryption"]]:
        """server_side_encryption block."""
        return self._values.get("server_side_encryption")

    @builtins.property
    def stream_enabled(self) -> typing.Optional[bool]:
        return self._values.get("stream_enabled")

    @builtins.property
    def stream_view_type(self) -> typing.Optional[str]:
        return self._values.get("stream_view_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["DynamodbTableTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def ttl(self) -> typing.Optional[typing.List["DynamodbTableTtl"]]:
        """ttl block."""
        return self._values.get("ttl")

    @builtins.property
    def write_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("write_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableGlobalSecondaryIndex",
    jsii_struct_bases=[],
    name_mapping={
        "hash_key": "hashKey",
        "name": "name",
        "projection_type": "projectionType",
        "non_key_attributes": "nonKeyAttributes",
        "range_key": "rangeKey",
        "read_capacity": "readCapacity",
        "write_capacity": "writeCapacity",
    },
)
class DynamodbTableGlobalSecondaryIndex:
    def __init__(
        self,
        *,
        hash_key: str,
        name: str,
        projection_type: str,
        non_key_attributes: typing.Optional[typing.List[str]] = None,
        range_key: typing.Optional[str] = None,
        read_capacity: typing.Optional[jsii.Number] = None,
        write_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param hash_key: 
        :param name: 
        :param projection_type: 
        :param non_key_attributes: 
        :param range_key: 
        :param read_capacity: 
        :param write_capacity: 
        """
        self._values = {
            "hash_key": hash_key,
            "name": name,
            "projection_type": projection_type,
        }
        if non_key_attributes is not None:
            self._values["non_key_attributes"] = non_key_attributes
        if range_key is not None:
            self._values["range_key"] = range_key
        if read_capacity is not None:
            self._values["read_capacity"] = read_capacity
        if write_capacity is not None:
            self._values["write_capacity"] = write_capacity

    @builtins.property
    def hash_key(self) -> str:
        return self._values.get("hash_key")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def projection_type(self) -> str:
        return self._values.get("projection_type")

    @builtins.property
    def non_key_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("non_key_attributes")

    @builtins.property
    def range_key(self) -> typing.Optional[str]:
        return self._values.get("range_key")

    @builtins.property
    def read_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("read_capacity")

    @builtins.property
    def write_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("write_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableGlobalSecondaryIndex(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class DynamodbTableItem(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableItem",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        hash_key: str,
        item: str,
        table_name: str,
        range_key: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param hash_key: 
        :param item: 
        :param table_name: 
        :param range_key: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = DynamodbTableItemConfig(
            hash_key=hash_key,
            item=item,
            table_name=table_name,
            range_key=range_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(DynamodbTableItem, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="hashKey")
    def hash_key(self) -> str:
        return jsii.get(self, "hashKey")

    @hash_key.setter
    def hash_key(self, value: str) -> None:
        jsii.set(self, "hashKey", value)

    @builtins.property
    @jsii.member(jsii_name="item")
    def item(self) -> str:
        return jsii.get(self, "item")

    @item.setter
    def item(self, value: str) -> None:
        jsii.set(self, "item", value)

    @builtins.property
    @jsii.member(jsii_name="tableName")
    def table_name(self) -> str:
        return jsii.get(self, "tableName")

    @table_name.setter
    def table_name(self, value: str) -> None:
        jsii.set(self, "tableName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="rangeKey")
    def range_key(self) -> typing.Optional[str]:
        return jsii.get(self, "rangeKey")

    @range_key.setter
    def range_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rangeKey", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableItemConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "hash_key": "hashKey",
        "item": "item",
        "table_name": "tableName",
        "range_key": "rangeKey",
    },
)
class DynamodbTableItemConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        hash_key: str,
        item: str,
        table_name: str,
        range_key: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param hash_key: 
        :param item: 
        :param table_name: 
        :param range_key: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "hash_key": hash_key,
            "item": item,
            "table_name": table_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if range_key is not None:
            self._values["range_key"] = range_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def hash_key(self) -> str:
        return self._values.get("hash_key")

    @builtins.property
    def item(self) -> str:
        return self._values.get("item")

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    @builtins.property
    def range_key(self) -> typing.Optional[str]:
        return self._values.get("range_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableItemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableLocalSecondaryIndex",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "projection_type": "projectionType",
        "range_key": "rangeKey",
        "non_key_attributes": "nonKeyAttributes",
    },
)
class DynamodbTableLocalSecondaryIndex:
    def __init__(
        self,
        *,
        name: str,
        projection_type: str,
        range_key: str,
        non_key_attributes: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param name: 
        :param projection_type: 
        :param range_key: 
        :param non_key_attributes: 
        """
        self._values = {
            "name": name,
            "projection_type": projection_type,
            "range_key": range_key,
        }
        if non_key_attributes is not None:
            self._values["non_key_attributes"] = non_key_attributes

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def projection_type(self) -> str:
        return self._values.get("projection_type")

    @builtins.property
    def range_key(self) -> str:
        return self._values.get("range_key")

    @builtins.property
    def non_key_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("non_key_attributes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableLocalSecondaryIndex(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTablePointInTimeRecovery",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class DynamodbTablePointInTimeRecovery:
    def __init__(self, *, enabled: bool) -> None:
        """
        :param enabled: 
        """
        self._values = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTablePointInTimeRecovery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableReplica",
    jsii_struct_bases=[],
    name_mapping={"region_name": "regionName"},
)
class DynamodbTableReplica:
    def __init__(self, *, region_name: str) -> None:
        """
        :param region_name: 
        """
        self._values = {
            "region_name": region_name,
        }

    @builtins.property
    def region_name(self) -> str:
        return self._values.get("region_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableReplica(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableServerSideEncryption",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "kms_key_arn": "kmsKeyArn"},
)
class DynamodbTableServerSideEncryption:
    def __init__(
        self, *, enabled: bool, kms_key_arn: typing.Optional[str] = None
    ) -> None:
        """
        :param enabled: 
        :param kms_key_arn: 
        """
        self._values = {
            "enabled": enabled,
        }
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableServerSideEncryption(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class DynamodbTableTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.DynamodbTableTtl",
    jsii_struct_bases=[],
    name_mapping={"attribute_name": "attributeName", "enabled": "enabled"},
)
class DynamodbTableTtl:
    def __init__(
        self, *, attribute_name: str, enabled: typing.Optional[bool] = None
    ) -> None:
        """
        :param attribute_name: 
        :param enabled: 
        """
        self._values = {
            "attribute_name": attribute_name,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def attribute_name(self) -> str:
        return self._values.get("attribute_name")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "DynamodbTableTtl(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EbsDefaultKmsKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EbsDefaultKmsKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        key_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EbsDefaultKmsKeyConfig(
            key_arn=key_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EbsDefaultKmsKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="keyArn")
    def key_arn(self) -> str:
        return jsii.get(self, "keyArn")

    @key_arn.setter
    def key_arn(self, value: str) -> None:
        jsii.set(self, "keyArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EbsDefaultKmsKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_arn": "keyArn",
    },
)
class EbsDefaultKmsKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "key_arn": key_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def key_arn(self) -> str:
        return self._values.get("key_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EbsDefaultKmsKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EbsEncryptionByDefault(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EbsEncryptionByDefault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EbsEncryptionByDefaultConfig(
            enabled=enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EbsEncryptionByDefault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EbsEncryptionByDefaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enabled": "enabled",
    },
)
class EbsEncryptionByDefaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EbsEncryptionByDefaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EbsSnapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EbsSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        volume_id: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EbsSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param volume_id: 
        :param description: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EbsSnapshotConfig(
            volume_id=volume_id,
            description=description,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EbsSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dataEncryptionKeyId")
    def data_encryption_key_id(self) -> str:
        return jsii.get(self, "dataEncryptionKeyId")

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> bool:
        return jsii.get(self, "encrypted")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="ownerAlias")
    def owner_alias(self) -> str:
        return jsii.get(self, "ownerAlias")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @volume_id.setter
    def volume_id(self, value: str) -> None:
        jsii.set(self, "volumeId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EbsSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["EbsSnapshotTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EbsSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "volume_id": "volumeId",
        "description": "description",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class EbsSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        volume_id: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EbsSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param volume_id: 
        :param description: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EbsSnapshotTimeouts(**timeouts)
        self._values = {
            "volume_id": volume_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def volume_id(self) -> str:
        return self._values.get("volume_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["EbsSnapshotTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EbsSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EbsSnapshotCopy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EbsSnapshotCopy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        source_region: str,
        source_snapshot_id: str,
        description: typing.Optional[str] = None,
        encrypted: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param source_region: 
        :param source_snapshot_id: 
        :param description: 
        :param encrypted: 
        :param kms_key_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EbsSnapshotCopyConfig(
            source_region=source_region,
            source_snapshot_id=source_snapshot_id,
            description=description,
            encrypted=encrypted,
            kms_key_id=kms_key_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EbsSnapshotCopy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dataEncryptionKeyId")
    def data_encryption_key_id(self) -> str:
        return jsii.get(self, "dataEncryptionKeyId")

    @builtins.property
    @jsii.member(jsii_name="ownerAlias")
    def owner_alias(self) -> str:
        return jsii.get(self, "ownerAlias")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @builtins.property
    @jsii.member(jsii_name="volumeSize")
    def volume_size(self) -> jsii.Number:
        return jsii.get(self, "volumeSize")

    @builtins.property
    @jsii.member(jsii_name="sourceRegion")
    def source_region(self) -> str:
        return jsii.get(self, "sourceRegion")

    @source_region.setter
    def source_region(self, value: str) -> None:
        jsii.set(self, "sourceRegion", value)

    @builtins.property
    @jsii.member(jsii_name="sourceSnapshotId")
    def source_snapshot_id(self) -> str:
        return jsii.get(self, "sourceSnapshotId")

    @source_snapshot_id.setter
    def source_snapshot_id(self, value: str) -> None:
        jsii.set(self, "sourceSnapshotId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EbsSnapshotCopyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "source_region": "sourceRegion",
        "source_snapshot_id": "sourceSnapshotId",
        "description": "description",
        "encrypted": "encrypted",
        "kms_key_id": "kmsKeyId",
        "tags": "tags",
    },
)
class EbsSnapshotCopyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        source_region: str,
        source_snapshot_id: str,
        description: typing.Optional[str] = None,
        encrypted: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param source_region: 
        :param source_snapshot_id: 
        :param description: 
        :param encrypted: 
        :param kms_key_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "source_region": source_region,
            "source_snapshot_id": source_snapshot_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def source_region(self) -> str:
        return self._values.get("source_region")

    @builtins.property
    def source_snapshot_id(self) -> str:
        return self._values.get("source_snapshot_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EbsSnapshotCopyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EbsSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class EbsSnapshotTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EbsSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EbsVolume(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EbsVolume",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        availability_zone: str,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        multi_attach_enabled: typing.Optional[bool] = None,
        outpost_arn: typing.Optional[str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param availability_zone: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param multi_attach_enabled: 
        :param outpost_arn: 
        :param size: 
        :param snapshot_id: 
        :param tags: 
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EbsVolumeConfig(
            availability_zone=availability_zone,
            encrypted=encrypted,
            iops=iops,
            kms_key_id=kms_key_id,
            multi_attach_enabled=multi_attach_enabled,
            outpost_arn=outpost_arn,
            size=size,
            snapshot_id=snapshot_id,
            tags=tags,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EbsVolume, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: str) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="iops")
    def iops(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "iops")

    @iops.setter
    def iops(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "iops", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="multiAttachEnabled")
    def multi_attach_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "multiAttachEnabled")

    @multi_attach_enabled.setter
    def multi_attach_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "multiAttachEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "outpostArn")

    @outpost_arn.setter
    def outpost_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "outpostArn", value)

    @builtins.property
    @jsii.member(jsii_name="size")
    def size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "size")

    @size.setter
    def size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "size", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotId")

    @snapshot_id.setter
    def snapshot_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EbsVolumeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "availability_zone": "availabilityZone",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "multi_attach_enabled": "multiAttachEnabled",
        "outpost_arn": "outpostArn",
        "size": "size",
        "snapshot_id": "snapshotId",
        "tags": "tags",
        "type": "type",
    },
)
class EbsVolumeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        availability_zone: str,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        multi_attach_enabled: typing.Optional[bool] = None,
        outpost_arn: typing.Optional[str] = None,
        size: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param availability_zone: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param multi_attach_enabled: 
        :param outpost_arn: 
        :param size: 
        :param snapshot_id: 
        :param tags: 
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "availability_zone": availability_zone,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if multi_attach_enabled is not None:
            self._values["multi_attach_enabled"] = multi_attach_enabled
        if outpost_arn is not None:
            self._values["outpost_arn"] = outpost_arn
        if size is not None:
            self._values["size"] = size
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if tags is not None:
            self._values["tags"] = tags
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def availability_zone(self) -> str:
        return self._values.get("availability_zone")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def multi_attach_enabled(self) -> typing.Optional[bool]:
        return self._values.get("multi_attach_enabled")

    @builtins.property
    def outpost_arn(self) -> typing.Optional[str]:
        return self._values.get("outpost_arn")

    @builtins.property
    def size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("size")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EbsVolumeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2AvailabilityZoneGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2AvailabilityZoneGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        group_name: str,
        opt_in_status: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group_name: 
        :param opt_in_status: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2AvailabilityZoneGroupConfig(
            group_name=group_name,
            opt_in_status=opt_in_status,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2AvailabilityZoneGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="groupName")
    def group_name(self) -> str:
        return jsii.get(self, "groupName")

    @group_name.setter
    def group_name(self, value: str) -> None:
        jsii.set(self, "groupName", value)

    @builtins.property
    @jsii.member(jsii_name="optInStatus")
    def opt_in_status(self) -> str:
        return jsii.get(self, "optInStatus")

    @opt_in_status.setter
    def opt_in_status(self, value: str) -> None:
        jsii.set(self, "optInStatus", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2AvailabilityZoneGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group_name": "groupName",
        "opt_in_status": "optInStatus",
    },
)
class Ec2AvailabilityZoneGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group_name: str,
        opt_in_status: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group_name: 
        :param opt_in_status: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "group_name": group_name,
            "opt_in_status": opt_in_status,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def group_name(self) -> str:
        return self._values.get("group_name")

    @builtins.property
    def opt_in_status(self) -> str:
        return self._values.get("opt_in_status")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2AvailabilityZoneGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2CapacityReservation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2CapacityReservation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        availability_zone: str,
        instance_count: jsii.Number,
        instance_platform: str,
        instance_type: str,
        ebs_optimized: typing.Optional[bool] = None,
        end_date: typing.Optional[str] = None,
        end_date_type: typing.Optional[str] = None,
        ephemeral_storage: typing.Optional[bool] = None,
        instance_match_criteria: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tenancy: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param availability_zone: 
        :param instance_count: 
        :param instance_platform: 
        :param instance_type: 
        :param ebs_optimized: 
        :param end_date: 
        :param end_date_type: 
        :param ephemeral_storage: 
        :param instance_match_criteria: 
        :param tags: 
        :param tenancy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2CapacityReservationConfig(
            availability_zone=availability_zone,
            instance_count=instance_count,
            instance_platform=instance_platform,
            instance_type=instance_type,
            ebs_optimized=ebs_optimized,
            end_date=end_date,
            end_date_type=end_date_type,
            ephemeral_storage=ephemeral_storage,
            instance_match_criteria=instance_match_criteria,
            tags=tags,
            tenancy=tenancy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2CapacityReservation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: str) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="instanceCount")
    def instance_count(self) -> jsii.Number:
        return jsii.get(self, "instanceCount")

    @instance_count.setter
    def instance_count(self, value: jsii.Number) -> None:
        jsii.set(self, "instanceCount", value)

    @builtins.property
    @jsii.member(jsii_name="instancePlatform")
    def instance_platform(self) -> str:
        return jsii.get(self, "instancePlatform")

    @instance_platform.setter
    def instance_platform(self, value: str) -> None:
        jsii.set(self, "instancePlatform", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: str) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> typing.Optional[bool]:
        return jsii.get(self, "ebsOptimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ebsOptimized", value)

    @builtins.property
    @jsii.member(jsii_name="endDate")
    def end_date(self) -> typing.Optional[str]:
        return jsii.get(self, "endDate")

    @end_date.setter
    def end_date(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endDate", value)

    @builtins.property
    @jsii.member(jsii_name="endDateType")
    def end_date_type(self) -> typing.Optional[str]:
        return jsii.get(self, "endDateType")

    @end_date_type.setter
    def end_date_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endDateType", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralStorage")
    def ephemeral_storage(self) -> typing.Optional[bool]:
        return jsii.get(self, "ephemeralStorage")

    @ephemeral_storage.setter
    def ephemeral_storage(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ephemeralStorage", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceMatchCriteria")
    def instance_match_criteria(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceMatchCriteria")

    @instance_match_criteria.setter
    def instance_match_criteria(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceMatchCriteria", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="tenancy")
    def tenancy(self) -> typing.Optional[str]:
        return jsii.get(self, "tenancy")

    @tenancy.setter
    def tenancy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tenancy", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2CapacityReservationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "availability_zone": "availabilityZone",
        "instance_count": "instanceCount",
        "instance_platform": "instancePlatform",
        "instance_type": "instanceType",
        "ebs_optimized": "ebsOptimized",
        "end_date": "endDate",
        "end_date_type": "endDateType",
        "ephemeral_storage": "ephemeralStorage",
        "instance_match_criteria": "instanceMatchCriteria",
        "tags": "tags",
        "tenancy": "tenancy",
    },
)
class Ec2CapacityReservationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        availability_zone: str,
        instance_count: jsii.Number,
        instance_platform: str,
        instance_type: str,
        ebs_optimized: typing.Optional[bool] = None,
        end_date: typing.Optional[str] = None,
        end_date_type: typing.Optional[str] = None,
        ephemeral_storage: typing.Optional[bool] = None,
        instance_match_criteria: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tenancy: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param availability_zone: 
        :param instance_count: 
        :param instance_platform: 
        :param instance_type: 
        :param ebs_optimized: 
        :param end_date: 
        :param end_date_type: 
        :param ephemeral_storage: 
        :param instance_match_criteria: 
        :param tags: 
        :param tenancy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "availability_zone": availability_zone,
            "instance_count": instance_count,
            "instance_platform": instance_platform,
            "instance_type": instance_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if end_date is not None:
            self._values["end_date"] = end_date
        if end_date_type is not None:
            self._values["end_date_type"] = end_date_type
        if ephemeral_storage is not None:
            self._values["ephemeral_storage"] = ephemeral_storage
        if instance_match_criteria is not None:
            self._values["instance_match_criteria"] = instance_match_criteria
        if tags is not None:
            self._values["tags"] = tags
        if tenancy is not None:
            self._values["tenancy"] = tenancy

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def availability_zone(self) -> str:
        return self._values.get("availability_zone")

    @builtins.property
    def instance_count(self) -> jsii.Number:
        return self._values.get("instance_count")

    @builtins.property
    def instance_platform(self) -> str:
        return self._values.get("instance_platform")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[bool]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def end_date(self) -> typing.Optional[str]:
        return self._values.get("end_date")

    @builtins.property
    def end_date_type(self) -> typing.Optional[str]:
        return self._values.get("end_date_type")

    @builtins.property
    def ephemeral_storage(self) -> typing.Optional[bool]:
        return self._values.get("ephemeral_storage")

    @builtins.property
    def instance_match_criteria(self) -> typing.Optional[str]:
        return self._values.get("instance_match_criteria")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def tenancy(self) -> typing.Optional[str]:
        return self._values.get("tenancy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2CapacityReservationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2ClientVpnAuthorizationRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnAuthorizationRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        client_vpn_endpoint_id: str,
        target_network_cidr: str,
        access_group_id: typing.Optional[str] = None,
        authorize_all_groups: typing.Optional[bool] = None,
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param client_vpn_endpoint_id: 
        :param target_network_cidr: 
        :param access_group_id: 
        :param authorize_all_groups: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2ClientVpnAuthorizationRuleConfig(
            client_vpn_endpoint_id=client_vpn_endpoint_id,
            target_network_cidr=target_network_cidr,
            access_group_id=access_group_id,
            authorize_all_groups=authorize_all_groups,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2ClientVpnAuthorizationRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="clientVpnEndpointId")
    def client_vpn_endpoint_id(self) -> str:
        return jsii.get(self, "clientVpnEndpointId")

    @client_vpn_endpoint_id.setter
    def client_vpn_endpoint_id(self, value: str) -> None:
        jsii.set(self, "clientVpnEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="targetNetworkCidr")
    def target_network_cidr(self) -> str:
        return jsii.get(self, "targetNetworkCidr")

    @target_network_cidr.setter
    def target_network_cidr(self, value: str) -> None:
        jsii.set(self, "targetNetworkCidr", value)

    @builtins.property
    @jsii.member(jsii_name="accessGroupId")
    def access_group_id(self) -> typing.Optional[str]:
        return jsii.get(self, "accessGroupId")

    @access_group_id.setter
    def access_group_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accessGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="authorizeAllGroups")
    def authorize_all_groups(self) -> typing.Optional[bool]:
        return jsii.get(self, "authorizeAllGroups")

    @authorize_all_groups.setter
    def authorize_all_groups(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "authorizeAllGroups", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnAuthorizationRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "client_vpn_endpoint_id": "clientVpnEndpointId",
        "target_network_cidr": "targetNetworkCidr",
        "access_group_id": "accessGroupId",
        "authorize_all_groups": "authorizeAllGroups",
        "description": "description",
    },
)
class Ec2ClientVpnAuthorizationRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        client_vpn_endpoint_id: str,
        target_network_cidr: str,
        access_group_id: typing.Optional[str] = None,
        authorize_all_groups: typing.Optional[bool] = None,
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param client_vpn_endpoint_id: 
        :param target_network_cidr: 
        :param access_group_id: 
        :param authorize_all_groups: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "client_vpn_endpoint_id": client_vpn_endpoint_id,
            "target_network_cidr": target_network_cidr,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_group_id is not None:
            self._values["access_group_id"] = access_group_id
        if authorize_all_groups is not None:
            self._values["authorize_all_groups"] = authorize_all_groups
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def client_vpn_endpoint_id(self) -> str:
        return self._values.get("client_vpn_endpoint_id")

    @builtins.property
    def target_network_cidr(self) -> str:
        return self._values.get("target_network_cidr")

    @builtins.property
    def access_group_id(self) -> typing.Optional[str]:
        return self._values.get("access_group_id")

    @builtins.property
    def authorize_all_groups(self) -> typing.Optional[bool]:
        return self._values.get("authorize_all_groups")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ClientVpnAuthorizationRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2ClientVpnEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        authentication_options: typing.List[
            "Ec2ClientVpnEndpointAuthenticationOptions"
        ],
        client_cidr_block: str,
        connection_log_options: typing.List["Ec2ClientVpnEndpointConnectionLogOptions"],
        server_certificate_arn: str,
        description: typing.Optional[str] = None,
        dns_servers: typing.Optional[typing.List[str]] = None,
        split_tunnel: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transport_protocol: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param authentication_options: authentication_options block.
        :param client_cidr_block: 
        :param connection_log_options: connection_log_options block.
        :param server_certificate_arn: 
        :param description: 
        :param dns_servers: 
        :param split_tunnel: 
        :param tags: 
        :param transport_protocol: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2ClientVpnEndpointConfig(
            authentication_options=authentication_options,
            client_cidr_block=client_cidr_block,
            connection_log_options=connection_log_options,
            server_certificate_arn=server_certificate_arn,
            description=description,
            dns_servers=dns_servers,
            split_tunnel=split_tunnel,
            tags=tags,
            transport_protocol=transport_protocol,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2ClientVpnEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="authenticationOptions")
    def authentication_options(
        self,
    ) -> typing.List["Ec2ClientVpnEndpointAuthenticationOptions"]:
        return jsii.get(self, "authenticationOptions")

    @authentication_options.setter
    def authentication_options(
        self, value: typing.List["Ec2ClientVpnEndpointAuthenticationOptions"]
    ) -> None:
        jsii.set(self, "authenticationOptions", value)

    @builtins.property
    @jsii.member(jsii_name="clientCidrBlock")
    def client_cidr_block(self) -> str:
        return jsii.get(self, "clientCidrBlock")

    @client_cidr_block.setter
    def client_cidr_block(self, value: str) -> None:
        jsii.set(self, "clientCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="connectionLogOptions")
    def connection_log_options(
        self,
    ) -> typing.List["Ec2ClientVpnEndpointConnectionLogOptions"]:
        return jsii.get(self, "connectionLogOptions")

    @connection_log_options.setter
    def connection_log_options(
        self, value: typing.List["Ec2ClientVpnEndpointConnectionLogOptions"]
    ) -> None:
        jsii.set(self, "connectionLogOptions", value)

    @builtins.property
    @jsii.member(jsii_name="serverCertificateArn")
    def server_certificate_arn(self) -> str:
        return jsii.get(self, "serverCertificateArn")

    @server_certificate_arn.setter
    def server_certificate_arn(self, value: str) -> None:
        jsii.set(self, "serverCertificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="dnsServers")
    def dns_servers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "dnsServers")

    @dns_servers.setter
    def dns_servers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "dnsServers", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="splitTunnel")
    def split_tunnel(self) -> typing.Optional[bool]:
        return jsii.get(self, "splitTunnel")

    @split_tunnel.setter
    def split_tunnel(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "splitTunnel", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="transportProtocol")
    def transport_protocol(self) -> typing.Optional[str]:
        return jsii.get(self, "transportProtocol")

    @transport_protocol.setter
    def transport_protocol(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "transportProtocol", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnEndpointAuthenticationOptions",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "active_directory_id": "activeDirectoryId",
        "root_certificate_chain_arn": "rootCertificateChainArn",
    },
)
class Ec2ClientVpnEndpointAuthenticationOptions:
    def __init__(
        self,
        *,
        type: str,
        active_directory_id: typing.Optional[str] = None,
        root_certificate_chain_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param active_directory_id: 
        :param root_certificate_chain_arn: 
        """
        self._values = {
            "type": type,
        }
        if active_directory_id is not None:
            self._values["active_directory_id"] = active_directory_id
        if root_certificate_chain_arn is not None:
            self._values["root_certificate_chain_arn"] = root_certificate_chain_arn

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def active_directory_id(self) -> typing.Optional[str]:
        return self._values.get("active_directory_id")

    @builtins.property
    def root_certificate_chain_arn(self) -> typing.Optional[str]:
        return self._values.get("root_certificate_chain_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ClientVpnEndpointAuthenticationOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "authentication_options": "authenticationOptions",
        "client_cidr_block": "clientCidrBlock",
        "connection_log_options": "connectionLogOptions",
        "server_certificate_arn": "serverCertificateArn",
        "description": "description",
        "dns_servers": "dnsServers",
        "split_tunnel": "splitTunnel",
        "tags": "tags",
        "transport_protocol": "transportProtocol",
    },
)
class Ec2ClientVpnEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        authentication_options: typing.List[
            "Ec2ClientVpnEndpointAuthenticationOptions"
        ],
        client_cidr_block: str,
        connection_log_options: typing.List["Ec2ClientVpnEndpointConnectionLogOptions"],
        server_certificate_arn: str,
        description: typing.Optional[str] = None,
        dns_servers: typing.Optional[typing.List[str]] = None,
        split_tunnel: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transport_protocol: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param authentication_options: authentication_options block.
        :param client_cidr_block: 
        :param connection_log_options: connection_log_options block.
        :param server_certificate_arn: 
        :param description: 
        :param dns_servers: 
        :param split_tunnel: 
        :param tags: 
        :param transport_protocol: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "authentication_options": authentication_options,
            "client_cidr_block": client_cidr_block,
            "connection_log_options": connection_log_options,
            "server_certificate_arn": server_certificate_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if dns_servers is not None:
            self._values["dns_servers"] = dns_servers
        if split_tunnel is not None:
            self._values["split_tunnel"] = split_tunnel
        if tags is not None:
            self._values["tags"] = tags
        if transport_protocol is not None:
            self._values["transport_protocol"] = transport_protocol

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def authentication_options(
        self,
    ) -> typing.List["Ec2ClientVpnEndpointAuthenticationOptions"]:
        """authentication_options block."""
        return self._values.get("authentication_options")

    @builtins.property
    def client_cidr_block(self) -> str:
        return self._values.get("client_cidr_block")

    @builtins.property
    def connection_log_options(
        self,
    ) -> typing.List["Ec2ClientVpnEndpointConnectionLogOptions"]:
        """connection_log_options block."""
        return self._values.get("connection_log_options")

    @builtins.property
    def server_certificate_arn(self) -> str:
        return self._values.get("server_certificate_arn")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def dns_servers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("dns_servers")

    @builtins.property
    def split_tunnel(self) -> typing.Optional[bool]:
        return self._values.get("split_tunnel")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def transport_protocol(self) -> typing.Optional[str]:
        return self._values.get("transport_protocol")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ClientVpnEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnEndpointConnectionLogOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "cloudwatch_log_group": "cloudwatchLogGroup",
        "cloudwatch_log_stream": "cloudwatchLogStream",
    },
)
class Ec2ClientVpnEndpointConnectionLogOptions:
    def __init__(
        self,
        *,
        enabled: bool,
        cloudwatch_log_group: typing.Optional[str] = None,
        cloudwatch_log_stream: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param cloudwatch_log_group: 
        :param cloudwatch_log_stream: 
        """
        self._values = {
            "enabled": enabled,
        }
        if cloudwatch_log_group is not None:
            self._values["cloudwatch_log_group"] = cloudwatch_log_group
        if cloudwatch_log_stream is not None:
            self._values["cloudwatch_log_stream"] = cloudwatch_log_stream

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def cloudwatch_log_group(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_log_group")

    @builtins.property
    def cloudwatch_log_stream(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_log_stream")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ClientVpnEndpointConnectionLogOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2ClientVpnNetworkAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnNetworkAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        client_vpn_endpoint_id: str,
        subnet_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param client_vpn_endpoint_id: 
        :param subnet_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2ClientVpnNetworkAssociationConfig(
            client_vpn_endpoint_id=client_vpn_endpoint_id,
            subnet_id=subnet_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2ClientVpnNetworkAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="clientVpnEndpointId")
    def client_vpn_endpoint_id(self) -> str:
        return jsii.get(self, "clientVpnEndpointId")

    @client_vpn_endpoint_id.setter
    def client_vpn_endpoint_id(self, value: str) -> None:
        jsii.set(self, "clientVpnEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnNetworkAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "client_vpn_endpoint_id": "clientVpnEndpointId",
        "subnet_id": "subnetId",
    },
)
class Ec2ClientVpnNetworkAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        client_vpn_endpoint_id: str,
        subnet_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param client_vpn_endpoint_id: 
        :param subnet_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "client_vpn_endpoint_id": client_vpn_endpoint_id,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def client_vpn_endpoint_id(self) -> str:
        return self._values.get("client_vpn_endpoint_id")

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ClientVpnNetworkAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2ClientVpnRoute(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnRoute",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        client_vpn_endpoint_id: str,
        destination_cidr_block: str,
        target_vpc_subnet_id: str,
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param client_vpn_endpoint_id: 
        :param destination_cidr_block: 
        :param target_vpc_subnet_id: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2ClientVpnRouteConfig(
            client_vpn_endpoint_id=client_vpn_endpoint_id,
            destination_cidr_block=destination_cidr_block,
            target_vpc_subnet_id=target_vpc_subnet_id,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2ClientVpnRoute, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="origin")
    def origin(self) -> str:
        return jsii.get(self, "origin")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @builtins.property
    @jsii.member(jsii_name="clientVpnEndpointId")
    def client_vpn_endpoint_id(self) -> str:
        return jsii.get(self, "clientVpnEndpointId")

    @client_vpn_endpoint_id.setter
    def client_vpn_endpoint_id(self, value: str) -> None:
        jsii.set(self, "clientVpnEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> str:
        return jsii.get(self, "destinationCidrBlock")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: str) -> None:
        jsii.set(self, "destinationCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="targetVpcSubnetId")
    def target_vpc_subnet_id(self) -> str:
        return jsii.get(self, "targetVpcSubnetId")

    @target_vpc_subnet_id.setter
    def target_vpc_subnet_id(self, value: str) -> None:
        jsii.set(self, "targetVpcSubnetId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2ClientVpnRouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "client_vpn_endpoint_id": "clientVpnEndpointId",
        "destination_cidr_block": "destinationCidrBlock",
        "target_vpc_subnet_id": "targetVpcSubnetId",
        "description": "description",
    },
)
class Ec2ClientVpnRouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        client_vpn_endpoint_id: str,
        destination_cidr_block: str,
        target_vpc_subnet_id: str,
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param client_vpn_endpoint_id: 
        :param destination_cidr_block: 
        :param target_vpc_subnet_id: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "client_vpn_endpoint_id": client_vpn_endpoint_id,
            "destination_cidr_block": destination_cidr_block,
            "target_vpc_subnet_id": target_vpc_subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def client_vpn_endpoint_id(self) -> str:
        return self._values.get("client_vpn_endpoint_id")

    @builtins.property
    def destination_cidr_block(self) -> str:
        return self._values.get("destination_cidr_block")

    @builtins.property
    def target_vpc_subnet_id(self) -> str:
        return self._values.get("target_vpc_subnet_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2ClientVpnRouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2Fleet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2Fleet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        launch_template_config: typing.List["Ec2FleetLaunchTemplateConfig"],
        target_capacity_specification: typing.List[
            "Ec2FleetTargetCapacitySpecification"
        ],
        excess_capacity_termination_policy: typing.Optional[str] = None,
        on_demand_options: typing.Optional[
            typing.List["Ec2FleetOnDemandOptions"]
        ] = None,
        replace_unhealthy_instances: typing.Optional[bool] = None,
        spot_options: typing.Optional[typing.List["Ec2FleetSpotOptions"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        terminate_instances: typing.Optional[bool] = None,
        terminate_instances_with_expiration: typing.Optional[bool] = None,
        timeouts: typing.Optional["Ec2FleetTimeouts"] = None,
        type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param launch_template_config: launch_template_config block.
        :param target_capacity_specification: target_capacity_specification block.
        :param excess_capacity_termination_policy: 
        :param on_demand_options: on_demand_options block.
        :param replace_unhealthy_instances: 
        :param spot_options: spot_options block.
        :param tags: 
        :param terminate_instances: 
        :param terminate_instances_with_expiration: 
        :param timeouts: timeouts block.
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2FleetConfig(
            launch_template_config=launch_template_config,
            target_capacity_specification=target_capacity_specification,
            excess_capacity_termination_policy=excess_capacity_termination_policy,
            on_demand_options=on_demand_options,
            replace_unhealthy_instances=replace_unhealthy_instances,
            spot_options=spot_options,
            tags=tags,
            terminate_instances=terminate_instances,
            terminate_instances_with_expiration=terminate_instances_with_expiration,
            timeouts=timeouts,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2Fleet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="launchTemplateConfig")
    def launch_template_config(self) -> typing.List["Ec2FleetLaunchTemplateConfig"]:
        return jsii.get(self, "launchTemplateConfig")

    @launch_template_config.setter
    def launch_template_config(
        self, value: typing.List["Ec2FleetLaunchTemplateConfig"]
    ) -> None:
        jsii.set(self, "launchTemplateConfig", value)

    @builtins.property
    @jsii.member(jsii_name="targetCapacitySpecification")
    def target_capacity_specification(
        self,
    ) -> typing.List["Ec2FleetTargetCapacitySpecification"]:
        return jsii.get(self, "targetCapacitySpecification")

    @target_capacity_specification.setter
    def target_capacity_specification(
        self, value: typing.List["Ec2FleetTargetCapacitySpecification"]
    ) -> None:
        jsii.set(self, "targetCapacitySpecification", value)

    @builtins.property
    @jsii.member(jsii_name="excessCapacityTerminationPolicy")
    def excess_capacity_termination_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "excessCapacityTerminationPolicy")

    @excess_capacity_termination_policy.setter
    def excess_capacity_termination_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "excessCapacityTerminationPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="onDemandOptions")
    def on_demand_options(
        self,
    ) -> typing.Optional[typing.List["Ec2FleetOnDemandOptions"]]:
        return jsii.get(self, "onDemandOptions")

    @on_demand_options.setter
    def on_demand_options(
        self, value: typing.Optional[typing.List["Ec2FleetOnDemandOptions"]]
    ) -> None:
        jsii.set(self, "onDemandOptions", value)

    @builtins.property
    @jsii.member(jsii_name="replaceUnhealthyInstances")
    def replace_unhealthy_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "replaceUnhealthyInstances")

    @replace_unhealthy_instances.setter
    def replace_unhealthy_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "replaceUnhealthyInstances", value)

    @builtins.property
    @jsii.member(jsii_name="spotOptions")
    def spot_options(self) -> typing.Optional[typing.List["Ec2FleetSpotOptions"]]:
        return jsii.get(self, "spotOptions")

    @spot_options.setter
    def spot_options(
        self, value: typing.Optional[typing.List["Ec2FleetSpotOptions"]]
    ) -> None:
        jsii.set(self, "spotOptions", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="terminateInstances")
    def terminate_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "terminateInstances")

    @terminate_instances.setter
    def terminate_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "terminateInstances", value)

    @builtins.property
    @jsii.member(jsii_name="terminateInstancesWithExpiration")
    def terminate_instances_with_expiration(self) -> typing.Optional[bool]:
        return jsii.get(self, "terminateInstancesWithExpiration")

    @terminate_instances_with_expiration.setter
    def terminate_instances_with_expiration(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "terminateInstancesWithExpiration", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["Ec2FleetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["Ec2FleetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "launch_template_config": "launchTemplateConfig",
        "target_capacity_specification": "targetCapacitySpecification",
        "excess_capacity_termination_policy": "excessCapacityTerminationPolicy",
        "on_demand_options": "onDemandOptions",
        "replace_unhealthy_instances": "replaceUnhealthyInstances",
        "spot_options": "spotOptions",
        "tags": "tags",
        "terminate_instances": "terminateInstances",
        "terminate_instances_with_expiration": "terminateInstancesWithExpiration",
        "timeouts": "timeouts",
        "type": "type",
    },
)
class Ec2FleetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        launch_template_config: typing.List["Ec2FleetLaunchTemplateConfig"],
        target_capacity_specification: typing.List[
            "Ec2FleetTargetCapacitySpecification"
        ],
        excess_capacity_termination_policy: typing.Optional[str] = None,
        on_demand_options: typing.Optional[
            typing.List["Ec2FleetOnDemandOptions"]
        ] = None,
        replace_unhealthy_instances: typing.Optional[bool] = None,
        spot_options: typing.Optional[typing.List["Ec2FleetSpotOptions"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        terminate_instances: typing.Optional[bool] = None,
        terminate_instances_with_expiration: typing.Optional[bool] = None,
        timeouts: typing.Optional["Ec2FleetTimeouts"] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param launch_template_config: launch_template_config block.
        :param target_capacity_specification: target_capacity_specification block.
        :param excess_capacity_termination_policy: 
        :param on_demand_options: on_demand_options block.
        :param replace_unhealthy_instances: 
        :param spot_options: spot_options block.
        :param tags: 
        :param terminate_instances: 
        :param terminate_instances_with_expiration: 
        :param timeouts: timeouts block.
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = Ec2FleetTimeouts(**timeouts)
        self._values = {
            "launch_template_config": launch_template_config,
            "target_capacity_specification": target_capacity_specification,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if excess_capacity_termination_policy is not None:
            self._values[
                "excess_capacity_termination_policy"
            ] = excess_capacity_termination_policy
        if on_demand_options is not None:
            self._values["on_demand_options"] = on_demand_options
        if replace_unhealthy_instances is not None:
            self._values["replace_unhealthy_instances"] = replace_unhealthy_instances
        if spot_options is not None:
            self._values["spot_options"] = spot_options
        if tags is not None:
            self._values["tags"] = tags
        if terminate_instances is not None:
            self._values["terminate_instances"] = terminate_instances
        if terminate_instances_with_expiration is not None:
            self._values[
                "terminate_instances_with_expiration"
            ] = terminate_instances_with_expiration
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def launch_template_config(self) -> typing.List["Ec2FleetLaunchTemplateConfig"]:
        """launch_template_config block."""
        return self._values.get("launch_template_config")

    @builtins.property
    def target_capacity_specification(
        self,
    ) -> typing.List["Ec2FleetTargetCapacitySpecification"]:
        """target_capacity_specification block."""
        return self._values.get("target_capacity_specification")

    @builtins.property
    def excess_capacity_termination_policy(self) -> typing.Optional[str]:
        return self._values.get("excess_capacity_termination_policy")

    @builtins.property
    def on_demand_options(
        self,
    ) -> typing.Optional[typing.List["Ec2FleetOnDemandOptions"]]:
        """on_demand_options block."""
        return self._values.get("on_demand_options")

    @builtins.property
    def replace_unhealthy_instances(self) -> typing.Optional[bool]:
        return self._values.get("replace_unhealthy_instances")

    @builtins.property
    def spot_options(self) -> typing.Optional[typing.List["Ec2FleetSpotOptions"]]:
        """spot_options block."""
        return self._values.get("spot_options")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def terminate_instances(self) -> typing.Optional[bool]:
        return self._values.get("terminate_instances")

    @builtins.property
    def terminate_instances_with_expiration(self) -> typing.Optional[bool]:
        return self._values.get("terminate_instances_with_expiration")

    @builtins.property
    def timeouts(self) -> typing.Optional["Ec2FleetTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2FleetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetLaunchTemplateConfig",
    jsii_struct_bases=[],
    name_mapping={
        "launch_template_specification": "launchTemplateSpecification",
        "override": "override",
    },
)
class Ec2FleetLaunchTemplateConfig:
    def __init__(
        self,
        *,
        launch_template_specification: typing.List[
            "Ec2FleetLaunchTemplateConfigLaunchTemplateSpecification"
        ],
        override: typing.Optional[
            typing.List["Ec2FleetLaunchTemplateConfigOverride"]
        ] = None,
    ) -> None:
        """
        :param launch_template_specification: launch_template_specification block.
        :param override: override block.
        """
        self._values = {
            "launch_template_specification": launch_template_specification,
        }
        if override is not None:
            self._values["override"] = override

    @builtins.property
    def launch_template_specification(
        self,
    ) -> typing.List["Ec2FleetLaunchTemplateConfigLaunchTemplateSpecification"]:
        """launch_template_specification block."""
        return self._values.get("launch_template_specification")

    @builtins.property
    def override(
        self,
    ) -> typing.Optional[typing.List["Ec2FleetLaunchTemplateConfigOverride"]]:
        """override block."""
        return self._values.get("override")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2FleetLaunchTemplateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetLaunchTemplateConfigLaunchTemplateSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "version": "version",
        "launch_template_id": "launchTemplateId",
        "launch_template_name": "launchTemplateName",
    },
)
class Ec2FleetLaunchTemplateConfigLaunchTemplateSpecification:
    def __init__(
        self,
        *,
        version: str,
        launch_template_id: typing.Optional[str] = None,
        launch_template_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param version: 
        :param launch_template_id: 
        :param launch_template_name: 
        """
        self._values = {
            "version": version,
        }
        if launch_template_id is not None:
            self._values["launch_template_id"] = launch_template_id
        if launch_template_name is not None:
            self._values["launch_template_name"] = launch_template_name

    @builtins.property
    def version(self) -> str:
        return self._values.get("version")

    @builtins.property
    def launch_template_id(self) -> typing.Optional[str]:
        return self._values.get("launch_template_id")

    @builtins.property
    def launch_template_name(self) -> typing.Optional[str]:
        return self._values.get("launch_template_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Ec2FleetLaunchTemplateConfigLaunchTemplateSpecification(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetLaunchTemplateConfigOverride",
    jsii_struct_bases=[],
    name_mapping={
        "availability_zone": "availabilityZone",
        "instance_type": "instanceType",
        "max_price": "maxPrice",
        "priority": "priority",
        "subnet_id": "subnetId",
        "weighted_capacity": "weightedCapacity",
    },
)
class Ec2FleetLaunchTemplateConfigOverride:
    def __init__(
        self,
        *,
        availability_zone: typing.Optional[str] = None,
        instance_type: typing.Optional[str] = None,
        max_price: typing.Optional[str] = None,
        priority: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[str] = None,
        weighted_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param availability_zone: 
        :param instance_type: 
        :param max_price: 
        :param priority: 
        :param subnet_id: 
        :param weighted_capacity: 
        """
        self._values = {}
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if max_price is not None:
            self._values["max_price"] = max_price
        if priority is not None:
            self._values["priority"] = priority
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if weighted_capacity is not None:
            self._values["weighted_capacity"] = weighted_capacity

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def instance_type(self) -> typing.Optional[str]:
        return self._values.get("instance_type")

    @builtins.property
    def max_price(self) -> typing.Optional[str]:
        return self._values.get("max_price")

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        return self._values.get("priority")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def weighted_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weighted_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2FleetLaunchTemplateConfigOverride(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetOnDemandOptions",
    jsii_struct_bases=[],
    name_mapping={"allocation_strategy": "allocationStrategy"},
)
class Ec2FleetOnDemandOptions:
    def __init__(self, *, allocation_strategy: typing.Optional[str] = None) -> None:
        """
        :param allocation_strategy: 
        """
        self._values = {}
        if allocation_strategy is not None:
            self._values["allocation_strategy"] = allocation_strategy

    @builtins.property
    def allocation_strategy(self) -> typing.Optional[str]:
        return self._values.get("allocation_strategy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2FleetOnDemandOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetSpotOptions",
    jsii_struct_bases=[],
    name_mapping={
        "allocation_strategy": "allocationStrategy",
        "instance_interruption_behavior": "instanceInterruptionBehavior",
        "instance_pools_to_use_count": "instancePoolsToUseCount",
    },
)
class Ec2FleetSpotOptions:
    def __init__(
        self,
        *,
        allocation_strategy: typing.Optional[str] = None,
        instance_interruption_behavior: typing.Optional[str] = None,
        instance_pools_to_use_count: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param allocation_strategy: 
        :param instance_interruption_behavior: 
        :param instance_pools_to_use_count: 
        """
        self._values = {}
        if allocation_strategy is not None:
            self._values["allocation_strategy"] = allocation_strategy
        if instance_interruption_behavior is not None:
            self._values[
                "instance_interruption_behavior"
            ] = instance_interruption_behavior
        if instance_pools_to_use_count is not None:
            self._values["instance_pools_to_use_count"] = instance_pools_to_use_count

    @builtins.property
    def allocation_strategy(self) -> typing.Optional[str]:
        return self._values.get("allocation_strategy")

    @builtins.property
    def instance_interruption_behavior(self) -> typing.Optional[str]:
        return self._values.get("instance_interruption_behavior")

    @builtins.property
    def instance_pools_to_use_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_pools_to_use_count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2FleetSpotOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetTargetCapacitySpecification",
    jsii_struct_bases=[],
    name_mapping={
        "default_target_capacity_type": "defaultTargetCapacityType",
        "total_target_capacity": "totalTargetCapacity",
        "on_demand_target_capacity": "onDemandTargetCapacity",
        "spot_target_capacity": "spotTargetCapacity",
    },
)
class Ec2FleetTargetCapacitySpecification:
    def __init__(
        self,
        *,
        default_target_capacity_type: str,
        total_target_capacity: jsii.Number,
        on_demand_target_capacity: typing.Optional[jsii.Number] = None,
        spot_target_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param default_target_capacity_type: 
        :param total_target_capacity: 
        :param on_demand_target_capacity: 
        :param spot_target_capacity: 
        """
        self._values = {
            "default_target_capacity_type": default_target_capacity_type,
            "total_target_capacity": total_target_capacity,
        }
        if on_demand_target_capacity is not None:
            self._values["on_demand_target_capacity"] = on_demand_target_capacity
        if spot_target_capacity is not None:
            self._values["spot_target_capacity"] = spot_target_capacity

    @builtins.property
    def default_target_capacity_type(self) -> str:
        return self._values.get("default_target_capacity_type")

    @builtins.property
    def total_target_capacity(self) -> jsii.Number:
        return self._values.get("total_target_capacity")

    @builtins.property
    def on_demand_target_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("on_demand_target_capacity")

    @builtins.property
    def spot_target_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("spot_target_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2FleetTargetCapacitySpecification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2FleetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class Ec2FleetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2FleetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2LocalGatewayRoute(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2LocalGatewayRoute",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        destination_cidr_block: str,
        local_gateway_route_table_id: str,
        local_gateway_virtual_interface_group_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination_cidr_block: 
        :param local_gateway_route_table_id: 
        :param local_gateway_virtual_interface_group_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2LocalGatewayRouteConfig(
            destination_cidr_block=destination_cidr_block,
            local_gateway_route_table_id=local_gateway_route_table_id,
            local_gateway_virtual_interface_group_id=local_gateway_virtual_interface_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2LocalGatewayRoute, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> str:
        return jsii.get(self, "destinationCidrBlock")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: str) -> None:
        jsii.set(self, "destinationCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="localGatewayRouteTableId")
    def local_gateway_route_table_id(self) -> str:
        return jsii.get(self, "localGatewayRouteTableId")

    @local_gateway_route_table_id.setter
    def local_gateway_route_table_id(self, value: str) -> None:
        jsii.set(self, "localGatewayRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="localGatewayVirtualInterfaceGroupId")
    def local_gateway_virtual_interface_group_id(self) -> str:
        return jsii.get(self, "localGatewayVirtualInterfaceGroupId")

    @local_gateway_virtual_interface_group_id.setter
    def local_gateway_virtual_interface_group_id(self, value: str) -> None:
        jsii.set(self, "localGatewayVirtualInterfaceGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2LocalGatewayRouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination_cidr_block": "destinationCidrBlock",
        "local_gateway_route_table_id": "localGatewayRouteTableId",
        "local_gateway_virtual_interface_group_id": "localGatewayVirtualInterfaceGroupId",
    },
)
class Ec2LocalGatewayRouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination_cidr_block: str,
        local_gateway_route_table_id: str,
        local_gateway_virtual_interface_group_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination_cidr_block: 
        :param local_gateway_route_table_id: 
        :param local_gateway_virtual_interface_group_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "destination_cidr_block": destination_cidr_block,
            "local_gateway_route_table_id": local_gateway_route_table_id,
            "local_gateway_virtual_interface_group_id": local_gateway_virtual_interface_group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def destination_cidr_block(self) -> str:
        return self._values.get("destination_cidr_block")

    @builtins.property
    def local_gateway_route_table_id(self) -> str:
        return self._values.get("local_gateway_route_table_id")

    @builtins.property
    def local_gateway_virtual_interface_group_id(self) -> str:
        return self._values.get("local_gateway_virtual_interface_group_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2LocalGatewayRouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2LocalGatewayRouteTableVpcAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2LocalGatewayRouteTableVpcAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        local_gateway_route_table_id: str,
        vpc_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param local_gateway_route_table_id: 
        :param vpc_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2LocalGatewayRouteTableVpcAssociationConfig(
            local_gateway_route_table_id=local_gateway_route_table_id,
            vpc_id=vpc_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2LocalGatewayRouteTableVpcAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="localGatewayId")
    def local_gateway_id(self) -> str:
        return jsii.get(self, "localGatewayId")

    @builtins.property
    @jsii.member(jsii_name="localGatewayRouteTableId")
    def local_gateway_route_table_id(self) -> str:
        return jsii.get(self, "localGatewayRouteTableId")

    @local_gateway_route_table_id.setter
    def local_gateway_route_table_id(self, value: str) -> None:
        jsii.set(self, "localGatewayRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2LocalGatewayRouteTableVpcAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "local_gateway_route_table_id": "localGatewayRouteTableId",
        "vpc_id": "vpcId",
        "tags": "tags",
    },
)
class Ec2LocalGatewayRouteTableVpcAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        local_gateway_route_table_id: str,
        vpc_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param local_gateway_route_table_id: 
        :param vpc_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "local_gateway_route_table_id": local_gateway_route_table_id,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def local_gateway_route_table_id(self) -> str:
        return self._values.get("local_gateway_route_table_id")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2LocalGatewayRouteTableVpcAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2Tag(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2Tag",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        key: str,
        resource_id: str,
        value: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key: 
        :param resource_id: 
        :param value: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TagConfig(
            key=key,
            resource_id=resource_id,
            value=value,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2Tag, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="key")
    def key(self) -> str:
        return jsii.get(self, "key")

    @key.setter
    def key(self, value: str) -> None:
        jsii.set(self, "key", value)

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @resource_id.setter
    def resource_id(self, value: str) -> None:
        jsii.set(self, "resourceId", value)

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")

    @value.setter
    def value(self, value: str) -> None:
        jsii.set(self, "value", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TagConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key": "key",
        "resource_id": "resourceId",
        "value": "value",
    },
)
class Ec2TagConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key: str,
        resource_id: str,
        value: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key: 
        :param resource_id: 
        :param value: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "key": key,
            "resource_id": resource_id,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def resource_id(self) -> str:
        return self._values.get("resource_id")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TagConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TrafficMirrorFilter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorFilter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        description: typing.Optional[str] = None,
        network_services: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param description: 
        :param network_services: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TrafficMirrorFilterConfig(
            description=description,
            network_services=network_services,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TrafficMirrorFilter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="networkServices")
    def network_services(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "networkServices")

    @network_services.setter
    def network_services(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "networkServices", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorFilterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "network_services": "networkServices",
        "tags": "tags",
    },
)
class Ec2TrafficMirrorFilterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[str] = None,
        network_services: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: 
        :param network_services: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if network_services is not None:
            self._values["network_services"] = network_services
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def network_services(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("network_services")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TrafficMirrorFilterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TrafficMirrorFilterRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorFilterRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        destination_cidr_block: str,
        rule_action: str,
        rule_number: jsii.Number,
        source_cidr_block: str,
        traffic_direction: str,
        traffic_mirror_filter_id: str,
        description: typing.Optional[str] = None,
        destination_port_range: typing.Optional[
            typing.List["Ec2TrafficMirrorFilterRuleDestinationPortRange"]
        ] = None,
        protocol: typing.Optional[jsii.Number] = None,
        source_port_range: typing.Optional[
            typing.List["Ec2TrafficMirrorFilterRuleSourcePortRange"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination_cidr_block: 
        :param rule_action: 
        :param rule_number: 
        :param source_cidr_block: 
        :param traffic_direction: 
        :param traffic_mirror_filter_id: 
        :param description: 
        :param destination_port_range: destination_port_range block.
        :param protocol: 
        :param source_port_range: source_port_range block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TrafficMirrorFilterRuleConfig(
            destination_cidr_block=destination_cidr_block,
            rule_action=rule_action,
            rule_number=rule_number,
            source_cidr_block=source_cidr_block,
            traffic_direction=traffic_direction,
            traffic_mirror_filter_id=traffic_mirror_filter_id,
            description=description,
            destination_port_range=destination_port_range,
            protocol=protocol,
            source_port_range=source_port_range,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TrafficMirrorFilterRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> str:
        return jsii.get(self, "destinationCidrBlock")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: str) -> None:
        jsii.set(self, "destinationCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="ruleAction")
    def rule_action(self) -> str:
        return jsii.get(self, "ruleAction")

    @rule_action.setter
    def rule_action(self, value: str) -> None:
        jsii.set(self, "ruleAction", value)

    @builtins.property
    @jsii.member(jsii_name="ruleNumber")
    def rule_number(self) -> jsii.Number:
        return jsii.get(self, "ruleNumber")

    @rule_number.setter
    def rule_number(self, value: jsii.Number) -> None:
        jsii.set(self, "ruleNumber", value)

    @builtins.property
    @jsii.member(jsii_name="sourceCidrBlock")
    def source_cidr_block(self) -> str:
        return jsii.get(self, "sourceCidrBlock")

    @source_cidr_block.setter
    def source_cidr_block(self, value: str) -> None:
        jsii.set(self, "sourceCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="trafficDirection")
    def traffic_direction(self) -> str:
        return jsii.get(self, "trafficDirection")

    @traffic_direction.setter
    def traffic_direction(self, value: str) -> None:
        jsii.set(self, "trafficDirection", value)

    @builtins.property
    @jsii.member(jsii_name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> str:
        return jsii.get(self, "trafficMirrorFilterId")

    @traffic_mirror_filter_id.setter
    def traffic_mirror_filter_id(self, value: str) -> None:
        jsii.set(self, "trafficMirrorFilterId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="destinationPortRange")
    def destination_port_range(
        self,
    ) -> typing.Optional[typing.List["Ec2TrafficMirrorFilterRuleDestinationPortRange"]]:
        return jsii.get(self, "destinationPortRange")

    @destination_port_range.setter
    def destination_port_range(
        self,
        value: typing.Optional[
            typing.List["Ec2TrafficMirrorFilterRuleDestinationPortRange"]
        ],
    ) -> None:
        jsii.set(self, "destinationPortRange", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="sourcePortRange")
    def source_port_range(
        self,
    ) -> typing.Optional[typing.List["Ec2TrafficMirrorFilterRuleSourcePortRange"]]:
        return jsii.get(self, "sourcePortRange")

    @source_port_range.setter
    def source_port_range(
        self,
        value: typing.Optional[
            typing.List["Ec2TrafficMirrorFilterRuleSourcePortRange"]
        ],
    ) -> None:
        jsii.set(self, "sourcePortRange", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorFilterRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination_cidr_block": "destinationCidrBlock",
        "rule_action": "ruleAction",
        "rule_number": "ruleNumber",
        "source_cidr_block": "sourceCidrBlock",
        "traffic_direction": "trafficDirection",
        "traffic_mirror_filter_id": "trafficMirrorFilterId",
        "description": "description",
        "destination_port_range": "destinationPortRange",
        "protocol": "protocol",
        "source_port_range": "sourcePortRange",
    },
)
class Ec2TrafficMirrorFilterRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination_cidr_block: str,
        rule_action: str,
        rule_number: jsii.Number,
        source_cidr_block: str,
        traffic_direction: str,
        traffic_mirror_filter_id: str,
        description: typing.Optional[str] = None,
        destination_port_range: typing.Optional[
            typing.List["Ec2TrafficMirrorFilterRuleDestinationPortRange"]
        ] = None,
        protocol: typing.Optional[jsii.Number] = None,
        source_port_range: typing.Optional[
            typing.List["Ec2TrafficMirrorFilterRuleSourcePortRange"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination_cidr_block: 
        :param rule_action: 
        :param rule_number: 
        :param source_cidr_block: 
        :param traffic_direction: 
        :param traffic_mirror_filter_id: 
        :param description: 
        :param destination_port_range: destination_port_range block.
        :param protocol: 
        :param source_port_range: source_port_range block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "destination_cidr_block": destination_cidr_block,
            "rule_action": rule_action,
            "rule_number": rule_number,
            "source_cidr_block": source_cidr_block,
            "traffic_direction": traffic_direction,
            "traffic_mirror_filter_id": traffic_mirror_filter_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if destination_port_range is not None:
            self._values["destination_port_range"] = destination_port_range
        if protocol is not None:
            self._values["protocol"] = protocol
        if source_port_range is not None:
            self._values["source_port_range"] = source_port_range

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def destination_cidr_block(self) -> str:
        return self._values.get("destination_cidr_block")

    @builtins.property
    def rule_action(self) -> str:
        return self._values.get("rule_action")

    @builtins.property
    def rule_number(self) -> jsii.Number:
        return self._values.get("rule_number")

    @builtins.property
    def source_cidr_block(self) -> str:
        return self._values.get("source_cidr_block")

    @builtins.property
    def traffic_direction(self) -> str:
        return self._values.get("traffic_direction")

    @builtins.property
    def traffic_mirror_filter_id(self) -> str:
        return self._values.get("traffic_mirror_filter_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def destination_port_range(
        self,
    ) -> typing.Optional[typing.List["Ec2TrafficMirrorFilterRuleDestinationPortRange"]]:
        """destination_port_range block."""
        return self._values.get("destination_port_range")

    @builtins.property
    def protocol(self) -> typing.Optional[jsii.Number]:
        return self._values.get("protocol")

    @builtins.property
    def source_port_range(
        self,
    ) -> typing.Optional[typing.List["Ec2TrafficMirrorFilterRuleSourcePortRange"]]:
        """source_port_range block."""
        return self._values.get("source_port_range")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TrafficMirrorFilterRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorFilterRuleDestinationPortRange",
    jsii_struct_bases=[],
    name_mapping={"from_port": "fromPort", "to_port": "toPort"},
)
class Ec2TrafficMirrorFilterRuleDestinationPortRange:
    def __init__(
        self,
        *,
        from_port: typing.Optional[jsii.Number] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param from_port: 
        :param to_port: 
        """
        self._values = {}
        if from_port is not None:
            self._values["from_port"] = from_port
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TrafficMirrorFilterRuleDestinationPortRange(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorFilterRuleSourcePortRange",
    jsii_struct_bases=[],
    name_mapping={"from_port": "fromPort", "to_port": "toPort"},
)
class Ec2TrafficMirrorFilterRuleSourcePortRange:
    def __init__(
        self,
        *,
        from_port: typing.Optional[jsii.Number] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param from_port: 
        :param to_port: 
        """
        self._values = {}
        if from_port is not None:
            self._values["from_port"] = from_port
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TrafficMirrorFilterRuleSourcePortRange(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TrafficMirrorSession(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorSession",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        network_interface_id: str,
        session_number: jsii.Number,
        traffic_mirror_filter_id: str,
        traffic_mirror_target_id: str,
        description: typing.Optional[str] = None,
        packet_length: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        virtual_network_id: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param network_interface_id: 
        :param session_number: 
        :param traffic_mirror_filter_id: 
        :param traffic_mirror_target_id: 
        :param description: 
        :param packet_length: 
        :param tags: 
        :param virtual_network_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TrafficMirrorSessionConfig(
            network_interface_id=network_interface_id,
            session_number=session_number,
            traffic_mirror_filter_id=traffic_mirror_filter_id,
            traffic_mirror_target_id=traffic_mirror_target_id,
            description=description,
            packet_length=packet_length,
            tags=tags,
            virtual_network_id=virtual_network_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TrafficMirrorSession, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="sessionNumber")
    def session_number(self) -> jsii.Number:
        return jsii.get(self, "sessionNumber")

    @session_number.setter
    def session_number(self, value: jsii.Number) -> None:
        jsii.set(self, "sessionNumber", value)

    @builtins.property
    @jsii.member(jsii_name="trafficMirrorFilterId")
    def traffic_mirror_filter_id(self) -> str:
        return jsii.get(self, "trafficMirrorFilterId")

    @traffic_mirror_filter_id.setter
    def traffic_mirror_filter_id(self, value: str) -> None:
        jsii.set(self, "trafficMirrorFilterId", value)

    @builtins.property
    @jsii.member(jsii_name="trafficMirrorTargetId")
    def traffic_mirror_target_id(self) -> str:
        return jsii.get(self, "trafficMirrorTargetId")

    @traffic_mirror_target_id.setter
    def traffic_mirror_target_id(self, value: str) -> None:
        jsii.set(self, "trafficMirrorTargetId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="packetLength")
    def packet_length(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "packetLength")

    @packet_length.setter
    def packet_length(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "packetLength", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="virtualNetworkId")
    def virtual_network_id(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "virtualNetworkId")

    @virtual_network_id.setter
    def virtual_network_id(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "virtualNetworkId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorSessionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_interface_id": "networkInterfaceId",
        "session_number": "sessionNumber",
        "traffic_mirror_filter_id": "trafficMirrorFilterId",
        "traffic_mirror_target_id": "trafficMirrorTargetId",
        "description": "description",
        "packet_length": "packetLength",
        "tags": "tags",
        "virtual_network_id": "virtualNetworkId",
    },
)
class Ec2TrafficMirrorSessionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_interface_id: str,
        session_number: jsii.Number,
        traffic_mirror_filter_id: str,
        traffic_mirror_target_id: str,
        description: typing.Optional[str] = None,
        packet_length: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        virtual_network_id: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_interface_id: 
        :param session_number: 
        :param traffic_mirror_filter_id: 
        :param traffic_mirror_target_id: 
        :param description: 
        :param packet_length: 
        :param tags: 
        :param virtual_network_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "network_interface_id": network_interface_id,
            "session_number": session_number,
            "traffic_mirror_filter_id": traffic_mirror_filter_id,
            "traffic_mirror_target_id": traffic_mirror_target_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if packet_length is not None:
            self._values["packet_length"] = packet_length
        if tags is not None:
            self._values["tags"] = tags
        if virtual_network_id is not None:
            self._values["virtual_network_id"] = virtual_network_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def network_interface_id(self) -> str:
        return self._values.get("network_interface_id")

    @builtins.property
    def session_number(self) -> jsii.Number:
        return self._values.get("session_number")

    @builtins.property
    def traffic_mirror_filter_id(self) -> str:
        return self._values.get("traffic_mirror_filter_id")

    @builtins.property
    def traffic_mirror_target_id(self) -> str:
        return self._values.get("traffic_mirror_target_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def packet_length(self) -> typing.Optional[jsii.Number]:
        return self._values.get("packet_length")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def virtual_network_id(self) -> typing.Optional[jsii.Number]:
        return self._values.get("virtual_network_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TrafficMirrorSessionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TrafficMirrorTarget(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorTarget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        description: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        network_load_balancer_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param description: 
        :param network_interface_id: 
        :param network_load_balancer_arn: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TrafficMirrorTargetConfig(
            description=description,
            network_interface_id=network_interface_id,
            network_load_balancer_arn=network_load_balancer_arn,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TrafficMirrorTarget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> typing.Optional[str]:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="networkLoadBalancerArn")
    def network_load_balancer_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "networkLoadBalancerArn")

    @network_load_balancer_arn.setter
    def network_load_balancer_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "networkLoadBalancerArn", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TrafficMirrorTargetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "network_interface_id": "networkInterfaceId",
        "network_load_balancer_arn": "networkLoadBalancerArn",
        "tags": "tags",
    },
)
class Ec2TrafficMirrorTargetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        network_load_balancer_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: 
        :param network_interface_id: 
        :param network_load_balancer_arn: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if network_interface_id is not None:
            self._values["network_interface_id"] = network_interface_id
        if network_load_balancer_arn is not None:
            self._values["network_load_balancer_arn"] = network_load_balancer_arn
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def network_interface_id(self) -> typing.Optional[str]:
        return self._values.get("network_interface_id")

    @builtins.property
    def network_load_balancer_arn(self) -> typing.Optional[str]:
        return self._values.get("network_load_balancer_arn")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TrafficMirrorTargetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TransitGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        amazon_side_asn: typing.Optional[jsii.Number] = None,
        auto_accept_shared_attachments: typing.Optional[str] = None,
        default_route_table_association: typing.Optional[str] = None,
        default_route_table_propagation: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        dns_support: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpn_ecmp_support: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param amazon_side_asn: 
        :param auto_accept_shared_attachments: 
        :param default_route_table_association: 
        :param default_route_table_propagation: 
        :param description: 
        :param dns_support: 
        :param tags: 
        :param vpn_ecmp_support: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayConfig(
            amazon_side_asn=amazon_side_asn,
            auto_accept_shared_attachments=auto_accept_shared_attachments,
            default_route_table_association=default_route_table_association,
            default_route_table_propagation=default_route_table_propagation,
            description=description,
            dns_support=dns_support,
            tags=tags,
            vpn_ecmp_support=vpn_ecmp_support,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="associationDefaultRouteTableId")
    def association_default_route_table_id(self) -> str:
        return jsii.get(self, "associationDefaultRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="propagationDefaultRouteTableId")
    def propagation_default_route_table_id(self) -> str:
        return jsii.get(self, "propagationDefaultRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "amazonSideAsn")

    @amazon_side_asn.setter
    def amazon_side_asn(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "amazonSideAsn", value)

    @builtins.property
    @jsii.member(jsii_name="autoAcceptSharedAttachments")
    def auto_accept_shared_attachments(self) -> typing.Optional[str]:
        return jsii.get(self, "autoAcceptSharedAttachments")

    @auto_accept_shared_attachments.setter
    def auto_accept_shared_attachments(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "autoAcceptSharedAttachments", value)

    @builtins.property
    @jsii.member(jsii_name="defaultRouteTableAssociation")
    def default_route_table_association(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultRouteTableAssociation")

    @default_route_table_association.setter
    def default_route_table_association(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultRouteTableAssociation", value)

    @builtins.property
    @jsii.member(jsii_name="defaultRouteTablePropagation")
    def default_route_table_propagation(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultRouteTablePropagation")

    @default_route_table_propagation.setter
    def default_route_table_propagation(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultRouteTablePropagation", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="dnsSupport")
    def dns_support(self) -> typing.Optional[str]:
        return jsii.get(self, "dnsSupport")

    @dns_support.setter
    def dns_support(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dnsSupport", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpnEcmpSupport")
    def vpn_ecmp_support(self) -> typing.Optional[str]:
        return jsii.get(self, "vpnEcmpSupport")

    @vpn_ecmp_support.setter
    def vpn_ecmp_support(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpnEcmpSupport", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "amazon_side_asn": "amazonSideAsn",
        "auto_accept_shared_attachments": "autoAcceptSharedAttachments",
        "default_route_table_association": "defaultRouteTableAssociation",
        "default_route_table_propagation": "defaultRouteTablePropagation",
        "description": "description",
        "dns_support": "dnsSupport",
        "tags": "tags",
        "vpn_ecmp_support": "vpnEcmpSupport",
    },
)
class Ec2TransitGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        amazon_side_asn: typing.Optional[jsii.Number] = None,
        auto_accept_shared_attachments: typing.Optional[str] = None,
        default_route_table_association: typing.Optional[str] = None,
        default_route_table_propagation: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        dns_support: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpn_ecmp_support: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param amazon_side_asn: 
        :param auto_accept_shared_attachments: 
        :param default_route_table_association: 
        :param default_route_table_propagation: 
        :param description: 
        :param dns_support: 
        :param tags: 
        :param vpn_ecmp_support: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_side_asn is not None:
            self._values["amazon_side_asn"] = amazon_side_asn
        if auto_accept_shared_attachments is not None:
            self._values[
                "auto_accept_shared_attachments"
            ] = auto_accept_shared_attachments
        if default_route_table_association is not None:
            self._values[
                "default_route_table_association"
            ] = default_route_table_association
        if default_route_table_propagation is not None:
            self._values[
                "default_route_table_propagation"
            ] = default_route_table_propagation
        if description is not None:
            self._values["description"] = description
        if dns_support is not None:
            self._values["dns_support"] = dns_support
        if tags is not None:
            self._values["tags"] = tags
        if vpn_ecmp_support is not None:
            self._values["vpn_ecmp_support"] = vpn_ecmp_support

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def amazon_side_asn(self) -> typing.Optional[jsii.Number]:
        return self._values.get("amazon_side_asn")

    @builtins.property
    def auto_accept_shared_attachments(self) -> typing.Optional[str]:
        return self._values.get("auto_accept_shared_attachments")

    @builtins.property
    def default_route_table_association(self) -> typing.Optional[str]:
        return self._values.get("default_route_table_association")

    @builtins.property
    def default_route_table_propagation(self) -> typing.Optional[str]:
        return self._values.get("default_route_table_propagation")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def dns_support(self) -> typing.Optional[str]:
        return self._values.get("dns_support")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpn_ecmp_support(self) -> typing.Optional[str]:
        return self._values.get("vpn_ecmp_support")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TransitGatewayPeeringAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayPeeringAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        peer_region: str,
        peer_transit_gateway_id: str,
        transit_gateway_id: str,
        peer_account_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param peer_region: 
        :param peer_transit_gateway_id: 
        :param transit_gateway_id: 
        :param peer_account_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayPeeringAttachmentConfig(
            peer_region=peer_region,
            peer_transit_gateway_id=peer_transit_gateway_id,
            transit_gateway_id=transit_gateway_id,
            peer_account_id=peer_account_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGatewayPeeringAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="peerRegion")
    def peer_region(self) -> str:
        return jsii.get(self, "peerRegion")

    @peer_region.setter
    def peer_region(self, value: str) -> None:
        jsii.set(self, "peerRegion", value)

    @builtins.property
    @jsii.member(jsii_name="peerTransitGatewayId")
    def peer_transit_gateway_id(self) -> str:
        return jsii.get(self, "peerTransitGatewayId")

    @peer_transit_gateway_id.setter
    def peer_transit_gateway_id(self, value: str) -> None:
        jsii.set(self, "peerTransitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="peerAccountId")
    def peer_account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "peerAccountId")

    @peer_account_id.setter
    def peer_account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "peerAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class Ec2TransitGatewayPeeringAttachmentAccepter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayPeeringAttachmentAccepter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        transit_gateway_attachment_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param transit_gateway_attachment_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayPeeringAttachmentAccepterConfig(
            transit_gateway_attachment_id=transit_gateway_attachment_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(
            Ec2TransitGatewayPeeringAttachmentAccepter, self, [scope, id, config]
        )

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="peerAccountId")
    def peer_account_id(self) -> str:
        return jsii.get(self, "peerAccountId")

    @builtins.property
    @jsii.member(jsii_name="peerRegion")
    def peer_region(self) -> str:
        return jsii.get(self, "peerRegion")

    @builtins.property
    @jsii.member(jsii_name="peerTransitGatewayId")
    def peer_transit_gateway_id(self) -> str:
        return jsii.get(self, "peerTransitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayAttachmentId")
    def transit_gateway_attachment_id(self) -> str:
        return jsii.get(self, "transitGatewayAttachmentId")

    @transit_gateway_attachment_id.setter
    def transit_gateway_attachment_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayAttachmentId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayPeeringAttachmentAccepterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "transit_gateway_attachment_id": "transitGatewayAttachmentId",
        "tags": "tags",
    },
)
class Ec2TransitGatewayPeeringAttachmentAccepterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        transit_gateway_attachment_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param transit_gateway_attachment_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "transit_gateway_attachment_id": transit_gateway_attachment_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def transit_gateway_attachment_id(self) -> str:
        return self._values.get("transit_gateway_attachment_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayPeeringAttachmentAccepterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayPeeringAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "peer_region": "peerRegion",
        "peer_transit_gateway_id": "peerTransitGatewayId",
        "transit_gateway_id": "transitGatewayId",
        "peer_account_id": "peerAccountId",
        "tags": "tags",
    },
)
class Ec2TransitGatewayPeeringAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        peer_region: str,
        peer_transit_gateway_id: str,
        transit_gateway_id: str,
        peer_account_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param peer_region: 
        :param peer_transit_gateway_id: 
        :param transit_gateway_id: 
        :param peer_account_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "peer_region": peer_region,
            "peer_transit_gateway_id": peer_transit_gateway_id,
            "transit_gateway_id": transit_gateway_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if peer_account_id is not None:
            self._values["peer_account_id"] = peer_account_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def peer_region(self) -> str:
        return self._values.get("peer_region")

    @builtins.property
    def peer_transit_gateway_id(self) -> str:
        return self._values.get("peer_transit_gateway_id")

    @builtins.property
    def transit_gateway_id(self) -> str:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def peer_account_id(self) -> typing.Optional[str]:
        return self._values.get("peer_account_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayPeeringAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TransitGatewayRoute(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRoute",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        destination_cidr_block: str,
        transit_gateway_route_table_id: str,
        blackhole: typing.Optional[bool] = None,
        transit_gateway_attachment_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination_cidr_block: 
        :param transit_gateway_route_table_id: 
        :param blackhole: 
        :param transit_gateway_attachment_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayRouteConfig(
            destination_cidr_block=destination_cidr_block,
            transit_gateway_route_table_id=transit_gateway_route_table_id,
            blackhole=blackhole,
            transit_gateway_attachment_id=transit_gateway_attachment_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGatewayRoute, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> str:
        return jsii.get(self, "destinationCidrBlock")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: str) -> None:
        jsii.set(self, "destinationCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayRouteTableId")
    def transit_gateway_route_table_id(self) -> str:
        return jsii.get(self, "transitGatewayRouteTableId")

    @transit_gateway_route_table_id.setter
    def transit_gateway_route_table_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="blackhole")
    def blackhole(self) -> typing.Optional[bool]:
        return jsii.get(self, "blackhole")

    @blackhole.setter
    def blackhole(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "blackhole", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayAttachmentId")
    def transit_gateway_attachment_id(self) -> typing.Optional[str]:
        return jsii.get(self, "transitGatewayAttachmentId")

    @transit_gateway_attachment_id.setter
    def transit_gateway_attachment_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "transitGatewayAttachmentId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination_cidr_block": "destinationCidrBlock",
        "transit_gateway_route_table_id": "transitGatewayRouteTableId",
        "blackhole": "blackhole",
        "transit_gateway_attachment_id": "transitGatewayAttachmentId",
    },
)
class Ec2TransitGatewayRouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination_cidr_block: str,
        transit_gateway_route_table_id: str,
        blackhole: typing.Optional[bool] = None,
        transit_gateway_attachment_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination_cidr_block: 
        :param transit_gateway_route_table_id: 
        :param blackhole: 
        :param transit_gateway_attachment_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "destination_cidr_block": destination_cidr_block,
            "transit_gateway_route_table_id": transit_gateway_route_table_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if blackhole is not None:
            self._values["blackhole"] = blackhole
        if transit_gateway_attachment_id is not None:
            self._values[
                "transit_gateway_attachment_id"
            ] = transit_gateway_attachment_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def destination_cidr_block(self) -> str:
        return self._values.get("destination_cidr_block")

    @builtins.property
    def transit_gateway_route_table_id(self) -> str:
        return self._values.get("transit_gateway_route_table_id")

    @builtins.property
    def blackhole(self) -> typing.Optional[bool]:
        return self._values.get("blackhole")

    @builtins.property
    def transit_gateway_attachment_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_attachment_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayRouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TransitGatewayRouteTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        transit_gateway_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param transit_gateway_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayRouteTableConfig(
            transit_gateway_id=transit_gateway_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGatewayRouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="defaultAssociationRouteTable")
    def default_association_route_table(self) -> bool:
        return jsii.get(self, "defaultAssociationRouteTable")

    @builtins.property
    @jsii.member(jsii_name="defaultPropagationRouteTable")
    def default_propagation_route_table(self) -> bool:
        return jsii.get(self, "defaultPropagationRouteTable")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class Ec2TransitGatewayRouteTableAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRouteTableAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        transit_gateway_attachment_id: str,
        transit_gateway_route_table_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param transit_gateway_attachment_id: 
        :param transit_gateway_route_table_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayRouteTableAssociationConfig(
            transit_gateway_attachment_id=transit_gateway_attachment_id,
            transit_gateway_route_table_id=transit_gateway_route_table_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGatewayRouteTableAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @builtins.property
    @jsii.member(jsii_name="resourceType")
    def resource_type(self) -> str:
        return jsii.get(self, "resourceType")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayAttachmentId")
    def transit_gateway_attachment_id(self) -> str:
        return jsii.get(self, "transitGatewayAttachmentId")

    @transit_gateway_attachment_id.setter
    def transit_gateway_attachment_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayAttachmentId", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayRouteTableId")
    def transit_gateway_route_table_id(self) -> str:
        return jsii.get(self, "transitGatewayRouteTableId")

    @transit_gateway_route_table_id.setter
    def transit_gateway_route_table_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRouteTableAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "transit_gateway_attachment_id": "transitGatewayAttachmentId",
        "transit_gateway_route_table_id": "transitGatewayRouteTableId",
    },
)
class Ec2TransitGatewayRouteTableAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        transit_gateway_attachment_id: str,
        transit_gateway_route_table_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param transit_gateway_attachment_id: 
        :param transit_gateway_route_table_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "transit_gateway_attachment_id": transit_gateway_attachment_id,
            "transit_gateway_route_table_id": transit_gateway_route_table_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def transit_gateway_attachment_id(self) -> str:
        return self._values.get("transit_gateway_attachment_id")

    @builtins.property
    def transit_gateway_route_table_id(self) -> str:
        return self._values.get("transit_gateway_route_table_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayRouteTableAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "transit_gateway_id": "transitGatewayId",
        "tags": "tags",
    },
)
class Ec2TransitGatewayRouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        transit_gateway_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param transit_gateway_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "transit_gateway_id": transit_gateway_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def transit_gateway_id(self) -> str:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayRouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TransitGatewayRouteTablePropagation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRouteTablePropagation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        transit_gateway_attachment_id: str,
        transit_gateway_route_table_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param transit_gateway_attachment_id: 
        :param transit_gateway_route_table_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayRouteTablePropagationConfig(
            transit_gateway_attachment_id=transit_gateway_attachment_id,
            transit_gateway_route_table_id=transit_gateway_route_table_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGatewayRouteTablePropagation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resourceId")
    def resource_id(self) -> str:
        return jsii.get(self, "resourceId")

    @builtins.property
    @jsii.member(jsii_name="resourceType")
    def resource_type(self) -> str:
        return jsii.get(self, "resourceType")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayAttachmentId")
    def transit_gateway_attachment_id(self) -> str:
        return jsii.get(self, "transitGatewayAttachmentId")

    @transit_gateway_attachment_id.setter
    def transit_gateway_attachment_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayAttachmentId", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayRouteTableId")
    def transit_gateway_route_table_id(self) -> str:
        return jsii.get(self, "transitGatewayRouteTableId")

    @transit_gateway_route_table_id.setter
    def transit_gateway_route_table_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayRouteTableId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayRouteTablePropagationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "transit_gateway_attachment_id": "transitGatewayAttachmentId",
        "transit_gateway_route_table_id": "transitGatewayRouteTableId",
    },
)
class Ec2TransitGatewayRouteTablePropagationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        transit_gateway_attachment_id: str,
        transit_gateway_route_table_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param transit_gateway_attachment_id: 
        :param transit_gateway_route_table_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "transit_gateway_attachment_id": transit_gateway_attachment_id,
            "transit_gateway_route_table_id": transit_gateway_route_table_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def transit_gateway_attachment_id(self) -> str:
        return self._values.get("transit_gateway_attachment_id")

    @builtins.property
    def transit_gateway_route_table_id(self) -> str:
        return self._values.get("transit_gateway_route_table_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayRouteTablePropagationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Ec2TransitGatewayVpcAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayVpcAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        subnet_ids: typing.List[str],
        transit_gateway_id: str,
        vpc_id: str,
        dns_support: typing.Optional[str] = None,
        ipv6_support: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_default_route_table_association: typing.Optional[bool] = None,
        transit_gateway_default_route_table_propagation: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param subnet_ids: 
        :param transit_gateway_id: 
        :param vpc_id: 
        :param dns_support: 
        :param ipv6_support: 
        :param tags: 
        :param transit_gateway_default_route_table_association: 
        :param transit_gateway_default_route_table_propagation: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayVpcAttachmentConfig(
            subnet_ids=subnet_ids,
            transit_gateway_id=transit_gateway_id,
            vpc_id=vpc_id,
            dns_support=dns_support,
            ipv6_support=ipv6_support,
            tags=tags,
            transit_gateway_default_route_table_association=transit_gateway_default_route_table_association,
            transit_gateway_default_route_table_propagation=transit_gateway_default_route_table_propagation,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGatewayVpcAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="vpcOwnerId")
    def vpc_owner_id(self) -> str:
        return jsii.get(self, "vpcOwnerId")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="dnsSupport")
    def dns_support(self) -> typing.Optional[str]:
        return jsii.get(self, "dnsSupport")

    @dns_support.setter
    def dns_support(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dnsSupport", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6Support")
    def ipv6_support(self) -> typing.Optional[str]:
        return jsii.get(self, "ipv6Support")

    @ipv6_support.setter
    def ipv6_support(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipv6Support", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayDefaultRouteTableAssociation")
    def transit_gateway_default_route_table_association(self) -> typing.Optional[bool]:
        return jsii.get(self, "transitGatewayDefaultRouteTableAssociation")

    @transit_gateway_default_route_table_association.setter
    def transit_gateway_default_route_table_association(
        self, value: typing.Optional[bool]
    ) -> None:
        jsii.set(self, "transitGatewayDefaultRouteTableAssociation", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayDefaultRouteTablePropagation")
    def transit_gateway_default_route_table_propagation(self) -> typing.Optional[bool]:
        return jsii.get(self, "transitGatewayDefaultRouteTablePropagation")

    @transit_gateway_default_route_table_propagation.setter
    def transit_gateway_default_route_table_propagation(
        self, value: typing.Optional[bool]
    ) -> None:
        jsii.set(self, "transitGatewayDefaultRouteTablePropagation", value)


class Ec2TransitGatewayVpcAttachmentAccepter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayVpcAttachmentAccepter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        transit_gateway_attachment_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_default_route_table_association: typing.Optional[bool] = None,
        transit_gateway_default_route_table_propagation: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param transit_gateway_attachment_id: 
        :param tags: 
        :param transit_gateway_default_route_table_association: 
        :param transit_gateway_default_route_table_propagation: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Ec2TransitGatewayVpcAttachmentAccepterConfig(
            transit_gateway_attachment_id=transit_gateway_attachment_id,
            tags=tags,
            transit_gateway_default_route_table_association=transit_gateway_default_route_table_association,
            transit_gateway_default_route_table_propagation=transit_gateway_default_route_table_propagation,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Ec2TransitGatewayVpcAttachmentAccepter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dnsSupport")
    def dns_support(self) -> str:
        return jsii.get(self, "dnsSupport")

    @builtins.property
    @jsii.member(jsii_name="ipv6Support")
    def ipv6_support(self) -> str:
        return jsii.get(self, "ipv6Support")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> str:
        return jsii.get(self, "transitGatewayId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="vpcOwnerId")
    def vpc_owner_id(self) -> str:
        return jsii.get(self, "vpcOwnerId")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayAttachmentId")
    def transit_gateway_attachment_id(self) -> str:
        return jsii.get(self, "transitGatewayAttachmentId")

    @transit_gateway_attachment_id.setter
    def transit_gateway_attachment_id(self, value: str) -> None:
        jsii.set(self, "transitGatewayAttachmentId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayDefaultRouteTableAssociation")
    def transit_gateway_default_route_table_association(self) -> typing.Optional[bool]:
        return jsii.get(self, "transitGatewayDefaultRouteTableAssociation")

    @transit_gateway_default_route_table_association.setter
    def transit_gateway_default_route_table_association(
        self, value: typing.Optional[bool]
    ) -> None:
        jsii.set(self, "transitGatewayDefaultRouteTableAssociation", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayDefaultRouteTablePropagation")
    def transit_gateway_default_route_table_propagation(self) -> typing.Optional[bool]:
        return jsii.get(self, "transitGatewayDefaultRouteTablePropagation")

    @transit_gateway_default_route_table_propagation.setter
    def transit_gateway_default_route_table_propagation(
        self, value: typing.Optional[bool]
    ) -> None:
        jsii.set(self, "transitGatewayDefaultRouteTablePropagation", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayVpcAttachmentAccepterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "transit_gateway_attachment_id": "transitGatewayAttachmentId",
        "tags": "tags",
        "transit_gateway_default_route_table_association": "transitGatewayDefaultRouteTableAssociation",
        "transit_gateway_default_route_table_propagation": "transitGatewayDefaultRouteTablePropagation",
    },
)
class Ec2TransitGatewayVpcAttachmentAccepterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        transit_gateway_attachment_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_default_route_table_association: typing.Optional[bool] = None,
        transit_gateway_default_route_table_propagation: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param transit_gateway_attachment_id: 
        :param tags: 
        :param transit_gateway_default_route_table_association: 
        :param transit_gateway_default_route_table_propagation: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "transit_gateway_attachment_id": transit_gateway_attachment_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if transit_gateway_default_route_table_association is not None:
            self._values[
                "transit_gateway_default_route_table_association"
            ] = transit_gateway_default_route_table_association
        if transit_gateway_default_route_table_propagation is not None:
            self._values[
                "transit_gateway_default_route_table_propagation"
            ] = transit_gateway_default_route_table_propagation

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def transit_gateway_attachment_id(self) -> str:
        return self._values.get("transit_gateway_attachment_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def transit_gateway_default_route_table_association(self) -> typing.Optional[bool]:
        return self._values.get("transit_gateway_default_route_table_association")

    @builtins.property
    def transit_gateway_default_route_table_propagation(self) -> typing.Optional[bool]:
        return self._values.get("transit_gateway_default_route_table_propagation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayVpcAttachmentAccepterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Ec2TransitGatewayVpcAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "subnet_ids": "subnetIds",
        "transit_gateway_id": "transitGatewayId",
        "vpc_id": "vpcId",
        "dns_support": "dnsSupport",
        "ipv6_support": "ipv6Support",
        "tags": "tags",
        "transit_gateway_default_route_table_association": "transitGatewayDefaultRouteTableAssociation",
        "transit_gateway_default_route_table_propagation": "transitGatewayDefaultRouteTablePropagation",
    },
)
class Ec2TransitGatewayVpcAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        subnet_ids: typing.List[str],
        transit_gateway_id: str,
        vpc_id: str,
        dns_support: typing.Optional[str] = None,
        ipv6_support: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_default_route_table_association: typing.Optional[bool] = None,
        transit_gateway_default_route_table_propagation: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param subnet_ids: 
        :param transit_gateway_id: 
        :param vpc_id: 
        :param dns_support: 
        :param ipv6_support: 
        :param tags: 
        :param transit_gateway_default_route_table_association: 
        :param transit_gateway_default_route_table_propagation: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "subnet_ids": subnet_ids,
            "transit_gateway_id": transit_gateway_id,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dns_support is not None:
            self._values["dns_support"] = dns_support
        if ipv6_support is not None:
            self._values["ipv6_support"] = ipv6_support
        if tags is not None:
            self._values["tags"] = tags
        if transit_gateway_default_route_table_association is not None:
            self._values[
                "transit_gateway_default_route_table_association"
            ] = transit_gateway_default_route_table_association
        if transit_gateway_default_route_table_propagation is not None:
            self._values[
                "transit_gateway_default_route_table_propagation"
            ] = transit_gateway_default_route_table_propagation

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def transit_gateway_id(self) -> str:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def dns_support(self) -> typing.Optional[str]:
        return self._values.get("dns_support")

    @builtins.property
    def ipv6_support(self) -> typing.Optional[str]:
        return self._values.get("ipv6_support")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def transit_gateway_default_route_table_association(self) -> typing.Optional[bool]:
        return self._values.get("transit_gateway_default_route_table_association")

    @builtins.property
    def transit_gateway_default_route_table_propagation(self) -> typing.Optional[bool]:
        return self._values.get("transit_gateway_default_route_table_propagation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Ec2TransitGatewayVpcAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EcrLifecyclePolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EcrLifecyclePolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy: str,
        repository: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy: 
        :param repository: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EcrLifecyclePolicyConfig(
            policy=policy,
            repository=repository,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EcrLifecyclePolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> str:
        return jsii.get(self, "registryId")

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="repository")
    def repository(self) -> str:
        return jsii.get(self, "repository")

    @repository.setter
    def repository(self, value: str) -> None:
        jsii.set(self, "repository", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcrLifecyclePolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy": "policy",
        "repository": "repository",
    },
)
class EcrLifecyclePolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy: str,
        repository: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy: 
        :param repository: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy": policy,
            "repository": repository,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def repository(self) -> str:
        return self._values.get("repository")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcrLifecyclePolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EcrRepository(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EcrRepository",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        image_scanning_configuration: typing.Optional[
            typing.List["EcrRepositoryImageScanningConfiguration"]
        ] = None,
        image_tag_mutability: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EcrRepositoryTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param image_scanning_configuration: image_scanning_configuration block.
        :param image_tag_mutability: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EcrRepositoryConfig(
            name=name,
            image_scanning_configuration=image_scanning_configuration,
            image_tag_mutability=image_tag_mutability,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EcrRepository, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> str:
        return jsii.get(self, "registryId")

    @builtins.property
    @jsii.member(jsii_name="repositoryUrl")
    def repository_url(self) -> str:
        return jsii.get(self, "repositoryUrl")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="imageScanningConfiguration")
    def image_scanning_configuration(
        self,
    ) -> typing.Optional[typing.List["EcrRepositoryImageScanningConfiguration"]]:
        return jsii.get(self, "imageScanningConfiguration")

    @image_scanning_configuration.setter
    def image_scanning_configuration(
        self,
        value: typing.Optional[typing.List["EcrRepositoryImageScanningConfiguration"]],
    ) -> None:
        jsii.set(self, "imageScanningConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="imageTagMutability")
    def image_tag_mutability(self) -> typing.Optional[str]:
        return jsii.get(self, "imageTagMutability")

    @image_tag_mutability.setter
    def image_tag_mutability(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "imageTagMutability", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EcrRepositoryTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["EcrRepositoryTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcrRepositoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "image_scanning_configuration": "imageScanningConfiguration",
        "image_tag_mutability": "imageTagMutability",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class EcrRepositoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        image_scanning_configuration: typing.Optional[
            typing.List["EcrRepositoryImageScanningConfiguration"]
        ] = None,
        image_tag_mutability: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EcrRepositoryTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param image_scanning_configuration: image_scanning_configuration block.
        :param image_tag_mutability: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EcrRepositoryTimeouts(**timeouts)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if image_scanning_configuration is not None:
            self._values["image_scanning_configuration"] = image_scanning_configuration
        if image_tag_mutability is not None:
            self._values["image_tag_mutability"] = image_tag_mutability
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def image_scanning_configuration(
        self,
    ) -> typing.Optional[typing.List["EcrRepositoryImageScanningConfiguration"]]:
        """image_scanning_configuration block."""
        return self._values.get("image_scanning_configuration")

    @builtins.property
    def image_tag_mutability(self) -> typing.Optional[str]:
        return self._values.get("image_tag_mutability")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["EcrRepositoryTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcrRepositoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcrRepositoryImageScanningConfiguration",
    jsii_struct_bases=[],
    name_mapping={"scan_on_push": "scanOnPush"},
)
class EcrRepositoryImageScanningConfiguration:
    def __init__(self, *, scan_on_push: bool) -> None:
        """
        :param scan_on_push: 
        """
        self._values = {
            "scan_on_push": scan_on_push,
        }

    @builtins.property
    def scan_on_push(self) -> bool:
        return self._values.get("scan_on_push")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcrRepositoryImageScanningConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EcrRepositoryPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EcrRepositoryPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy: str,
        repository: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy: 
        :param repository: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EcrRepositoryPolicyConfig(
            policy=policy,
            repository=repository,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EcrRepositoryPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="registryId")
    def registry_id(self) -> str:
        return jsii.get(self, "registryId")

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="repository")
    def repository(self) -> str:
        return jsii.get(self, "repository")

    @repository.setter
    def repository(self, value: str) -> None:
        jsii.set(self, "repository", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcrRepositoryPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy": "policy",
        "repository": "repository",
    },
)
class EcrRepositoryPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy: str,
        repository: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy: 
        :param repository: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy": policy,
            "repository": repository,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def repository(self) -> str:
        return self._values.get("repository")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcrRepositoryPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcrRepositoryTimeouts",
    jsii_struct_bases=[],
    name_mapping={"delete": "delete"},
)
class EcrRepositoryTimeouts:
    def __init__(self, *, delete: typing.Optional[str] = None) -> None:
        """
        :param delete: 
        """
        self._values = {}
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcrRepositoryTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EcsCapacityProvider(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EcsCapacityProvider",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        auto_scaling_group_provider: typing.List[
            "EcsCapacityProviderAutoScalingGroupProvider"
        ],
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param auto_scaling_group_provider: auto_scaling_group_provider block.
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EcsCapacityProviderConfig(
            auto_scaling_group_provider=auto_scaling_group_provider,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EcsCapacityProvider, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="autoScalingGroupProvider")
    def auto_scaling_group_provider(
        self,
    ) -> typing.List["EcsCapacityProviderAutoScalingGroupProvider"]:
        return jsii.get(self, "autoScalingGroupProvider")

    @auto_scaling_group_provider.setter
    def auto_scaling_group_provider(
        self, value: typing.List["EcsCapacityProviderAutoScalingGroupProvider"]
    ) -> None:
        jsii.set(self, "autoScalingGroupProvider", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsCapacityProviderAutoScalingGroupProvider",
    jsii_struct_bases=[],
    name_mapping={
        "auto_scaling_group_arn": "autoScalingGroupArn",
        "managed_scaling": "managedScaling",
        "managed_termination_protection": "managedTerminationProtection",
    },
)
class EcsCapacityProviderAutoScalingGroupProvider:
    def __init__(
        self,
        *,
        auto_scaling_group_arn: str,
        managed_scaling: typing.Optional[
            typing.List["EcsCapacityProviderAutoScalingGroupProviderManagedScaling"]
        ] = None,
        managed_termination_protection: typing.Optional[str] = None,
    ) -> None:
        """
        :param auto_scaling_group_arn: 
        :param managed_scaling: managed_scaling block.
        :param managed_termination_protection: 
        """
        self._values = {
            "auto_scaling_group_arn": auto_scaling_group_arn,
        }
        if managed_scaling is not None:
            self._values["managed_scaling"] = managed_scaling
        if managed_termination_protection is not None:
            self._values[
                "managed_termination_protection"
            ] = managed_termination_protection

    @builtins.property
    def auto_scaling_group_arn(self) -> str:
        return self._values.get("auto_scaling_group_arn")

    @builtins.property
    def managed_scaling(
        self,
    ) -> typing.Optional[
        typing.List["EcsCapacityProviderAutoScalingGroupProviderManagedScaling"]
    ]:
        """managed_scaling block."""
        return self._values.get("managed_scaling")

    @builtins.property
    def managed_termination_protection(self) -> typing.Optional[str]:
        return self._values.get("managed_termination_protection")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsCapacityProviderAutoScalingGroupProvider(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsCapacityProviderAutoScalingGroupProviderManagedScaling",
    jsii_struct_bases=[],
    name_mapping={
        "maximum_scaling_step_size": "maximumScalingStepSize",
        "minimum_scaling_step_size": "minimumScalingStepSize",
        "status": "status",
        "target_capacity": "targetCapacity",
    },
)
class EcsCapacityProviderAutoScalingGroupProviderManagedScaling:
    def __init__(
        self,
        *,
        maximum_scaling_step_size: typing.Optional[jsii.Number] = None,
        minimum_scaling_step_size: typing.Optional[jsii.Number] = None,
        status: typing.Optional[str] = None,
        target_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param maximum_scaling_step_size: 
        :param minimum_scaling_step_size: 
        :param status: 
        :param target_capacity: 
        """
        self._values = {}
        if maximum_scaling_step_size is not None:
            self._values["maximum_scaling_step_size"] = maximum_scaling_step_size
        if minimum_scaling_step_size is not None:
            self._values["minimum_scaling_step_size"] = minimum_scaling_step_size
        if status is not None:
            self._values["status"] = status
        if target_capacity is not None:
            self._values["target_capacity"] = target_capacity

    @builtins.property
    def maximum_scaling_step_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("maximum_scaling_step_size")

    @builtins.property
    def minimum_scaling_step_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("minimum_scaling_step_size")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    @builtins.property
    def target_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("target_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "EcsCapacityProviderAutoScalingGroupProviderManagedScaling(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsCapacityProviderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "auto_scaling_group_provider": "autoScalingGroupProvider",
        "name": "name",
        "tags": "tags",
    },
)
class EcsCapacityProviderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        auto_scaling_group_provider: typing.List[
            "EcsCapacityProviderAutoScalingGroupProvider"
        ],
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param auto_scaling_group_provider: auto_scaling_group_provider block.
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "auto_scaling_group_provider": auto_scaling_group_provider,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def auto_scaling_group_provider(
        self,
    ) -> typing.List["EcsCapacityProviderAutoScalingGroupProvider"]:
        """auto_scaling_group_provider block."""
        return self._values.get("auto_scaling_group_provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsCapacityProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EcsCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EcsCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        capacity_providers: typing.Optional[typing.List[str]] = None,
        default_capacity_provider_strategy: typing.Optional[
            typing.List["EcsClusterDefaultCapacityProviderStrategy"]
        ] = None,
        setting: typing.Optional[typing.List["EcsClusterSetting"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param capacity_providers: 
        :param default_capacity_provider_strategy: default_capacity_provider_strategy block.
        :param setting: setting block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EcsClusterConfig(
            name=name,
            capacity_providers=capacity_providers,
            default_capacity_provider_strategy=default_capacity_provider_strategy,
            setting=setting,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EcsCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="capacityProviders")
    def capacity_providers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "capacityProviders")

    @capacity_providers.setter
    def capacity_providers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "capacityProviders", value)

    @builtins.property
    @jsii.member(jsii_name="defaultCapacityProviderStrategy")
    def default_capacity_provider_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsClusterDefaultCapacityProviderStrategy"]]:
        return jsii.get(self, "defaultCapacityProviderStrategy")

    @default_capacity_provider_strategy.setter
    def default_capacity_provider_strategy(
        self,
        value: typing.Optional[
            typing.List["EcsClusterDefaultCapacityProviderStrategy"]
        ],
    ) -> None:
        jsii.set(self, "defaultCapacityProviderStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="setting")
    def setting(self) -> typing.Optional[typing.List["EcsClusterSetting"]]:
        return jsii.get(self, "setting")

    @setting.setter
    def setting(self, value: typing.Optional[typing.List["EcsClusterSetting"]]) -> None:
        jsii.set(self, "setting", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "capacity_providers": "capacityProviders",
        "default_capacity_provider_strategy": "defaultCapacityProviderStrategy",
        "setting": "setting",
        "tags": "tags",
    },
)
class EcsClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        capacity_providers: typing.Optional[typing.List[str]] = None,
        default_capacity_provider_strategy: typing.Optional[
            typing.List["EcsClusterDefaultCapacityProviderStrategy"]
        ] = None,
        setting: typing.Optional[typing.List["EcsClusterSetting"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param capacity_providers: 
        :param default_capacity_provider_strategy: default_capacity_provider_strategy block.
        :param setting: setting block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if capacity_providers is not None:
            self._values["capacity_providers"] = capacity_providers
        if default_capacity_provider_strategy is not None:
            self._values[
                "default_capacity_provider_strategy"
            ] = default_capacity_provider_strategy
        if setting is not None:
            self._values["setting"] = setting
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def capacity_providers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("capacity_providers")

    @builtins.property
    def default_capacity_provider_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsClusterDefaultCapacityProviderStrategy"]]:
        """default_capacity_provider_strategy block."""
        return self._values.get("default_capacity_provider_strategy")

    @builtins.property
    def setting(self) -> typing.Optional[typing.List["EcsClusterSetting"]]:
        """setting block."""
        return self._values.get("setting")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsClusterDefaultCapacityProviderStrategy",
    jsii_struct_bases=[],
    name_mapping={
        "capacity_provider": "capacityProvider",
        "base": "base",
        "weight": "weight",
    },
)
class EcsClusterDefaultCapacityProviderStrategy:
    def __init__(
        self,
        *,
        capacity_provider: str,
        base: typing.Optional[jsii.Number] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param capacity_provider: 
        :param base: 
        :param weight: 
        """
        self._values = {
            "capacity_provider": capacity_provider,
        }
        if base is not None:
            self._values["base"] = base
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def capacity_provider(self) -> str:
        return self._values.get("capacity_provider")

    @builtins.property
    def base(self) -> typing.Optional[jsii.Number]:
        return self._values.get("base")

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsClusterDefaultCapacityProviderStrategy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsClusterSetting",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class EcsClusterSetting:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsClusterSetting(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EcsService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EcsService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        capacity_provider_strategy: typing.Optional[
            typing.List["EcsServiceCapacityProviderStrategy"]
        ] = None,
        cluster: typing.Optional[str] = None,
        deployment_controller: typing.Optional[
            typing.List["EcsServiceDeploymentController"]
        ] = None,
        deployment_maximum_percent: typing.Optional[jsii.Number] = None,
        deployment_minimum_healthy_percent: typing.Optional[jsii.Number] = None,
        desired_count: typing.Optional[jsii.Number] = None,
        enable_ecs_managed_tags: typing.Optional[bool] = None,
        force_new_deployment: typing.Optional[bool] = None,
        health_check_grace_period_seconds: typing.Optional[jsii.Number] = None,
        iam_role: typing.Optional[str] = None,
        launch_type: typing.Optional[str] = None,
        load_balancer: typing.Optional[typing.List["EcsServiceLoadBalancer"]] = None,
        network_configuration: typing.Optional[
            typing.List["EcsServiceNetworkConfiguration"]
        ] = None,
        ordered_placement_strategy: typing.Optional[
            typing.List["EcsServiceOrderedPlacementStrategy"]
        ] = None,
        placement_constraints: typing.Optional[
            typing.List["EcsServicePlacementConstraints"]
        ] = None,
        placement_strategy: typing.Optional[
            typing.List["EcsServicePlacementStrategy"]
        ] = None,
        platform_version: typing.Optional[str] = None,
        propagate_tags: typing.Optional[str] = None,
        scheduling_strategy: typing.Optional[str] = None,
        service_registries: typing.Optional[
            typing.List["EcsServiceServiceRegistries"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        task_definition: typing.Optional[str] = None,
        timeouts: typing.Optional["EcsServiceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param capacity_provider_strategy: capacity_provider_strategy block.
        :param cluster: 
        :param deployment_controller: deployment_controller block.
        :param deployment_maximum_percent: 
        :param deployment_minimum_healthy_percent: 
        :param desired_count: 
        :param enable_ecs_managed_tags: 
        :param force_new_deployment: 
        :param health_check_grace_period_seconds: 
        :param iam_role: 
        :param launch_type: 
        :param load_balancer: load_balancer block.
        :param network_configuration: network_configuration block.
        :param ordered_placement_strategy: ordered_placement_strategy block.
        :param placement_constraints: placement_constraints block.
        :param placement_strategy: placement_strategy block.
        :param platform_version: 
        :param propagate_tags: 
        :param scheduling_strategy: 
        :param service_registries: service_registries block.
        :param tags: 
        :param task_definition: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EcsServiceConfig(
            name=name,
            capacity_provider_strategy=capacity_provider_strategy,
            cluster=cluster,
            deployment_controller=deployment_controller,
            deployment_maximum_percent=deployment_maximum_percent,
            deployment_minimum_healthy_percent=deployment_minimum_healthy_percent,
            desired_count=desired_count,
            enable_ecs_managed_tags=enable_ecs_managed_tags,
            force_new_deployment=force_new_deployment,
            health_check_grace_period_seconds=health_check_grace_period_seconds,
            iam_role=iam_role,
            launch_type=launch_type,
            load_balancer=load_balancer,
            network_configuration=network_configuration,
            ordered_placement_strategy=ordered_placement_strategy,
            placement_constraints=placement_constraints,
            placement_strategy=placement_strategy,
            platform_version=platform_version,
            propagate_tags=propagate_tags,
            scheduling_strategy=scheduling_strategy,
            service_registries=service_registries,
            tags=tags,
            task_definition=task_definition,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EcsService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="capacityProviderStrategy")
    def capacity_provider_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsServiceCapacityProviderStrategy"]]:
        return jsii.get(self, "capacityProviderStrategy")

    @capacity_provider_strategy.setter
    def capacity_provider_strategy(
        self, value: typing.Optional[typing.List["EcsServiceCapacityProviderStrategy"]]
    ) -> None:
        jsii.set(self, "capacityProviderStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="cluster")
    def cluster(self) -> typing.Optional[str]:
        return jsii.get(self, "cluster")

    @cluster.setter
    def cluster(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cluster", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentController")
    def deployment_controller(
        self,
    ) -> typing.Optional[typing.List["EcsServiceDeploymentController"]]:
        return jsii.get(self, "deploymentController")

    @deployment_controller.setter
    def deployment_controller(
        self, value: typing.Optional[typing.List["EcsServiceDeploymentController"]]
    ) -> None:
        jsii.set(self, "deploymentController", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentMaximumPercent")
    def deployment_maximum_percent(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "deploymentMaximumPercent")

    @deployment_maximum_percent.setter
    def deployment_maximum_percent(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "deploymentMaximumPercent", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentMinimumHealthyPercent")
    def deployment_minimum_healthy_percent(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "deploymentMinimumHealthyPercent")

    @deployment_minimum_healthy_percent.setter
    def deployment_minimum_healthy_percent(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "deploymentMinimumHealthyPercent", value)

    @builtins.property
    @jsii.member(jsii_name="desiredCount")
    def desired_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "desiredCount")

    @desired_count.setter
    def desired_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "desiredCount", value)

    @builtins.property
    @jsii.member(jsii_name="enableEcsManagedTags")
    def enable_ecs_managed_tags(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableEcsManagedTags")

    @enable_ecs_managed_tags.setter
    def enable_ecs_managed_tags(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableEcsManagedTags", value)

    @builtins.property
    @jsii.member(jsii_name="forceNewDeployment")
    def force_new_deployment(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceNewDeployment")

    @force_new_deployment.setter
    def force_new_deployment(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceNewDeployment", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckGracePeriodSeconds")
    def health_check_grace_period_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "healthCheckGracePeriodSeconds")

    @health_check_grace_period_seconds.setter
    def health_check_grace_period_seconds(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "healthCheckGracePeriodSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="iamRole")
    def iam_role(self) -> typing.Optional[str]:
        return jsii.get(self, "iamRole")

    @iam_role.setter
    def iam_role(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamRole", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="launchType")
    def launch_type(self) -> typing.Optional[str]:
        return jsii.get(self, "launchType")

    @launch_type.setter
    def launch_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "launchType", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancer")
    def load_balancer(self) -> typing.Optional[typing.List["EcsServiceLoadBalancer"]]:
        return jsii.get(self, "loadBalancer")

    @load_balancer.setter
    def load_balancer(
        self, value: typing.Optional[typing.List["EcsServiceLoadBalancer"]]
    ) -> None:
        jsii.set(self, "loadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="networkConfiguration")
    def network_configuration(
        self,
    ) -> typing.Optional[typing.List["EcsServiceNetworkConfiguration"]]:
        return jsii.get(self, "networkConfiguration")

    @network_configuration.setter
    def network_configuration(
        self, value: typing.Optional[typing.List["EcsServiceNetworkConfiguration"]]
    ) -> None:
        jsii.set(self, "networkConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="orderedPlacementStrategy")
    def ordered_placement_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsServiceOrderedPlacementStrategy"]]:
        return jsii.get(self, "orderedPlacementStrategy")

    @ordered_placement_strategy.setter
    def ordered_placement_strategy(
        self, value: typing.Optional[typing.List["EcsServiceOrderedPlacementStrategy"]]
    ) -> None:
        jsii.set(self, "orderedPlacementStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="placementConstraints")
    def placement_constraints(
        self,
    ) -> typing.Optional[typing.List["EcsServicePlacementConstraints"]]:
        return jsii.get(self, "placementConstraints")

    @placement_constraints.setter
    def placement_constraints(
        self, value: typing.Optional[typing.List["EcsServicePlacementConstraints"]]
    ) -> None:
        jsii.set(self, "placementConstraints", value)

    @builtins.property
    @jsii.member(jsii_name="placementStrategy")
    def placement_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsServicePlacementStrategy"]]:
        return jsii.get(self, "placementStrategy")

    @placement_strategy.setter
    def placement_strategy(
        self, value: typing.Optional[typing.List["EcsServicePlacementStrategy"]]
    ) -> None:
        jsii.set(self, "placementStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="platformVersion")
    def platform_version(self) -> typing.Optional[str]:
        return jsii.get(self, "platformVersion")

    @platform_version.setter
    def platform_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "platformVersion", value)

    @builtins.property
    @jsii.member(jsii_name="propagateTags")
    def propagate_tags(self) -> typing.Optional[str]:
        return jsii.get(self, "propagateTags")

    @propagate_tags.setter
    def propagate_tags(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "propagateTags", value)

    @builtins.property
    @jsii.member(jsii_name="schedulingStrategy")
    def scheduling_strategy(self) -> typing.Optional[str]:
        return jsii.get(self, "schedulingStrategy")

    @scheduling_strategy.setter
    def scheduling_strategy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "schedulingStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="serviceRegistries")
    def service_registries(
        self,
    ) -> typing.Optional[typing.List["EcsServiceServiceRegistries"]]:
        return jsii.get(self, "serviceRegistries")

    @service_registries.setter
    def service_registries(
        self, value: typing.Optional[typing.List["EcsServiceServiceRegistries"]]
    ) -> None:
        jsii.set(self, "serviceRegistries", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="taskDefinition")
    def task_definition(self) -> typing.Optional[str]:
        return jsii.get(self, "taskDefinition")

    @task_definition.setter
    def task_definition(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "taskDefinition", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EcsServiceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["EcsServiceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceCapacityProviderStrategy",
    jsii_struct_bases=[],
    name_mapping={
        "capacity_provider": "capacityProvider",
        "base": "base",
        "weight": "weight",
    },
)
class EcsServiceCapacityProviderStrategy:
    def __init__(
        self,
        *,
        capacity_provider: str,
        base: typing.Optional[jsii.Number] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param capacity_provider: 
        :param base: 
        :param weight: 
        """
        self._values = {
            "capacity_provider": capacity_provider,
        }
        if base is not None:
            self._values["base"] = base
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def capacity_provider(self) -> str:
        return self._values.get("capacity_provider")

    @builtins.property
    def base(self) -> typing.Optional[jsii.Number]:
        return self._values.get("base")

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceCapacityProviderStrategy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "capacity_provider_strategy": "capacityProviderStrategy",
        "cluster": "cluster",
        "deployment_controller": "deploymentController",
        "deployment_maximum_percent": "deploymentMaximumPercent",
        "deployment_minimum_healthy_percent": "deploymentMinimumHealthyPercent",
        "desired_count": "desiredCount",
        "enable_ecs_managed_tags": "enableEcsManagedTags",
        "force_new_deployment": "forceNewDeployment",
        "health_check_grace_period_seconds": "healthCheckGracePeriodSeconds",
        "iam_role": "iamRole",
        "launch_type": "launchType",
        "load_balancer": "loadBalancer",
        "network_configuration": "networkConfiguration",
        "ordered_placement_strategy": "orderedPlacementStrategy",
        "placement_constraints": "placementConstraints",
        "placement_strategy": "placementStrategy",
        "platform_version": "platformVersion",
        "propagate_tags": "propagateTags",
        "scheduling_strategy": "schedulingStrategy",
        "service_registries": "serviceRegistries",
        "tags": "tags",
        "task_definition": "taskDefinition",
        "timeouts": "timeouts",
    },
)
class EcsServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        capacity_provider_strategy: typing.Optional[
            typing.List["EcsServiceCapacityProviderStrategy"]
        ] = None,
        cluster: typing.Optional[str] = None,
        deployment_controller: typing.Optional[
            typing.List["EcsServiceDeploymentController"]
        ] = None,
        deployment_maximum_percent: typing.Optional[jsii.Number] = None,
        deployment_minimum_healthy_percent: typing.Optional[jsii.Number] = None,
        desired_count: typing.Optional[jsii.Number] = None,
        enable_ecs_managed_tags: typing.Optional[bool] = None,
        force_new_deployment: typing.Optional[bool] = None,
        health_check_grace_period_seconds: typing.Optional[jsii.Number] = None,
        iam_role: typing.Optional[str] = None,
        launch_type: typing.Optional[str] = None,
        load_balancer: typing.Optional[typing.List["EcsServiceLoadBalancer"]] = None,
        network_configuration: typing.Optional[
            typing.List["EcsServiceNetworkConfiguration"]
        ] = None,
        ordered_placement_strategy: typing.Optional[
            typing.List["EcsServiceOrderedPlacementStrategy"]
        ] = None,
        placement_constraints: typing.Optional[
            typing.List["EcsServicePlacementConstraints"]
        ] = None,
        placement_strategy: typing.Optional[
            typing.List["EcsServicePlacementStrategy"]
        ] = None,
        platform_version: typing.Optional[str] = None,
        propagate_tags: typing.Optional[str] = None,
        scheduling_strategy: typing.Optional[str] = None,
        service_registries: typing.Optional[
            typing.List["EcsServiceServiceRegistries"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        task_definition: typing.Optional[str] = None,
        timeouts: typing.Optional["EcsServiceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param capacity_provider_strategy: capacity_provider_strategy block.
        :param cluster: 
        :param deployment_controller: deployment_controller block.
        :param deployment_maximum_percent: 
        :param deployment_minimum_healthy_percent: 
        :param desired_count: 
        :param enable_ecs_managed_tags: 
        :param force_new_deployment: 
        :param health_check_grace_period_seconds: 
        :param iam_role: 
        :param launch_type: 
        :param load_balancer: load_balancer block.
        :param network_configuration: network_configuration block.
        :param ordered_placement_strategy: ordered_placement_strategy block.
        :param placement_constraints: placement_constraints block.
        :param placement_strategy: placement_strategy block.
        :param platform_version: 
        :param propagate_tags: 
        :param scheduling_strategy: 
        :param service_registries: service_registries block.
        :param tags: 
        :param task_definition: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EcsServiceTimeouts(**timeouts)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if capacity_provider_strategy is not None:
            self._values["capacity_provider_strategy"] = capacity_provider_strategy
        if cluster is not None:
            self._values["cluster"] = cluster
        if deployment_controller is not None:
            self._values["deployment_controller"] = deployment_controller
        if deployment_maximum_percent is not None:
            self._values["deployment_maximum_percent"] = deployment_maximum_percent
        if deployment_minimum_healthy_percent is not None:
            self._values[
                "deployment_minimum_healthy_percent"
            ] = deployment_minimum_healthy_percent
        if desired_count is not None:
            self._values["desired_count"] = desired_count
        if enable_ecs_managed_tags is not None:
            self._values["enable_ecs_managed_tags"] = enable_ecs_managed_tags
        if force_new_deployment is not None:
            self._values["force_new_deployment"] = force_new_deployment
        if health_check_grace_period_seconds is not None:
            self._values[
                "health_check_grace_period_seconds"
            ] = health_check_grace_period_seconds
        if iam_role is not None:
            self._values["iam_role"] = iam_role
        if launch_type is not None:
            self._values["launch_type"] = launch_type
        if load_balancer is not None:
            self._values["load_balancer"] = load_balancer
        if network_configuration is not None:
            self._values["network_configuration"] = network_configuration
        if ordered_placement_strategy is not None:
            self._values["ordered_placement_strategy"] = ordered_placement_strategy
        if placement_constraints is not None:
            self._values["placement_constraints"] = placement_constraints
        if placement_strategy is not None:
            self._values["placement_strategy"] = placement_strategy
        if platform_version is not None:
            self._values["platform_version"] = platform_version
        if propagate_tags is not None:
            self._values["propagate_tags"] = propagate_tags
        if scheduling_strategy is not None:
            self._values["scheduling_strategy"] = scheduling_strategy
        if service_registries is not None:
            self._values["service_registries"] = service_registries
        if tags is not None:
            self._values["tags"] = tags
        if task_definition is not None:
            self._values["task_definition"] = task_definition
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def capacity_provider_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsServiceCapacityProviderStrategy"]]:
        """capacity_provider_strategy block."""
        return self._values.get("capacity_provider_strategy")

    @builtins.property
    def cluster(self) -> typing.Optional[str]:
        return self._values.get("cluster")

    @builtins.property
    def deployment_controller(
        self,
    ) -> typing.Optional[typing.List["EcsServiceDeploymentController"]]:
        """deployment_controller block."""
        return self._values.get("deployment_controller")

    @builtins.property
    def deployment_maximum_percent(self) -> typing.Optional[jsii.Number]:
        return self._values.get("deployment_maximum_percent")

    @builtins.property
    def deployment_minimum_healthy_percent(self) -> typing.Optional[jsii.Number]:
        return self._values.get("deployment_minimum_healthy_percent")

    @builtins.property
    def desired_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("desired_count")

    @builtins.property
    def enable_ecs_managed_tags(self) -> typing.Optional[bool]:
        return self._values.get("enable_ecs_managed_tags")

    @builtins.property
    def force_new_deployment(self) -> typing.Optional[bool]:
        return self._values.get("force_new_deployment")

    @builtins.property
    def health_check_grace_period_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("health_check_grace_period_seconds")

    @builtins.property
    def iam_role(self) -> typing.Optional[str]:
        return self._values.get("iam_role")

    @builtins.property
    def launch_type(self) -> typing.Optional[str]:
        return self._values.get("launch_type")

    @builtins.property
    def load_balancer(self) -> typing.Optional[typing.List["EcsServiceLoadBalancer"]]:
        """load_balancer block."""
        return self._values.get("load_balancer")

    @builtins.property
    def network_configuration(
        self,
    ) -> typing.Optional[typing.List["EcsServiceNetworkConfiguration"]]:
        """network_configuration block."""
        return self._values.get("network_configuration")

    @builtins.property
    def ordered_placement_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsServiceOrderedPlacementStrategy"]]:
        """ordered_placement_strategy block."""
        return self._values.get("ordered_placement_strategy")

    @builtins.property
    def placement_constraints(
        self,
    ) -> typing.Optional[typing.List["EcsServicePlacementConstraints"]]:
        """placement_constraints block."""
        return self._values.get("placement_constraints")

    @builtins.property
    def placement_strategy(
        self,
    ) -> typing.Optional[typing.List["EcsServicePlacementStrategy"]]:
        """placement_strategy block."""
        return self._values.get("placement_strategy")

    @builtins.property
    def platform_version(self) -> typing.Optional[str]:
        return self._values.get("platform_version")

    @builtins.property
    def propagate_tags(self) -> typing.Optional[str]:
        return self._values.get("propagate_tags")

    @builtins.property
    def scheduling_strategy(self) -> typing.Optional[str]:
        return self._values.get("scheduling_strategy")

    @builtins.property
    def service_registries(
        self,
    ) -> typing.Optional[typing.List["EcsServiceServiceRegistries"]]:
        """service_registries block."""
        return self._values.get("service_registries")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def task_definition(self) -> typing.Optional[str]:
        return self._values.get("task_definition")

    @builtins.property
    def timeouts(self) -> typing.Optional["EcsServiceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceDeploymentController",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class EcsServiceDeploymentController:
    def __init__(self, *, type: typing.Optional[str] = None) -> None:
        """
        :param type: 
        """
        self._values = {}
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceDeploymentController(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceLoadBalancer",
    jsii_struct_bases=[],
    name_mapping={
        "container_name": "containerName",
        "container_port": "containerPort",
        "elb_name": "elbName",
        "target_group_arn": "targetGroupArn",
    },
)
class EcsServiceLoadBalancer:
    def __init__(
        self,
        *,
        container_name: str,
        container_port: jsii.Number,
        elb_name: typing.Optional[str] = None,
        target_group_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param container_name: 
        :param container_port: 
        :param elb_name: 
        :param target_group_arn: 
        """
        self._values = {
            "container_name": container_name,
            "container_port": container_port,
        }
        if elb_name is not None:
            self._values["elb_name"] = elb_name
        if target_group_arn is not None:
            self._values["target_group_arn"] = target_group_arn

    @builtins.property
    def container_name(self) -> str:
        return self._values.get("container_name")

    @builtins.property
    def container_port(self) -> jsii.Number:
        return self._values.get("container_port")

    @builtins.property
    def elb_name(self) -> typing.Optional[str]:
        return self._values.get("elb_name")

    @builtins.property
    def target_group_arn(self) -> typing.Optional[str]:
        return self._values.get("target_group_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceLoadBalancer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceNetworkConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "subnets": "subnets",
        "assign_public_ip": "assignPublicIp",
        "security_groups": "securityGroups",
    },
)
class EcsServiceNetworkConfiguration:
    def __init__(
        self,
        *,
        subnets: typing.List[str],
        assign_public_ip: typing.Optional[bool] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param subnets: 
        :param assign_public_ip: 
        :param security_groups: 
        """
        self._values = {
            "subnets": subnets,
        }
        if assign_public_ip is not None:
            self._values["assign_public_ip"] = assign_public_ip
        if security_groups is not None:
            self._values["security_groups"] = security_groups

    @builtins.property
    def subnets(self) -> typing.List[str]:
        return self._values.get("subnets")

    @builtins.property
    def assign_public_ip(self) -> typing.Optional[bool]:
        return self._values.get("assign_public_ip")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceNetworkConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceOrderedPlacementStrategy",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "field": "field"},
)
class EcsServiceOrderedPlacementStrategy:
    def __init__(self, *, type: str, field: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param field: 
        """
        self._values = {
            "type": type,
        }
        if field is not None:
            self._values["field"] = field

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def field(self) -> typing.Optional[str]:
        return self._values.get("field")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceOrderedPlacementStrategy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServicePlacementConstraints",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "expression": "expression"},
)
class EcsServicePlacementConstraints:
    def __init__(self, *, type: str, expression: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param expression: 
        """
        self._values = {
            "type": type,
        }
        if expression is not None:
            self._values["expression"] = expression

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def expression(self) -> typing.Optional[str]:
        return self._values.get("expression")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServicePlacementConstraints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServicePlacementStrategy",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "field": "field"},
)
class EcsServicePlacementStrategy:
    def __init__(self, *, type: str, field: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param field: 
        """
        self._values = {
            "type": type,
        }
        if field is not None:
            self._values["field"] = field

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def field(self) -> typing.Optional[str]:
        return self._values.get("field")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServicePlacementStrategy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceServiceRegistries",
    jsii_struct_bases=[],
    name_mapping={
        "registry_arn": "registryArn",
        "container_name": "containerName",
        "container_port": "containerPort",
        "port": "port",
    },
)
class EcsServiceServiceRegistries:
    def __init__(
        self,
        *,
        registry_arn: str,
        container_name: typing.Optional[str] = None,
        container_port: typing.Optional[jsii.Number] = None,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param registry_arn: 
        :param container_name: 
        :param container_port: 
        :param port: 
        """
        self._values = {
            "registry_arn": registry_arn,
        }
        if container_name is not None:
            self._values["container_name"] = container_name
        if container_port is not None:
            self._values["container_port"] = container_port
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def registry_arn(self) -> str:
        return self._values.get("registry_arn")

    @builtins.property
    def container_name(self) -> typing.Optional[str]:
        return self._values.get("container_name")

    @builtins.property
    def container_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("container_port")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceServiceRegistries(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsServiceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"delete": "delete"},
)
class EcsServiceTimeouts:
    def __init__(self, *, delete: typing.Optional[str] = None) -> None:
        """
        :param delete: 
        """
        self._values = {}
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsServiceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EcsTaskDefinition(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinition",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        container_definitions: str,
        family: str,
        cpu: typing.Optional[str] = None,
        execution_role_arn: typing.Optional[str] = None,
        inference_accelerator: typing.Optional[
            typing.List["EcsTaskDefinitionInferenceAccelerator"]
        ] = None,
        ipc_mode: typing.Optional[str] = None,
        memory: typing.Optional[str] = None,
        network_mode: typing.Optional[str] = None,
        pid_mode: typing.Optional[str] = None,
        placement_constraints: typing.Optional[
            typing.List["EcsTaskDefinitionPlacementConstraints"]
        ] = None,
        proxy_configuration: typing.Optional[
            typing.List["EcsTaskDefinitionProxyConfiguration"]
        ] = None,
        requires_compatibilities: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        task_role_arn: typing.Optional[str] = None,
        volume: typing.Optional[typing.List["EcsTaskDefinitionVolume"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param container_definitions: 
        :param family: 
        :param cpu: 
        :param execution_role_arn: 
        :param inference_accelerator: inference_accelerator block.
        :param ipc_mode: 
        :param memory: 
        :param network_mode: 
        :param pid_mode: 
        :param placement_constraints: placement_constraints block.
        :param proxy_configuration: proxy_configuration block.
        :param requires_compatibilities: 
        :param tags: 
        :param task_role_arn: 
        :param volume: volume block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EcsTaskDefinitionConfig(
            container_definitions=container_definitions,
            family=family,
            cpu=cpu,
            execution_role_arn=execution_role_arn,
            inference_accelerator=inference_accelerator,
            ipc_mode=ipc_mode,
            memory=memory,
            network_mode=network_mode,
            pid_mode=pid_mode,
            placement_constraints=placement_constraints,
            proxy_configuration=proxy_configuration,
            requires_compatibilities=requires_compatibilities,
            tags=tags,
            task_role_arn=task_role_arn,
            volume=volume,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EcsTaskDefinition, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="revision")
    def revision(self) -> jsii.Number:
        return jsii.get(self, "revision")

    @builtins.property
    @jsii.member(jsii_name="containerDefinitions")
    def container_definitions(self) -> str:
        return jsii.get(self, "containerDefinitions")

    @container_definitions.setter
    def container_definitions(self, value: str) -> None:
        jsii.set(self, "containerDefinitions", value)

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="cpu")
    def cpu(self) -> typing.Optional[str]:
        return jsii.get(self, "cpu")

    @cpu.setter
    def cpu(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cpu", value)

    @builtins.property
    @jsii.member(jsii_name="executionRoleArn")
    def execution_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "executionRoleArn")

    @execution_role_arn.setter
    def execution_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "executionRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="inferenceAccelerator")
    def inference_accelerator(
        self,
    ) -> typing.Optional[typing.List["EcsTaskDefinitionInferenceAccelerator"]]:
        return jsii.get(self, "inferenceAccelerator")

    @inference_accelerator.setter
    def inference_accelerator(
        self,
        value: typing.Optional[typing.List["EcsTaskDefinitionInferenceAccelerator"]],
    ) -> None:
        jsii.set(self, "inferenceAccelerator", value)

    @builtins.property
    @jsii.member(jsii_name="ipcMode")
    def ipc_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "ipcMode")

    @ipc_mode.setter
    def ipc_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipcMode", value)

    @builtins.property
    @jsii.member(jsii_name="memory")
    def memory(self) -> typing.Optional[str]:
        return jsii.get(self, "memory")

    @memory.setter
    def memory(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "memory", value)

    @builtins.property
    @jsii.member(jsii_name="networkMode")
    def network_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "networkMode")

    @network_mode.setter
    def network_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "networkMode", value)

    @builtins.property
    @jsii.member(jsii_name="pidMode")
    def pid_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "pidMode")

    @pid_mode.setter
    def pid_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "pidMode", value)

    @builtins.property
    @jsii.member(jsii_name="placementConstraints")
    def placement_constraints(
        self,
    ) -> typing.Optional[typing.List["EcsTaskDefinitionPlacementConstraints"]]:
        return jsii.get(self, "placementConstraints")

    @placement_constraints.setter
    def placement_constraints(
        self,
        value: typing.Optional[typing.List["EcsTaskDefinitionPlacementConstraints"]],
    ) -> None:
        jsii.set(self, "placementConstraints", value)

    @builtins.property
    @jsii.member(jsii_name="proxyConfiguration")
    def proxy_configuration(
        self,
    ) -> typing.Optional[typing.List["EcsTaskDefinitionProxyConfiguration"]]:
        return jsii.get(self, "proxyConfiguration")

    @proxy_configuration.setter
    def proxy_configuration(
        self, value: typing.Optional[typing.List["EcsTaskDefinitionProxyConfiguration"]]
    ) -> None:
        jsii.set(self, "proxyConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="requiresCompatibilities")
    def requires_compatibilities(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "requiresCompatibilities")

    @requires_compatibilities.setter
    def requires_compatibilities(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "requiresCompatibilities", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="taskRoleArn")
    def task_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "taskRoleArn")

    @task_role_arn.setter
    def task_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "taskRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="volume")
    def volume(self) -> typing.Optional[typing.List["EcsTaskDefinitionVolume"]]:
        return jsii.get(self, "volume")

    @volume.setter
    def volume(
        self, value: typing.Optional[typing.List["EcsTaskDefinitionVolume"]]
    ) -> None:
        jsii.set(self, "volume", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "container_definitions": "containerDefinitions",
        "family": "family",
        "cpu": "cpu",
        "execution_role_arn": "executionRoleArn",
        "inference_accelerator": "inferenceAccelerator",
        "ipc_mode": "ipcMode",
        "memory": "memory",
        "network_mode": "networkMode",
        "pid_mode": "pidMode",
        "placement_constraints": "placementConstraints",
        "proxy_configuration": "proxyConfiguration",
        "requires_compatibilities": "requiresCompatibilities",
        "tags": "tags",
        "task_role_arn": "taskRoleArn",
        "volume": "volume",
    },
)
class EcsTaskDefinitionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        container_definitions: str,
        family: str,
        cpu: typing.Optional[str] = None,
        execution_role_arn: typing.Optional[str] = None,
        inference_accelerator: typing.Optional[
            typing.List["EcsTaskDefinitionInferenceAccelerator"]
        ] = None,
        ipc_mode: typing.Optional[str] = None,
        memory: typing.Optional[str] = None,
        network_mode: typing.Optional[str] = None,
        pid_mode: typing.Optional[str] = None,
        placement_constraints: typing.Optional[
            typing.List["EcsTaskDefinitionPlacementConstraints"]
        ] = None,
        proxy_configuration: typing.Optional[
            typing.List["EcsTaskDefinitionProxyConfiguration"]
        ] = None,
        requires_compatibilities: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        task_role_arn: typing.Optional[str] = None,
        volume: typing.Optional[typing.List["EcsTaskDefinitionVolume"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param container_definitions: 
        :param family: 
        :param cpu: 
        :param execution_role_arn: 
        :param inference_accelerator: inference_accelerator block.
        :param ipc_mode: 
        :param memory: 
        :param network_mode: 
        :param pid_mode: 
        :param placement_constraints: placement_constraints block.
        :param proxy_configuration: proxy_configuration block.
        :param requires_compatibilities: 
        :param tags: 
        :param task_role_arn: 
        :param volume: volume block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "container_definitions": container_definitions,
            "family": family,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cpu is not None:
            self._values["cpu"] = cpu
        if execution_role_arn is not None:
            self._values["execution_role_arn"] = execution_role_arn
        if inference_accelerator is not None:
            self._values["inference_accelerator"] = inference_accelerator
        if ipc_mode is not None:
            self._values["ipc_mode"] = ipc_mode
        if memory is not None:
            self._values["memory"] = memory
        if network_mode is not None:
            self._values["network_mode"] = network_mode
        if pid_mode is not None:
            self._values["pid_mode"] = pid_mode
        if placement_constraints is not None:
            self._values["placement_constraints"] = placement_constraints
        if proxy_configuration is not None:
            self._values["proxy_configuration"] = proxy_configuration
        if requires_compatibilities is not None:
            self._values["requires_compatibilities"] = requires_compatibilities
        if tags is not None:
            self._values["tags"] = tags
        if task_role_arn is not None:
            self._values["task_role_arn"] = task_role_arn
        if volume is not None:
            self._values["volume"] = volume

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def container_definitions(self) -> str:
        return self._values.get("container_definitions")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def cpu(self) -> typing.Optional[str]:
        return self._values.get("cpu")

    @builtins.property
    def execution_role_arn(self) -> typing.Optional[str]:
        return self._values.get("execution_role_arn")

    @builtins.property
    def inference_accelerator(
        self,
    ) -> typing.Optional[typing.List["EcsTaskDefinitionInferenceAccelerator"]]:
        """inference_accelerator block."""
        return self._values.get("inference_accelerator")

    @builtins.property
    def ipc_mode(self) -> typing.Optional[str]:
        return self._values.get("ipc_mode")

    @builtins.property
    def memory(self) -> typing.Optional[str]:
        return self._values.get("memory")

    @builtins.property
    def network_mode(self) -> typing.Optional[str]:
        return self._values.get("network_mode")

    @builtins.property
    def pid_mode(self) -> typing.Optional[str]:
        return self._values.get("pid_mode")

    @builtins.property
    def placement_constraints(
        self,
    ) -> typing.Optional[typing.List["EcsTaskDefinitionPlacementConstraints"]]:
        """placement_constraints block."""
        return self._values.get("placement_constraints")

    @builtins.property
    def proxy_configuration(
        self,
    ) -> typing.Optional[typing.List["EcsTaskDefinitionProxyConfiguration"]]:
        """proxy_configuration block."""
        return self._values.get("proxy_configuration")

    @builtins.property
    def requires_compatibilities(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("requires_compatibilities")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def task_role_arn(self) -> typing.Optional[str]:
        return self._values.get("task_role_arn")

    @builtins.property
    def volume(self) -> typing.Optional[typing.List["EcsTaskDefinitionVolume"]]:
        """volume block."""
        return self._values.get("volume")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsTaskDefinitionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionInferenceAccelerator",
    jsii_struct_bases=[],
    name_mapping={"device_name": "deviceName", "device_type": "deviceType"},
)
class EcsTaskDefinitionInferenceAccelerator:
    def __init__(self, *, device_name: str, device_type: str) -> None:
        """
        :param device_name: 
        :param device_type: 
        """
        self._values = {
            "device_name": device_name,
            "device_type": device_type,
        }

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def device_type(self) -> str:
        return self._values.get("device_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsTaskDefinitionInferenceAccelerator(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionPlacementConstraints",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "expression": "expression"},
)
class EcsTaskDefinitionPlacementConstraints:
    def __init__(self, *, type: str, expression: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param expression: 
        """
        self._values = {
            "type": type,
        }
        if expression is not None:
            self._values["expression"] = expression

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def expression(self) -> typing.Optional[str]:
        return self._values.get("expression")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsTaskDefinitionPlacementConstraints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionProxyConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "container_name": "containerName",
        "properties": "properties",
        "type": "type",
    },
)
class EcsTaskDefinitionProxyConfiguration:
    def __init__(
        self,
        *,
        container_name: str,
        properties: typing.Optional[typing.Mapping[str, str]] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param container_name: 
        :param properties: 
        :param type: 
        """
        self._values = {
            "container_name": container_name,
        }
        if properties is not None:
            self._values["properties"] = properties
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def container_name(self) -> str:
        return self._values.get("container_name")

    @builtins.property
    def properties(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("properties")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsTaskDefinitionProxyConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionVolume",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "docker_volume_configuration": "dockerVolumeConfiguration",
        "efs_volume_configuration": "efsVolumeConfiguration",
        "host_path": "hostPath",
    },
)
class EcsTaskDefinitionVolume:
    def __init__(
        self,
        *,
        name: str,
        docker_volume_configuration: typing.Optional[
            typing.List["EcsTaskDefinitionVolumeDockerVolumeConfiguration"]
        ] = None,
        efs_volume_configuration: typing.Optional[
            typing.List["EcsTaskDefinitionVolumeEfsVolumeConfiguration"]
        ] = None,
        host_path: typing.Optional[str] = None,
    ) -> None:
        """
        :param name: 
        :param docker_volume_configuration: docker_volume_configuration block.
        :param efs_volume_configuration: efs_volume_configuration block.
        :param host_path: 
        """
        self._values = {
            "name": name,
        }
        if docker_volume_configuration is not None:
            self._values["docker_volume_configuration"] = docker_volume_configuration
        if efs_volume_configuration is not None:
            self._values["efs_volume_configuration"] = efs_volume_configuration
        if host_path is not None:
            self._values["host_path"] = host_path

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def docker_volume_configuration(
        self,
    ) -> typing.Optional[
        typing.List["EcsTaskDefinitionVolumeDockerVolumeConfiguration"]
    ]:
        """docker_volume_configuration block."""
        return self._values.get("docker_volume_configuration")

    @builtins.property
    def efs_volume_configuration(
        self,
    ) -> typing.Optional[typing.List["EcsTaskDefinitionVolumeEfsVolumeConfiguration"]]:
        """efs_volume_configuration block."""
        return self._values.get("efs_volume_configuration")

    @builtins.property
    def host_path(self) -> typing.Optional[str]:
        return self._values.get("host_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsTaskDefinitionVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionVolumeDockerVolumeConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "autoprovision": "autoprovision",
        "driver": "driver",
        "driver_opts": "driverOpts",
        "labels": "labels",
        "scope": "scope",
    },
)
class EcsTaskDefinitionVolumeDockerVolumeConfiguration:
    def __init__(
        self,
        *,
        autoprovision: typing.Optional[bool] = None,
        driver: typing.Optional[str] = None,
        driver_opts: typing.Optional[typing.Mapping[str, str]] = None,
        labels: typing.Optional[typing.Mapping[str, str]] = None,
        scope: typing.Optional[str] = None,
    ) -> None:
        """
        :param autoprovision: 
        :param driver: 
        :param driver_opts: 
        :param labels: 
        :param scope: 
        """
        self._values = {}
        if autoprovision is not None:
            self._values["autoprovision"] = autoprovision
        if driver is not None:
            self._values["driver"] = driver
        if driver_opts is not None:
            self._values["driver_opts"] = driver_opts
        if labels is not None:
            self._values["labels"] = labels
        if scope is not None:
            self._values["scope"] = scope

    @builtins.property
    def autoprovision(self) -> typing.Optional[bool]:
        return self._values.get("autoprovision")

    @builtins.property
    def driver(self) -> typing.Optional[str]:
        return self._values.get("driver")

    @builtins.property
    def driver_opts(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("driver_opts")

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("labels")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsTaskDefinitionVolumeDockerVolumeConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionVolumeEfsVolumeConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "file_system_id": "fileSystemId",
        "authorization_config": "authorizationConfig",
        "root_directory": "rootDirectory",
        "transit_encryption": "transitEncryption",
        "transit_encryption_port": "transitEncryptionPort",
    },
)
class EcsTaskDefinitionVolumeEfsVolumeConfiguration:
    def __init__(
        self,
        *,
        file_system_id: str,
        authorization_config: typing.Optional[
            typing.List[
                "EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig"
            ]
        ] = None,
        root_directory: typing.Optional[str] = None,
        transit_encryption: typing.Optional[str] = None,
        transit_encryption_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param file_system_id: 
        :param authorization_config: authorization_config block.
        :param root_directory: 
        :param transit_encryption: 
        :param transit_encryption_port: 
        """
        self._values = {
            "file_system_id": file_system_id,
        }
        if authorization_config is not None:
            self._values["authorization_config"] = authorization_config
        if root_directory is not None:
            self._values["root_directory"] = root_directory
        if transit_encryption is not None:
            self._values["transit_encryption"] = transit_encryption
        if transit_encryption_port is not None:
            self._values["transit_encryption_port"] = transit_encryption_port

    @builtins.property
    def file_system_id(self) -> str:
        return self._values.get("file_system_id")

    @builtins.property
    def authorization_config(
        self,
    ) -> typing.Optional[
        typing.List["EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig"]
    ]:
        """authorization_config block."""
        return self._values.get("authorization_config")

    @builtins.property
    def root_directory(self) -> typing.Optional[str]:
        return self._values.get("root_directory")

    @builtins.property
    def transit_encryption(self) -> typing.Optional[str]:
        return self._values.get("transit_encryption")

    @builtins.property
    def transit_encryption_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("transit_encryption_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EcsTaskDefinitionVolumeEfsVolumeConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig",
    jsii_struct_bases=[],
    name_mapping={"access_point_id": "accessPointId", "iam": "iam"},
)
class EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig:
    def __init__(
        self,
        *,
        access_point_id: typing.Optional[str] = None,
        iam: typing.Optional[str] = None,
    ) -> None:
        """
        :param access_point_id: 
        :param iam: 
        """
        self._values = {}
        if access_point_id is not None:
            self._values["access_point_id"] = access_point_id
        if iam is not None:
            self._values["iam"] = iam

    @builtins.property
    def access_point_id(self) -> typing.Optional[str]:
        return self._values.get("access_point_id")

    @builtins.property
    def iam(self) -> typing.Optional[str]:
        return self._values.get("iam")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class EfsAccessPoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EfsAccessPoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        file_system_id: str,
        posix_user: typing.Optional[typing.List["EfsAccessPointPosixUser"]] = None,
        root_directory: typing.Optional[
            typing.List["EfsAccessPointRootDirectory"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param file_system_id: 
        :param posix_user: posix_user block.
        :param root_directory: root_directory block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EfsAccessPointConfig(
            file_system_id=file_system_id,
            posix_user=posix_user,
            root_directory=root_directory,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EfsAccessPoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="fileSystemArn")
    def file_system_arn(self) -> str:
        return jsii.get(self, "fileSystemArn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="fileSystemId")
    def file_system_id(self) -> str:
        return jsii.get(self, "fileSystemId")

    @file_system_id.setter
    def file_system_id(self, value: str) -> None:
        jsii.set(self, "fileSystemId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="posixUser")
    def posix_user(self) -> typing.Optional[typing.List["EfsAccessPointPosixUser"]]:
        return jsii.get(self, "posixUser")

    @posix_user.setter
    def posix_user(
        self, value: typing.Optional[typing.List["EfsAccessPointPosixUser"]]
    ) -> None:
        jsii.set(self, "posixUser", value)

    @builtins.property
    @jsii.member(jsii_name="rootDirectory")
    def root_directory(
        self,
    ) -> typing.Optional[typing.List["EfsAccessPointRootDirectory"]]:
        return jsii.get(self, "rootDirectory")

    @root_directory.setter
    def root_directory(
        self, value: typing.Optional[typing.List["EfsAccessPointRootDirectory"]]
    ) -> None:
        jsii.set(self, "rootDirectory", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsAccessPointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "file_system_id": "fileSystemId",
        "posix_user": "posixUser",
        "root_directory": "rootDirectory",
        "tags": "tags",
    },
)
class EfsAccessPointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        file_system_id: str,
        posix_user: typing.Optional[typing.List["EfsAccessPointPosixUser"]] = None,
        root_directory: typing.Optional[
            typing.List["EfsAccessPointRootDirectory"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param file_system_id: 
        :param posix_user: posix_user block.
        :param root_directory: root_directory block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "file_system_id": file_system_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if posix_user is not None:
            self._values["posix_user"] = posix_user
        if root_directory is not None:
            self._values["root_directory"] = root_directory
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def file_system_id(self) -> str:
        return self._values.get("file_system_id")

    @builtins.property
    def posix_user(self) -> typing.Optional[typing.List["EfsAccessPointPosixUser"]]:
        """posix_user block."""
        return self._values.get("posix_user")

    @builtins.property
    def root_directory(
        self,
    ) -> typing.Optional[typing.List["EfsAccessPointRootDirectory"]]:
        """root_directory block."""
        return self._values.get("root_directory")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsAccessPointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsAccessPointPosixUser",
    jsii_struct_bases=[],
    name_mapping={"gid": "gid", "uid": "uid", "secondary_gids": "secondaryGids"},
)
class EfsAccessPointPosixUser:
    def __init__(
        self,
        *,
        gid: jsii.Number,
        uid: jsii.Number,
        secondary_gids: typing.Optional[typing.List[jsii.Number]] = None,
    ) -> None:
        """
        :param gid: 
        :param uid: 
        :param secondary_gids: 
        """
        self._values = {
            "gid": gid,
            "uid": uid,
        }
        if secondary_gids is not None:
            self._values["secondary_gids"] = secondary_gids

    @builtins.property
    def gid(self) -> jsii.Number:
        return self._values.get("gid")

    @builtins.property
    def uid(self) -> jsii.Number:
        return self._values.get("uid")

    @builtins.property
    def secondary_gids(self) -> typing.Optional[typing.List[jsii.Number]]:
        return self._values.get("secondary_gids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsAccessPointPosixUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsAccessPointRootDirectory",
    jsii_struct_bases=[],
    name_mapping={"creation_info": "creationInfo", "path": "path"},
)
class EfsAccessPointRootDirectory:
    def __init__(
        self,
        *,
        creation_info: typing.Optional[
            typing.List["EfsAccessPointRootDirectoryCreationInfo"]
        ] = None,
        path: typing.Optional[str] = None,
    ) -> None:
        """
        :param creation_info: creation_info block.
        :param path: 
        """
        self._values = {}
        if creation_info is not None:
            self._values["creation_info"] = creation_info
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def creation_info(
        self,
    ) -> typing.Optional[typing.List["EfsAccessPointRootDirectoryCreationInfo"]]:
        """creation_info block."""
        return self._values.get("creation_info")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsAccessPointRootDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsAccessPointRootDirectoryCreationInfo",
    jsii_struct_bases=[],
    name_mapping={
        "owner_gid": "ownerGid",
        "owner_uid": "ownerUid",
        "permissions": "permissions",
    },
)
class EfsAccessPointRootDirectoryCreationInfo:
    def __init__(
        self, *, owner_gid: jsii.Number, owner_uid: jsii.Number, permissions: str
    ) -> None:
        """
        :param owner_gid: 
        :param owner_uid: 
        :param permissions: 
        """
        self._values = {
            "owner_gid": owner_gid,
            "owner_uid": owner_uid,
            "permissions": permissions,
        }

    @builtins.property
    def owner_gid(self) -> jsii.Number:
        return self._values.get("owner_gid")

    @builtins.property
    def owner_uid(self) -> jsii.Number:
        return self._values.get("owner_uid")

    @builtins.property
    def permissions(self) -> str:
        return self._values.get("permissions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsAccessPointRootDirectoryCreationInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EfsFileSystem(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EfsFileSystem",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        creation_token: typing.Optional[str] = None,
        encrypted: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        lifecycle_policy: typing.Optional[
            typing.List["EfsFileSystemLifecyclePolicy"]
        ] = None,
        performance_mode: typing.Optional[str] = None,
        provisioned_throughput_in_mibps: typing.Optional[jsii.Number] = None,
        reference_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        throughput_mode: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param creation_token: 
        :param encrypted: 
        :param kms_key_id: 
        :param lifecycle_policy: lifecycle_policy block.
        :param performance_mode: 
        :param provisioned_throughput_in_mibps: 
        :param reference_name: 
        :param tags: 
        :param throughput_mode: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EfsFileSystemConfig(
            creation_token=creation_token,
            encrypted=encrypted,
            kms_key_id=kms_key_id,
            lifecycle_policy=lifecycle_policy,
            performance_mode=performance_mode,
            provisioned_throughput_in_mibps=provisioned_throughput_in_mibps,
            reference_name=reference_name,
            tags=tags,
            throughput_mode=throughput_mode,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EfsFileSystem, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="creationToken")
    def creation_token(self) -> typing.Optional[str]:
        return jsii.get(self, "creationToken")

    @creation_token.setter
    def creation_token(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "creationToken", value)

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="lifecyclePolicy")
    def lifecycle_policy(
        self,
    ) -> typing.Optional[typing.List["EfsFileSystemLifecyclePolicy"]]:
        return jsii.get(self, "lifecyclePolicy")

    @lifecycle_policy.setter
    def lifecycle_policy(
        self, value: typing.Optional[typing.List["EfsFileSystemLifecyclePolicy"]]
    ) -> None:
        jsii.set(self, "lifecyclePolicy", value)

    @builtins.property
    @jsii.member(jsii_name="performanceMode")
    def performance_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "performanceMode")

    @performance_mode.setter
    def performance_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "performanceMode", value)

    @builtins.property
    @jsii.member(jsii_name="provisionedThroughputInMibps")
    def provisioned_throughput_in_mibps(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "provisionedThroughputInMibps")

    @provisioned_throughput_in_mibps.setter
    def provisioned_throughput_in_mibps(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "provisionedThroughputInMibps", value)

    @builtins.property
    @jsii.member(jsii_name="referenceName")
    def reference_name(self) -> typing.Optional[str]:
        return jsii.get(self, "referenceName")

    @reference_name.setter
    def reference_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "referenceName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="throughputMode")
    def throughput_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "throughputMode")

    @throughput_mode.setter
    def throughput_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "throughputMode", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsFileSystemConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "creation_token": "creationToken",
        "encrypted": "encrypted",
        "kms_key_id": "kmsKeyId",
        "lifecycle_policy": "lifecyclePolicy",
        "performance_mode": "performanceMode",
        "provisioned_throughput_in_mibps": "provisionedThroughputInMibps",
        "reference_name": "referenceName",
        "tags": "tags",
        "throughput_mode": "throughputMode",
    },
)
class EfsFileSystemConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        creation_token: typing.Optional[str] = None,
        encrypted: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        lifecycle_policy: typing.Optional[
            typing.List["EfsFileSystemLifecyclePolicy"]
        ] = None,
        performance_mode: typing.Optional[str] = None,
        provisioned_throughput_in_mibps: typing.Optional[jsii.Number] = None,
        reference_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        throughput_mode: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param creation_token: 
        :param encrypted: 
        :param kms_key_id: 
        :param lifecycle_policy: lifecycle_policy block.
        :param performance_mode: 
        :param provisioned_throughput_in_mibps: 
        :param reference_name: 
        :param tags: 
        :param throughput_mode: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if creation_token is not None:
            self._values["creation_token"] = creation_token
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if lifecycle_policy is not None:
            self._values["lifecycle_policy"] = lifecycle_policy
        if performance_mode is not None:
            self._values["performance_mode"] = performance_mode
        if provisioned_throughput_in_mibps is not None:
            self._values[
                "provisioned_throughput_in_mibps"
            ] = provisioned_throughput_in_mibps
        if reference_name is not None:
            self._values["reference_name"] = reference_name
        if tags is not None:
            self._values["tags"] = tags
        if throughput_mode is not None:
            self._values["throughput_mode"] = throughput_mode

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def creation_token(self) -> typing.Optional[str]:
        return self._values.get("creation_token")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def lifecycle_policy(
        self,
    ) -> typing.Optional[typing.List["EfsFileSystemLifecyclePolicy"]]:
        """lifecycle_policy block."""
        return self._values.get("lifecycle_policy")

    @builtins.property
    def performance_mode(self) -> typing.Optional[str]:
        return self._values.get("performance_mode")

    @builtins.property
    def provisioned_throughput_in_mibps(self) -> typing.Optional[jsii.Number]:
        return self._values.get("provisioned_throughput_in_mibps")

    @builtins.property
    def reference_name(self) -> typing.Optional[str]:
        return self._values.get("reference_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def throughput_mode(self) -> typing.Optional[str]:
        return self._values.get("throughput_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsFileSystemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsFileSystemLifecyclePolicy",
    jsii_struct_bases=[],
    name_mapping={"transition_to_ia": "transitionToIa"},
)
class EfsFileSystemLifecyclePolicy:
    def __init__(self, *, transition_to_ia: str) -> None:
        """
        :param transition_to_ia: 
        """
        self._values = {
            "transition_to_ia": transition_to_ia,
        }

    @builtins.property
    def transition_to_ia(self) -> str:
        return self._values.get("transition_to_ia")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsFileSystemLifecyclePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EfsFileSystemPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EfsFileSystemPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        file_system_id: str,
        policy: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param file_system_id: 
        :param policy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EfsFileSystemPolicyConfig(
            file_system_id=file_system_id,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EfsFileSystemPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="fileSystemId")
    def file_system_id(self) -> str:
        return jsii.get(self, "fileSystemId")

    @file_system_id.setter
    def file_system_id(self, value: str) -> None:
        jsii.set(self, "fileSystemId", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsFileSystemPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "file_system_id": "fileSystemId",
        "policy": "policy",
    },
)
class EfsFileSystemPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        file_system_id: str,
        policy: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param file_system_id: 
        :param policy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "file_system_id": file_system_id,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def file_system_id(self) -> str:
        return self._values.get("file_system_id")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsFileSystemPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EfsMountTarget(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EfsMountTarget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        file_system_id: str,
        subnet_id: str,
        ip_address: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param file_system_id: 
        :param subnet_id: 
        :param ip_address: 
        :param security_groups: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EfsMountTargetConfig(
            file_system_id=file_system_id,
            subnet_id=subnet_id,
            ip_address=ip_address,
            security_groups=security_groups,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EfsMountTarget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> str:
        return jsii.get(self, "availabilityZoneId")

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneName")
    def availability_zone_name(self) -> str:
        return jsii.get(self, "availabilityZoneName")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="fileSystemArn")
    def file_system_arn(self) -> str:
        return jsii.get(self, "fileSystemArn")

    @builtins.property
    @jsii.member(jsii_name="mountTargetDnsName")
    def mount_target_dns_name(self) -> str:
        return jsii.get(self, "mountTargetDnsName")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="fileSystemId")
    def file_system_id(self) -> str:
        return jsii.get(self, "fileSystemId")

    @file_system_id.setter
    def file_system_id(self, value: str) -> None:
        jsii.set(self, "fileSystemId", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> typing.Optional[str]:
        return jsii.get(self, "ipAddress")

    @ip_address.setter
    def ip_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EfsMountTargetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "file_system_id": "fileSystemId",
        "subnet_id": "subnetId",
        "ip_address": "ipAddress",
        "security_groups": "securityGroups",
    },
)
class EfsMountTargetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        file_system_id: str,
        subnet_id: str,
        ip_address: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param file_system_id: 
        :param subnet_id: 
        :param ip_address: 
        :param security_groups: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "file_system_id": file_system_id,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if security_groups is not None:
            self._values["security_groups"] = security_groups

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def file_system_id(self) -> str:
        return self._values.get("file_system_id")

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    @builtins.property
    def ip_address(self) -> typing.Optional[str]:
        return self._values.get("ip_address")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EfsMountTargetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EgressOnlyInternetGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EgressOnlyInternetGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EgressOnlyInternetGatewayConfig(
            vpc_id=vpc_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EgressOnlyInternetGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EgressOnlyInternetGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_id": "vpcId",
        "tags": "tags",
    },
)
class EgressOnlyInternetGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EgressOnlyInternetGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Eip(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Eip",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        associate_with_private_ip: typing.Optional[str] = None,
        customer_owned_ipv4_pool: typing.Optional[str] = None,
        instance: typing.Optional[str] = None,
        network_interface: typing.Optional[str] = None,
        public_ipv4_pool: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EipTimeouts"] = None,
        vpc: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param associate_with_private_ip: 
        :param customer_owned_ipv4_pool: 
        :param instance: 
        :param network_interface: 
        :param public_ipv4_pool: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EipConfig(
            associate_with_private_ip=associate_with_private_ip,
            customer_owned_ipv4_pool=customer_owned_ipv4_pool,
            instance=instance,
            network_interface=network_interface,
            public_ipv4_pool=public_ipv4_pool,
            tags=tags,
            timeouts=timeouts,
            vpc=vpc,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Eip, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocationId")
    def allocation_id(self) -> str:
        return jsii.get(self, "allocationId")

    @builtins.property
    @jsii.member(jsii_name="associationId")
    def association_id(self) -> str:
        return jsii.get(self, "associationId")

    @builtins.property
    @jsii.member(jsii_name="customerOwnedIp")
    def customer_owned_ip(self) -> str:
        return jsii.get(self, "customerOwnedIp")

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @builtins.property
    @jsii.member(jsii_name="privateDns")
    def private_dns(self) -> str:
        return jsii.get(self, "privateDns")

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> str:
        return jsii.get(self, "privateIp")

    @builtins.property
    @jsii.member(jsii_name="publicDns")
    def public_dns(self) -> str:
        return jsii.get(self, "publicDns")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")

    @builtins.property
    @jsii.member(jsii_name="associateWithPrivateIp")
    def associate_with_private_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "associateWithPrivateIp")

    @associate_with_private_ip.setter
    def associate_with_private_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "associateWithPrivateIp", value)

    @builtins.property
    @jsii.member(jsii_name="customerOwnedIpv4Pool")
    def customer_owned_ipv4_pool(self) -> typing.Optional[str]:
        return jsii.get(self, "customerOwnedIpv4Pool")

    @customer_owned_ipv4_pool.setter
    def customer_owned_ipv4_pool(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerOwnedIpv4Pool", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instance")
    def instance(self) -> typing.Optional[str]:
        return jsii.get(self, "instance")

    @instance.setter
    def instance(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instance", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterface")
    def network_interface(self) -> typing.Optional[str]:
        return jsii.get(self, "networkInterface")

    @network_interface.setter
    def network_interface(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "networkInterface", value)

    @builtins.property
    @jsii.member(jsii_name="publicIpv4Pool")
    def public_ipv4_pool(self) -> typing.Optional[str]:
        return jsii.get(self, "publicIpv4Pool")

    @public_ipv4_pool.setter
    def public_ipv4_pool(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "publicIpv4Pool", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EipTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["EipTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpc")
    def vpc(self) -> typing.Optional[bool]:
        return jsii.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "vpc", value)


class EipAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EipAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        allocation_id: typing.Optional[str] = None,
        allow_reassociation: typing.Optional[bool] = None,
        instance_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        private_ip_address: typing.Optional[str] = None,
        public_ip: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param allocation_id: 
        :param allow_reassociation: 
        :param instance_id: 
        :param network_interface_id: 
        :param private_ip_address: 
        :param public_ip: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EipAssociationConfig(
            allocation_id=allocation_id,
            allow_reassociation=allow_reassociation,
            instance_id=instance_id,
            network_interface_id=network_interface_id,
            private_ip_address=private_ip_address,
            public_ip=public_ip,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EipAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocationId")
    def allocation_id(self) -> typing.Optional[str]:
        return jsii.get(self, "allocationId")

    @allocation_id.setter
    def allocation_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "allocationId", value)

    @builtins.property
    @jsii.member(jsii_name="allowReassociation")
    def allow_reassociation(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowReassociation")

    @allow_reassociation.setter
    def allow_reassociation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowReassociation", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceId")

    @instance_id.setter
    def instance_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> typing.Optional[str]:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> typing.Optional[str]:
        return jsii.get(self, "privateIpAddress")

    @private_ip_address.setter
    def private_ip_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateIpAddress", value)

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "publicIp")

    @public_ip.setter
    def public_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "publicIp", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EipAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "allocation_id": "allocationId",
        "allow_reassociation": "allowReassociation",
        "instance_id": "instanceId",
        "network_interface_id": "networkInterfaceId",
        "private_ip_address": "privateIpAddress",
        "public_ip": "publicIp",
    },
)
class EipAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        allocation_id: typing.Optional[str] = None,
        allow_reassociation: typing.Optional[bool] = None,
        instance_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        private_ip_address: typing.Optional[str] = None,
        public_ip: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param allocation_id: 
        :param allow_reassociation: 
        :param instance_id: 
        :param network_interface_id: 
        :param private_ip_address: 
        :param public_ip: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocation_id is not None:
            self._values["allocation_id"] = allocation_id
        if allow_reassociation is not None:
            self._values["allow_reassociation"] = allow_reassociation
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if network_interface_id is not None:
            self._values["network_interface_id"] = network_interface_id
        if private_ip_address is not None:
            self._values["private_ip_address"] = private_ip_address
        if public_ip is not None:
            self._values["public_ip"] = public_ip

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def allocation_id(self) -> typing.Optional[str]:
        return self._values.get("allocation_id")

    @builtins.property
    def allow_reassociation(self) -> typing.Optional[bool]:
        return self._values.get("allow_reassociation")

    @builtins.property
    def instance_id(self) -> typing.Optional[str]:
        return self._values.get("instance_id")

    @builtins.property
    def network_interface_id(self) -> typing.Optional[str]:
        return self._values.get("network_interface_id")

    @builtins.property
    def private_ip_address(self) -> typing.Optional[str]:
        return self._values.get("private_ip_address")

    @builtins.property
    def public_ip(self) -> typing.Optional[str]:
        return self._values.get("public_ip")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EipAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EipConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "associate_with_private_ip": "associateWithPrivateIp",
        "customer_owned_ipv4_pool": "customerOwnedIpv4Pool",
        "instance": "instance",
        "network_interface": "networkInterface",
        "public_ipv4_pool": "publicIpv4Pool",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc": "vpc",
    },
)
class EipConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        associate_with_private_ip: typing.Optional[str] = None,
        customer_owned_ipv4_pool: typing.Optional[str] = None,
        instance: typing.Optional[str] = None,
        network_interface: typing.Optional[str] = None,
        public_ipv4_pool: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EipTimeouts"] = None,
        vpc: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param associate_with_private_ip: 
        :param customer_owned_ipv4_pool: 
        :param instance: 
        :param network_interface: 
        :param public_ipv4_pool: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EipTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if associate_with_private_ip is not None:
            self._values["associate_with_private_ip"] = associate_with_private_ip
        if customer_owned_ipv4_pool is not None:
            self._values["customer_owned_ipv4_pool"] = customer_owned_ipv4_pool
        if instance is not None:
            self._values["instance"] = instance
        if network_interface is not None:
            self._values["network_interface"] = network_interface
        if public_ipv4_pool is not None:
            self._values["public_ipv4_pool"] = public_ipv4_pool
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc is not None:
            self._values["vpc"] = vpc

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def associate_with_private_ip(self) -> typing.Optional[str]:
        return self._values.get("associate_with_private_ip")

    @builtins.property
    def customer_owned_ipv4_pool(self) -> typing.Optional[str]:
        return self._values.get("customer_owned_ipv4_pool")

    @builtins.property
    def instance(self) -> typing.Optional[str]:
        return self._values.get("instance")

    @builtins.property
    def network_interface(self) -> typing.Optional[str]:
        return self._values.get("network_interface")

    @builtins.property
    def public_ipv4_pool(self) -> typing.Optional[str]:
        return self._values.get("public_ipv4_pool")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["EipTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc(self) -> typing.Optional[bool]:
        return self._values.get("vpc")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EipConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EipTimeouts",
    jsii_struct_bases=[],
    name_mapping={"delete": "delete", "read": "read", "update": "update"},
)
class EipTimeouts:
    def __init__(
        self,
        *,
        delete: typing.Optional[str] = None,
        read: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete: 
        :param read: 
        :param update: 
        """
        self._values = {}
        if delete is not None:
            self._values["delete"] = delete
        if read is not None:
            self._values["read"] = read
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def read(self) -> typing.Optional[str]:
        return self._values.get("read")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EipTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EksCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        role_arn: str,
        vpc_config: typing.List["EksClusterVpcConfig"],
        enabled_cluster_log_types: typing.Optional[typing.List[str]] = None,
        encryption_config: typing.Optional[
            typing.List["EksClusterEncryptionConfig"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EksClusterTimeouts"] = None,
        version: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param role_arn: 
        :param vpc_config: vpc_config block.
        :param enabled_cluster_log_types: 
        :param encryption_config: encryption_config block.
        :param tags: 
        :param timeouts: timeouts block.
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EksClusterConfig(
            name=name,
            role_arn=role_arn,
            vpc_config=vpc_config,
            enabled_cluster_log_types=enabled_cluster_log_types,
            encryption_config=encryption_config,
            tags=tags,
            timeouts=timeouts,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EksCluster, self, [scope, id, config])

    @jsii.member(jsii_name="certificateAuthority")
    def certificate_authority(self, index: str) -> "EksClusterCertificateAuthority":
        """
        :param index: -
        """
        return jsii.invoke(self, "certificateAuthority", [index])

    @jsii.member(jsii_name="identity")
    def identity(self, index: str) -> "EksClusterIdentity":
        """
        :param index: -
        """
        return jsii.invoke(self, "identity", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> str:
        return jsii.get(self, "createdAt")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="platformVersion")
    def platform_version(self) -> str:
        return jsii.get(self, "platformVersion")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConfig")
    def vpc_config(self) -> typing.List["EksClusterVpcConfig"]:
        return jsii.get(self, "vpcConfig")

    @vpc_config.setter
    def vpc_config(self, value: typing.List["EksClusterVpcConfig"]) -> None:
        jsii.set(self, "vpcConfig", value)

    @builtins.property
    @jsii.member(jsii_name="enabledClusterLogTypes")
    def enabled_cluster_log_types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "enabledClusterLogTypes")

    @enabled_cluster_log_types.setter
    def enabled_cluster_log_types(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "enabledClusterLogTypes", value)

    @builtins.property
    @jsii.member(jsii_name="encryptionConfig")
    def encryption_config(
        self,
    ) -> typing.Optional[typing.List["EksClusterEncryptionConfig"]]:
        return jsii.get(self, "encryptionConfig")

    @encryption_config.setter
    def encryption_config(
        self, value: typing.Optional[typing.List["EksClusterEncryptionConfig"]]
    ) -> None:
        jsii.set(self, "encryptionConfig", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EksClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["EksClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[str]:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "version", value)


class EksClusterCertificateAuthority(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterCertificateAuthority",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            EksClusterCertificateAuthority,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="data")
    def data(self) -> str:
        return jsii.get(self, "data")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "role_arn": "roleArn",
        "vpc_config": "vpcConfig",
        "enabled_cluster_log_types": "enabledClusterLogTypes",
        "encryption_config": "encryptionConfig",
        "tags": "tags",
        "timeouts": "timeouts",
        "version": "version",
    },
)
class EksClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        role_arn: str,
        vpc_config: typing.List["EksClusterVpcConfig"],
        enabled_cluster_log_types: typing.Optional[typing.List[str]] = None,
        encryption_config: typing.Optional[
            typing.List["EksClusterEncryptionConfig"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EksClusterTimeouts"] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param role_arn: 
        :param vpc_config: vpc_config block.
        :param enabled_cluster_log_types: 
        :param encryption_config: encryption_config block.
        :param tags: 
        :param timeouts: timeouts block.
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EksClusterTimeouts(**timeouts)
        self._values = {
            "name": name,
            "role_arn": role_arn,
            "vpc_config": vpc_config,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled_cluster_log_types is not None:
            self._values["enabled_cluster_log_types"] = enabled_cluster_log_types
        if encryption_config is not None:
            self._values["encryption_config"] = encryption_config
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def vpc_config(self) -> typing.List["EksClusterVpcConfig"]:
        """vpc_config block."""
        return self._values.get("vpc_config")

    @builtins.property
    def enabled_cluster_log_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("enabled_cluster_log_types")

    @builtins.property
    def encryption_config(
        self,
    ) -> typing.Optional[typing.List["EksClusterEncryptionConfig"]]:
        """encryption_config block."""
        return self._values.get("encryption_config")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["EksClusterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterEncryptionConfig",
    jsii_struct_bases=[],
    name_mapping={"provider": "provider", "resources": "resources"},
)
class EksClusterEncryptionConfig:
    def __init__(
        self,
        *,
        provider: typing.List["EksClusterEncryptionConfigProvider"],
        resources: typing.List[str],
    ) -> None:
        """
        :param provider: provider block.
        :param resources: 
        """
        self._values = {
            "provider": provider,
            "resources": resources,
        }

    @builtins.property
    def provider(self) -> typing.List["EksClusterEncryptionConfigProvider"]:
        """provider block."""
        return self._values.get("provider")

    @builtins.property
    def resources(self) -> typing.List[str]:
        return self._values.get("resources")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksClusterEncryptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterEncryptionConfigProvider",
    jsii_struct_bases=[],
    name_mapping={"key_arn": "keyArn"},
)
class EksClusterEncryptionConfigProvider:
    def __init__(self, *, key_arn: str) -> None:
        """
        :param key_arn: 
        """
        self._values = {
            "key_arn": key_arn,
        }

    @builtins.property
    def key_arn(self) -> str:
        return self._values.get("key_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksClusterEncryptionConfigProvider(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EksClusterIdentity(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterIdentity",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            EksClusterIdentity, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="oidc")
    def oidc(self) -> typing.Any:
        return jsii.get(self, "oidc")


class EksClusterIdentityOidc(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterIdentityOidc",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            EksClusterIdentityOidc,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="issuer")
    def issuer(self) -> str:
        return jsii.get(self, "issuer")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class EksClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksClusterVpcConfig",
    jsii_struct_bases=[],
    name_mapping={
        "subnet_ids": "subnetIds",
        "endpoint_private_access": "endpointPrivateAccess",
        "endpoint_public_access": "endpointPublicAccess",
        "public_access_cidrs": "publicAccessCidrs",
        "security_group_ids": "securityGroupIds",
    },
)
class EksClusterVpcConfig:
    def __init__(
        self,
        *,
        subnet_ids: typing.List[str],
        endpoint_private_access: typing.Optional[bool] = None,
        endpoint_public_access: typing.Optional[bool] = None,
        public_access_cidrs: typing.Optional[typing.List[str]] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param subnet_ids: 
        :param endpoint_private_access: 
        :param endpoint_public_access: 
        :param public_access_cidrs: 
        :param security_group_ids: 
        """
        self._values = {
            "subnet_ids": subnet_ids,
        }
        if endpoint_private_access is not None:
            self._values["endpoint_private_access"] = endpoint_private_access
        if endpoint_public_access is not None:
            self._values["endpoint_public_access"] = endpoint_public_access
        if public_access_cidrs is not None:
            self._values["public_access_cidrs"] = public_access_cidrs
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def endpoint_private_access(self) -> typing.Optional[bool]:
        return self._values.get("endpoint_private_access")

    @builtins.property
    def endpoint_public_access(self) -> typing.Optional[bool]:
        return self._values.get("endpoint_public_access")

    @builtins.property
    def public_access_cidrs(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("public_access_cidrs")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksClusterVpcConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EksFargateProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksFargateProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_name: str,
        fargate_profile_name: str,
        pod_execution_role_arn: str,
        selector: typing.List["EksFargateProfileSelector"],
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EksFargateProfileTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_name: 
        :param fargate_profile_name: 
        :param pod_execution_role_arn: 
        :param selector: selector block.
        :param subnet_ids: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EksFargateProfileConfig(
            cluster_name=cluster_name,
            fargate_profile_name=fargate_profile_name,
            pod_execution_role_arn=pod_execution_role_arn,
            selector=selector,
            subnet_ids=subnet_ids,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EksFargateProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter
    def cluster_name(self, value: str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property
    @jsii.member(jsii_name="fargateProfileName")
    def fargate_profile_name(self) -> str:
        return jsii.get(self, "fargateProfileName")

    @fargate_profile_name.setter
    def fargate_profile_name(self, value: str) -> None:
        jsii.set(self, "fargateProfileName", value)

    @builtins.property
    @jsii.member(jsii_name="podExecutionRoleArn")
    def pod_execution_role_arn(self) -> str:
        return jsii.get(self, "podExecutionRoleArn")

    @pod_execution_role_arn.setter
    def pod_execution_role_arn(self, value: str) -> None:
        jsii.set(self, "podExecutionRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="selector")
    def selector(self) -> typing.List["EksFargateProfileSelector"]:
        return jsii.get(self, "selector")

    @selector.setter
    def selector(self, value: typing.List["EksFargateProfileSelector"]) -> None:
        jsii.set(self, "selector", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EksFargateProfileTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["EksFargateProfileTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksFargateProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_name": "clusterName",
        "fargate_profile_name": "fargateProfileName",
        "pod_execution_role_arn": "podExecutionRoleArn",
        "selector": "selector",
        "subnet_ids": "subnetIds",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class EksFargateProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_name: str,
        fargate_profile_name: str,
        pod_execution_role_arn: str,
        selector: typing.List["EksFargateProfileSelector"],
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EksFargateProfileTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_name: 
        :param fargate_profile_name: 
        :param pod_execution_role_arn: 
        :param selector: selector block.
        :param subnet_ids: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EksFargateProfileTimeouts(**timeouts)
        self._values = {
            "cluster_name": cluster_name,
            "fargate_profile_name": fargate_profile_name,
            "pod_execution_role_arn": pod_execution_role_arn,
            "selector": selector,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_name(self) -> str:
        return self._values.get("cluster_name")

    @builtins.property
    def fargate_profile_name(self) -> str:
        return self._values.get("fargate_profile_name")

    @builtins.property
    def pod_execution_role_arn(self) -> str:
        return self._values.get("pod_execution_role_arn")

    @builtins.property
    def selector(self) -> typing.List["EksFargateProfileSelector"]:
        """selector block."""
        return self._values.get("selector")

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["EksFargateProfileTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksFargateProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksFargateProfileSelector",
    jsii_struct_bases=[],
    name_mapping={"namespace": "namespace", "labels": "labels"},
)
class EksFargateProfileSelector:
    def __init__(
        self,
        *,
        namespace: str,
        labels: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param namespace: 
        :param labels: 
        """
        self._values = {
            "namespace": namespace,
        }
        if labels is not None:
            self._values["labels"] = labels

    @builtins.property
    def namespace(self) -> str:
        return self._values.get("namespace")

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("labels")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksFargateProfileSelector(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksFargateProfileTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class EksFargateProfileTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksFargateProfileTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EksNodeGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksNodeGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_name: str,
        node_group_name: str,
        node_role_arn: str,
        scaling_config: typing.List["EksNodeGroupScalingConfig"],
        subnet_ids: typing.List[str],
        ami_type: typing.Optional[str] = None,
        disk_size: typing.Optional[jsii.Number] = None,
        force_update_version: typing.Optional[bool] = None,
        instance_types: typing.Optional[typing.List[str]] = None,
        labels: typing.Optional[typing.Mapping[str, str]] = None,
        release_version: typing.Optional[str] = None,
        remote_access: typing.Optional[typing.List["EksNodeGroupRemoteAccess"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EksNodeGroupTimeouts"] = None,
        version: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_name: 
        :param node_group_name: 
        :param node_role_arn: 
        :param scaling_config: scaling_config block.
        :param subnet_ids: 
        :param ami_type: 
        :param disk_size: 
        :param force_update_version: 
        :param instance_types: 
        :param labels: 
        :param release_version: 
        :param remote_access: remote_access block.
        :param tags: 
        :param timeouts: timeouts block.
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EksNodeGroupConfig(
            cluster_name=cluster_name,
            node_group_name=node_group_name,
            node_role_arn=node_role_arn,
            scaling_config=scaling_config,
            subnet_ids=subnet_ids,
            ami_type=ami_type,
            disk_size=disk_size,
            force_update_version=force_update_version,
            instance_types=instance_types,
            labels=labels,
            release_version=release_version,
            remote_access=remote_access,
            tags=tags,
            timeouts=timeouts,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EksNodeGroup, self, [scope, id, config])

    @jsii.member(jsii_name="resources")
    def resources(self, index: str) -> "EksNodeGroupResources":
        """
        :param index: -
        """
        return jsii.invoke(self, "resources", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter
    def cluster_name(self, value: str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property
    @jsii.member(jsii_name="nodeGroupName")
    def node_group_name(self) -> str:
        return jsii.get(self, "nodeGroupName")

    @node_group_name.setter
    def node_group_name(self, value: str) -> None:
        jsii.set(self, "nodeGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="nodeRoleArn")
    def node_role_arn(self) -> str:
        return jsii.get(self, "nodeRoleArn")

    @node_role_arn.setter
    def node_role_arn(self, value: str) -> None:
        jsii.set(self, "nodeRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="scalingConfig")
    def scaling_config(self) -> typing.List["EksNodeGroupScalingConfig"]:
        return jsii.get(self, "scalingConfig")

    @scaling_config.setter
    def scaling_config(self, value: typing.List["EksNodeGroupScalingConfig"]) -> None:
        jsii.set(self, "scalingConfig", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="amiType")
    def ami_type(self) -> typing.Optional[str]:
        return jsii.get(self, "amiType")

    @ami_type.setter
    def ami_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amiType", value)

    @builtins.property
    @jsii.member(jsii_name="diskSize")
    def disk_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "diskSize")

    @disk_size.setter
    def disk_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "diskSize", value)

    @builtins.property
    @jsii.member(jsii_name="forceUpdateVersion")
    def force_update_version(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceUpdateVersion")

    @force_update_version.setter
    def force_update_version(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceUpdateVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceTypes")
    def instance_types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "instanceTypes")

    @instance_types.setter
    def instance_types(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "instanceTypes", value)

    @builtins.property
    @jsii.member(jsii_name="labels")
    def labels(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "labels")

    @labels.setter
    def labels(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "labels", value)

    @builtins.property
    @jsii.member(jsii_name="releaseVersion")
    def release_version(self) -> typing.Optional[str]:
        return jsii.get(self, "releaseVersion")

    @release_version.setter
    def release_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "releaseVersion", value)

    @builtins.property
    @jsii.member(jsii_name="remoteAccess")
    def remote_access(self) -> typing.Optional[typing.List["EksNodeGroupRemoteAccess"]]:
        return jsii.get(self, "remoteAccess")

    @remote_access.setter
    def remote_access(
        self, value: typing.Optional[typing.List["EksNodeGroupRemoteAccess"]]
    ) -> None:
        jsii.set(self, "remoteAccess", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["EksNodeGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["EksNodeGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[str]:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksNodeGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_name": "clusterName",
        "node_group_name": "nodeGroupName",
        "node_role_arn": "nodeRoleArn",
        "scaling_config": "scalingConfig",
        "subnet_ids": "subnetIds",
        "ami_type": "amiType",
        "disk_size": "diskSize",
        "force_update_version": "forceUpdateVersion",
        "instance_types": "instanceTypes",
        "labels": "labels",
        "release_version": "releaseVersion",
        "remote_access": "remoteAccess",
        "tags": "tags",
        "timeouts": "timeouts",
        "version": "version",
    },
)
class EksNodeGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_name: str,
        node_group_name: str,
        node_role_arn: str,
        scaling_config: typing.List["EksNodeGroupScalingConfig"],
        subnet_ids: typing.List[str],
        ami_type: typing.Optional[str] = None,
        disk_size: typing.Optional[jsii.Number] = None,
        force_update_version: typing.Optional[bool] = None,
        instance_types: typing.Optional[typing.List[str]] = None,
        labels: typing.Optional[typing.Mapping[str, str]] = None,
        release_version: typing.Optional[str] = None,
        remote_access: typing.Optional[typing.List["EksNodeGroupRemoteAccess"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["EksNodeGroupTimeouts"] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_name: 
        :param node_group_name: 
        :param node_role_arn: 
        :param scaling_config: scaling_config block.
        :param subnet_ids: 
        :param ami_type: 
        :param disk_size: 
        :param force_update_version: 
        :param instance_types: 
        :param labels: 
        :param release_version: 
        :param remote_access: remote_access block.
        :param tags: 
        :param timeouts: timeouts block.
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = EksNodeGroupTimeouts(**timeouts)
        self._values = {
            "cluster_name": cluster_name,
            "node_group_name": node_group_name,
            "node_role_arn": node_role_arn,
            "scaling_config": scaling_config,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ami_type is not None:
            self._values["ami_type"] = ami_type
        if disk_size is not None:
            self._values["disk_size"] = disk_size
        if force_update_version is not None:
            self._values["force_update_version"] = force_update_version
        if instance_types is not None:
            self._values["instance_types"] = instance_types
        if labels is not None:
            self._values["labels"] = labels
        if release_version is not None:
            self._values["release_version"] = release_version
        if remote_access is not None:
            self._values["remote_access"] = remote_access
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_name(self) -> str:
        return self._values.get("cluster_name")

    @builtins.property
    def node_group_name(self) -> str:
        return self._values.get("node_group_name")

    @builtins.property
    def node_role_arn(self) -> str:
        return self._values.get("node_role_arn")

    @builtins.property
    def scaling_config(self) -> typing.List["EksNodeGroupScalingConfig"]:
        """scaling_config block."""
        return self._values.get("scaling_config")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def ami_type(self) -> typing.Optional[str]:
        return self._values.get("ami_type")

    @builtins.property
    def disk_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("disk_size")

    @builtins.property
    def force_update_version(self) -> typing.Optional[bool]:
        return self._values.get("force_update_version")

    @builtins.property
    def instance_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("instance_types")

    @builtins.property
    def labels(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("labels")

    @builtins.property
    def release_version(self) -> typing.Optional[str]:
        return self._values.get("release_version")

    @builtins.property
    def remote_access(self) -> typing.Optional[typing.List["EksNodeGroupRemoteAccess"]]:
        """remote_access block."""
        return self._values.get("remote_access")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["EksNodeGroupTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksNodeGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksNodeGroupRemoteAccess",
    jsii_struct_bases=[],
    name_mapping={
        "ec2_ssh_key": "ec2SshKey",
        "source_security_group_ids": "sourceSecurityGroupIds",
    },
)
class EksNodeGroupRemoteAccess:
    def __init__(
        self,
        *,
        ec2_ssh_key: typing.Optional[str] = None,
        source_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param ec2_ssh_key: 
        :param source_security_group_ids: 
        """
        self._values = {}
        if ec2_ssh_key is not None:
            self._values["ec2_ssh_key"] = ec2_ssh_key
        if source_security_group_ids is not None:
            self._values["source_security_group_ids"] = source_security_group_ids

    @builtins.property
    def ec2_ssh_key(self) -> typing.Optional[str]:
        return self._values.get("ec2_ssh_key")

    @builtins.property
    def source_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("source_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksNodeGroupRemoteAccess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EksNodeGroupResources(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksNodeGroupResources",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            EksNodeGroupResources,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="autoscalingGroups")
    def autoscaling_groups(self) -> typing.Any:
        return jsii.get(self, "autoscalingGroups")

    @builtins.property
    @jsii.member(jsii_name="remoteAccessSecurityGroupId")
    def remote_access_security_group_id(self) -> str:
        return jsii.get(self, "remoteAccessSecurityGroupId")


class EksNodeGroupResourcesAutoscalingGroups(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EksNodeGroupResourcesAutoscalingGroups",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            EksNodeGroupResourcesAutoscalingGroups,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksNodeGroupScalingConfig",
    jsii_struct_bases=[],
    name_mapping={
        "desired_size": "desiredSize",
        "max_size": "maxSize",
        "min_size": "minSize",
    },
)
class EksNodeGroupScalingConfig:
    def __init__(
        self, *, desired_size: jsii.Number, max_size: jsii.Number, min_size: jsii.Number
    ) -> None:
        """
        :param desired_size: 
        :param max_size: 
        :param min_size: 
        """
        self._values = {
            "desired_size": desired_size,
            "max_size": max_size,
            "min_size": min_size,
        }

    @builtins.property
    def desired_size(self) -> jsii.Number:
        return self._values.get("desired_size")

    @builtins.property
    def max_size(self) -> jsii.Number:
        return self._values.get("max_size")

    @builtins.property
    def min_size(self) -> jsii.Number:
        return self._values.get("min_size")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksNodeGroupScalingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EksNodeGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class EksNodeGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EksNodeGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticBeanstalkApplication(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkApplication",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        appversion_lifecycle: typing.Optional[
            typing.List["ElasticBeanstalkApplicationAppversionLifecycle"]
        ] = None,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param appversion_lifecycle: appversion_lifecycle block.
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticBeanstalkApplicationConfig(
            name=name,
            appversion_lifecycle=appversion_lifecycle,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticBeanstalkApplication, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="appversionLifecycle")
    def appversion_lifecycle(
        self,
    ) -> typing.Optional[typing.List["ElasticBeanstalkApplicationAppversionLifecycle"]]:
        return jsii.get(self, "appversionLifecycle")

    @appversion_lifecycle.setter
    def appversion_lifecycle(
        self,
        value: typing.Optional[
            typing.List["ElasticBeanstalkApplicationAppversionLifecycle"]
        ],
    ) -> None:
        jsii.set(self, "appversionLifecycle", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkApplicationAppversionLifecycle",
    jsii_struct_bases=[],
    name_mapping={
        "service_role": "serviceRole",
        "delete_source_from_s3": "deleteSourceFromS3",
        "max_age_in_days": "maxAgeInDays",
        "max_count": "maxCount",
    },
)
class ElasticBeanstalkApplicationAppversionLifecycle:
    def __init__(
        self,
        *,
        service_role: str,
        delete_source_from_s3: typing.Optional[bool] = None,
        max_age_in_days: typing.Optional[jsii.Number] = None,
        max_count: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param service_role: 
        :param delete_source_from_s3: 
        :param max_age_in_days: 
        :param max_count: 
        """
        self._values = {
            "service_role": service_role,
        }
        if delete_source_from_s3 is not None:
            self._values["delete_source_from_s3"] = delete_source_from_s3
        if max_age_in_days is not None:
            self._values["max_age_in_days"] = max_age_in_days
        if max_count is not None:
            self._values["max_count"] = max_count

    @builtins.property
    def service_role(self) -> str:
        return self._values.get("service_role")

    @builtins.property
    def delete_source_from_s3(self) -> typing.Optional[bool]:
        return self._values.get("delete_source_from_s3")

    @builtins.property
    def max_age_in_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_age_in_days")

    @builtins.property
    def max_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticBeanstalkApplicationAppversionLifecycle(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkApplicationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "appversion_lifecycle": "appversionLifecycle",
        "description": "description",
        "tags": "tags",
    },
)
class ElasticBeanstalkApplicationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        appversion_lifecycle: typing.Optional[
            typing.List["ElasticBeanstalkApplicationAppversionLifecycle"]
        ] = None,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param appversion_lifecycle: appversion_lifecycle block.
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if appversion_lifecycle is not None:
            self._values["appversion_lifecycle"] = appversion_lifecycle
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def appversion_lifecycle(
        self,
    ) -> typing.Optional[typing.List["ElasticBeanstalkApplicationAppversionLifecycle"]]:
        """appversion_lifecycle block."""
        return self._values.get("appversion_lifecycle")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticBeanstalkApplicationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticBeanstalkApplicationVersion(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkApplicationVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application: str,
        bucket: str,
        key: str,
        name: str,
        description: typing.Optional[str] = None,
        force_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application: 
        :param bucket: 
        :param key: 
        :param name: 
        :param description: 
        :param force_delete: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticBeanstalkApplicationVersionConfig(
            application=application,
            bucket=bucket,
            key=key,
            name=name,
            description=description,
            force_delete=force_delete,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticBeanstalkApplicationVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="application")
    def application(self) -> str:
        return jsii.get(self, "application")

    @application.setter
    def application(self, value: str) -> None:
        jsii.set(self, "application", value)

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="key")
    def key(self) -> str:
        return jsii.get(self, "key")

    @key.setter
    def key(self, value: str) -> None:
        jsii.set(self, "key", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="forceDelete")
    def force_delete(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDelete")

    @force_delete.setter
    def force_delete(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDelete", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkApplicationVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application": "application",
        "bucket": "bucket",
        "key": "key",
        "name": "name",
        "description": "description",
        "force_delete": "forceDelete",
        "tags": "tags",
    },
)
class ElasticBeanstalkApplicationVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application: str,
        bucket: str,
        key: str,
        name: str,
        description: typing.Optional[str] = None,
        force_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application: 
        :param bucket: 
        :param key: 
        :param name: 
        :param description: 
        :param force_delete: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application": application,
            "bucket": bucket,
            "key": key,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if force_delete is not None:
            self._values["force_delete"] = force_delete
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application(self) -> str:
        return self._values.get("application")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def force_delete(self) -> typing.Optional[bool]:
        return self._values.get("force_delete")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticBeanstalkApplicationVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticBeanstalkConfigurationTemplate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkConfigurationTemplate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application: str,
        name: str,
        description: typing.Optional[str] = None,
        environment_id: typing.Optional[str] = None,
        setting: typing.Optional[
            typing.List["ElasticBeanstalkConfigurationTemplateSetting"]
        ] = None,
        solution_stack_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application: 
        :param name: 
        :param description: 
        :param environment_id: 
        :param setting: setting block.
        :param solution_stack_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticBeanstalkConfigurationTemplateConfig(
            application=application,
            name=name,
            description=description,
            environment_id=environment_id,
            setting=setting,
            solution_stack_name=solution_stack_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticBeanstalkConfigurationTemplate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="application")
    def application(self) -> str:
        return jsii.get(self, "application")

    @application.setter
    def application(self, value: str) -> None:
        jsii.set(self, "application", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="environmentId")
    def environment_id(self) -> typing.Optional[str]:
        return jsii.get(self, "environmentId")

    @environment_id.setter
    def environment_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "environmentId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="setting")
    def setting(
        self,
    ) -> typing.Optional[typing.List["ElasticBeanstalkConfigurationTemplateSetting"]]:
        return jsii.get(self, "setting")

    @setting.setter
    def setting(
        self,
        value: typing.Optional[
            typing.List["ElasticBeanstalkConfigurationTemplateSetting"]
        ],
    ) -> None:
        jsii.set(self, "setting", value)

    @builtins.property
    @jsii.member(jsii_name="solutionStackName")
    def solution_stack_name(self) -> typing.Optional[str]:
        return jsii.get(self, "solutionStackName")

    @solution_stack_name.setter
    def solution_stack_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "solutionStackName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkConfigurationTemplateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application": "application",
        "name": "name",
        "description": "description",
        "environment_id": "environmentId",
        "setting": "setting",
        "solution_stack_name": "solutionStackName",
    },
)
class ElasticBeanstalkConfigurationTemplateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application: str,
        name: str,
        description: typing.Optional[str] = None,
        environment_id: typing.Optional[str] = None,
        setting: typing.Optional[
            typing.List["ElasticBeanstalkConfigurationTemplateSetting"]
        ] = None,
        solution_stack_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application: 
        :param name: 
        :param description: 
        :param environment_id: 
        :param setting: setting block.
        :param solution_stack_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application": application,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if environment_id is not None:
            self._values["environment_id"] = environment_id
        if setting is not None:
            self._values["setting"] = setting
        if solution_stack_name is not None:
            self._values["solution_stack_name"] = solution_stack_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application(self) -> str:
        return self._values.get("application")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def environment_id(self) -> typing.Optional[str]:
        return self._values.get("environment_id")

    @builtins.property
    def setting(
        self,
    ) -> typing.Optional[typing.List["ElasticBeanstalkConfigurationTemplateSetting"]]:
        """setting block."""
        return self._values.get("setting")

    @builtins.property
    def solution_stack_name(self) -> typing.Optional[str]:
        return self._values.get("solution_stack_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticBeanstalkConfigurationTemplateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkConfigurationTemplateSetting",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "namespace": "namespace",
        "value": "value",
        "resource": "resource",
    },
)
class ElasticBeanstalkConfigurationTemplateSetting:
    def __init__(
        self,
        *,
        name: str,
        namespace: str,
        value: str,
        resource: typing.Optional[str] = None,
    ) -> None:
        """
        :param name: 
        :param namespace: 
        :param value: 
        :param resource: 
        """
        self._values = {
            "name": name,
            "namespace": namespace,
            "value": value,
        }
        if resource is not None:
            self._values["resource"] = resource

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def namespace(self) -> str:
        return self._values.get("namespace")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def resource(self) -> typing.Optional[str]:
        return self._values.get("resource")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticBeanstalkConfigurationTemplateSetting(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticBeanstalkEnvironment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkEnvironment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application: str,
        name: str,
        cname_prefix: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        platform_arn: typing.Optional[str] = None,
        poll_interval: typing.Optional[str] = None,
        setting: typing.Optional[
            typing.List["ElasticBeanstalkEnvironmentSetting"]
        ] = None,
        solution_stack_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        template_name: typing.Optional[str] = None,
        tier: typing.Optional[str] = None,
        version_label: typing.Optional[str] = None,
        wait_for_ready_timeout: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application: 
        :param name: 
        :param cname_prefix: 
        :param description: 
        :param platform_arn: 
        :param poll_interval: 
        :param setting: setting block.
        :param solution_stack_name: 
        :param tags: 
        :param template_name: 
        :param tier: 
        :param version_label: 
        :param wait_for_ready_timeout: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticBeanstalkEnvironmentConfig(
            application=application,
            name=name,
            cname_prefix=cname_prefix,
            description=description,
            platform_arn=platform_arn,
            poll_interval=poll_interval,
            setting=setting,
            solution_stack_name=solution_stack_name,
            tags=tags,
            template_name=template_name,
            tier=tier,
            version_label=version_label,
            wait_for_ready_timeout=wait_for_ready_timeout,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticBeanstalkEnvironment, self, [scope, id, config])

    @jsii.member(jsii_name="allSettings")
    def all_settings(self, index: str) -> "ElasticBeanstalkEnvironmentAllSettings":
        """
        :param index: -
        """
        return jsii.invoke(self, "allSettings", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="autoscalingGroups")
    def autoscaling_groups(self) -> typing.List[str]:
        return jsii.get(self, "autoscalingGroups")

    @builtins.property
    @jsii.member(jsii_name="cname")
    def cname(self) -> str:
        return jsii.get(self, "cname")

    @builtins.property
    @jsii.member(jsii_name="endpointUrl")
    def endpoint_url(self) -> str:
        return jsii.get(self, "endpointUrl")

    @builtins.property
    @jsii.member(jsii_name="instances")
    def instances(self) -> typing.List[str]:
        return jsii.get(self, "instances")

    @builtins.property
    @jsii.member(jsii_name="launchConfigurations")
    def launch_configurations(self) -> typing.List[str]:
        return jsii.get(self, "launchConfigurations")

    @builtins.property
    @jsii.member(jsii_name="loadBalancers")
    def load_balancers(self) -> typing.List[str]:
        return jsii.get(self, "loadBalancers")

    @builtins.property
    @jsii.member(jsii_name="queues")
    def queues(self) -> typing.List[str]:
        return jsii.get(self, "queues")

    @builtins.property
    @jsii.member(jsii_name="triggers")
    def triggers(self) -> typing.List[str]:
        return jsii.get(self, "triggers")

    @builtins.property
    @jsii.member(jsii_name="application")
    def application(self) -> str:
        return jsii.get(self, "application")

    @application.setter
    def application(self, value: str) -> None:
        jsii.set(self, "application", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="cnamePrefix")
    def cname_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "cnamePrefix")

    @cname_prefix.setter
    def cname_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cnamePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="platformArn")
    def platform_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "platformArn")

    @platform_arn.setter
    def platform_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "platformArn", value)

    @builtins.property
    @jsii.member(jsii_name="pollInterval")
    def poll_interval(self) -> typing.Optional[str]:
        return jsii.get(self, "pollInterval")

    @poll_interval.setter
    def poll_interval(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "pollInterval", value)

    @builtins.property
    @jsii.member(jsii_name="setting")
    def setting(
        self,
    ) -> typing.Optional[typing.List["ElasticBeanstalkEnvironmentSetting"]]:
        return jsii.get(self, "setting")

    @setting.setter
    def setting(
        self, value: typing.Optional[typing.List["ElasticBeanstalkEnvironmentSetting"]]
    ) -> None:
        jsii.set(self, "setting", value)

    @builtins.property
    @jsii.member(jsii_name="solutionStackName")
    def solution_stack_name(self) -> typing.Optional[str]:
        return jsii.get(self, "solutionStackName")

    @solution_stack_name.setter
    def solution_stack_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "solutionStackName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="templateName")
    def template_name(self) -> typing.Optional[str]:
        return jsii.get(self, "templateName")

    @template_name.setter
    def template_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "templateName", value)

    @builtins.property
    @jsii.member(jsii_name="tier")
    def tier(self) -> typing.Optional[str]:
        return jsii.get(self, "tier")

    @tier.setter
    def tier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tier", value)

    @builtins.property
    @jsii.member(jsii_name="versionLabel")
    def version_label(self) -> typing.Optional[str]:
        return jsii.get(self, "versionLabel")

    @version_label.setter
    def version_label(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "versionLabel", value)

    @builtins.property
    @jsii.member(jsii_name="waitForReadyTimeout")
    def wait_for_ready_timeout(self) -> typing.Optional[str]:
        return jsii.get(self, "waitForReadyTimeout")

    @wait_for_ready_timeout.setter
    def wait_for_ready_timeout(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "waitForReadyTimeout", value)


class ElasticBeanstalkEnvironmentAllSettings(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkEnvironmentAllSettings",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            ElasticBeanstalkEnvironmentAllSettings,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="namespace")
    def namespace(self) -> str:
        return jsii.get(self, "namespace")

    @builtins.property
    @jsii.member(jsii_name="resource")
    def resource(self) -> str:
        return jsii.get(self, "resource")

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkEnvironmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application": "application",
        "name": "name",
        "cname_prefix": "cnamePrefix",
        "description": "description",
        "platform_arn": "platformArn",
        "poll_interval": "pollInterval",
        "setting": "setting",
        "solution_stack_name": "solutionStackName",
        "tags": "tags",
        "template_name": "templateName",
        "tier": "tier",
        "version_label": "versionLabel",
        "wait_for_ready_timeout": "waitForReadyTimeout",
    },
)
class ElasticBeanstalkEnvironmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application: str,
        name: str,
        cname_prefix: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        platform_arn: typing.Optional[str] = None,
        poll_interval: typing.Optional[str] = None,
        setting: typing.Optional[
            typing.List["ElasticBeanstalkEnvironmentSetting"]
        ] = None,
        solution_stack_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        template_name: typing.Optional[str] = None,
        tier: typing.Optional[str] = None,
        version_label: typing.Optional[str] = None,
        wait_for_ready_timeout: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application: 
        :param name: 
        :param cname_prefix: 
        :param description: 
        :param platform_arn: 
        :param poll_interval: 
        :param setting: setting block.
        :param solution_stack_name: 
        :param tags: 
        :param template_name: 
        :param tier: 
        :param version_label: 
        :param wait_for_ready_timeout: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application": application,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cname_prefix is not None:
            self._values["cname_prefix"] = cname_prefix
        if description is not None:
            self._values["description"] = description
        if platform_arn is not None:
            self._values["platform_arn"] = platform_arn
        if poll_interval is not None:
            self._values["poll_interval"] = poll_interval
        if setting is not None:
            self._values["setting"] = setting
        if solution_stack_name is not None:
            self._values["solution_stack_name"] = solution_stack_name
        if tags is not None:
            self._values["tags"] = tags
        if template_name is not None:
            self._values["template_name"] = template_name
        if tier is not None:
            self._values["tier"] = tier
        if version_label is not None:
            self._values["version_label"] = version_label
        if wait_for_ready_timeout is not None:
            self._values["wait_for_ready_timeout"] = wait_for_ready_timeout

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application(self) -> str:
        return self._values.get("application")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def cname_prefix(self) -> typing.Optional[str]:
        return self._values.get("cname_prefix")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def platform_arn(self) -> typing.Optional[str]:
        return self._values.get("platform_arn")

    @builtins.property
    def poll_interval(self) -> typing.Optional[str]:
        return self._values.get("poll_interval")

    @builtins.property
    def setting(
        self,
    ) -> typing.Optional[typing.List["ElasticBeanstalkEnvironmentSetting"]]:
        """setting block."""
        return self._values.get("setting")

    @builtins.property
    def solution_stack_name(self) -> typing.Optional[str]:
        return self._values.get("solution_stack_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def template_name(self) -> typing.Optional[str]:
        return self._values.get("template_name")

    @builtins.property
    def tier(self) -> typing.Optional[str]:
        return self._values.get("tier")

    @builtins.property
    def version_label(self) -> typing.Optional[str]:
        return self._values.get("version_label")

    @builtins.property
    def wait_for_ready_timeout(self) -> typing.Optional[str]:
        return self._values.get("wait_for_ready_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticBeanstalkEnvironmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticBeanstalkEnvironmentSetting",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "namespace": "namespace",
        "value": "value",
        "resource": "resource",
    },
)
class ElasticBeanstalkEnvironmentSetting:
    def __init__(
        self,
        *,
        name: str,
        namespace: str,
        value: str,
        resource: typing.Optional[str] = None,
    ) -> None:
        """
        :param name: 
        :param namespace: 
        :param value: 
        :param resource: 
        """
        self._values = {
            "name": name,
            "namespace": namespace,
            "value": value,
        }
        if resource is not None:
            self._values["resource"] = resource

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def namespace(self) -> str:
        return self._values.get("namespace")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def resource(self) -> typing.Optional[str]:
        return self._values.get("resource")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticBeanstalkEnvironmentSetting(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticacheCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_id: str,
        apply_immediately: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        az_mode: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        node_type: typing.Optional[str] = None,
        notification_topic_arn: typing.Optional[str] = None,
        num_cache_nodes: typing.Optional[jsii.Number] = None,
        parameter_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_availability_zones: typing.Optional[typing.List[str]] = None,
        replication_group_id: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        snapshot_arns: typing.Optional[typing.List[str]] = None,
        snapshot_name: typing.Optional[str] = None,
        snapshot_retention_limit: typing.Optional[jsii.Number] = None,
        snapshot_window: typing.Optional[str] = None,
        subnet_group_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_id: 
        :param apply_immediately: 
        :param availability_zone: 
        :param availability_zones: 
        :param az_mode: 
        :param engine: 
        :param engine_version: 
        :param maintenance_window: 
        :param node_type: 
        :param notification_topic_arn: 
        :param num_cache_nodes: 
        :param parameter_group_name: 
        :param port: 
        :param preferred_availability_zones: 
        :param replication_group_id: 
        :param security_group_ids: 
        :param security_group_names: 
        :param snapshot_arns: 
        :param snapshot_name: 
        :param snapshot_retention_limit: 
        :param snapshot_window: 
        :param subnet_group_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticacheClusterConfig(
            cluster_id=cluster_id,
            apply_immediately=apply_immediately,
            availability_zone=availability_zone,
            availability_zones=availability_zones,
            az_mode=az_mode,
            engine=engine,
            engine_version=engine_version,
            maintenance_window=maintenance_window,
            node_type=node_type,
            notification_topic_arn=notification_topic_arn,
            num_cache_nodes=num_cache_nodes,
            parameter_group_name=parameter_group_name,
            port=port,
            preferred_availability_zones=preferred_availability_zones,
            replication_group_id=replication_group_id,
            security_group_ids=security_group_ids,
            security_group_names=security_group_names,
            snapshot_arns=snapshot_arns,
            snapshot_name=snapshot_name,
            snapshot_retention_limit=snapshot_retention_limit,
            snapshot_window=snapshot_window,
            subnet_group_name=subnet_group_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticacheCluster, self, [scope, id, config])

    @jsii.member(jsii_name="cacheNodes")
    def cache_nodes(self, index: str) -> "ElasticacheClusterCacheNodes":
        """
        :param index: -
        """
        return jsii.invoke(self, "cacheNodes", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="clusterAddress")
    def cluster_address(self) -> str:
        return jsii.get(self, "clusterAddress")

    @builtins.property
    @jsii.member(jsii_name="configurationEndpoint")
    def configuration_endpoint(self) -> str:
        return jsii.get(self, "configurationEndpoint")

    @builtins.property
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> str:
        return jsii.get(self, "clusterId")

    @cluster_id.setter
    def cluster_id(self, value: str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="azMode")
    def az_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "azMode")

    @az_mode.setter
    def az_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "azMode", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "maintenanceWindow")

    @maintenance_window.setter
    def maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> typing.Optional[str]:
        return jsii.get(self, "nodeType")

    @node_type.setter
    def node_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "nodeType", value)

    @builtins.property
    @jsii.member(jsii_name="notificationTopicArn")
    def notification_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "notificationTopicArn")

    @notification_topic_arn.setter
    def notification_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "notificationTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="numCacheNodes")
    def num_cache_nodes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "numCacheNodes")

    @num_cache_nodes.setter
    def num_cache_nodes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "numCacheNodes", value)

    @builtins.property
    @jsii.member(jsii_name="parameterGroupName")
    def parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "parameterGroupName")

    @parameter_group_name.setter
    def parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "parameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="preferredAvailabilityZones")
    def preferred_availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "preferredAvailabilityZones")

    @preferred_availability_zones.setter
    def preferred_availability_zones(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "preferredAvailabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="replicationGroupId")
    def replication_group_id(self) -> typing.Optional[str]:
        return jsii.get(self, "replicationGroupId")

    @replication_group_id.setter
    def replication_group_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "replicationGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupNames")
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupNames")

    @security_group_names.setter
    def security_group_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupNames", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotArns")
    def snapshot_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "snapshotArns")

    @snapshot_arns.setter
    def snapshot_arns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "snapshotArns", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotName")
    def snapshot_name(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotName")

    @snapshot_name.setter
    def snapshot_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotName", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotRetentionLimit")
    def snapshot_retention_limit(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "snapshotRetentionLimit")

    @snapshot_retention_limit.setter
    def snapshot_retention_limit(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "snapshotRetentionLimit", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotWindow")
    def snapshot_window(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotWindow")

    @snapshot_window.setter
    def snapshot_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotWindow", value)

    @builtins.property
    @jsii.member(jsii_name="subnetGroupName")
    def subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetGroupName")

    @subnet_group_name.setter
    def subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class ElasticacheClusterCacheNodes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheClusterCacheNodes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            ElasticacheClusterCacheNodes,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="address")
    def address(self) -> str:
        return jsii.get(self, "address")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "apply_immediately": "applyImmediately",
        "availability_zone": "availabilityZone",
        "availability_zones": "availabilityZones",
        "az_mode": "azMode",
        "engine": "engine",
        "engine_version": "engineVersion",
        "maintenance_window": "maintenanceWindow",
        "node_type": "nodeType",
        "notification_topic_arn": "notificationTopicArn",
        "num_cache_nodes": "numCacheNodes",
        "parameter_group_name": "parameterGroupName",
        "port": "port",
        "preferred_availability_zones": "preferredAvailabilityZones",
        "replication_group_id": "replicationGroupId",
        "security_group_ids": "securityGroupIds",
        "security_group_names": "securityGroupNames",
        "snapshot_arns": "snapshotArns",
        "snapshot_name": "snapshotName",
        "snapshot_retention_limit": "snapshotRetentionLimit",
        "snapshot_window": "snapshotWindow",
        "subnet_group_name": "subnetGroupName",
        "tags": "tags",
    },
)
class ElasticacheClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: str,
        apply_immediately: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        az_mode: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        node_type: typing.Optional[str] = None,
        notification_topic_arn: typing.Optional[str] = None,
        num_cache_nodes: typing.Optional[jsii.Number] = None,
        parameter_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_availability_zones: typing.Optional[typing.List[str]] = None,
        replication_group_id: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        snapshot_arns: typing.Optional[typing.List[str]] = None,
        snapshot_name: typing.Optional[str] = None,
        snapshot_retention_limit: typing.Optional[jsii.Number] = None,
        snapshot_window: typing.Optional[str] = None,
        subnet_group_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: 
        :param apply_immediately: 
        :param availability_zone: 
        :param availability_zones: 
        :param az_mode: 
        :param engine: 
        :param engine_version: 
        :param maintenance_window: 
        :param node_type: 
        :param notification_topic_arn: 
        :param num_cache_nodes: 
        :param parameter_group_name: 
        :param port: 
        :param preferred_availability_zones: 
        :param replication_group_id: 
        :param security_group_ids: 
        :param security_group_names: 
        :param snapshot_arns: 
        :param snapshot_name: 
        :param snapshot_retention_limit: 
        :param snapshot_window: 
        :param subnet_group_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_id": cluster_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if az_mode is not None:
            self._values["az_mode"] = az_mode
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if node_type is not None:
            self._values["node_type"] = node_type
        if notification_topic_arn is not None:
            self._values["notification_topic_arn"] = notification_topic_arn
        if num_cache_nodes is not None:
            self._values["num_cache_nodes"] = num_cache_nodes
        if parameter_group_name is not None:
            self._values["parameter_group_name"] = parameter_group_name
        if port is not None:
            self._values["port"] = port
        if preferred_availability_zones is not None:
            self._values["preferred_availability_zones"] = preferred_availability_zones
        if replication_group_id is not None:
            self._values["replication_group_id"] = replication_group_id
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if security_group_names is not None:
            self._values["security_group_names"] = security_group_names
        if snapshot_arns is not None:
            self._values["snapshot_arns"] = snapshot_arns
        if snapshot_name is not None:
            self._values["snapshot_name"] = snapshot_name
        if snapshot_retention_limit is not None:
            self._values["snapshot_retention_limit"] = snapshot_retention_limit
        if snapshot_window is not None:
            self._values["snapshot_window"] = snapshot_window
        if subnet_group_name is not None:
            self._values["subnet_group_name"] = subnet_group_name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_id(self) -> str:
        return self._values.get("cluster_id")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def az_mode(self) -> typing.Optional[str]:
        return self._values.get("az_mode")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("maintenance_window")

    @builtins.property
    def node_type(self) -> typing.Optional[str]:
        return self._values.get("node_type")

    @builtins.property
    def notification_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("notification_topic_arn")

    @builtins.property
    def num_cache_nodes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("num_cache_nodes")

    @builtins.property
    def parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("parameter_group_name")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def preferred_availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("preferred_availability_zones")

    @builtins.property
    def replication_group_id(self) -> typing.Optional[str]:
        return self._values.get("replication_group_id")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_names")

    @builtins.property
    def snapshot_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("snapshot_arns")

    @builtins.property
    def snapshot_name(self) -> typing.Optional[str]:
        return self._values.get("snapshot_name")

    @builtins.property
    def snapshot_retention_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("snapshot_retention_limit")

    @builtins.property
    def snapshot_window(self) -> typing.Optional[str]:
        return self._values.get("snapshot_window")

    @builtins.property
    def subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("subnet_group_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticacheParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        family: str,
        name: str,
        description: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["ElasticacheParameterGroupParameter"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param family: 
        :param name: 
        :param description: 
        :param parameter: parameter block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticacheParameterGroupConfig(
            family=family,
            name=name,
            description=description,
            parameter=parameter,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticacheParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parameter")
    def parameter(
        self,
    ) -> typing.Optional[typing.List["ElasticacheParameterGroupParameter"]]:
        return jsii.get(self, "parameter")

    @parameter.setter
    def parameter(
        self, value: typing.Optional[typing.List["ElasticacheParameterGroupParameter"]]
    ) -> None:
        jsii.set(self, "parameter", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "name": "name",
        "description": "description",
        "parameter": "parameter",
    },
)
class ElasticacheParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: str,
        name: str,
        description: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["ElasticacheParameterGroupParameter"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: 
        :param name: 
        :param description: 
        :param parameter: parameter block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "family": family,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if parameter is not None:
            self._values["parameter"] = parameter

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[typing.List["ElasticacheParameterGroupParameter"]]:
        """parameter block."""
        return self._values.get("parameter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheParameterGroupParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class ElasticacheParameterGroupParameter:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheParameterGroupParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticacheReplicationGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheReplicationGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        replication_group_description: str,
        replication_group_id: str,
        apply_immediately: typing.Optional[bool] = None,
        at_rest_encryption_enabled: typing.Optional[bool] = None,
        auth_token: typing.Optional[str] = None,
        automatic_failover_enabled: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        cluster_mode: typing.Optional[
            typing.List["ElasticacheReplicationGroupClusterMode"]
        ] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        node_type: typing.Optional[str] = None,
        notification_topic_arn: typing.Optional[str] = None,
        number_cache_clusters: typing.Optional[jsii.Number] = None,
        parameter_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        snapshot_arns: typing.Optional[typing.List[str]] = None,
        snapshot_name: typing.Optional[str] = None,
        snapshot_retention_limit: typing.Optional[jsii.Number] = None,
        snapshot_window: typing.Optional[str] = None,
        subnet_group_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["ElasticacheReplicationGroupTimeouts"] = None,
        transit_encryption_enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param replication_group_description: 
        :param replication_group_id: 
        :param apply_immediately: 
        :param at_rest_encryption_enabled: 
        :param auth_token: 
        :param automatic_failover_enabled: 
        :param auto_minor_version_upgrade: 
        :param availability_zones: 
        :param cluster_mode: cluster_mode block.
        :param engine: 
        :param engine_version: 
        :param kms_key_id: 
        :param maintenance_window: 
        :param node_type: 
        :param notification_topic_arn: 
        :param number_cache_clusters: 
        :param parameter_group_name: 
        :param port: 
        :param security_group_ids: 
        :param security_group_names: 
        :param snapshot_arns: 
        :param snapshot_name: 
        :param snapshot_retention_limit: 
        :param snapshot_window: 
        :param subnet_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param transit_encryption_enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticacheReplicationGroupConfig(
            replication_group_description=replication_group_description,
            replication_group_id=replication_group_id,
            apply_immediately=apply_immediately,
            at_rest_encryption_enabled=at_rest_encryption_enabled,
            auth_token=auth_token,
            automatic_failover_enabled=automatic_failover_enabled,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
            availability_zones=availability_zones,
            cluster_mode=cluster_mode,
            engine=engine,
            engine_version=engine_version,
            kms_key_id=kms_key_id,
            maintenance_window=maintenance_window,
            node_type=node_type,
            notification_topic_arn=notification_topic_arn,
            number_cache_clusters=number_cache_clusters,
            parameter_group_name=parameter_group_name,
            port=port,
            security_group_ids=security_group_ids,
            security_group_names=security_group_names,
            snapshot_arns=snapshot_arns,
            snapshot_name=snapshot_name,
            snapshot_retention_limit=snapshot_retention_limit,
            snapshot_window=snapshot_window,
            subnet_group_name=subnet_group_name,
            tags=tags,
            timeouts=timeouts,
            transit_encryption_enabled=transit_encryption_enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticacheReplicationGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="configurationEndpointAddress")
    def configuration_endpoint_address(self) -> str:
        return jsii.get(self, "configurationEndpointAddress")

    @builtins.property
    @jsii.member(jsii_name="memberClusters")
    def member_clusters(self) -> typing.List[str]:
        return jsii.get(self, "memberClusters")

    @builtins.property
    @jsii.member(jsii_name="primaryEndpointAddress")
    def primary_endpoint_address(self) -> str:
        return jsii.get(self, "primaryEndpointAddress")

    @builtins.property
    @jsii.member(jsii_name="replicationGroupDescription")
    def replication_group_description(self) -> str:
        return jsii.get(self, "replicationGroupDescription")

    @replication_group_description.setter
    def replication_group_description(self, value: str) -> None:
        jsii.set(self, "replicationGroupDescription", value)

    @builtins.property
    @jsii.member(jsii_name="replicationGroupId")
    def replication_group_id(self) -> str:
        return jsii.get(self, "replicationGroupId")

    @replication_group_id.setter
    def replication_group_id(self, value: str) -> None:
        jsii.set(self, "replicationGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="atRestEncryptionEnabled")
    def at_rest_encryption_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "atRestEncryptionEnabled")

    @at_rest_encryption_enabled.setter
    def at_rest_encryption_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "atRestEncryptionEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="authToken")
    def auth_token(self) -> typing.Optional[str]:
        return jsii.get(self, "authToken")

    @auth_token.setter
    def auth_token(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authToken", value)

    @builtins.property
    @jsii.member(jsii_name="automaticFailoverEnabled")
    def automatic_failover_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "automaticFailoverEnabled")

    @automatic_failover_enabled.setter
    def automatic_failover_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "automaticFailoverEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoMinorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="clusterMode")
    def cluster_mode(
        self,
    ) -> typing.Optional[typing.List["ElasticacheReplicationGroupClusterMode"]]:
        return jsii.get(self, "clusterMode")

    @cluster_mode.setter
    def cluster_mode(
        self,
        value: typing.Optional[typing.List["ElasticacheReplicationGroupClusterMode"]],
    ) -> None:
        jsii.set(self, "clusterMode", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="maintenanceWindow")
    def maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "maintenanceWindow")

    @maintenance_window.setter
    def maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> typing.Optional[str]:
        return jsii.get(self, "nodeType")

    @node_type.setter
    def node_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "nodeType", value)

    @builtins.property
    @jsii.member(jsii_name="notificationTopicArn")
    def notification_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "notificationTopicArn")

    @notification_topic_arn.setter
    def notification_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "notificationTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="numberCacheClusters")
    def number_cache_clusters(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "numberCacheClusters")

    @number_cache_clusters.setter
    def number_cache_clusters(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "numberCacheClusters", value)

    @builtins.property
    @jsii.member(jsii_name="parameterGroupName")
    def parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "parameterGroupName")

    @parameter_group_name.setter
    def parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "parameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupNames")
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupNames")

    @security_group_names.setter
    def security_group_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupNames", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotArns")
    def snapshot_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "snapshotArns")

    @snapshot_arns.setter
    def snapshot_arns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "snapshotArns", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotName")
    def snapshot_name(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotName")

    @snapshot_name.setter
    def snapshot_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotName", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotRetentionLimit")
    def snapshot_retention_limit(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "snapshotRetentionLimit")

    @snapshot_retention_limit.setter
    def snapshot_retention_limit(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "snapshotRetentionLimit", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotWindow")
    def snapshot_window(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotWindow")

    @snapshot_window.setter
    def snapshot_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotWindow", value)

    @builtins.property
    @jsii.member(jsii_name="subnetGroupName")
    def subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetGroupName")

    @subnet_group_name.setter
    def subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ElasticacheReplicationGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["ElasticacheReplicationGroupTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="transitEncryptionEnabled")
    def transit_encryption_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "transitEncryptionEnabled")

    @transit_encryption_enabled.setter
    def transit_encryption_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "transitEncryptionEnabled", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheReplicationGroupClusterMode",
    jsii_struct_bases=[],
    name_mapping={
        "num_node_groups": "numNodeGroups",
        "replicas_per_node_group": "replicasPerNodeGroup",
    },
)
class ElasticacheReplicationGroupClusterMode:
    def __init__(
        self, *, num_node_groups: jsii.Number, replicas_per_node_group: jsii.Number
    ) -> None:
        """
        :param num_node_groups: 
        :param replicas_per_node_group: 
        """
        self._values = {
            "num_node_groups": num_node_groups,
            "replicas_per_node_group": replicas_per_node_group,
        }

    @builtins.property
    def num_node_groups(self) -> jsii.Number:
        return self._values.get("num_node_groups")

    @builtins.property
    def replicas_per_node_group(self) -> jsii.Number:
        return self._values.get("replicas_per_node_group")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheReplicationGroupClusterMode(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheReplicationGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "replication_group_description": "replicationGroupDescription",
        "replication_group_id": "replicationGroupId",
        "apply_immediately": "applyImmediately",
        "at_rest_encryption_enabled": "atRestEncryptionEnabled",
        "auth_token": "authToken",
        "automatic_failover_enabled": "automaticFailoverEnabled",
        "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
        "availability_zones": "availabilityZones",
        "cluster_mode": "clusterMode",
        "engine": "engine",
        "engine_version": "engineVersion",
        "kms_key_id": "kmsKeyId",
        "maintenance_window": "maintenanceWindow",
        "node_type": "nodeType",
        "notification_topic_arn": "notificationTopicArn",
        "number_cache_clusters": "numberCacheClusters",
        "parameter_group_name": "parameterGroupName",
        "port": "port",
        "security_group_ids": "securityGroupIds",
        "security_group_names": "securityGroupNames",
        "snapshot_arns": "snapshotArns",
        "snapshot_name": "snapshotName",
        "snapshot_retention_limit": "snapshotRetentionLimit",
        "snapshot_window": "snapshotWindow",
        "subnet_group_name": "subnetGroupName",
        "tags": "tags",
        "timeouts": "timeouts",
        "transit_encryption_enabled": "transitEncryptionEnabled",
    },
)
class ElasticacheReplicationGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        replication_group_description: str,
        replication_group_id: str,
        apply_immediately: typing.Optional[bool] = None,
        at_rest_encryption_enabled: typing.Optional[bool] = None,
        auth_token: typing.Optional[str] = None,
        automatic_failover_enabled: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        cluster_mode: typing.Optional[
            typing.List["ElasticacheReplicationGroupClusterMode"]
        ] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        maintenance_window: typing.Optional[str] = None,
        node_type: typing.Optional[str] = None,
        notification_topic_arn: typing.Optional[str] = None,
        number_cache_clusters: typing.Optional[jsii.Number] = None,
        parameter_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        snapshot_arns: typing.Optional[typing.List[str]] = None,
        snapshot_name: typing.Optional[str] = None,
        snapshot_retention_limit: typing.Optional[jsii.Number] = None,
        snapshot_window: typing.Optional[str] = None,
        subnet_group_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["ElasticacheReplicationGroupTimeouts"] = None,
        transit_encryption_enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param replication_group_description: 
        :param replication_group_id: 
        :param apply_immediately: 
        :param at_rest_encryption_enabled: 
        :param auth_token: 
        :param automatic_failover_enabled: 
        :param auto_minor_version_upgrade: 
        :param availability_zones: 
        :param cluster_mode: cluster_mode block.
        :param engine: 
        :param engine_version: 
        :param kms_key_id: 
        :param maintenance_window: 
        :param node_type: 
        :param notification_topic_arn: 
        :param number_cache_clusters: 
        :param parameter_group_name: 
        :param port: 
        :param security_group_ids: 
        :param security_group_names: 
        :param snapshot_arns: 
        :param snapshot_name: 
        :param snapshot_retention_limit: 
        :param snapshot_window: 
        :param subnet_group_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param transit_encryption_enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ElasticacheReplicationGroupTimeouts(**timeouts)
        self._values = {
            "replication_group_description": replication_group_description,
            "replication_group_id": replication_group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if at_rest_encryption_enabled is not None:
            self._values["at_rest_encryption_enabled"] = at_rest_encryption_enabled
        if auth_token is not None:
            self._values["auth_token"] = auth_token
        if automatic_failover_enabled is not None:
            self._values["automatic_failover_enabled"] = automatic_failover_enabled
        if auto_minor_version_upgrade is not None:
            self._values["auto_minor_version_upgrade"] = auto_minor_version_upgrade
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if cluster_mode is not None:
            self._values["cluster_mode"] = cluster_mode
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if maintenance_window is not None:
            self._values["maintenance_window"] = maintenance_window
        if node_type is not None:
            self._values["node_type"] = node_type
        if notification_topic_arn is not None:
            self._values["notification_topic_arn"] = notification_topic_arn
        if number_cache_clusters is not None:
            self._values["number_cache_clusters"] = number_cache_clusters
        if parameter_group_name is not None:
            self._values["parameter_group_name"] = parameter_group_name
        if port is not None:
            self._values["port"] = port
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if security_group_names is not None:
            self._values["security_group_names"] = security_group_names
        if snapshot_arns is not None:
            self._values["snapshot_arns"] = snapshot_arns
        if snapshot_name is not None:
            self._values["snapshot_name"] = snapshot_name
        if snapshot_retention_limit is not None:
            self._values["snapshot_retention_limit"] = snapshot_retention_limit
        if snapshot_window is not None:
            self._values["snapshot_window"] = snapshot_window
        if subnet_group_name is not None:
            self._values["subnet_group_name"] = subnet_group_name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if transit_encryption_enabled is not None:
            self._values["transit_encryption_enabled"] = transit_encryption_enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def replication_group_description(self) -> str:
        return self._values.get("replication_group_description")

    @builtins.property
    def replication_group_id(self) -> str:
        return self._values.get("replication_group_id")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def at_rest_encryption_enabled(self) -> typing.Optional[bool]:
        return self._values.get("at_rest_encryption_enabled")

    @builtins.property
    def auth_token(self) -> typing.Optional[str]:
        return self._values.get("auth_token")

    @builtins.property
    def automatic_failover_enabled(self) -> typing.Optional[bool]:
        return self._values.get("automatic_failover_enabled")

    @builtins.property
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("auto_minor_version_upgrade")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def cluster_mode(
        self,
    ) -> typing.Optional[typing.List["ElasticacheReplicationGroupClusterMode"]]:
        """cluster_mode block."""
        return self._values.get("cluster_mode")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("maintenance_window")

    @builtins.property
    def node_type(self) -> typing.Optional[str]:
        return self._values.get("node_type")

    @builtins.property
    def notification_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("notification_topic_arn")

    @builtins.property
    def number_cache_clusters(self) -> typing.Optional[jsii.Number]:
        return self._values.get("number_cache_clusters")

    @builtins.property
    def parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("parameter_group_name")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_names")

    @builtins.property
    def snapshot_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("snapshot_arns")

    @builtins.property
    def snapshot_name(self) -> typing.Optional[str]:
        return self._values.get("snapshot_name")

    @builtins.property
    def snapshot_retention_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("snapshot_retention_limit")

    @builtins.property
    def snapshot_window(self) -> typing.Optional[str]:
        return self._values.get("snapshot_window")

    @builtins.property
    def subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("subnet_group_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["ElasticacheReplicationGroupTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def transit_encryption_enabled(self) -> typing.Optional[bool]:
        return self._values.get("transit_encryption_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheReplicationGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheReplicationGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ElasticacheReplicationGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheReplicationGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticacheSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        security_group_names: typing.List[str],
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param security_group_names: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticacheSecurityGroupConfig(
            name=name,
            security_group_names=security_group_names,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticacheSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupNames")
    def security_group_names(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupNames")

    @security_group_names.setter
    def security_group_names(self, value: typing.List[str]) -> None:
        jsii.set(self, "securityGroupNames", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "security_group_names": "securityGroupNames",
        "description": "description",
    },
)
class ElasticacheSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        security_group_names: typing.List[str],
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param security_group_names: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "security_group_names": security_group_names,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def security_group_names(self) -> typing.List[str]:
        return self._values.get("security_group_names")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticacheSubnetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheSubnetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param subnet_ids: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticacheSubnetGroupConfig(
            name=name,
            subnet_ids=subnet_ids,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticacheSubnetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticacheSubnetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "subnet_ids": "subnetIds",
        "description": "description",
    },
)
class ElasticacheSubnetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param subnet_ids: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticacheSubnetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticsearchDomain(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomain",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: str,
        access_policies: typing.Optional[str] = None,
        advanced_options: typing.Optional[typing.Mapping[str, str]] = None,
        advanced_security_options: typing.Optional[
            typing.List["ElasticsearchDomainAdvancedSecurityOptions"]
        ] = None,
        cluster_config: typing.Optional[
            typing.List["ElasticsearchDomainClusterConfig"]
        ] = None,
        cognito_options: typing.Optional[
            typing.List["ElasticsearchDomainCognitoOptions"]
        ] = None,
        domain_endpoint_options: typing.Optional[
            typing.List["ElasticsearchDomainDomainEndpointOptions"]
        ] = None,
        ebs_options: typing.Optional[
            typing.List["ElasticsearchDomainEbsOptions"]
        ] = None,
        elasticsearch_version: typing.Optional[str] = None,
        encrypt_at_rest: typing.Optional[
            typing.List["ElasticsearchDomainEncryptAtRest"]
        ] = None,
        log_publishing_options: typing.Optional[
            typing.List["ElasticsearchDomainLogPublishingOptions"]
        ] = None,
        node_to_node_encryption: typing.Optional[
            typing.List["ElasticsearchDomainNodeToNodeEncryption"]
        ] = None,
        snapshot_options: typing.Optional[
            typing.List["ElasticsearchDomainSnapshotOptions"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["ElasticsearchDomainTimeouts"] = None,
        vpc_options: typing.Optional[
            typing.List["ElasticsearchDomainVpcOptions"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param access_policies: 
        :param advanced_options: 
        :param advanced_security_options: advanced_security_options block.
        :param cluster_config: cluster_config block.
        :param cognito_options: cognito_options block.
        :param domain_endpoint_options: domain_endpoint_options block.
        :param ebs_options: ebs_options block.
        :param elasticsearch_version: 
        :param encrypt_at_rest: encrypt_at_rest block.
        :param log_publishing_options: log_publishing_options block.
        :param node_to_node_encryption: node_to_node_encryption block.
        :param snapshot_options: snapshot_options block.
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_options: vpc_options block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticsearchDomainConfig(
            domain_name=domain_name,
            access_policies=access_policies,
            advanced_options=advanced_options,
            advanced_security_options=advanced_security_options,
            cluster_config=cluster_config,
            cognito_options=cognito_options,
            domain_endpoint_options=domain_endpoint_options,
            ebs_options=ebs_options,
            elasticsearch_version=elasticsearch_version,
            encrypt_at_rest=encrypt_at_rest,
            log_publishing_options=log_publishing_options,
            node_to_node_encryption=node_to_node_encryption,
            snapshot_options=snapshot_options,
            tags=tags,
            timeouts=timeouts,
            vpc_options=vpc_options,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticsearchDomain, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domainId")
    def domain_id(self) -> str:
        return jsii.get(self, "domainId")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="kibanaEndpoint")
    def kibana_endpoint(self) -> str:
        return jsii.get(self, "kibanaEndpoint")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="accessPolicies")
    def access_policies(self) -> typing.Optional[str]:
        return jsii.get(self, "accessPolicies")

    @access_policies.setter
    def access_policies(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accessPolicies", value)

    @builtins.property
    @jsii.member(jsii_name="advancedOptions")
    def advanced_options(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "advancedOptions")

    @advanced_options.setter
    def advanced_options(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "advancedOptions", value)

    @builtins.property
    @jsii.member(jsii_name="advancedSecurityOptions")
    def advanced_security_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainAdvancedSecurityOptions"]]:
        return jsii.get(self, "advancedSecurityOptions")

    @advanced_security_options.setter
    def advanced_security_options(
        self,
        value: typing.Optional[
            typing.List["ElasticsearchDomainAdvancedSecurityOptions"]
        ],
    ) -> None:
        jsii.set(self, "advancedSecurityOptions", value)

    @builtins.property
    @jsii.member(jsii_name="clusterConfig")
    def cluster_config(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainClusterConfig"]]:
        return jsii.get(self, "clusterConfig")

    @cluster_config.setter
    def cluster_config(
        self, value: typing.Optional[typing.List["ElasticsearchDomainClusterConfig"]]
    ) -> None:
        jsii.set(self, "clusterConfig", value)

    @builtins.property
    @jsii.member(jsii_name="cognitoOptions")
    def cognito_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainCognitoOptions"]]:
        return jsii.get(self, "cognitoOptions")

    @cognito_options.setter
    def cognito_options(
        self, value: typing.Optional[typing.List["ElasticsearchDomainCognitoOptions"]]
    ) -> None:
        jsii.set(self, "cognitoOptions", value)

    @builtins.property
    @jsii.member(jsii_name="domainEndpointOptions")
    def domain_endpoint_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainDomainEndpointOptions"]]:
        return jsii.get(self, "domainEndpointOptions")

    @domain_endpoint_options.setter
    def domain_endpoint_options(
        self,
        value: typing.Optional[typing.List["ElasticsearchDomainDomainEndpointOptions"]],
    ) -> None:
        jsii.set(self, "domainEndpointOptions", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptions")
    def ebs_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainEbsOptions"]]:
        return jsii.get(self, "ebsOptions")

    @ebs_options.setter
    def ebs_options(
        self, value: typing.Optional[typing.List["ElasticsearchDomainEbsOptions"]]
    ) -> None:
        jsii.set(self, "ebsOptions", value)

    @builtins.property
    @jsii.member(jsii_name="elasticsearchVersion")
    def elasticsearch_version(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticsearchVersion")

    @elasticsearch_version.setter
    def elasticsearch_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticsearchVersion", value)

    @builtins.property
    @jsii.member(jsii_name="encryptAtRest")
    def encrypt_at_rest(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainEncryptAtRest"]]:
        return jsii.get(self, "encryptAtRest")

    @encrypt_at_rest.setter
    def encrypt_at_rest(
        self, value: typing.Optional[typing.List["ElasticsearchDomainEncryptAtRest"]]
    ) -> None:
        jsii.set(self, "encryptAtRest", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="logPublishingOptions")
    def log_publishing_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainLogPublishingOptions"]]:
        return jsii.get(self, "logPublishingOptions")

    @log_publishing_options.setter
    def log_publishing_options(
        self,
        value: typing.Optional[typing.List["ElasticsearchDomainLogPublishingOptions"]],
    ) -> None:
        jsii.set(self, "logPublishingOptions", value)

    @builtins.property
    @jsii.member(jsii_name="nodeToNodeEncryption")
    def node_to_node_encryption(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainNodeToNodeEncryption"]]:
        return jsii.get(self, "nodeToNodeEncryption")

    @node_to_node_encryption.setter
    def node_to_node_encryption(
        self,
        value: typing.Optional[typing.List["ElasticsearchDomainNodeToNodeEncryption"]],
    ) -> None:
        jsii.set(self, "nodeToNodeEncryption", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotOptions")
    def snapshot_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainSnapshotOptions"]]:
        return jsii.get(self, "snapshotOptions")

    @snapshot_options.setter
    def snapshot_options(
        self, value: typing.Optional[typing.List["ElasticsearchDomainSnapshotOptions"]]
    ) -> None:
        jsii.set(self, "snapshotOptions", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ElasticsearchDomainTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["ElasticsearchDomainTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcOptions")
    def vpc_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainVpcOptions"]]:
        return jsii.get(self, "vpcOptions")

    @vpc_options.setter
    def vpc_options(
        self, value: typing.Optional[typing.List["ElasticsearchDomainVpcOptions"]]
    ) -> None:
        jsii.set(self, "vpcOptions", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainAdvancedSecurityOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "internal_user_database_enabled": "internalUserDatabaseEnabled",
        "master_user_options": "masterUserOptions",
    },
)
class ElasticsearchDomainAdvancedSecurityOptions:
    def __init__(
        self,
        *,
        enabled: bool,
        internal_user_database_enabled: typing.Optional[bool] = None,
        master_user_options: typing.Optional[
            typing.List["ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions"]
        ] = None,
    ) -> None:
        """
        :param enabled: 
        :param internal_user_database_enabled: 
        :param master_user_options: master_user_options block.
        """
        self._values = {
            "enabled": enabled,
        }
        if internal_user_database_enabled is not None:
            self._values[
                "internal_user_database_enabled"
            ] = internal_user_database_enabled
        if master_user_options is not None:
            self._values["master_user_options"] = master_user_options

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def internal_user_database_enabled(self) -> typing.Optional[bool]:
        return self._values.get("internal_user_database_enabled")

    @builtins.property
    def master_user_options(
        self,
    ) -> typing.Optional[
        typing.List["ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions"]
    ]:
        """master_user_options block."""
        return self._values.get("master_user_options")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainAdvancedSecurityOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions",
    jsii_struct_bases=[],
    name_mapping={
        "master_user_arn": "masterUserArn",
        "master_user_name": "masterUserName",
        "master_user_password": "masterUserPassword",
    },
)
class ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions:
    def __init__(
        self,
        *,
        master_user_arn: typing.Optional[str] = None,
        master_user_name: typing.Optional[str] = None,
        master_user_password: typing.Optional[str] = None,
    ) -> None:
        """
        :param master_user_arn: 
        :param master_user_name: 
        :param master_user_password: 
        """
        self._values = {}
        if master_user_arn is not None:
            self._values["master_user_arn"] = master_user_arn
        if master_user_name is not None:
            self._values["master_user_name"] = master_user_name
        if master_user_password is not None:
            self._values["master_user_password"] = master_user_password

    @builtins.property
    def master_user_arn(self) -> typing.Optional[str]:
        return self._values.get("master_user_arn")

    @builtins.property
    def master_user_name(self) -> typing.Optional[str]:
        return self._values.get("master_user_name")

    @builtins.property
    def master_user_password(self) -> typing.Optional[str]:
        return self._values.get("master_user_password")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainClusterConfig",
    jsii_struct_bases=[],
    name_mapping={
        "dedicated_master_count": "dedicatedMasterCount",
        "dedicated_master_enabled": "dedicatedMasterEnabled",
        "dedicated_master_type": "dedicatedMasterType",
        "instance_count": "instanceCount",
        "instance_type": "instanceType",
        "warm_count": "warmCount",
        "warm_enabled": "warmEnabled",
        "warm_type": "warmType",
        "zone_awareness_config": "zoneAwarenessConfig",
        "zone_awareness_enabled": "zoneAwarenessEnabled",
    },
)
class ElasticsearchDomainClusterConfig:
    def __init__(
        self,
        *,
        dedicated_master_count: typing.Optional[jsii.Number] = None,
        dedicated_master_enabled: typing.Optional[bool] = None,
        dedicated_master_type: typing.Optional[str] = None,
        instance_count: typing.Optional[jsii.Number] = None,
        instance_type: typing.Optional[str] = None,
        warm_count: typing.Optional[jsii.Number] = None,
        warm_enabled: typing.Optional[bool] = None,
        warm_type: typing.Optional[str] = None,
        zone_awareness_config: typing.Optional[
            typing.List["ElasticsearchDomainClusterConfigZoneAwarenessConfig"]
        ] = None,
        zone_awareness_enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param dedicated_master_count: 
        :param dedicated_master_enabled: 
        :param dedicated_master_type: 
        :param instance_count: 
        :param instance_type: 
        :param warm_count: 
        :param warm_enabled: 
        :param warm_type: 
        :param zone_awareness_config: zone_awareness_config block.
        :param zone_awareness_enabled: 
        """
        self._values = {}
        if dedicated_master_count is not None:
            self._values["dedicated_master_count"] = dedicated_master_count
        if dedicated_master_enabled is not None:
            self._values["dedicated_master_enabled"] = dedicated_master_enabled
        if dedicated_master_type is not None:
            self._values["dedicated_master_type"] = dedicated_master_type
        if instance_count is not None:
            self._values["instance_count"] = instance_count
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if warm_count is not None:
            self._values["warm_count"] = warm_count
        if warm_enabled is not None:
            self._values["warm_enabled"] = warm_enabled
        if warm_type is not None:
            self._values["warm_type"] = warm_type
        if zone_awareness_config is not None:
            self._values["zone_awareness_config"] = zone_awareness_config
        if zone_awareness_enabled is not None:
            self._values["zone_awareness_enabled"] = zone_awareness_enabled

    @builtins.property
    def dedicated_master_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("dedicated_master_count")

    @builtins.property
    def dedicated_master_enabled(self) -> typing.Optional[bool]:
        return self._values.get("dedicated_master_enabled")

    @builtins.property
    def dedicated_master_type(self) -> typing.Optional[str]:
        return self._values.get("dedicated_master_type")

    @builtins.property
    def instance_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_count")

    @builtins.property
    def instance_type(self) -> typing.Optional[str]:
        return self._values.get("instance_type")

    @builtins.property
    def warm_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("warm_count")

    @builtins.property
    def warm_enabled(self) -> typing.Optional[bool]:
        return self._values.get("warm_enabled")

    @builtins.property
    def warm_type(self) -> typing.Optional[str]:
        return self._values.get("warm_type")

    @builtins.property
    def zone_awareness_config(
        self,
    ) -> typing.Optional[
        typing.List["ElasticsearchDomainClusterConfigZoneAwarenessConfig"]
    ]:
        """zone_awareness_config block."""
        return self._values.get("zone_awareness_config")

    @builtins.property
    def zone_awareness_enabled(self) -> typing.Optional[bool]:
        return self._values.get("zone_awareness_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainClusterConfigZoneAwarenessConfig",
    jsii_struct_bases=[],
    name_mapping={"availability_zone_count": "availabilityZoneCount"},
)
class ElasticsearchDomainClusterConfigZoneAwarenessConfig:
    def __init__(
        self, *, availability_zone_count: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param availability_zone_count: 
        """
        self._values = {}
        if availability_zone_count is not None:
            self._values["availability_zone_count"] = availability_zone_count

    @builtins.property
    def availability_zone_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("availability_zone_count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainClusterConfigZoneAwarenessConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainCognitoOptions",
    jsii_struct_bases=[],
    name_mapping={
        "identity_pool_id": "identityPoolId",
        "role_arn": "roleArn",
        "user_pool_id": "userPoolId",
        "enabled": "enabled",
    },
)
class ElasticsearchDomainCognitoOptions:
    def __init__(
        self,
        *,
        identity_pool_id: str,
        role_arn: str,
        user_pool_id: str,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param identity_pool_id: 
        :param role_arn: 
        :param user_pool_id: 
        :param enabled: 
        """
        self._values = {
            "identity_pool_id": identity_pool_id,
            "role_arn": role_arn,
            "user_pool_id": user_pool_id,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def identity_pool_id(self) -> str:
        return self._values.get("identity_pool_id")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def user_pool_id(self) -> str:
        return self._values.get("user_pool_id")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainCognitoOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
        "access_policies": "accessPolicies",
        "advanced_options": "advancedOptions",
        "advanced_security_options": "advancedSecurityOptions",
        "cluster_config": "clusterConfig",
        "cognito_options": "cognitoOptions",
        "domain_endpoint_options": "domainEndpointOptions",
        "ebs_options": "ebsOptions",
        "elasticsearch_version": "elasticsearchVersion",
        "encrypt_at_rest": "encryptAtRest",
        "log_publishing_options": "logPublishingOptions",
        "node_to_node_encryption": "nodeToNodeEncryption",
        "snapshot_options": "snapshotOptions",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_options": "vpcOptions",
    },
)
class ElasticsearchDomainConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: str,
        access_policies: typing.Optional[str] = None,
        advanced_options: typing.Optional[typing.Mapping[str, str]] = None,
        advanced_security_options: typing.Optional[
            typing.List["ElasticsearchDomainAdvancedSecurityOptions"]
        ] = None,
        cluster_config: typing.Optional[
            typing.List["ElasticsearchDomainClusterConfig"]
        ] = None,
        cognito_options: typing.Optional[
            typing.List["ElasticsearchDomainCognitoOptions"]
        ] = None,
        domain_endpoint_options: typing.Optional[
            typing.List["ElasticsearchDomainDomainEndpointOptions"]
        ] = None,
        ebs_options: typing.Optional[
            typing.List["ElasticsearchDomainEbsOptions"]
        ] = None,
        elasticsearch_version: typing.Optional[str] = None,
        encrypt_at_rest: typing.Optional[
            typing.List["ElasticsearchDomainEncryptAtRest"]
        ] = None,
        log_publishing_options: typing.Optional[
            typing.List["ElasticsearchDomainLogPublishingOptions"]
        ] = None,
        node_to_node_encryption: typing.Optional[
            typing.List["ElasticsearchDomainNodeToNodeEncryption"]
        ] = None,
        snapshot_options: typing.Optional[
            typing.List["ElasticsearchDomainSnapshotOptions"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["ElasticsearchDomainTimeouts"] = None,
        vpc_options: typing.Optional[
            typing.List["ElasticsearchDomainVpcOptions"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        :param access_policies: 
        :param advanced_options: 
        :param advanced_security_options: advanced_security_options block.
        :param cluster_config: cluster_config block.
        :param cognito_options: cognito_options block.
        :param domain_endpoint_options: domain_endpoint_options block.
        :param ebs_options: ebs_options block.
        :param elasticsearch_version: 
        :param encrypt_at_rest: encrypt_at_rest block.
        :param log_publishing_options: log_publishing_options block.
        :param node_to_node_encryption: node_to_node_encryption block.
        :param snapshot_options: snapshot_options block.
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_options: vpc_options block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ElasticsearchDomainTimeouts(**timeouts)
        self._values = {
            "domain_name": domain_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_policies is not None:
            self._values["access_policies"] = access_policies
        if advanced_options is not None:
            self._values["advanced_options"] = advanced_options
        if advanced_security_options is not None:
            self._values["advanced_security_options"] = advanced_security_options
        if cluster_config is not None:
            self._values["cluster_config"] = cluster_config
        if cognito_options is not None:
            self._values["cognito_options"] = cognito_options
        if domain_endpoint_options is not None:
            self._values["domain_endpoint_options"] = domain_endpoint_options
        if ebs_options is not None:
            self._values["ebs_options"] = ebs_options
        if elasticsearch_version is not None:
            self._values["elasticsearch_version"] = elasticsearch_version
        if encrypt_at_rest is not None:
            self._values["encrypt_at_rest"] = encrypt_at_rest
        if log_publishing_options is not None:
            self._values["log_publishing_options"] = log_publishing_options
        if node_to_node_encryption is not None:
            self._values["node_to_node_encryption"] = node_to_node_encryption
        if snapshot_options is not None:
            self._values["snapshot_options"] = snapshot_options
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_options is not None:
            self._values["vpc_options"] = vpc_options

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def access_policies(self) -> typing.Optional[str]:
        return self._values.get("access_policies")

    @builtins.property
    def advanced_options(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("advanced_options")

    @builtins.property
    def advanced_security_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainAdvancedSecurityOptions"]]:
        """advanced_security_options block."""
        return self._values.get("advanced_security_options")

    @builtins.property
    def cluster_config(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainClusterConfig"]]:
        """cluster_config block."""
        return self._values.get("cluster_config")

    @builtins.property
    def cognito_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainCognitoOptions"]]:
        """cognito_options block."""
        return self._values.get("cognito_options")

    @builtins.property
    def domain_endpoint_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainDomainEndpointOptions"]]:
        """domain_endpoint_options block."""
        return self._values.get("domain_endpoint_options")

    @builtins.property
    def ebs_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainEbsOptions"]]:
        """ebs_options block."""
        return self._values.get("ebs_options")

    @builtins.property
    def elasticsearch_version(self) -> typing.Optional[str]:
        return self._values.get("elasticsearch_version")

    @builtins.property
    def encrypt_at_rest(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainEncryptAtRest"]]:
        """encrypt_at_rest block."""
        return self._values.get("encrypt_at_rest")

    @builtins.property
    def log_publishing_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainLogPublishingOptions"]]:
        """log_publishing_options block."""
        return self._values.get("log_publishing_options")

    @builtins.property
    def node_to_node_encryption(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainNodeToNodeEncryption"]]:
        """node_to_node_encryption block."""
        return self._values.get("node_to_node_encryption")

    @builtins.property
    def snapshot_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainSnapshotOptions"]]:
        """snapshot_options block."""
        return self._values.get("snapshot_options")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["ElasticsearchDomainTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_options(
        self,
    ) -> typing.Optional[typing.List["ElasticsearchDomainVpcOptions"]]:
        """vpc_options block."""
        return self._values.get("vpc_options")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainDomainEndpointOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enforce_https": "enforceHttps",
        "tls_security_policy": "tlsSecurityPolicy",
    },
)
class ElasticsearchDomainDomainEndpointOptions:
    def __init__(
        self, *, enforce_https: bool, tls_security_policy: typing.Optional[str] = None
    ) -> None:
        """
        :param enforce_https: 
        :param tls_security_policy: 
        """
        self._values = {
            "enforce_https": enforce_https,
        }
        if tls_security_policy is not None:
            self._values["tls_security_policy"] = tls_security_policy

    @builtins.property
    def enforce_https(self) -> bool:
        return self._values.get("enforce_https")

    @builtins.property
    def tls_security_policy(self) -> typing.Optional[str]:
        return self._values.get("tls_security_policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainDomainEndpointOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainEbsOptions",
    jsii_struct_bases=[],
    name_mapping={
        "ebs_enabled": "ebsEnabled",
        "iops": "iops",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class ElasticsearchDomainEbsOptions:
    def __init__(
        self,
        *,
        ebs_enabled: bool,
        iops: typing.Optional[jsii.Number] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param ebs_enabled: 
        :param iops: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {
            "ebs_enabled": ebs_enabled,
        }
        if iops is not None:
            self._values["iops"] = iops
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def ebs_enabled(self) -> bool:
        return self._values.get("ebs_enabled")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainEbsOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainEncryptAtRest",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "kms_key_id": "kmsKeyId"},
)
class ElasticsearchDomainEncryptAtRest:
    def __init__(
        self, *, enabled: bool, kms_key_id: typing.Optional[str] = None
    ) -> None:
        """
        :param enabled: 
        :param kms_key_id: 
        """
        self._values = {
            "enabled": enabled,
        }
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainEncryptAtRest(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainLogPublishingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_log_group_arn": "cloudwatchLogGroupArn",
        "log_type": "logType",
        "enabled": "enabled",
    },
)
class ElasticsearchDomainLogPublishingOptions:
    def __init__(
        self,
        *,
        cloudwatch_log_group_arn: str,
        log_type: str,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param cloudwatch_log_group_arn: 
        :param log_type: 
        :param enabled: 
        """
        self._values = {
            "cloudwatch_log_group_arn": cloudwatch_log_group_arn,
            "log_type": log_type,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def cloudwatch_log_group_arn(self) -> str:
        return self._values.get("cloudwatch_log_group_arn")

    @builtins.property
    def log_type(self) -> str:
        return self._values.get("log_type")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainLogPublishingOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainNodeToNodeEncryption",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class ElasticsearchDomainNodeToNodeEncryption:
    def __init__(self, *, enabled: bool) -> None:
        """
        :param enabled: 
        """
        self._values = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainNodeToNodeEncryption(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElasticsearchDomainPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        access_policies: str,
        domain_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param access_policies: 
        :param domain_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElasticsearchDomainPolicyConfig(
            access_policies=access_policies,
            domain_name=domain_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElasticsearchDomainPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accessPolicies")
    def access_policies(self) -> str:
        return jsii.get(self, "accessPolicies")

    @access_policies.setter
    def access_policies(self, value: str) -> None:
        jsii.set(self, "accessPolicies", value)

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_policies": "accessPolicies",
        "domain_name": "domainName",
    },
)
class ElasticsearchDomainPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_policies: str,
        domain_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_policies: 
        :param domain_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "access_policies": access_policies,
            "domain_name": domain_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def access_policies(self) -> str:
        return self._values.get("access_policies")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainSnapshotOptions",
    jsii_struct_bases=[],
    name_mapping={"automated_snapshot_start_hour": "automatedSnapshotStartHour"},
)
class ElasticsearchDomainSnapshotOptions:
    def __init__(self, *, automated_snapshot_start_hour: jsii.Number) -> None:
        """
        :param automated_snapshot_start_hour: 
        """
        self._values = {
            "automated_snapshot_start_hour": automated_snapshot_start_hour,
        }

    @builtins.property
    def automated_snapshot_start_hour(self) -> jsii.Number:
        return self._values.get("automated_snapshot_start_hour")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainSnapshotOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainTimeouts",
    jsii_struct_bases=[],
    name_mapping={"update": "update"},
)
class ElasticsearchDomainTimeouts:
    def __init__(self, *, update: typing.Optional[str] = None) -> None:
        """
        :param update: 
        """
        self._values = {}
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElasticsearchDomainVpcOptions",
    jsii_struct_bases=[],
    name_mapping={"security_group_ids": "securityGroupIds", "subnet_ids": "subnetIds"},
)
class ElasticsearchDomainVpcOptions:
    def __init__(
        self,
        *,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param security_group_ids: 
        :param subnet_ids: 
        """
        self._values = {}
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnet_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElasticsearchDomainVpcOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElastictranscoderPipeline(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPipeline",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        input_bucket: str,
        role: str,
        aws_kms_key_arn: typing.Optional[str] = None,
        content_config: typing.Optional[
            typing.List["ElastictranscoderPipelineContentConfig"]
        ] = None,
        content_config_permissions: typing.Optional[
            typing.List["ElastictranscoderPipelineContentConfigPermissions"]
        ] = None,
        name: typing.Optional[str] = None,
        notifications: typing.Optional[
            typing.List["ElastictranscoderPipelineNotifications"]
        ] = None,
        output_bucket: typing.Optional[str] = None,
        thumbnail_config: typing.Optional[
            typing.List["ElastictranscoderPipelineThumbnailConfig"]
        ] = None,
        thumbnail_config_permissions: typing.Optional[
            typing.List["ElastictranscoderPipelineThumbnailConfigPermissions"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param input_bucket: 
        :param role: 
        :param aws_kms_key_arn: 
        :param content_config: content_config block.
        :param content_config_permissions: content_config_permissions block.
        :param name: 
        :param notifications: notifications block.
        :param output_bucket: 
        :param thumbnail_config: thumbnail_config block.
        :param thumbnail_config_permissions: thumbnail_config_permissions block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElastictranscoderPipelineConfig(
            input_bucket=input_bucket,
            role=role,
            aws_kms_key_arn=aws_kms_key_arn,
            content_config=content_config,
            content_config_permissions=content_config_permissions,
            name=name,
            notifications=notifications,
            output_bucket=output_bucket,
            thumbnail_config=thumbnail_config,
            thumbnail_config_permissions=thumbnail_config_permissions,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElastictranscoderPipeline, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="inputBucket")
    def input_bucket(self) -> str:
        return jsii.get(self, "inputBucket")

    @input_bucket.setter
    def input_bucket(self, value: str) -> None:
        jsii.set(self, "inputBucket", value)

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> str:
        return jsii.get(self, "role")

    @role.setter
    def role(self, value: str) -> None:
        jsii.set(self, "role", value)

    @builtins.property
    @jsii.member(jsii_name="awsKmsKeyArn")
    def aws_kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "awsKmsKeyArn")

    @aws_kms_key_arn.setter
    def aws_kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "awsKmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="contentConfig")
    def content_config(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPipelineContentConfig"]]:
        return jsii.get(self, "contentConfig")

    @content_config.setter
    def content_config(
        self,
        value: typing.Optional[typing.List["ElastictranscoderPipelineContentConfig"]],
    ) -> None:
        jsii.set(self, "contentConfig", value)

    @builtins.property
    @jsii.member(jsii_name="contentConfigPermissions")
    def content_config_permissions(
        self,
    ) -> typing.Optional[
        typing.List["ElastictranscoderPipelineContentConfigPermissions"]
    ]:
        return jsii.get(self, "contentConfigPermissions")

    @content_config_permissions.setter
    def content_config_permissions(
        self,
        value: typing.Optional[
            typing.List["ElastictranscoderPipelineContentConfigPermissions"]
        ],
    ) -> None:
        jsii.set(self, "contentConfigPermissions", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="notifications")
    def notifications(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPipelineNotifications"]]:
        return jsii.get(self, "notifications")

    @notifications.setter
    def notifications(
        self,
        value: typing.Optional[typing.List["ElastictranscoderPipelineNotifications"]],
    ) -> None:
        jsii.set(self, "notifications", value)

    @builtins.property
    @jsii.member(jsii_name="outputBucket")
    def output_bucket(self) -> typing.Optional[str]:
        return jsii.get(self, "outputBucket")

    @output_bucket.setter
    def output_bucket(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "outputBucket", value)

    @builtins.property
    @jsii.member(jsii_name="thumbnailConfig")
    def thumbnail_config(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPipelineThumbnailConfig"]]:
        return jsii.get(self, "thumbnailConfig")

    @thumbnail_config.setter
    def thumbnail_config(
        self,
        value: typing.Optional[typing.List["ElastictranscoderPipelineThumbnailConfig"]],
    ) -> None:
        jsii.set(self, "thumbnailConfig", value)

    @builtins.property
    @jsii.member(jsii_name="thumbnailConfigPermissions")
    def thumbnail_config_permissions(
        self,
    ) -> typing.Optional[
        typing.List["ElastictranscoderPipelineThumbnailConfigPermissions"]
    ]:
        return jsii.get(self, "thumbnailConfigPermissions")

    @thumbnail_config_permissions.setter
    def thumbnail_config_permissions(
        self,
        value: typing.Optional[
            typing.List["ElastictranscoderPipelineThumbnailConfigPermissions"]
        ],
    ) -> None:
        jsii.set(self, "thumbnailConfigPermissions", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPipelineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "input_bucket": "inputBucket",
        "role": "role",
        "aws_kms_key_arn": "awsKmsKeyArn",
        "content_config": "contentConfig",
        "content_config_permissions": "contentConfigPermissions",
        "name": "name",
        "notifications": "notifications",
        "output_bucket": "outputBucket",
        "thumbnail_config": "thumbnailConfig",
        "thumbnail_config_permissions": "thumbnailConfigPermissions",
    },
)
class ElastictranscoderPipelineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        input_bucket: str,
        role: str,
        aws_kms_key_arn: typing.Optional[str] = None,
        content_config: typing.Optional[
            typing.List["ElastictranscoderPipelineContentConfig"]
        ] = None,
        content_config_permissions: typing.Optional[
            typing.List["ElastictranscoderPipelineContentConfigPermissions"]
        ] = None,
        name: typing.Optional[str] = None,
        notifications: typing.Optional[
            typing.List["ElastictranscoderPipelineNotifications"]
        ] = None,
        output_bucket: typing.Optional[str] = None,
        thumbnail_config: typing.Optional[
            typing.List["ElastictranscoderPipelineThumbnailConfig"]
        ] = None,
        thumbnail_config_permissions: typing.Optional[
            typing.List["ElastictranscoderPipelineThumbnailConfigPermissions"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param input_bucket: 
        :param role: 
        :param aws_kms_key_arn: 
        :param content_config: content_config block.
        :param content_config_permissions: content_config_permissions block.
        :param name: 
        :param notifications: notifications block.
        :param output_bucket: 
        :param thumbnail_config: thumbnail_config block.
        :param thumbnail_config_permissions: thumbnail_config_permissions block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "input_bucket": input_bucket,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if aws_kms_key_arn is not None:
            self._values["aws_kms_key_arn"] = aws_kms_key_arn
        if content_config is not None:
            self._values["content_config"] = content_config
        if content_config_permissions is not None:
            self._values["content_config_permissions"] = content_config_permissions
        if name is not None:
            self._values["name"] = name
        if notifications is not None:
            self._values["notifications"] = notifications
        if output_bucket is not None:
            self._values["output_bucket"] = output_bucket
        if thumbnail_config is not None:
            self._values["thumbnail_config"] = thumbnail_config
        if thumbnail_config_permissions is not None:
            self._values["thumbnail_config_permissions"] = thumbnail_config_permissions

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def input_bucket(self) -> str:
        return self._values.get("input_bucket")

    @builtins.property
    def role(self) -> str:
        return self._values.get("role")

    @builtins.property
    def aws_kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("aws_kms_key_arn")

    @builtins.property
    def content_config(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPipelineContentConfig"]]:
        """content_config block."""
        return self._values.get("content_config")

    @builtins.property
    def content_config_permissions(
        self,
    ) -> typing.Optional[
        typing.List["ElastictranscoderPipelineContentConfigPermissions"]
    ]:
        """content_config_permissions block."""
        return self._values.get("content_config_permissions")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def notifications(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPipelineNotifications"]]:
        """notifications block."""
        return self._values.get("notifications")

    @builtins.property
    def output_bucket(self) -> typing.Optional[str]:
        return self._values.get("output_bucket")

    @builtins.property
    def thumbnail_config(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPipelineThumbnailConfig"]]:
        """thumbnail_config block."""
        return self._values.get("thumbnail_config")

    @builtins.property
    def thumbnail_config_permissions(
        self,
    ) -> typing.Optional[
        typing.List["ElastictranscoderPipelineThumbnailConfigPermissions"]
    ]:
        """thumbnail_config_permissions block."""
        return self._values.get("thumbnail_config_permissions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPipelineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPipelineContentConfig",
    jsii_struct_bases=[],
    name_mapping={"bucket": "bucket", "storage_class": "storageClass"},
)
class ElastictranscoderPipelineContentConfig:
    def __init__(
        self,
        *,
        bucket: typing.Optional[str] = None,
        storage_class: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket: 
        :param storage_class: 
        """
        self._values = {}
        if bucket is not None:
            self._values["bucket"] = bucket
        if storage_class is not None:
            self._values["storage_class"] = storage_class

    @builtins.property
    def bucket(self) -> typing.Optional[str]:
        return self._values.get("bucket")

    @builtins.property
    def storage_class(self) -> typing.Optional[str]:
        return self._values.get("storage_class")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPipelineContentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPipelineContentConfigPermissions",
    jsii_struct_bases=[],
    name_mapping={
        "access": "access",
        "grantee": "grantee",
        "grantee_type": "granteeType",
    },
)
class ElastictranscoderPipelineContentConfigPermissions:
    def __init__(
        self,
        *,
        access: typing.Optional[typing.List[str]] = None,
        grantee: typing.Optional[str] = None,
        grantee_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param access: 
        :param grantee: 
        :param grantee_type: 
        """
        self._values = {}
        if access is not None:
            self._values["access"] = access
        if grantee is not None:
            self._values["grantee"] = grantee
        if grantee_type is not None:
            self._values["grantee_type"] = grantee_type

    @builtins.property
    def access(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("access")

    @builtins.property
    def grantee(self) -> typing.Optional[str]:
        return self._values.get("grantee")

    @builtins.property
    def grantee_type(self) -> typing.Optional[str]:
        return self._values.get("grantee_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPipelineContentConfigPermissions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPipelineNotifications",
    jsii_struct_bases=[],
    name_mapping={
        "completed": "completed",
        "error": "error",
        "progressing": "progressing",
        "warning": "warning",
    },
)
class ElastictranscoderPipelineNotifications:
    def __init__(
        self,
        *,
        completed: typing.Optional[str] = None,
        error: typing.Optional[str] = None,
        progressing: typing.Optional[str] = None,
        warning: typing.Optional[str] = None,
    ) -> None:
        """
        :param completed: 
        :param error: 
        :param progressing: 
        :param warning: 
        """
        self._values = {}
        if completed is not None:
            self._values["completed"] = completed
        if error is not None:
            self._values["error"] = error
        if progressing is not None:
            self._values["progressing"] = progressing
        if warning is not None:
            self._values["warning"] = warning

    @builtins.property
    def completed(self) -> typing.Optional[str]:
        return self._values.get("completed")

    @builtins.property
    def error(self) -> typing.Optional[str]:
        return self._values.get("error")

    @builtins.property
    def progressing(self) -> typing.Optional[str]:
        return self._values.get("progressing")

    @builtins.property
    def warning(self) -> typing.Optional[str]:
        return self._values.get("warning")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPipelineNotifications(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPipelineThumbnailConfig",
    jsii_struct_bases=[],
    name_mapping={"bucket": "bucket", "storage_class": "storageClass"},
)
class ElastictranscoderPipelineThumbnailConfig:
    def __init__(
        self,
        *,
        bucket: typing.Optional[str] = None,
        storage_class: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket: 
        :param storage_class: 
        """
        self._values = {}
        if bucket is not None:
            self._values["bucket"] = bucket
        if storage_class is not None:
            self._values["storage_class"] = storage_class

    @builtins.property
    def bucket(self) -> typing.Optional[str]:
        return self._values.get("bucket")

    @builtins.property
    def storage_class(self) -> typing.Optional[str]:
        return self._values.get("storage_class")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPipelineThumbnailConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPipelineThumbnailConfigPermissions",
    jsii_struct_bases=[],
    name_mapping={
        "access": "access",
        "grantee": "grantee",
        "grantee_type": "granteeType",
    },
)
class ElastictranscoderPipelineThumbnailConfigPermissions:
    def __init__(
        self,
        *,
        access: typing.Optional[typing.List[str]] = None,
        grantee: typing.Optional[str] = None,
        grantee_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param access: 
        :param grantee: 
        :param grantee_type: 
        """
        self._values = {}
        if access is not None:
            self._values["access"] = access
        if grantee is not None:
            self._values["grantee"] = grantee
        if grantee_type is not None:
            self._values["grantee_type"] = grantee_type

    @builtins.property
    def access(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("access")

    @builtins.property
    def grantee(self) -> typing.Optional[str]:
        return self._values.get("grantee")

    @builtins.property
    def grantee_type(self) -> typing.Optional[str]:
        return self._values.get("grantee_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPipelineThumbnailConfigPermissions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElastictranscoderPreset(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPreset",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        container: str,
        audio: typing.Optional[typing.List["ElastictranscoderPresetAudio"]] = None,
        audio_codec_options: typing.Optional[
            typing.List["ElastictranscoderPresetAudioCodecOptions"]
        ] = None,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        thumbnails: typing.Optional[
            typing.List["ElastictranscoderPresetThumbnails"]
        ] = None,
        type: typing.Optional[str] = None,
        video: typing.Optional[typing.List["ElastictranscoderPresetVideo"]] = None,
        video_codec_options: typing.Optional[typing.Mapping[str, str]] = None,
        video_watermarks: typing.Optional[
            typing.List["ElastictranscoderPresetVideoWatermarks"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param container: 
        :param audio: audio block.
        :param audio_codec_options: audio_codec_options block.
        :param description: 
        :param name: 
        :param thumbnails: thumbnails block.
        :param type: 
        :param video: video block.
        :param video_codec_options: 
        :param video_watermarks: video_watermarks block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElastictranscoderPresetConfig(
            container=container,
            audio=audio,
            audio_codec_options=audio_codec_options,
            description=description,
            name=name,
            thumbnails=thumbnails,
            type=type,
            video=video,
            video_codec_options=video_codec_options,
            video_watermarks=video_watermarks,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElastictranscoderPreset, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="container")
    def container(self) -> str:
        return jsii.get(self, "container")

    @container.setter
    def container(self, value: str) -> None:
        jsii.set(self, "container", value)

    @builtins.property
    @jsii.member(jsii_name="audio")
    def audio(self) -> typing.Optional[typing.List["ElastictranscoderPresetAudio"]]:
        return jsii.get(self, "audio")

    @audio.setter
    def audio(
        self, value: typing.Optional[typing.List["ElastictranscoderPresetAudio"]]
    ) -> None:
        jsii.set(self, "audio", value)

    @builtins.property
    @jsii.member(jsii_name="audioCodecOptions")
    def audio_codec_options(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPresetAudioCodecOptions"]]:
        return jsii.get(self, "audioCodecOptions")

    @audio_codec_options.setter
    def audio_codec_options(
        self,
        value: typing.Optional[typing.List["ElastictranscoderPresetAudioCodecOptions"]],
    ) -> None:
        jsii.set(self, "audioCodecOptions", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="thumbnails")
    def thumbnails(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPresetThumbnails"]]:
        return jsii.get(self, "thumbnails")

    @thumbnails.setter
    def thumbnails(
        self, value: typing.Optional[typing.List["ElastictranscoderPresetThumbnails"]]
    ) -> None:
        jsii.set(self, "thumbnails", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="video")
    def video(self) -> typing.Optional[typing.List["ElastictranscoderPresetVideo"]]:
        return jsii.get(self, "video")

    @video.setter
    def video(
        self, value: typing.Optional[typing.List["ElastictranscoderPresetVideo"]]
    ) -> None:
        jsii.set(self, "video", value)

    @builtins.property
    @jsii.member(jsii_name="videoCodecOptions")
    def video_codec_options(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "videoCodecOptions")

    @video_codec_options.setter
    def video_codec_options(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "videoCodecOptions", value)

    @builtins.property
    @jsii.member(jsii_name="videoWatermarks")
    def video_watermarks(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPresetVideoWatermarks"]]:
        return jsii.get(self, "videoWatermarks")

    @video_watermarks.setter
    def video_watermarks(
        self,
        value: typing.Optional[typing.List["ElastictranscoderPresetVideoWatermarks"]],
    ) -> None:
        jsii.set(self, "videoWatermarks", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPresetAudio",
    jsii_struct_bases=[],
    name_mapping={
        "audio_packing_mode": "audioPackingMode",
        "bit_rate": "bitRate",
        "channels": "channels",
        "codec": "codec",
        "sample_rate": "sampleRate",
    },
)
class ElastictranscoderPresetAudio:
    def __init__(
        self,
        *,
        audio_packing_mode: typing.Optional[str] = None,
        bit_rate: typing.Optional[str] = None,
        channels: typing.Optional[str] = None,
        codec: typing.Optional[str] = None,
        sample_rate: typing.Optional[str] = None,
    ) -> None:
        """
        :param audio_packing_mode: 
        :param bit_rate: 
        :param channels: 
        :param codec: 
        :param sample_rate: 
        """
        self._values = {}
        if audio_packing_mode is not None:
            self._values["audio_packing_mode"] = audio_packing_mode
        if bit_rate is not None:
            self._values["bit_rate"] = bit_rate
        if channels is not None:
            self._values["channels"] = channels
        if codec is not None:
            self._values["codec"] = codec
        if sample_rate is not None:
            self._values["sample_rate"] = sample_rate

    @builtins.property
    def audio_packing_mode(self) -> typing.Optional[str]:
        return self._values.get("audio_packing_mode")

    @builtins.property
    def bit_rate(self) -> typing.Optional[str]:
        return self._values.get("bit_rate")

    @builtins.property
    def channels(self) -> typing.Optional[str]:
        return self._values.get("channels")

    @builtins.property
    def codec(self) -> typing.Optional[str]:
        return self._values.get("codec")

    @builtins.property
    def sample_rate(self) -> typing.Optional[str]:
        return self._values.get("sample_rate")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPresetAudio(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPresetAudioCodecOptions",
    jsii_struct_bases=[],
    name_mapping={
        "bit_depth": "bitDepth",
        "bit_order": "bitOrder",
        "profile": "profile",
        "signed": "signed",
    },
)
class ElastictranscoderPresetAudioCodecOptions:
    def __init__(
        self,
        *,
        bit_depth: typing.Optional[str] = None,
        bit_order: typing.Optional[str] = None,
        profile: typing.Optional[str] = None,
        signed: typing.Optional[str] = None,
    ) -> None:
        """
        :param bit_depth: 
        :param bit_order: 
        :param profile: 
        :param signed: 
        """
        self._values = {}
        if bit_depth is not None:
            self._values["bit_depth"] = bit_depth
        if bit_order is not None:
            self._values["bit_order"] = bit_order
        if profile is not None:
            self._values["profile"] = profile
        if signed is not None:
            self._values["signed"] = signed

    @builtins.property
    def bit_depth(self) -> typing.Optional[str]:
        return self._values.get("bit_depth")

    @builtins.property
    def bit_order(self) -> typing.Optional[str]:
        return self._values.get("bit_order")

    @builtins.property
    def profile(self) -> typing.Optional[str]:
        return self._values.get("profile")

    @builtins.property
    def signed(self) -> typing.Optional[str]:
        return self._values.get("signed")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPresetAudioCodecOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPresetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "container": "container",
        "audio": "audio",
        "audio_codec_options": "audioCodecOptions",
        "description": "description",
        "name": "name",
        "thumbnails": "thumbnails",
        "type": "type",
        "video": "video",
        "video_codec_options": "videoCodecOptions",
        "video_watermarks": "videoWatermarks",
    },
)
class ElastictranscoderPresetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        container: str,
        audio: typing.Optional[typing.List["ElastictranscoderPresetAudio"]] = None,
        audio_codec_options: typing.Optional[
            typing.List["ElastictranscoderPresetAudioCodecOptions"]
        ] = None,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        thumbnails: typing.Optional[
            typing.List["ElastictranscoderPresetThumbnails"]
        ] = None,
        type: typing.Optional[str] = None,
        video: typing.Optional[typing.List["ElastictranscoderPresetVideo"]] = None,
        video_codec_options: typing.Optional[typing.Mapping[str, str]] = None,
        video_watermarks: typing.Optional[
            typing.List["ElastictranscoderPresetVideoWatermarks"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param container: 
        :param audio: audio block.
        :param audio_codec_options: audio_codec_options block.
        :param description: 
        :param name: 
        :param thumbnails: thumbnails block.
        :param type: 
        :param video: video block.
        :param video_codec_options: 
        :param video_watermarks: video_watermarks block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "container": container,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if audio is not None:
            self._values["audio"] = audio
        if audio_codec_options is not None:
            self._values["audio_codec_options"] = audio_codec_options
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if thumbnails is not None:
            self._values["thumbnails"] = thumbnails
        if type is not None:
            self._values["type"] = type
        if video is not None:
            self._values["video"] = video
        if video_codec_options is not None:
            self._values["video_codec_options"] = video_codec_options
        if video_watermarks is not None:
            self._values["video_watermarks"] = video_watermarks

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def container(self) -> str:
        return self._values.get("container")

    @builtins.property
    def audio(self) -> typing.Optional[typing.List["ElastictranscoderPresetAudio"]]:
        """audio block."""
        return self._values.get("audio")

    @builtins.property
    def audio_codec_options(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPresetAudioCodecOptions"]]:
        """audio_codec_options block."""
        return self._values.get("audio_codec_options")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def thumbnails(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPresetThumbnails"]]:
        """thumbnails block."""
        return self._values.get("thumbnails")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    @builtins.property
    def video(self) -> typing.Optional[typing.List["ElastictranscoderPresetVideo"]]:
        """video block."""
        return self._values.get("video")

    @builtins.property
    def video_codec_options(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("video_codec_options")

    @builtins.property
    def video_watermarks(
        self,
    ) -> typing.Optional[typing.List["ElastictranscoderPresetVideoWatermarks"]]:
        """video_watermarks block."""
        return self._values.get("video_watermarks")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPresetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPresetThumbnails",
    jsii_struct_bases=[],
    name_mapping={
        "aspect_ratio": "aspectRatio",
        "format": "format",
        "interval": "interval",
        "max_height": "maxHeight",
        "max_width": "maxWidth",
        "padding_policy": "paddingPolicy",
        "resolution": "resolution",
        "sizing_policy": "sizingPolicy",
    },
)
class ElastictranscoderPresetThumbnails:
    def __init__(
        self,
        *,
        aspect_ratio: typing.Optional[str] = None,
        format: typing.Optional[str] = None,
        interval: typing.Optional[str] = None,
        max_height: typing.Optional[str] = None,
        max_width: typing.Optional[str] = None,
        padding_policy: typing.Optional[str] = None,
        resolution: typing.Optional[str] = None,
        sizing_policy: typing.Optional[str] = None,
    ) -> None:
        """
        :param aspect_ratio: 
        :param format: 
        :param interval: 
        :param max_height: 
        :param max_width: 
        :param padding_policy: 
        :param resolution: 
        :param sizing_policy: 
        """
        self._values = {}
        if aspect_ratio is not None:
            self._values["aspect_ratio"] = aspect_ratio
        if format is not None:
            self._values["format"] = format
        if interval is not None:
            self._values["interval"] = interval
        if max_height is not None:
            self._values["max_height"] = max_height
        if max_width is not None:
            self._values["max_width"] = max_width
        if padding_policy is not None:
            self._values["padding_policy"] = padding_policy
        if resolution is not None:
            self._values["resolution"] = resolution
        if sizing_policy is not None:
            self._values["sizing_policy"] = sizing_policy

    @builtins.property
    def aspect_ratio(self) -> typing.Optional[str]:
        return self._values.get("aspect_ratio")

    @builtins.property
    def format(self) -> typing.Optional[str]:
        return self._values.get("format")

    @builtins.property
    def interval(self) -> typing.Optional[str]:
        return self._values.get("interval")

    @builtins.property
    def max_height(self) -> typing.Optional[str]:
        return self._values.get("max_height")

    @builtins.property
    def max_width(self) -> typing.Optional[str]:
        return self._values.get("max_width")

    @builtins.property
    def padding_policy(self) -> typing.Optional[str]:
        return self._values.get("padding_policy")

    @builtins.property
    def resolution(self) -> typing.Optional[str]:
        return self._values.get("resolution")

    @builtins.property
    def sizing_policy(self) -> typing.Optional[str]:
        return self._values.get("sizing_policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPresetThumbnails(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPresetVideo",
    jsii_struct_bases=[],
    name_mapping={
        "aspect_ratio": "aspectRatio",
        "bit_rate": "bitRate",
        "codec": "codec",
        "display_aspect_ratio": "displayAspectRatio",
        "fixed_gop": "fixedGop",
        "frame_rate": "frameRate",
        "keyframes_max_dist": "keyframesMaxDist",
        "max_frame_rate": "maxFrameRate",
        "max_height": "maxHeight",
        "max_width": "maxWidth",
        "padding_policy": "paddingPolicy",
        "resolution": "resolution",
        "sizing_policy": "sizingPolicy",
    },
)
class ElastictranscoderPresetVideo:
    def __init__(
        self,
        *,
        aspect_ratio: typing.Optional[str] = None,
        bit_rate: typing.Optional[str] = None,
        codec: typing.Optional[str] = None,
        display_aspect_ratio: typing.Optional[str] = None,
        fixed_gop: typing.Optional[str] = None,
        frame_rate: typing.Optional[str] = None,
        keyframes_max_dist: typing.Optional[str] = None,
        max_frame_rate: typing.Optional[str] = None,
        max_height: typing.Optional[str] = None,
        max_width: typing.Optional[str] = None,
        padding_policy: typing.Optional[str] = None,
        resolution: typing.Optional[str] = None,
        sizing_policy: typing.Optional[str] = None,
    ) -> None:
        """
        :param aspect_ratio: 
        :param bit_rate: 
        :param codec: 
        :param display_aspect_ratio: 
        :param fixed_gop: 
        :param frame_rate: 
        :param keyframes_max_dist: 
        :param max_frame_rate: 
        :param max_height: 
        :param max_width: 
        :param padding_policy: 
        :param resolution: 
        :param sizing_policy: 
        """
        self._values = {}
        if aspect_ratio is not None:
            self._values["aspect_ratio"] = aspect_ratio
        if bit_rate is not None:
            self._values["bit_rate"] = bit_rate
        if codec is not None:
            self._values["codec"] = codec
        if display_aspect_ratio is not None:
            self._values["display_aspect_ratio"] = display_aspect_ratio
        if fixed_gop is not None:
            self._values["fixed_gop"] = fixed_gop
        if frame_rate is not None:
            self._values["frame_rate"] = frame_rate
        if keyframes_max_dist is not None:
            self._values["keyframes_max_dist"] = keyframes_max_dist
        if max_frame_rate is not None:
            self._values["max_frame_rate"] = max_frame_rate
        if max_height is not None:
            self._values["max_height"] = max_height
        if max_width is not None:
            self._values["max_width"] = max_width
        if padding_policy is not None:
            self._values["padding_policy"] = padding_policy
        if resolution is not None:
            self._values["resolution"] = resolution
        if sizing_policy is not None:
            self._values["sizing_policy"] = sizing_policy

    @builtins.property
    def aspect_ratio(self) -> typing.Optional[str]:
        return self._values.get("aspect_ratio")

    @builtins.property
    def bit_rate(self) -> typing.Optional[str]:
        return self._values.get("bit_rate")

    @builtins.property
    def codec(self) -> typing.Optional[str]:
        return self._values.get("codec")

    @builtins.property
    def display_aspect_ratio(self) -> typing.Optional[str]:
        return self._values.get("display_aspect_ratio")

    @builtins.property
    def fixed_gop(self) -> typing.Optional[str]:
        return self._values.get("fixed_gop")

    @builtins.property
    def frame_rate(self) -> typing.Optional[str]:
        return self._values.get("frame_rate")

    @builtins.property
    def keyframes_max_dist(self) -> typing.Optional[str]:
        return self._values.get("keyframes_max_dist")

    @builtins.property
    def max_frame_rate(self) -> typing.Optional[str]:
        return self._values.get("max_frame_rate")

    @builtins.property
    def max_height(self) -> typing.Optional[str]:
        return self._values.get("max_height")

    @builtins.property
    def max_width(self) -> typing.Optional[str]:
        return self._values.get("max_width")

    @builtins.property
    def padding_policy(self) -> typing.Optional[str]:
        return self._values.get("padding_policy")

    @builtins.property
    def resolution(self) -> typing.Optional[str]:
        return self._values.get("resolution")

    @builtins.property
    def sizing_policy(self) -> typing.Optional[str]:
        return self._values.get("sizing_policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPresetVideo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElastictranscoderPresetVideoWatermarks",
    jsii_struct_bases=[],
    name_mapping={
        "horizontal_align": "horizontalAlign",
        "horizontal_offset": "horizontalOffset",
        "id": "id",
        "max_height": "maxHeight",
        "max_width": "maxWidth",
        "opacity": "opacity",
        "sizing_policy": "sizingPolicy",
        "target": "target",
        "vertical_align": "verticalAlign",
        "vertical_offset": "verticalOffset",
    },
)
class ElastictranscoderPresetVideoWatermarks:
    def __init__(
        self,
        *,
        horizontal_align: typing.Optional[str] = None,
        horizontal_offset: typing.Optional[str] = None,
        id: typing.Optional[str] = None,
        max_height: typing.Optional[str] = None,
        max_width: typing.Optional[str] = None,
        opacity: typing.Optional[str] = None,
        sizing_policy: typing.Optional[str] = None,
        target: typing.Optional[str] = None,
        vertical_align: typing.Optional[str] = None,
        vertical_offset: typing.Optional[str] = None,
    ) -> None:
        """
        :param horizontal_align: 
        :param horizontal_offset: 
        :param id: 
        :param max_height: 
        :param max_width: 
        :param opacity: 
        :param sizing_policy: 
        :param target: 
        :param vertical_align: 
        :param vertical_offset: 
        """
        self._values = {}
        if horizontal_align is not None:
            self._values["horizontal_align"] = horizontal_align
        if horizontal_offset is not None:
            self._values["horizontal_offset"] = horizontal_offset
        if id is not None:
            self._values["id"] = id
        if max_height is not None:
            self._values["max_height"] = max_height
        if max_width is not None:
            self._values["max_width"] = max_width
        if opacity is not None:
            self._values["opacity"] = opacity
        if sizing_policy is not None:
            self._values["sizing_policy"] = sizing_policy
        if target is not None:
            self._values["target"] = target
        if vertical_align is not None:
            self._values["vertical_align"] = vertical_align
        if vertical_offset is not None:
            self._values["vertical_offset"] = vertical_offset

    @builtins.property
    def horizontal_align(self) -> typing.Optional[str]:
        return self._values.get("horizontal_align")

    @builtins.property
    def horizontal_offset(self) -> typing.Optional[str]:
        return self._values.get("horizontal_offset")

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def max_height(self) -> typing.Optional[str]:
        return self._values.get("max_height")

    @builtins.property
    def max_width(self) -> typing.Optional[str]:
        return self._values.get("max_width")

    @builtins.property
    def opacity(self) -> typing.Optional[str]:
        return self._values.get("opacity")

    @builtins.property
    def sizing_policy(self) -> typing.Optional[str]:
        return self._values.get("sizing_policy")

    @builtins.property
    def target(self) -> typing.Optional[str]:
        return self._values.get("target")

    @builtins.property
    def vertical_align(self) -> typing.Optional[str]:
        return self._values.get("vertical_align")

    @builtins.property
    def vertical_offset(self) -> typing.Optional[str]:
        return self._values.get("vertical_offset")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElastictranscoderPresetVideoWatermarks(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Elb(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Elb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        listener: typing.List["ElbListener"],
        access_logs: typing.Optional[typing.List["ElbAccessLogs"]] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        connection_draining: typing.Optional[bool] = None,
        connection_draining_timeout: typing.Optional[jsii.Number] = None,
        cross_zone_load_balancing: typing.Optional[bool] = None,
        health_check: typing.Optional[typing.List["ElbHealthCheck"]] = None,
        idle_timeout: typing.Optional[jsii.Number] = None,
        instances: typing.Optional[typing.List[str]] = None,
        internal: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_security_group: typing.Optional[str] = None,
        subnets: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param listener: listener block.
        :param access_logs: access_logs block.
        :param availability_zones: 
        :param connection_draining: 
        :param connection_draining_timeout: 
        :param cross_zone_load_balancing: 
        :param health_check: health_check block.
        :param idle_timeout: 
        :param instances: 
        :param internal: 
        :param name: 
        :param name_prefix: 
        :param security_groups: 
        :param source_security_group: 
        :param subnets: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElbConfig(
            listener=listener,
            access_logs=access_logs,
            availability_zones=availability_zones,
            connection_draining=connection_draining,
            connection_draining_timeout=connection_draining_timeout,
            cross_zone_load_balancing=cross_zone_load_balancing,
            health_check=health_check,
            idle_timeout=idle_timeout,
            instances=instances,
            internal=internal,
            name=name,
            name_prefix=name_prefix,
            security_groups=security_groups,
            source_security_group=source_security_group,
            subnets=subnets,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Elb, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="sourceSecurityGroupId")
    def source_security_group_id(self) -> str:
        return jsii.get(self, "sourceSecurityGroupId")

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @builtins.property
    @jsii.member(jsii_name="listener")
    def listener(self) -> typing.List["ElbListener"]:
        return jsii.get(self, "listener")

    @listener.setter
    def listener(self, value: typing.List["ElbListener"]) -> None:
        jsii.set(self, "listener", value)

    @builtins.property
    @jsii.member(jsii_name="accessLogs")
    def access_logs(self) -> typing.Optional[typing.List["ElbAccessLogs"]]:
        return jsii.get(self, "accessLogs")

    @access_logs.setter
    def access_logs(self, value: typing.Optional[typing.List["ElbAccessLogs"]]) -> None:
        jsii.set(self, "accessLogs", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="connectionDraining")
    def connection_draining(self) -> typing.Optional[bool]:
        return jsii.get(self, "connectionDraining")

    @connection_draining.setter
    def connection_draining(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "connectionDraining", value)

    @builtins.property
    @jsii.member(jsii_name="connectionDrainingTimeout")
    def connection_draining_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "connectionDrainingTimeout")

    @connection_draining_timeout.setter
    def connection_draining_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "connectionDrainingTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="crossZoneLoadBalancing")
    def cross_zone_load_balancing(self) -> typing.Optional[bool]:
        return jsii.get(self, "crossZoneLoadBalancing")

    @cross_zone_load_balancing.setter
    def cross_zone_load_balancing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "crossZoneLoadBalancing", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheck")
    def health_check(self) -> typing.Optional[typing.List["ElbHealthCheck"]]:
        return jsii.get(self, "healthCheck")

    @health_check.setter
    def health_check(
        self, value: typing.Optional[typing.List["ElbHealthCheck"]]
    ) -> None:
        jsii.set(self, "healthCheck", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeout")

    @idle_timeout.setter
    def idle_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="instances")
    def instances(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "instances")

    @instances.setter
    def instances(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "instances", value)

    @builtins.property
    @jsii.member(jsii_name="internal")
    def internal(self) -> typing.Optional[bool]:
        return jsii.get(self, "internal")

    @internal.setter
    def internal(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "internal", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="sourceSecurityGroup")
    def source_security_group(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceSecurityGroup")

    @source_security_group.setter
    def source_security_group(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceSecurityGroup", value)

    @builtins.property
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnets")

    @subnets.setter
    def subnets(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnets", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElbAccessLogs",
    jsii_struct_bases=[],
    name_mapping={
        "bucket": "bucket",
        "bucket_prefix": "bucketPrefix",
        "enabled": "enabled",
        "interval": "interval",
    },
)
class ElbAccessLogs:
    def __init__(
        self,
        *,
        bucket: str,
        bucket_prefix: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        interval: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param bucket: 
        :param bucket_prefix: 
        :param enabled: 
        :param interval: 
        """
        self._values = {
            "bucket": bucket,
        }
        if bucket_prefix is not None:
            self._values["bucket_prefix"] = bucket_prefix
        if enabled is not None:
            self._values["enabled"] = enabled
        if interval is not None:
            self._values["interval"] = interval

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def bucket_prefix(self) -> typing.Optional[str]:
        return self._values.get("bucket_prefix")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("interval")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElbAccessLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ElbAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ElbAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        elb: str,
        instance: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param elb: 
        :param instance: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ElbAttachmentConfig(
            elb=elb,
            instance=instance,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ElbAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="elb")
    def elb(self) -> str:
        return jsii.get(self, "elb")

    @elb.setter
    def elb(self, value: str) -> None:
        jsii.set(self, "elb", value)

    @builtins.property
    @jsii.member(jsii_name="instance")
    def instance(self) -> str:
        return jsii.get(self, "instance")

    @instance.setter
    def instance(self, value: str) -> None:
        jsii.set(self, "instance", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElbAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "elb": "elb",
        "instance": "instance",
    },
)
class ElbAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        elb: str,
        instance: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param elb: 
        :param instance: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "elb": elb,
            "instance": instance,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def elb(self) -> str:
        return self._values.get("elb")

    @builtins.property
    def instance(self) -> str:
        return self._values.get("instance")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElbAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "listener": "listener",
        "access_logs": "accessLogs",
        "availability_zones": "availabilityZones",
        "connection_draining": "connectionDraining",
        "connection_draining_timeout": "connectionDrainingTimeout",
        "cross_zone_load_balancing": "crossZoneLoadBalancing",
        "health_check": "healthCheck",
        "idle_timeout": "idleTimeout",
        "instances": "instances",
        "internal": "internal",
        "name": "name",
        "name_prefix": "namePrefix",
        "security_groups": "securityGroups",
        "source_security_group": "sourceSecurityGroup",
        "subnets": "subnets",
        "tags": "tags",
    },
)
class ElbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        listener: typing.List["ElbListener"],
        access_logs: typing.Optional[typing.List["ElbAccessLogs"]] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        connection_draining: typing.Optional[bool] = None,
        connection_draining_timeout: typing.Optional[jsii.Number] = None,
        cross_zone_load_balancing: typing.Optional[bool] = None,
        health_check: typing.Optional[typing.List["ElbHealthCheck"]] = None,
        idle_timeout: typing.Optional[jsii.Number] = None,
        instances: typing.Optional[typing.List[str]] = None,
        internal: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_security_group: typing.Optional[str] = None,
        subnets: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param listener: listener block.
        :param access_logs: access_logs block.
        :param availability_zones: 
        :param connection_draining: 
        :param connection_draining_timeout: 
        :param cross_zone_load_balancing: 
        :param health_check: health_check block.
        :param idle_timeout: 
        :param instances: 
        :param internal: 
        :param name: 
        :param name_prefix: 
        :param security_groups: 
        :param source_security_group: 
        :param subnets: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "listener": listener,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_logs is not None:
            self._values["access_logs"] = access_logs
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if connection_draining is not None:
            self._values["connection_draining"] = connection_draining
        if connection_draining_timeout is not None:
            self._values["connection_draining_timeout"] = connection_draining_timeout
        if cross_zone_load_balancing is not None:
            self._values["cross_zone_load_balancing"] = cross_zone_load_balancing
        if health_check is not None:
            self._values["health_check"] = health_check
        if idle_timeout is not None:
            self._values["idle_timeout"] = idle_timeout
        if instances is not None:
            self._values["instances"] = instances
        if internal is not None:
            self._values["internal"] = internal
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if source_security_group is not None:
            self._values["source_security_group"] = source_security_group
        if subnets is not None:
            self._values["subnets"] = subnets
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def listener(self) -> typing.List["ElbListener"]:
        """listener block."""
        return self._values.get("listener")

    @builtins.property
    def access_logs(self) -> typing.Optional[typing.List["ElbAccessLogs"]]:
        """access_logs block."""
        return self._values.get("access_logs")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def connection_draining(self) -> typing.Optional[bool]:
        return self._values.get("connection_draining")

    @builtins.property
    def connection_draining_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("connection_draining_timeout")

    @builtins.property
    def cross_zone_load_balancing(self) -> typing.Optional[bool]:
        return self._values.get("cross_zone_load_balancing")

    @builtins.property
    def health_check(self) -> typing.Optional[typing.List["ElbHealthCheck"]]:
        """health_check block."""
        return self._values.get("health_check")

    @builtins.property
    def idle_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("idle_timeout")

    @builtins.property
    def instances(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("instances")

    @builtins.property
    def internal(self) -> typing.Optional[bool]:
        return self._values.get("internal")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def source_security_group(self) -> typing.Optional[str]:
        return self._values.get("source_security_group")

    @builtins.property
    def subnets(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnets")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElbHealthCheck",
    jsii_struct_bases=[],
    name_mapping={
        "healthy_threshold": "healthyThreshold",
        "interval": "interval",
        "target": "target",
        "timeout": "timeout",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class ElbHealthCheck:
    def __init__(
        self,
        *,
        healthy_threshold: jsii.Number,
        interval: jsii.Number,
        target: str,
        timeout: jsii.Number,
        unhealthy_threshold: jsii.Number,
    ) -> None:
        """
        :param healthy_threshold: 
        :param interval: 
        :param target: 
        :param timeout: 
        :param unhealthy_threshold: 
        """
        self._values = {
            "healthy_threshold": healthy_threshold,
            "interval": interval,
            "target": target,
            "timeout": timeout,
            "unhealthy_threshold": unhealthy_threshold,
        }

    @builtins.property
    def healthy_threshold(self) -> jsii.Number:
        return self._values.get("healthy_threshold")

    @builtins.property
    def interval(self) -> jsii.Number:
        return self._values.get("interval")

    @builtins.property
    def target(self) -> str:
        return self._values.get("target")

    @builtins.property
    def timeout(self) -> jsii.Number:
        return self._values.get("timeout")

    @builtins.property
    def unhealthy_threshold(self) -> jsii.Number:
        return self._values.get("unhealthy_threshold")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElbHealthCheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ElbListener",
    jsii_struct_bases=[],
    name_mapping={
        "instance_port": "instancePort",
        "instance_protocol": "instanceProtocol",
        "lb_port": "lbPort",
        "lb_protocol": "lbProtocol",
        "ssl_certificate_id": "sslCertificateId",
    },
)
class ElbListener:
    def __init__(
        self,
        *,
        instance_port: jsii.Number,
        instance_protocol: str,
        lb_port: jsii.Number,
        lb_protocol: str,
        ssl_certificate_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param instance_port: 
        :param instance_protocol: 
        :param lb_port: 
        :param lb_protocol: 
        :param ssl_certificate_id: 
        """
        self._values = {
            "instance_port": instance_port,
            "instance_protocol": instance_protocol,
            "lb_port": lb_port,
            "lb_protocol": lb_protocol,
        }
        if ssl_certificate_id is not None:
            self._values["ssl_certificate_id"] = ssl_certificate_id

    @builtins.property
    def instance_port(self) -> jsii.Number:
        return self._values.get("instance_port")

    @builtins.property
    def instance_protocol(self) -> str:
        return self._values.get("instance_protocol")

    @builtins.property
    def lb_port(self) -> jsii.Number:
        return self._values.get("lb_port")

    @builtins.property
    def lb_protocol(self) -> str:
        return self._values.get("lb_protocol")

    @builtins.property
    def ssl_certificate_id(self) -> typing.Optional[str]:
        return self._values.get("ssl_certificate_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ElbListener(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EmrCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EmrCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        release_label: str,
        service_role: str,
        additional_info: typing.Optional[str] = None,
        applications: typing.Optional[typing.List[str]] = None,
        autoscaling_role: typing.Optional[str] = None,
        bootstrap_action: typing.Optional[
            typing.List["EmrClusterBootstrapAction"]
        ] = None,
        configurations: typing.Optional[str] = None,
        configurations_json: typing.Optional[str] = None,
        core_instance_count: typing.Optional[jsii.Number] = None,
        core_instance_group: typing.Optional[
            typing.List["EmrClusterCoreInstanceGroup"]
        ] = None,
        core_instance_type: typing.Optional[str] = None,
        custom_ami_id: typing.Optional[str] = None,
        ebs_root_volume_size: typing.Optional[jsii.Number] = None,
        ec2_attributes: typing.Optional[typing.List["EmrClusterEc2Attributes"]] = None,
        instance_group: typing.Optional[typing.List["EmrClusterInstanceGroup"]] = None,
        keep_job_flow_alive_when_no_steps: typing.Optional[bool] = None,
        kerberos_attributes: typing.Optional[
            typing.List["EmrClusterKerberosAttributes"]
        ] = None,
        log_uri: typing.Optional[str] = None,
        master_instance_group: typing.Optional[
            typing.List["EmrClusterMasterInstanceGroup"]
        ] = None,
        master_instance_type: typing.Optional[str] = None,
        scale_down_behavior: typing.Optional[str] = None,
        security_configuration: typing.Optional[str] = None,
        step: typing.Optional[typing.List["EmrClusterStep"]] = None,
        step_concurrency_level: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        termination_protection: typing.Optional[bool] = None,
        visible_to_all_users: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param release_label: 
        :param service_role: 
        :param additional_info: 
        :param applications: 
        :param autoscaling_role: 
        :param bootstrap_action: bootstrap_action block.
        :param configurations: 
        :param configurations_json: 
        :param core_instance_count: 
        :param core_instance_group: core_instance_group block.
        :param core_instance_type: 
        :param custom_ami_id: 
        :param ebs_root_volume_size: 
        :param ec2_attributes: ec2_attributes block.
        :param instance_group: instance_group block.
        :param keep_job_flow_alive_when_no_steps: 
        :param kerberos_attributes: kerberos_attributes block.
        :param log_uri: 
        :param master_instance_group: master_instance_group block.
        :param master_instance_type: 
        :param scale_down_behavior: 
        :param security_configuration: 
        :param step: 
        :param step_concurrency_level: 
        :param tags: 
        :param termination_protection: 
        :param visible_to_all_users: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EmrClusterConfig(
            name=name,
            release_label=release_label,
            service_role=service_role,
            additional_info=additional_info,
            applications=applications,
            autoscaling_role=autoscaling_role,
            bootstrap_action=bootstrap_action,
            configurations=configurations,
            configurations_json=configurations_json,
            core_instance_count=core_instance_count,
            core_instance_group=core_instance_group,
            core_instance_type=core_instance_type,
            custom_ami_id=custom_ami_id,
            ebs_root_volume_size=ebs_root_volume_size,
            ec2_attributes=ec2_attributes,
            instance_group=instance_group,
            keep_job_flow_alive_when_no_steps=keep_job_flow_alive_when_no_steps,
            kerberos_attributes=kerberos_attributes,
            log_uri=log_uri,
            master_instance_group=master_instance_group,
            master_instance_type=master_instance_type,
            scale_down_behavior=scale_down_behavior,
            security_configuration=security_configuration,
            step=step,
            step_concurrency_level=step_concurrency_level,
            tags=tags,
            termination_protection=termination_protection,
            visible_to_all_users=visible_to_all_users,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EmrCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="clusterState")
    def cluster_state(self) -> str:
        return jsii.get(self, "clusterState")

    @builtins.property
    @jsii.member(jsii_name="masterPublicDns")
    def master_public_dns(self) -> str:
        return jsii.get(self, "masterPublicDns")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="releaseLabel")
    def release_label(self) -> str:
        return jsii.get(self, "releaseLabel")

    @release_label.setter
    def release_label(self, value: str) -> None:
        jsii.set(self, "releaseLabel", value)

    @builtins.property
    @jsii.member(jsii_name="serviceRole")
    def service_role(self) -> str:
        return jsii.get(self, "serviceRole")

    @service_role.setter
    def service_role(self, value: str) -> None:
        jsii.set(self, "serviceRole", value)

    @builtins.property
    @jsii.member(jsii_name="additionalInfo")
    def additional_info(self) -> typing.Optional[str]:
        return jsii.get(self, "additionalInfo")

    @additional_info.setter
    def additional_info(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "additionalInfo", value)

    @builtins.property
    @jsii.member(jsii_name="applications")
    def applications(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "applications")

    @applications.setter
    def applications(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "applications", value)

    @builtins.property
    @jsii.member(jsii_name="autoscalingRole")
    def autoscaling_role(self) -> typing.Optional[str]:
        return jsii.get(self, "autoscalingRole")

    @autoscaling_role.setter
    def autoscaling_role(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "autoscalingRole", value)

    @builtins.property
    @jsii.member(jsii_name="bootstrapAction")
    def bootstrap_action(
        self,
    ) -> typing.Optional[typing.List["EmrClusterBootstrapAction"]]:
        return jsii.get(self, "bootstrapAction")

    @bootstrap_action.setter
    def bootstrap_action(
        self, value: typing.Optional[typing.List["EmrClusterBootstrapAction"]]
    ) -> None:
        jsii.set(self, "bootstrapAction", value)

    @builtins.property
    @jsii.member(jsii_name="configurations")
    def configurations(self) -> typing.Optional[str]:
        return jsii.get(self, "configurations")

    @configurations.setter
    def configurations(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "configurations", value)

    @builtins.property
    @jsii.member(jsii_name="configurationsJson")
    def configurations_json(self) -> typing.Optional[str]:
        return jsii.get(self, "configurationsJson")

    @configurations_json.setter
    def configurations_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "configurationsJson", value)

    @builtins.property
    @jsii.member(jsii_name="coreInstanceCount")
    def core_instance_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "coreInstanceCount")

    @core_instance_count.setter
    def core_instance_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "coreInstanceCount", value)

    @builtins.property
    @jsii.member(jsii_name="coreInstanceGroup")
    def core_instance_group(
        self,
    ) -> typing.Optional[typing.List["EmrClusterCoreInstanceGroup"]]:
        return jsii.get(self, "coreInstanceGroup")

    @core_instance_group.setter
    def core_instance_group(
        self, value: typing.Optional[typing.List["EmrClusterCoreInstanceGroup"]]
    ) -> None:
        jsii.set(self, "coreInstanceGroup", value)

    @builtins.property
    @jsii.member(jsii_name="coreInstanceType")
    def core_instance_type(self) -> typing.Optional[str]:
        return jsii.get(self, "coreInstanceType")

    @core_instance_type.setter
    def core_instance_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "coreInstanceType", value)

    @builtins.property
    @jsii.member(jsii_name="customAmiId")
    def custom_ami_id(self) -> typing.Optional[str]:
        return jsii.get(self, "customAmiId")

    @custom_ami_id.setter
    def custom_ami_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customAmiId", value)

    @builtins.property
    @jsii.member(jsii_name="ebsRootVolumeSize")
    def ebs_root_volume_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "ebsRootVolumeSize")

    @ebs_root_volume_size.setter
    def ebs_root_volume_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "ebsRootVolumeSize", value)

    @builtins.property
    @jsii.member(jsii_name="ec2Attributes")
    def ec2_attributes(self) -> typing.Optional[typing.List["EmrClusterEc2Attributes"]]:
        return jsii.get(self, "ec2Attributes")

    @ec2_attributes.setter
    def ec2_attributes(
        self, value: typing.Optional[typing.List["EmrClusterEc2Attributes"]]
    ) -> None:
        jsii.set(self, "ec2Attributes", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceGroup")
    def instance_group(self) -> typing.Optional[typing.List["EmrClusterInstanceGroup"]]:
        return jsii.get(self, "instanceGroup")

    @instance_group.setter
    def instance_group(
        self, value: typing.Optional[typing.List["EmrClusterInstanceGroup"]]
    ) -> None:
        jsii.set(self, "instanceGroup", value)

    @builtins.property
    @jsii.member(jsii_name="keepJobFlowAliveWhenNoSteps")
    def keep_job_flow_alive_when_no_steps(self) -> typing.Optional[bool]:
        return jsii.get(self, "keepJobFlowAliveWhenNoSteps")

    @keep_job_flow_alive_when_no_steps.setter
    def keep_job_flow_alive_when_no_steps(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "keepJobFlowAliveWhenNoSteps", value)

    @builtins.property
    @jsii.member(jsii_name="kerberosAttributes")
    def kerberos_attributes(
        self,
    ) -> typing.Optional[typing.List["EmrClusterKerberosAttributes"]]:
        return jsii.get(self, "kerberosAttributes")

    @kerberos_attributes.setter
    def kerberos_attributes(
        self, value: typing.Optional[typing.List["EmrClusterKerberosAttributes"]]
    ) -> None:
        jsii.set(self, "kerberosAttributes", value)

    @builtins.property
    @jsii.member(jsii_name="logUri")
    def log_uri(self) -> typing.Optional[str]:
        return jsii.get(self, "logUri")

    @log_uri.setter
    def log_uri(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "logUri", value)

    @builtins.property
    @jsii.member(jsii_name="masterInstanceGroup")
    def master_instance_group(
        self,
    ) -> typing.Optional[typing.List["EmrClusterMasterInstanceGroup"]]:
        return jsii.get(self, "masterInstanceGroup")

    @master_instance_group.setter
    def master_instance_group(
        self, value: typing.Optional[typing.List["EmrClusterMasterInstanceGroup"]]
    ) -> None:
        jsii.set(self, "masterInstanceGroup", value)

    @builtins.property
    @jsii.member(jsii_name="masterInstanceType")
    def master_instance_type(self) -> typing.Optional[str]:
        return jsii.get(self, "masterInstanceType")

    @master_instance_type.setter
    def master_instance_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "masterInstanceType", value)

    @builtins.property
    @jsii.member(jsii_name="scaleDownBehavior")
    def scale_down_behavior(self) -> typing.Optional[str]:
        return jsii.get(self, "scaleDownBehavior")

    @scale_down_behavior.setter
    def scale_down_behavior(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "scaleDownBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="securityConfiguration")
    def security_configuration(self) -> typing.Optional[str]:
        return jsii.get(self, "securityConfiguration")

    @security_configuration.setter
    def security_configuration(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "securityConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="step")
    def step(self) -> typing.Optional[typing.List["EmrClusterStep"]]:
        return jsii.get(self, "step")

    @step.setter
    def step(self, value: typing.Optional[typing.List["EmrClusterStep"]]) -> None:
        jsii.set(self, "step", value)

    @builtins.property
    @jsii.member(jsii_name="stepConcurrencyLevel")
    def step_concurrency_level(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "stepConcurrencyLevel")

    @step_concurrency_level.setter
    def step_concurrency_level(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "stepConcurrencyLevel", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="terminationProtection")
    def termination_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "terminationProtection")

    @termination_protection.setter
    def termination_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "terminationProtection", value)

    @builtins.property
    @jsii.member(jsii_name="visibleToAllUsers")
    def visible_to_all_users(self) -> typing.Optional[bool]:
        return jsii.get(self, "visibleToAllUsers")

    @visible_to_all_users.setter
    def visible_to_all_users(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "visibleToAllUsers", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterBootstrapAction",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "path": "path", "args": "args"},
)
class EmrClusterBootstrapAction:
    def __init__(
        self, *, name: str, path: str, args: typing.Optional[typing.List[str]] = None
    ) -> None:
        """
        :param name: 
        :param path: 
        :param args: 
        """
        self._values = {
            "name": name,
            "path": path,
        }
        if args is not None:
            self._values["args"] = args

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def path(self) -> str:
        return self._values.get("path")

    @builtins.property
    def args(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("args")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterBootstrapAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "release_label": "releaseLabel",
        "service_role": "serviceRole",
        "additional_info": "additionalInfo",
        "applications": "applications",
        "autoscaling_role": "autoscalingRole",
        "bootstrap_action": "bootstrapAction",
        "configurations": "configurations",
        "configurations_json": "configurationsJson",
        "core_instance_count": "coreInstanceCount",
        "core_instance_group": "coreInstanceGroup",
        "core_instance_type": "coreInstanceType",
        "custom_ami_id": "customAmiId",
        "ebs_root_volume_size": "ebsRootVolumeSize",
        "ec2_attributes": "ec2Attributes",
        "instance_group": "instanceGroup",
        "keep_job_flow_alive_when_no_steps": "keepJobFlowAliveWhenNoSteps",
        "kerberos_attributes": "kerberosAttributes",
        "log_uri": "logUri",
        "master_instance_group": "masterInstanceGroup",
        "master_instance_type": "masterInstanceType",
        "scale_down_behavior": "scaleDownBehavior",
        "security_configuration": "securityConfiguration",
        "step": "step",
        "step_concurrency_level": "stepConcurrencyLevel",
        "tags": "tags",
        "termination_protection": "terminationProtection",
        "visible_to_all_users": "visibleToAllUsers",
    },
)
class EmrClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        release_label: str,
        service_role: str,
        additional_info: typing.Optional[str] = None,
        applications: typing.Optional[typing.List[str]] = None,
        autoscaling_role: typing.Optional[str] = None,
        bootstrap_action: typing.Optional[
            typing.List["EmrClusterBootstrapAction"]
        ] = None,
        configurations: typing.Optional[str] = None,
        configurations_json: typing.Optional[str] = None,
        core_instance_count: typing.Optional[jsii.Number] = None,
        core_instance_group: typing.Optional[
            typing.List["EmrClusterCoreInstanceGroup"]
        ] = None,
        core_instance_type: typing.Optional[str] = None,
        custom_ami_id: typing.Optional[str] = None,
        ebs_root_volume_size: typing.Optional[jsii.Number] = None,
        ec2_attributes: typing.Optional[typing.List["EmrClusterEc2Attributes"]] = None,
        instance_group: typing.Optional[typing.List["EmrClusterInstanceGroup"]] = None,
        keep_job_flow_alive_when_no_steps: typing.Optional[bool] = None,
        kerberos_attributes: typing.Optional[
            typing.List["EmrClusterKerberosAttributes"]
        ] = None,
        log_uri: typing.Optional[str] = None,
        master_instance_group: typing.Optional[
            typing.List["EmrClusterMasterInstanceGroup"]
        ] = None,
        master_instance_type: typing.Optional[str] = None,
        scale_down_behavior: typing.Optional[str] = None,
        security_configuration: typing.Optional[str] = None,
        step: typing.Optional[typing.List["EmrClusterStep"]] = None,
        step_concurrency_level: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        termination_protection: typing.Optional[bool] = None,
        visible_to_all_users: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param release_label: 
        :param service_role: 
        :param additional_info: 
        :param applications: 
        :param autoscaling_role: 
        :param bootstrap_action: bootstrap_action block.
        :param configurations: 
        :param configurations_json: 
        :param core_instance_count: 
        :param core_instance_group: core_instance_group block.
        :param core_instance_type: 
        :param custom_ami_id: 
        :param ebs_root_volume_size: 
        :param ec2_attributes: ec2_attributes block.
        :param instance_group: instance_group block.
        :param keep_job_flow_alive_when_no_steps: 
        :param kerberos_attributes: kerberos_attributes block.
        :param log_uri: 
        :param master_instance_group: master_instance_group block.
        :param master_instance_type: 
        :param scale_down_behavior: 
        :param security_configuration: 
        :param step: 
        :param step_concurrency_level: 
        :param tags: 
        :param termination_protection: 
        :param visible_to_all_users: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "release_label": release_label,
            "service_role": service_role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if additional_info is not None:
            self._values["additional_info"] = additional_info
        if applications is not None:
            self._values["applications"] = applications
        if autoscaling_role is not None:
            self._values["autoscaling_role"] = autoscaling_role
        if bootstrap_action is not None:
            self._values["bootstrap_action"] = bootstrap_action
        if configurations is not None:
            self._values["configurations"] = configurations
        if configurations_json is not None:
            self._values["configurations_json"] = configurations_json
        if core_instance_count is not None:
            self._values["core_instance_count"] = core_instance_count
        if core_instance_group is not None:
            self._values["core_instance_group"] = core_instance_group
        if core_instance_type is not None:
            self._values["core_instance_type"] = core_instance_type
        if custom_ami_id is not None:
            self._values["custom_ami_id"] = custom_ami_id
        if ebs_root_volume_size is not None:
            self._values["ebs_root_volume_size"] = ebs_root_volume_size
        if ec2_attributes is not None:
            self._values["ec2_attributes"] = ec2_attributes
        if instance_group is not None:
            self._values["instance_group"] = instance_group
        if keep_job_flow_alive_when_no_steps is not None:
            self._values[
                "keep_job_flow_alive_when_no_steps"
            ] = keep_job_flow_alive_when_no_steps
        if kerberos_attributes is not None:
            self._values["kerberos_attributes"] = kerberos_attributes
        if log_uri is not None:
            self._values["log_uri"] = log_uri
        if master_instance_group is not None:
            self._values["master_instance_group"] = master_instance_group
        if master_instance_type is not None:
            self._values["master_instance_type"] = master_instance_type
        if scale_down_behavior is not None:
            self._values["scale_down_behavior"] = scale_down_behavior
        if security_configuration is not None:
            self._values["security_configuration"] = security_configuration
        if step is not None:
            self._values["step"] = step
        if step_concurrency_level is not None:
            self._values["step_concurrency_level"] = step_concurrency_level
        if tags is not None:
            self._values["tags"] = tags
        if termination_protection is not None:
            self._values["termination_protection"] = termination_protection
        if visible_to_all_users is not None:
            self._values["visible_to_all_users"] = visible_to_all_users

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def release_label(self) -> str:
        return self._values.get("release_label")

    @builtins.property
    def service_role(self) -> str:
        return self._values.get("service_role")

    @builtins.property
    def additional_info(self) -> typing.Optional[str]:
        return self._values.get("additional_info")

    @builtins.property
    def applications(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("applications")

    @builtins.property
    def autoscaling_role(self) -> typing.Optional[str]:
        return self._values.get("autoscaling_role")

    @builtins.property
    def bootstrap_action(
        self,
    ) -> typing.Optional[typing.List["EmrClusterBootstrapAction"]]:
        """bootstrap_action block."""
        return self._values.get("bootstrap_action")

    @builtins.property
    def configurations(self) -> typing.Optional[str]:
        return self._values.get("configurations")

    @builtins.property
    def configurations_json(self) -> typing.Optional[str]:
        return self._values.get("configurations_json")

    @builtins.property
    def core_instance_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("core_instance_count")

    @builtins.property
    def core_instance_group(
        self,
    ) -> typing.Optional[typing.List["EmrClusterCoreInstanceGroup"]]:
        """core_instance_group block."""
        return self._values.get("core_instance_group")

    @builtins.property
    def core_instance_type(self) -> typing.Optional[str]:
        return self._values.get("core_instance_type")

    @builtins.property
    def custom_ami_id(self) -> typing.Optional[str]:
        return self._values.get("custom_ami_id")

    @builtins.property
    def ebs_root_volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("ebs_root_volume_size")

    @builtins.property
    def ec2_attributes(self) -> typing.Optional[typing.List["EmrClusterEc2Attributes"]]:
        """ec2_attributes block."""
        return self._values.get("ec2_attributes")

    @builtins.property
    def instance_group(self) -> typing.Optional[typing.List["EmrClusterInstanceGroup"]]:
        """instance_group block."""
        return self._values.get("instance_group")

    @builtins.property
    def keep_job_flow_alive_when_no_steps(self) -> typing.Optional[bool]:
        return self._values.get("keep_job_flow_alive_when_no_steps")

    @builtins.property
    def kerberos_attributes(
        self,
    ) -> typing.Optional[typing.List["EmrClusterKerberosAttributes"]]:
        """kerberos_attributes block."""
        return self._values.get("kerberos_attributes")

    @builtins.property
    def log_uri(self) -> typing.Optional[str]:
        return self._values.get("log_uri")

    @builtins.property
    def master_instance_group(
        self,
    ) -> typing.Optional[typing.List["EmrClusterMasterInstanceGroup"]]:
        """master_instance_group block."""
        return self._values.get("master_instance_group")

    @builtins.property
    def master_instance_type(self) -> typing.Optional[str]:
        return self._values.get("master_instance_type")

    @builtins.property
    def scale_down_behavior(self) -> typing.Optional[str]:
        return self._values.get("scale_down_behavior")

    @builtins.property
    def security_configuration(self) -> typing.Optional[str]:
        return self._values.get("security_configuration")

    @builtins.property
    def step(self) -> typing.Optional[typing.List["EmrClusterStep"]]:
        return self._values.get("step")

    @builtins.property
    def step_concurrency_level(self) -> typing.Optional[jsii.Number]:
        return self._values.get("step_concurrency_level")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def termination_protection(self) -> typing.Optional[bool]:
        return self._values.get("termination_protection")

    @builtins.property
    def visible_to_all_users(self) -> typing.Optional[bool]:
        return self._values.get("visible_to_all_users")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterCoreInstanceGroup",
    jsii_struct_bases=[],
    name_mapping={
        "instance_type": "instanceType",
        "autoscaling_policy": "autoscalingPolicy",
        "bid_price": "bidPrice",
        "ebs_config": "ebsConfig",
        "instance_count": "instanceCount",
        "name": "name",
    },
)
class EmrClusterCoreInstanceGroup:
    def __init__(
        self,
        *,
        instance_type: str,
        autoscaling_policy: typing.Optional[str] = None,
        bid_price: typing.Optional[str] = None,
        ebs_config: typing.Optional[
            typing.List["EmrClusterCoreInstanceGroupEbsConfig"]
        ] = None,
        instance_count: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param instance_type: 
        :param autoscaling_policy: 
        :param bid_price: 
        :param ebs_config: ebs_config block.
        :param instance_count: 
        :param name: 
        """
        self._values = {
            "instance_type": instance_type,
        }
        if autoscaling_policy is not None:
            self._values["autoscaling_policy"] = autoscaling_policy
        if bid_price is not None:
            self._values["bid_price"] = bid_price
        if ebs_config is not None:
            self._values["ebs_config"] = ebs_config
        if instance_count is not None:
            self._values["instance_count"] = instance_count
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def autoscaling_policy(self) -> typing.Optional[str]:
        return self._values.get("autoscaling_policy")

    @builtins.property
    def bid_price(self) -> typing.Optional[str]:
        return self._values.get("bid_price")

    @builtins.property
    def ebs_config(
        self,
    ) -> typing.Optional[typing.List["EmrClusterCoreInstanceGroupEbsConfig"]]:
        """ebs_config block."""
        return self._values.get("ebs_config")

    @builtins.property
    def instance_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_count")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterCoreInstanceGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterCoreInstanceGroupEbsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "size": "size",
        "type": "type",
        "iops": "iops",
        "volumes_per_instance": "volumesPerInstance",
    },
)
class EmrClusterCoreInstanceGroupEbsConfig:
    def __init__(
        self,
        *,
        size: jsii.Number,
        type: str,
        iops: typing.Optional[jsii.Number] = None,
        volumes_per_instance: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param size: 
        :param type: 
        :param iops: 
        :param volumes_per_instance: 
        """
        self._values = {
            "size": size,
            "type": type,
        }
        if iops is not None:
            self._values["iops"] = iops
        if volumes_per_instance is not None:
            self._values["volumes_per_instance"] = volumes_per_instance

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def volumes_per_instance(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volumes_per_instance")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterCoreInstanceGroupEbsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterEc2Attributes",
    jsii_struct_bases=[],
    name_mapping={
        "instance_profile": "instanceProfile",
        "additional_master_security_groups": "additionalMasterSecurityGroups",
        "additional_slave_security_groups": "additionalSlaveSecurityGroups",
        "emr_managed_master_security_group": "emrManagedMasterSecurityGroup",
        "emr_managed_slave_security_group": "emrManagedSlaveSecurityGroup",
        "key_name": "keyName",
        "service_access_security_group": "serviceAccessSecurityGroup",
        "subnet_id": "subnetId",
    },
)
class EmrClusterEc2Attributes:
    def __init__(
        self,
        *,
        instance_profile: str,
        additional_master_security_groups: typing.Optional[str] = None,
        additional_slave_security_groups: typing.Optional[str] = None,
        emr_managed_master_security_group: typing.Optional[str] = None,
        emr_managed_slave_security_group: typing.Optional[str] = None,
        key_name: typing.Optional[str] = None,
        service_access_security_group: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param instance_profile: 
        :param additional_master_security_groups: 
        :param additional_slave_security_groups: 
        :param emr_managed_master_security_group: 
        :param emr_managed_slave_security_group: 
        :param key_name: 
        :param service_access_security_group: 
        :param subnet_id: 
        """
        self._values = {
            "instance_profile": instance_profile,
        }
        if additional_master_security_groups is not None:
            self._values[
                "additional_master_security_groups"
            ] = additional_master_security_groups
        if additional_slave_security_groups is not None:
            self._values[
                "additional_slave_security_groups"
            ] = additional_slave_security_groups
        if emr_managed_master_security_group is not None:
            self._values[
                "emr_managed_master_security_group"
            ] = emr_managed_master_security_group
        if emr_managed_slave_security_group is not None:
            self._values[
                "emr_managed_slave_security_group"
            ] = emr_managed_slave_security_group
        if key_name is not None:
            self._values["key_name"] = key_name
        if service_access_security_group is not None:
            self._values[
                "service_access_security_group"
            ] = service_access_security_group
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def instance_profile(self) -> str:
        return self._values.get("instance_profile")

    @builtins.property
    def additional_master_security_groups(self) -> typing.Optional[str]:
        return self._values.get("additional_master_security_groups")

    @builtins.property
    def additional_slave_security_groups(self) -> typing.Optional[str]:
        return self._values.get("additional_slave_security_groups")

    @builtins.property
    def emr_managed_master_security_group(self) -> typing.Optional[str]:
        return self._values.get("emr_managed_master_security_group")

    @builtins.property
    def emr_managed_slave_security_group(self) -> typing.Optional[str]:
        return self._values.get("emr_managed_slave_security_group")

    @builtins.property
    def key_name(self) -> typing.Optional[str]:
        return self._values.get("key_name")

    @builtins.property
    def service_access_security_group(self) -> typing.Optional[str]:
        return self._values.get("service_access_security_group")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterEc2Attributes(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterInstanceGroup",
    jsii_struct_bases=[],
    name_mapping={
        "instance_role": "instanceRole",
        "instance_type": "instanceType",
        "autoscaling_policy": "autoscalingPolicy",
        "bid_price": "bidPrice",
        "ebs_config": "ebsConfig",
        "instance_count": "instanceCount",
        "name": "name",
    },
)
class EmrClusterInstanceGroup:
    def __init__(
        self,
        *,
        instance_role: str,
        instance_type: str,
        autoscaling_policy: typing.Optional[str] = None,
        bid_price: typing.Optional[str] = None,
        ebs_config: typing.Optional[
            typing.List["EmrClusterInstanceGroupEbsConfig"]
        ] = None,
        instance_count: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param instance_role: 
        :param instance_type: 
        :param autoscaling_policy: 
        :param bid_price: 
        :param ebs_config: ebs_config block.
        :param instance_count: 
        :param name: 
        """
        self._values = {
            "instance_role": instance_role,
            "instance_type": instance_type,
        }
        if autoscaling_policy is not None:
            self._values["autoscaling_policy"] = autoscaling_policy
        if bid_price is not None:
            self._values["bid_price"] = bid_price
        if ebs_config is not None:
            self._values["ebs_config"] = ebs_config
        if instance_count is not None:
            self._values["instance_count"] = instance_count
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def instance_role(self) -> str:
        return self._values.get("instance_role")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def autoscaling_policy(self) -> typing.Optional[str]:
        return self._values.get("autoscaling_policy")

    @builtins.property
    def bid_price(self) -> typing.Optional[str]:
        return self._values.get("bid_price")

    @builtins.property
    def ebs_config(
        self,
    ) -> typing.Optional[typing.List["EmrClusterInstanceGroupEbsConfig"]]:
        """ebs_config block."""
        return self._values.get("ebs_config")

    @builtins.property
    def instance_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_count")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterInstanceGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterInstanceGroupEbsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "size": "size",
        "type": "type",
        "iops": "iops",
        "volumes_per_instance": "volumesPerInstance",
    },
)
class EmrClusterInstanceGroupEbsConfig:
    def __init__(
        self,
        *,
        size: jsii.Number,
        type: str,
        iops: typing.Optional[jsii.Number] = None,
        volumes_per_instance: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param size: 
        :param type: 
        :param iops: 
        :param volumes_per_instance: 
        """
        self._values = {
            "size": size,
            "type": type,
        }
        if iops is not None:
            self._values["iops"] = iops
        if volumes_per_instance is not None:
            self._values["volumes_per_instance"] = volumes_per_instance

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def volumes_per_instance(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volumes_per_instance")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterInstanceGroupEbsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterKerberosAttributes",
    jsii_struct_bases=[],
    name_mapping={
        "kdc_admin_password": "kdcAdminPassword",
        "realm": "realm",
        "ad_domain_join_password": "adDomainJoinPassword",
        "ad_domain_join_user": "adDomainJoinUser",
        "cross_realm_trust_principal_password": "crossRealmTrustPrincipalPassword",
    },
)
class EmrClusterKerberosAttributes:
    def __init__(
        self,
        *,
        kdc_admin_password: str,
        realm: str,
        ad_domain_join_password: typing.Optional[str] = None,
        ad_domain_join_user: typing.Optional[str] = None,
        cross_realm_trust_principal_password: typing.Optional[str] = None,
    ) -> None:
        """
        :param kdc_admin_password: 
        :param realm: 
        :param ad_domain_join_password: 
        :param ad_domain_join_user: 
        :param cross_realm_trust_principal_password: 
        """
        self._values = {
            "kdc_admin_password": kdc_admin_password,
            "realm": realm,
        }
        if ad_domain_join_password is not None:
            self._values["ad_domain_join_password"] = ad_domain_join_password
        if ad_domain_join_user is not None:
            self._values["ad_domain_join_user"] = ad_domain_join_user
        if cross_realm_trust_principal_password is not None:
            self._values[
                "cross_realm_trust_principal_password"
            ] = cross_realm_trust_principal_password

    @builtins.property
    def kdc_admin_password(self) -> str:
        return self._values.get("kdc_admin_password")

    @builtins.property
    def realm(self) -> str:
        return self._values.get("realm")

    @builtins.property
    def ad_domain_join_password(self) -> typing.Optional[str]:
        return self._values.get("ad_domain_join_password")

    @builtins.property
    def ad_domain_join_user(self) -> typing.Optional[str]:
        return self._values.get("ad_domain_join_user")

    @builtins.property
    def cross_realm_trust_principal_password(self) -> typing.Optional[str]:
        return self._values.get("cross_realm_trust_principal_password")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterKerberosAttributes(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterMasterInstanceGroup",
    jsii_struct_bases=[],
    name_mapping={
        "instance_type": "instanceType",
        "bid_price": "bidPrice",
        "ebs_config": "ebsConfig",
        "instance_count": "instanceCount",
        "name": "name",
    },
)
class EmrClusterMasterInstanceGroup:
    def __init__(
        self,
        *,
        instance_type: str,
        bid_price: typing.Optional[str] = None,
        ebs_config: typing.Optional[
            typing.List["EmrClusterMasterInstanceGroupEbsConfig"]
        ] = None,
        instance_count: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param instance_type: 
        :param bid_price: 
        :param ebs_config: ebs_config block.
        :param instance_count: 
        :param name: 
        """
        self._values = {
            "instance_type": instance_type,
        }
        if bid_price is not None:
            self._values["bid_price"] = bid_price
        if ebs_config is not None:
            self._values["ebs_config"] = ebs_config
        if instance_count is not None:
            self._values["instance_count"] = instance_count
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def bid_price(self) -> typing.Optional[str]:
        return self._values.get("bid_price")

    @builtins.property
    def ebs_config(
        self,
    ) -> typing.Optional[typing.List["EmrClusterMasterInstanceGroupEbsConfig"]]:
        """ebs_config block."""
        return self._values.get("ebs_config")

    @builtins.property
    def instance_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_count")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterMasterInstanceGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterMasterInstanceGroupEbsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "size": "size",
        "type": "type",
        "iops": "iops",
        "volumes_per_instance": "volumesPerInstance",
    },
)
class EmrClusterMasterInstanceGroupEbsConfig:
    def __init__(
        self,
        *,
        size: jsii.Number,
        type: str,
        iops: typing.Optional[jsii.Number] = None,
        volumes_per_instance: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param size: 
        :param type: 
        :param iops: 
        :param volumes_per_instance: 
        """
        self._values = {
            "size": size,
            "type": type,
        }
        if iops is not None:
            self._values["iops"] = iops
        if volumes_per_instance is not None:
            self._values["volumes_per_instance"] = volumes_per_instance

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def volumes_per_instance(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volumes_per_instance")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterMasterInstanceGroupEbsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterStep",
    jsii_struct_bases=[],
    name_mapping={
        "action_on_failure": "actionOnFailure",
        "hadoop_jar_step": "hadoopJarStep",
        "name": "name",
    },
)
class EmrClusterStep:
    def __init__(
        self,
        *,
        action_on_failure: typing.Optional[str] = None,
        hadoop_jar_step: typing.Optional[
            typing.List["EmrClusterStepHadoopJarStep"]
        ] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param action_on_failure: 
        :param hadoop_jar_step: 
        :param name: 
        """
        self._values = {}
        if action_on_failure is not None:
            self._values["action_on_failure"] = action_on_failure
        if hadoop_jar_step is not None:
            self._values["hadoop_jar_step"] = hadoop_jar_step
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def action_on_failure(self) -> typing.Optional[str]:
        return self._values.get("action_on_failure")

    @builtins.property
    def hadoop_jar_step(
        self,
    ) -> typing.Optional[typing.List["EmrClusterStepHadoopJarStep"]]:
        return self._values.get("hadoop_jar_step")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterStep(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrClusterStepHadoopJarStep",
    jsii_struct_bases=[],
    name_mapping={
        "args": "args",
        "jar": "jar",
        "main_class": "mainClass",
        "properties": "properties",
    },
)
class EmrClusterStepHadoopJarStep:
    def __init__(
        self,
        *,
        args: typing.Optional[typing.List[str]] = None,
        jar: typing.Optional[str] = None,
        main_class: typing.Optional[str] = None,
        properties: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param args: 
        :param jar: 
        :param main_class: 
        :param properties: 
        """
        self._values = {}
        if args is not None:
            self._values["args"] = args
        if jar is not None:
            self._values["jar"] = jar
        if main_class is not None:
            self._values["main_class"] = main_class
        if properties is not None:
            self._values["properties"] = properties

    @builtins.property
    def args(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("args")

    @builtins.property
    def jar(self) -> typing.Optional[str]:
        return self._values.get("jar")

    @builtins.property
    def main_class(self) -> typing.Optional[str]:
        return self._values.get("main_class")

    @builtins.property
    def properties(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("properties")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrClusterStepHadoopJarStep(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EmrInstanceGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EmrInstanceGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_id: str,
        instance_type: str,
        autoscaling_policy: typing.Optional[str] = None,
        bid_price: typing.Optional[str] = None,
        configurations_json: typing.Optional[str] = None,
        ebs_config: typing.Optional[typing.List["EmrInstanceGroupEbsConfig"]] = None,
        ebs_optimized: typing.Optional[bool] = None,
        instance_count: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_id: 
        :param instance_type: 
        :param autoscaling_policy: 
        :param bid_price: 
        :param configurations_json: 
        :param ebs_config: ebs_config block.
        :param ebs_optimized: 
        :param instance_count: 
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EmrInstanceGroupConfig(
            cluster_id=cluster_id,
            instance_type=instance_type,
            autoscaling_policy=autoscaling_policy,
            bid_price=bid_price,
            configurations_json=configurations_json,
            ebs_config=ebs_config,
            ebs_optimized=ebs_optimized,
            instance_count=instance_count,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EmrInstanceGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="runningInstanceCount")
    def running_instance_count(self) -> jsii.Number:
        return jsii.get(self, "runningInstanceCount")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="clusterId")
    def cluster_id(self) -> str:
        return jsii.get(self, "clusterId")

    @cluster_id.setter
    def cluster_id(self, value: str) -> None:
        jsii.set(self, "clusterId", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: str) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="autoscalingPolicy")
    def autoscaling_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "autoscalingPolicy")

    @autoscaling_policy.setter
    def autoscaling_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "autoscalingPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="bidPrice")
    def bid_price(self) -> typing.Optional[str]:
        return jsii.get(self, "bidPrice")

    @bid_price.setter
    def bid_price(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bidPrice", value)

    @builtins.property
    @jsii.member(jsii_name="configurationsJson")
    def configurations_json(self) -> typing.Optional[str]:
        return jsii.get(self, "configurationsJson")

    @configurations_json.setter
    def configurations_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "configurationsJson", value)

    @builtins.property
    @jsii.member(jsii_name="ebsConfig")
    def ebs_config(self) -> typing.Optional[typing.List["EmrInstanceGroupEbsConfig"]]:
        return jsii.get(self, "ebsConfig")

    @ebs_config.setter
    def ebs_config(
        self, value: typing.Optional[typing.List["EmrInstanceGroupEbsConfig"]]
    ) -> None:
        jsii.set(self, "ebsConfig", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> typing.Optional[bool]:
        return jsii.get(self, "ebsOptimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ebsOptimized", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceCount")
    def instance_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceCount")

    @instance_count.setter
    def instance_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceCount", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrInstanceGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_id": "clusterId",
        "instance_type": "instanceType",
        "autoscaling_policy": "autoscalingPolicy",
        "bid_price": "bidPrice",
        "configurations_json": "configurationsJson",
        "ebs_config": "ebsConfig",
        "ebs_optimized": "ebsOptimized",
        "instance_count": "instanceCount",
        "name": "name",
    },
)
class EmrInstanceGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_id: str,
        instance_type: str,
        autoscaling_policy: typing.Optional[str] = None,
        bid_price: typing.Optional[str] = None,
        configurations_json: typing.Optional[str] = None,
        ebs_config: typing.Optional[typing.List["EmrInstanceGroupEbsConfig"]] = None,
        ebs_optimized: typing.Optional[bool] = None,
        instance_count: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_id: 
        :param instance_type: 
        :param autoscaling_policy: 
        :param bid_price: 
        :param configurations_json: 
        :param ebs_config: ebs_config block.
        :param ebs_optimized: 
        :param instance_count: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_id": cluster_id,
            "instance_type": instance_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if autoscaling_policy is not None:
            self._values["autoscaling_policy"] = autoscaling_policy
        if bid_price is not None:
            self._values["bid_price"] = bid_price
        if configurations_json is not None:
            self._values["configurations_json"] = configurations_json
        if ebs_config is not None:
            self._values["ebs_config"] = ebs_config
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if instance_count is not None:
            self._values["instance_count"] = instance_count
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_id(self) -> str:
        return self._values.get("cluster_id")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def autoscaling_policy(self) -> typing.Optional[str]:
        return self._values.get("autoscaling_policy")

    @builtins.property
    def bid_price(self) -> typing.Optional[str]:
        return self._values.get("bid_price")

    @builtins.property
    def configurations_json(self) -> typing.Optional[str]:
        return self._values.get("configurations_json")

    @builtins.property
    def ebs_config(self) -> typing.Optional[typing.List["EmrInstanceGroupEbsConfig"]]:
        """ebs_config block."""
        return self._values.get("ebs_config")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[bool]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def instance_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_count")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrInstanceGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrInstanceGroupEbsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "size": "size",
        "type": "type",
        "iops": "iops",
        "volumes_per_instance": "volumesPerInstance",
    },
)
class EmrInstanceGroupEbsConfig:
    def __init__(
        self,
        *,
        size: jsii.Number,
        type: str,
        iops: typing.Optional[jsii.Number] = None,
        volumes_per_instance: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param size: 
        :param type: 
        :param iops: 
        :param volumes_per_instance: 
        """
        self._values = {
            "size": size,
            "type": type,
        }
        if iops is not None:
            self._values["iops"] = iops
        if volumes_per_instance is not None:
            self._values["volumes_per_instance"] = volumes_per_instance

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def volumes_per_instance(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volumes_per_instance")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrInstanceGroupEbsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class EmrSecurityConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.EmrSecurityConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        configuration: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param configuration: 
        :param name: 
        :param name_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = EmrSecurityConfigurationConfig(
            configuration=configuration,
            name=name,
            name_prefix=name_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(EmrSecurityConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="configuration")
    def configuration(self) -> str:
        return jsii.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: str) -> None:
        jsii.set(self, "configuration", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.EmrSecurityConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "configuration": "configuration",
        "name": "name",
        "name_prefix": "namePrefix",
    },
)
class EmrSecurityConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        configuration: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param configuration: 
        :param name: 
        :param name_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "configuration": configuration,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def configuration(self) -> str:
        return self._values.get("configuration")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "EmrSecurityConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FlowLog(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.FlowLog",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        traffic_type: str,
        eni_id: typing.Optional[str] = None,
        iam_role_arn: typing.Optional[str] = None,
        log_destination: typing.Optional[str] = None,
        log_destination_type: typing.Optional[str] = None,
        log_format: typing.Optional[str] = None,
        log_group_name: typing.Optional[str] = None,
        max_aggregation_interval: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param traffic_type: 
        :param eni_id: 
        :param iam_role_arn: 
        :param log_destination: 
        :param log_destination_type: 
        :param log_format: 
        :param log_group_name: 
        :param max_aggregation_interval: 
        :param subnet_id: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FlowLogConfig(
            traffic_type=traffic_type,
            eni_id=eni_id,
            iam_role_arn=iam_role_arn,
            log_destination=log_destination,
            log_destination_type=log_destination_type,
            log_format=log_format,
            log_group_name=log_group_name,
            max_aggregation_interval=max_aggregation_interval,
            subnet_id=subnet_id,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FlowLog, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="trafficType")
    def traffic_type(self) -> str:
        return jsii.get(self, "trafficType")

    @traffic_type.setter
    def traffic_type(self, value: str) -> None:
        jsii.set(self, "trafficType", value)

    @builtins.property
    @jsii.member(jsii_name="eniId")
    def eni_id(self) -> typing.Optional[str]:
        return jsii.get(self, "eniId")

    @eni_id.setter
    def eni_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "eniId", value)

    @builtins.property
    @jsii.member(jsii_name="iamRoleArn")
    def iam_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "iamRoleArn")

    @iam_role_arn.setter
    def iam_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="logDestination")
    def log_destination(self) -> typing.Optional[str]:
        return jsii.get(self, "logDestination")

    @log_destination.setter
    def log_destination(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "logDestination", value)

    @builtins.property
    @jsii.member(jsii_name="logDestinationType")
    def log_destination_type(self) -> typing.Optional[str]:
        return jsii.get(self, "logDestinationType")

    @log_destination_type.setter
    def log_destination_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "logDestinationType", value)

    @builtins.property
    @jsii.member(jsii_name="logFormat")
    def log_format(self) -> typing.Optional[str]:
        return jsii.get(self, "logFormat")

    @log_format.setter
    def log_format(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "logFormat", value)

    @builtins.property
    @jsii.member(jsii_name="logGroupName")
    def log_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "logGroupName")

    @log_group_name.setter
    def log_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "logGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="maxAggregationInterval")
    def max_aggregation_interval(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxAggregationInterval")

    @max_aggregation_interval.setter
    def max_aggregation_interval(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxAggregationInterval", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.FlowLogConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "traffic_type": "trafficType",
        "eni_id": "eniId",
        "iam_role_arn": "iamRoleArn",
        "log_destination": "logDestination",
        "log_destination_type": "logDestinationType",
        "log_format": "logFormat",
        "log_group_name": "logGroupName",
        "max_aggregation_interval": "maxAggregationInterval",
        "subnet_id": "subnetId",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class FlowLogConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        traffic_type: str,
        eni_id: typing.Optional[str] = None,
        iam_role_arn: typing.Optional[str] = None,
        log_destination: typing.Optional[str] = None,
        log_destination_type: typing.Optional[str] = None,
        log_format: typing.Optional[str] = None,
        log_group_name: typing.Optional[str] = None,
        max_aggregation_interval: typing.Optional[jsii.Number] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param traffic_type: 
        :param eni_id: 
        :param iam_role_arn: 
        :param log_destination: 
        :param log_destination_type: 
        :param log_format: 
        :param log_group_name: 
        :param max_aggregation_interval: 
        :param subnet_id: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "traffic_type": traffic_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if eni_id is not None:
            self._values["eni_id"] = eni_id
        if iam_role_arn is not None:
            self._values["iam_role_arn"] = iam_role_arn
        if log_destination is not None:
            self._values["log_destination"] = log_destination
        if log_destination_type is not None:
            self._values["log_destination_type"] = log_destination_type
        if log_format is not None:
            self._values["log_format"] = log_format
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if max_aggregation_interval is not None:
            self._values["max_aggregation_interval"] = max_aggregation_interval
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def traffic_type(self) -> str:
        return self._values.get("traffic_type")

    @builtins.property
    def eni_id(self) -> typing.Optional[str]:
        return self._values.get("eni_id")

    @builtins.property
    def iam_role_arn(self) -> typing.Optional[str]:
        return self._values.get("iam_role_arn")

    @builtins.property
    def log_destination(self) -> typing.Optional[str]:
        return self._values.get("log_destination")

    @builtins.property
    def log_destination_type(self) -> typing.Optional[str]:
        return self._values.get("log_destination_type")

    @builtins.property
    def log_format(self) -> typing.Optional[str]:
        return self._values.get("log_format")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def max_aggregation_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_aggregation_interval")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FlowLogConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FmsAdminAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.FmsAdminAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FmsAdminAccountConfig(
            account_id=account_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FmsAdminAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.FmsAdminAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_id": "accountId",
    },
)
class FmsAdminAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if account_id is not None:
            self._values["account_id"] = account_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_id(self) -> typing.Optional[str]:
        return self._values.get("account_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FmsAdminAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FsxLustreFileSystem(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.FsxLustreFileSystem",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        storage_capacity: jsii.Number,
        subnet_ids: typing.List[str],
        export_path: typing.Optional[str] = None,
        imported_file_chunk_size: typing.Optional[jsii.Number] = None,
        import_path: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["FsxLustreFileSystemTimeouts"] = None,
        weekly_maintenance_start_time: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param storage_capacity: 
        :param subnet_ids: 
        :param export_path: 
        :param imported_file_chunk_size: 
        :param import_path: 
        :param security_group_ids: 
        :param tags: 
        :param timeouts: timeouts block.
        :param weekly_maintenance_start_time: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FsxLustreFileSystemConfig(
            storage_capacity=storage_capacity,
            subnet_ids=subnet_ids,
            export_path=export_path,
            imported_file_chunk_size=imported_file_chunk_size,
            import_path=import_path,
            security_group_ids=security_group_ids,
            tags=tags,
            timeouts=timeouts,
            weekly_maintenance_start_time=weekly_maintenance_start_time,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FsxLustreFileSystem, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceIds")
    def network_interface_ids(self) -> typing.List[str]:
        return jsii.get(self, "networkInterfaceIds")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="storageCapacity")
    def storage_capacity(self) -> jsii.Number:
        return jsii.get(self, "storageCapacity")

    @storage_capacity.setter
    def storage_capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "storageCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="exportPath")
    def export_path(self) -> typing.Optional[str]:
        return jsii.get(self, "exportPath")

    @export_path.setter
    def export_path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "exportPath", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="importedFileChunkSize")
    def imported_file_chunk_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "importedFileChunkSize")

    @imported_file_chunk_size.setter
    def imported_file_chunk_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "importedFileChunkSize", value)

    @builtins.property
    @jsii.member(jsii_name="importPath")
    def import_path(self) -> typing.Optional[str]:
        return jsii.get(self, "importPath")

    @import_path.setter
    def import_path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "importPath", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FsxLustreFileSystemTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["FsxLustreFileSystemTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="weeklyMaintenanceStartTime")
    def weekly_maintenance_start_time(self) -> typing.Optional[str]:
        return jsii.get(self, "weeklyMaintenanceStartTime")

    @weekly_maintenance_start_time.setter
    def weekly_maintenance_start_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "weeklyMaintenanceStartTime", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.FsxLustreFileSystemConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "storage_capacity": "storageCapacity",
        "subnet_ids": "subnetIds",
        "export_path": "exportPath",
        "imported_file_chunk_size": "importedFileChunkSize",
        "import_path": "importPath",
        "security_group_ids": "securityGroupIds",
        "tags": "tags",
        "timeouts": "timeouts",
        "weekly_maintenance_start_time": "weeklyMaintenanceStartTime",
    },
)
class FsxLustreFileSystemConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        storage_capacity: jsii.Number,
        subnet_ids: typing.List[str],
        export_path: typing.Optional[str] = None,
        imported_file_chunk_size: typing.Optional[jsii.Number] = None,
        import_path: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["FsxLustreFileSystemTimeouts"] = None,
        weekly_maintenance_start_time: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param storage_capacity: 
        :param subnet_ids: 
        :param export_path: 
        :param imported_file_chunk_size: 
        :param import_path: 
        :param security_group_ids: 
        :param tags: 
        :param timeouts: timeouts block.
        :param weekly_maintenance_start_time: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FsxLustreFileSystemTimeouts(**timeouts)
        self._values = {
            "storage_capacity": storage_capacity,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if export_path is not None:
            self._values["export_path"] = export_path
        if imported_file_chunk_size is not None:
            self._values["imported_file_chunk_size"] = imported_file_chunk_size
        if import_path is not None:
            self._values["import_path"] = import_path
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if weekly_maintenance_start_time is not None:
            self._values[
                "weekly_maintenance_start_time"
            ] = weekly_maintenance_start_time

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def storage_capacity(self) -> jsii.Number:
        return self._values.get("storage_capacity")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def export_path(self) -> typing.Optional[str]:
        return self._values.get("export_path")

    @builtins.property
    def imported_file_chunk_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("imported_file_chunk_size")

    @builtins.property
    def import_path(self) -> typing.Optional[str]:
        return self._values.get("import_path")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["FsxLustreFileSystemTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def weekly_maintenance_start_time(self) -> typing.Optional[str]:
        return self._values.get("weekly_maintenance_start_time")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FsxLustreFileSystemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.FsxLustreFileSystemTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class FsxLustreFileSystemTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FsxLustreFileSystemTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class FsxWindowsFileSystem(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.FsxWindowsFileSystem",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        storage_capacity: jsii.Number,
        subnet_ids: typing.List[str],
        throughput_capacity: jsii.Number,
        active_directory_id: typing.Optional[str] = None,
        automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
        copy_tags_to_backups: typing.Optional[bool] = None,
        daily_automatic_backup_start_time: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        self_managed_active_directory: typing.Optional[
            typing.List["FsxWindowsFileSystemSelfManagedActiveDirectory"]
        ] = None,
        skip_final_backup: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["FsxWindowsFileSystemTimeouts"] = None,
        weekly_maintenance_start_time: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param storage_capacity: 
        :param subnet_ids: 
        :param throughput_capacity: 
        :param active_directory_id: 
        :param automatic_backup_retention_days: 
        :param copy_tags_to_backups: 
        :param daily_automatic_backup_start_time: 
        :param kms_key_id: 
        :param security_group_ids: 
        :param self_managed_active_directory: self_managed_active_directory block.
        :param skip_final_backup: 
        :param tags: 
        :param timeouts: timeouts block.
        :param weekly_maintenance_start_time: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = FsxWindowsFileSystemConfig(
            storage_capacity=storage_capacity,
            subnet_ids=subnet_ids,
            throughput_capacity=throughput_capacity,
            active_directory_id=active_directory_id,
            automatic_backup_retention_days=automatic_backup_retention_days,
            copy_tags_to_backups=copy_tags_to_backups,
            daily_automatic_backup_start_time=daily_automatic_backup_start_time,
            kms_key_id=kms_key_id,
            security_group_ids=security_group_ids,
            self_managed_active_directory=self_managed_active_directory,
            skip_final_backup=skip_final_backup,
            tags=tags,
            timeouts=timeouts,
            weekly_maintenance_start_time=weekly_maintenance_start_time,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(FsxWindowsFileSystem, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceIds")
    def network_interface_ids(self) -> typing.List[str]:
        return jsii.get(self, "networkInterfaceIds")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="storageCapacity")
    def storage_capacity(self) -> jsii.Number:
        return jsii.get(self, "storageCapacity")

    @storage_capacity.setter
    def storage_capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "storageCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="throughputCapacity")
    def throughput_capacity(self) -> jsii.Number:
        return jsii.get(self, "throughputCapacity")

    @throughput_capacity.setter
    def throughput_capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "throughputCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="activeDirectoryId")
    def active_directory_id(self) -> typing.Optional[str]:
        return jsii.get(self, "activeDirectoryId")

    @active_directory_id.setter
    def active_directory_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "activeDirectoryId", value)

    @builtins.property
    @jsii.member(jsii_name="automaticBackupRetentionDays")
    def automatic_backup_retention_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "automaticBackupRetentionDays")

    @automatic_backup_retention_days.setter
    def automatic_backup_retention_days(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "automaticBackupRetentionDays", value)

    @builtins.property
    @jsii.member(jsii_name="copyTagsToBackups")
    def copy_tags_to_backups(self) -> typing.Optional[bool]:
        return jsii.get(self, "copyTagsToBackups")

    @copy_tags_to_backups.setter
    def copy_tags_to_backups(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "copyTagsToBackups", value)

    @builtins.property
    @jsii.member(jsii_name="dailyAutomaticBackupStartTime")
    def daily_automatic_backup_start_time(self) -> typing.Optional[str]:
        return jsii.get(self, "dailyAutomaticBackupStartTime")

    @daily_automatic_backup_start_time.setter
    def daily_automatic_backup_start_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dailyAutomaticBackupStartTime", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="selfManagedActiveDirectory")
    def self_managed_active_directory(
        self,
    ) -> typing.Optional[typing.List["FsxWindowsFileSystemSelfManagedActiveDirectory"]]:
        return jsii.get(self, "selfManagedActiveDirectory")

    @self_managed_active_directory.setter
    def self_managed_active_directory(
        self,
        value: typing.Optional[
            typing.List["FsxWindowsFileSystemSelfManagedActiveDirectory"]
        ],
    ) -> None:
        jsii.set(self, "selfManagedActiveDirectory", value)

    @builtins.property
    @jsii.member(jsii_name="skipFinalBackup")
    def skip_final_backup(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipFinalBackup")

    @skip_final_backup.setter
    def skip_final_backup(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipFinalBackup", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["FsxWindowsFileSystemTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["FsxWindowsFileSystemTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="weeklyMaintenanceStartTime")
    def weekly_maintenance_start_time(self) -> typing.Optional[str]:
        return jsii.get(self, "weeklyMaintenanceStartTime")

    @weekly_maintenance_start_time.setter
    def weekly_maintenance_start_time(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "weeklyMaintenanceStartTime", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.FsxWindowsFileSystemConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "storage_capacity": "storageCapacity",
        "subnet_ids": "subnetIds",
        "throughput_capacity": "throughputCapacity",
        "active_directory_id": "activeDirectoryId",
        "automatic_backup_retention_days": "automaticBackupRetentionDays",
        "copy_tags_to_backups": "copyTagsToBackups",
        "daily_automatic_backup_start_time": "dailyAutomaticBackupStartTime",
        "kms_key_id": "kmsKeyId",
        "security_group_ids": "securityGroupIds",
        "self_managed_active_directory": "selfManagedActiveDirectory",
        "skip_final_backup": "skipFinalBackup",
        "tags": "tags",
        "timeouts": "timeouts",
        "weekly_maintenance_start_time": "weeklyMaintenanceStartTime",
    },
)
class FsxWindowsFileSystemConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        storage_capacity: jsii.Number,
        subnet_ids: typing.List[str],
        throughput_capacity: jsii.Number,
        active_directory_id: typing.Optional[str] = None,
        automatic_backup_retention_days: typing.Optional[jsii.Number] = None,
        copy_tags_to_backups: typing.Optional[bool] = None,
        daily_automatic_backup_start_time: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        self_managed_active_directory: typing.Optional[
            typing.List["FsxWindowsFileSystemSelfManagedActiveDirectory"]
        ] = None,
        skip_final_backup: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["FsxWindowsFileSystemTimeouts"] = None,
        weekly_maintenance_start_time: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param storage_capacity: 
        :param subnet_ids: 
        :param throughput_capacity: 
        :param active_directory_id: 
        :param automatic_backup_retention_days: 
        :param copy_tags_to_backups: 
        :param daily_automatic_backup_start_time: 
        :param kms_key_id: 
        :param security_group_ids: 
        :param self_managed_active_directory: self_managed_active_directory block.
        :param skip_final_backup: 
        :param tags: 
        :param timeouts: timeouts block.
        :param weekly_maintenance_start_time: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = FsxWindowsFileSystemTimeouts(**timeouts)
        self._values = {
            "storage_capacity": storage_capacity,
            "subnet_ids": subnet_ids,
            "throughput_capacity": throughput_capacity,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if active_directory_id is not None:
            self._values["active_directory_id"] = active_directory_id
        if automatic_backup_retention_days is not None:
            self._values[
                "automatic_backup_retention_days"
            ] = automatic_backup_retention_days
        if copy_tags_to_backups is not None:
            self._values["copy_tags_to_backups"] = copy_tags_to_backups
        if daily_automatic_backup_start_time is not None:
            self._values[
                "daily_automatic_backup_start_time"
            ] = daily_automatic_backup_start_time
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if self_managed_active_directory is not None:
            self._values[
                "self_managed_active_directory"
            ] = self_managed_active_directory
        if skip_final_backup is not None:
            self._values["skip_final_backup"] = skip_final_backup
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if weekly_maintenance_start_time is not None:
            self._values[
                "weekly_maintenance_start_time"
            ] = weekly_maintenance_start_time

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def storage_capacity(self) -> jsii.Number:
        return self._values.get("storage_capacity")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def throughput_capacity(self) -> jsii.Number:
        return self._values.get("throughput_capacity")

    @builtins.property
    def active_directory_id(self) -> typing.Optional[str]:
        return self._values.get("active_directory_id")

    @builtins.property
    def automatic_backup_retention_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("automatic_backup_retention_days")

    @builtins.property
    def copy_tags_to_backups(self) -> typing.Optional[bool]:
        return self._values.get("copy_tags_to_backups")

    @builtins.property
    def daily_automatic_backup_start_time(self) -> typing.Optional[str]:
        return self._values.get("daily_automatic_backup_start_time")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def self_managed_active_directory(
        self,
    ) -> typing.Optional[typing.List["FsxWindowsFileSystemSelfManagedActiveDirectory"]]:
        """self_managed_active_directory block."""
        return self._values.get("self_managed_active_directory")

    @builtins.property
    def skip_final_backup(self) -> typing.Optional[bool]:
        return self._values.get("skip_final_backup")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["FsxWindowsFileSystemTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def weekly_maintenance_start_time(self) -> typing.Optional[str]:
        return self._values.get("weekly_maintenance_start_time")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FsxWindowsFileSystemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.FsxWindowsFileSystemSelfManagedActiveDirectory",
    jsii_struct_bases=[],
    name_mapping={
        "dns_ips": "dnsIps",
        "domain_name": "domainName",
        "password": "password",
        "username": "username",
        "file_system_administrators_group": "fileSystemAdministratorsGroup",
        "organizational_unit_distinguished_name": "organizationalUnitDistinguishedName",
    },
)
class FsxWindowsFileSystemSelfManagedActiveDirectory:
    def __init__(
        self,
        *,
        dns_ips: typing.List[str],
        domain_name: str,
        password: str,
        username: str,
        file_system_administrators_group: typing.Optional[str] = None,
        organizational_unit_distinguished_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param dns_ips: 
        :param domain_name: 
        :param password: 
        :param username: 
        :param file_system_administrators_group: 
        :param organizational_unit_distinguished_name: 
        """
        self._values = {
            "dns_ips": dns_ips,
            "domain_name": domain_name,
            "password": password,
            "username": username,
        }
        if file_system_administrators_group is not None:
            self._values[
                "file_system_administrators_group"
            ] = file_system_administrators_group
        if organizational_unit_distinguished_name is not None:
            self._values[
                "organizational_unit_distinguished_name"
            ] = organizational_unit_distinguished_name

    @builtins.property
    def dns_ips(self) -> typing.List[str]:
        return self._values.get("dns_ips")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def password(self) -> str:
        return self._values.get("password")

    @builtins.property
    def username(self) -> str:
        return self._values.get("username")

    @builtins.property
    def file_system_administrators_group(self) -> typing.Optional[str]:
        return self._values.get("file_system_administrators_group")

    @builtins.property
    def organizational_unit_distinguished_name(self) -> typing.Optional[str]:
        return self._values.get("organizational_unit_distinguished_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FsxWindowsFileSystemSelfManagedActiveDirectory(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.FsxWindowsFileSystemTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class FsxWindowsFileSystemTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "FsxWindowsFileSystemTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GameliftAlias(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        routing_strategy: typing.List["GameliftAliasRoutingStrategy"],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param routing_strategy: routing_strategy block.
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GameliftAliasConfig(
            name=name,
            routing_strategy=routing_strategy,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GameliftAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="routingStrategy")
    def routing_strategy(self) -> typing.List["GameliftAliasRoutingStrategy"]:
        return jsii.get(self, "routingStrategy")

    @routing_strategy.setter
    def routing_strategy(
        self, value: typing.List["GameliftAliasRoutingStrategy"]
    ) -> None:
        jsii.set(self, "routingStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "routing_strategy": "routingStrategy",
        "description": "description",
        "tags": "tags",
    },
)
class GameliftAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        routing_strategy: typing.List["GameliftAliasRoutingStrategy"],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param routing_strategy: routing_strategy block.
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "routing_strategy": routing_strategy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def routing_strategy(self) -> typing.List["GameliftAliasRoutingStrategy"]:
        """routing_strategy block."""
        return self._values.get("routing_strategy")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftAliasRoutingStrategy",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "fleet_id": "fleetId", "message": "message"},
)
class GameliftAliasRoutingStrategy:
    def __init__(
        self,
        *,
        type: str,
        fleet_id: typing.Optional[str] = None,
        message: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param fleet_id: 
        :param message: 
        """
        self._values = {
            "type": type,
        }
        if fleet_id is not None:
            self._values["fleet_id"] = fleet_id
        if message is not None:
            self._values["message"] = message

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def fleet_id(self) -> typing.Optional[str]:
        return self._values.get("fleet_id")

    @builtins.property
    def message(self) -> typing.Optional[str]:
        return self._values.get("message")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftAliasRoutingStrategy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GameliftBuild(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftBuild",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        operating_system: str,
        storage_location: typing.List["GameliftBuildStorageLocation"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        version: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param operating_system: 
        :param storage_location: storage_location block.
        :param tags: 
        :param version: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GameliftBuildConfig(
            name=name,
            operating_system=operating_system,
            storage_location=storage_location,
            tags=tags,
            version=version,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GameliftBuild, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="operatingSystem")
    def operating_system(self) -> str:
        return jsii.get(self, "operatingSystem")

    @operating_system.setter
    def operating_system(self, value: str) -> None:
        jsii.set(self, "operatingSystem", value)

    @builtins.property
    @jsii.member(jsii_name="storageLocation")
    def storage_location(self) -> typing.List["GameliftBuildStorageLocation"]:
        return jsii.get(self, "storageLocation")

    @storage_location.setter
    def storage_location(
        self, value: typing.List["GameliftBuildStorageLocation"]
    ) -> None:
        jsii.set(self, "storageLocation", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> typing.Optional[str]:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "version", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftBuildConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "operating_system": "operatingSystem",
        "storage_location": "storageLocation",
        "tags": "tags",
        "version": "version",
    },
)
class GameliftBuildConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        operating_system: str,
        storage_location: typing.List["GameliftBuildStorageLocation"],
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param operating_system: 
        :param storage_location: storage_location block.
        :param tags: 
        :param version: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "operating_system": operating_system,
            "storage_location": storage_location,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def operating_system(self) -> str:
        return self._values.get("operating_system")

    @builtins.property
    def storage_location(self) -> typing.List["GameliftBuildStorageLocation"]:
        """storage_location block."""
        return self._values.get("storage_location")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftBuildConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftBuildStorageLocation",
    jsii_struct_bases=[],
    name_mapping={"bucket": "bucket", "key": "key", "role_arn": "roleArn"},
)
class GameliftBuildStorageLocation:
    def __init__(self, *, bucket: str, key: str, role_arn: str) -> None:
        """
        :param bucket: 
        :param key: 
        :param role_arn: 
        """
        self._values = {
            "bucket": bucket,
            "key": key,
            "role_arn": role_arn,
        }

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftBuildStorageLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GameliftFleet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftFleet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        build_id: str,
        ec2_instance_type: str,
        name: str,
        description: typing.Optional[str] = None,
        ec2_inbound_permission: typing.Optional[
            typing.List["GameliftFleetEc2InboundPermission"]
        ] = None,
        fleet_type: typing.Optional[str] = None,
        instance_role_arn: typing.Optional[str] = None,
        metric_groups: typing.Optional[typing.List[str]] = None,
        new_game_session_protection_policy: typing.Optional[str] = None,
        resource_creation_limit_policy: typing.Optional[
            typing.List["GameliftFleetResourceCreationLimitPolicy"]
        ] = None,
        runtime_configuration: typing.Optional[
            typing.List["GameliftFleetRuntimeConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["GameliftFleetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param build_id: 
        :param ec2_instance_type: 
        :param name: 
        :param description: 
        :param ec2_inbound_permission: ec2_inbound_permission block.
        :param fleet_type: 
        :param instance_role_arn: 
        :param metric_groups: 
        :param new_game_session_protection_policy: 
        :param resource_creation_limit_policy: resource_creation_limit_policy block.
        :param runtime_configuration: runtime_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GameliftFleetConfig(
            build_id=build_id,
            ec2_instance_type=ec2_instance_type,
            name=name,
            description=description,
            ec2_inbound_permission=ec2_inbound_permission,
            fleet_type=fleet_type,
            instance_role_arn=instance_role_arn,
            metric_groups=metric_groups,
            new_game_session_protection_policy=new_game_session_protection_policy,
            resource_creation_limit_policy=resource_creation_limit_policy,
            runtime_configuration=runtime_configuration,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GameliftFleet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="logPaths")
    def log_paths(self) -> typing.List[str]:
        return jsii.get(self, "logPaths")

    @builtins.property
    @jsii.member(jsii_name="operatingSystem")
    def operating_system(self) -> str:
        return jsii.get(self, "operatingSystem")

    @builtins.property
    @jsii.member(jsii_name="buildId")
    def build_id(self) -> str:
        return jsii.get(self, "buildId")

    @build_id.setter
    def build_id(self, value: str) -> None:
        jsii.set(self, "buildId", value)

    @builtins.property
    @jsii.member(jsii_name="ec2InstanceType")
    def ec2_instance_type(self) -> str:
        return jsii.get(self, "ec2InstanceType")

    @ec2_instance_type.setter
    def ec2_instance_type(self, value: str) -> None:
        jsii.set(self, "ec2InstanceType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="ec2InboundPermission")
    def ec2_inbound_permission(
        self,
    ) -> typing.Optional[typing.List["GameliftFleetEc2InboundPermission"]]:
        return jsii.get(self, "ec2InboundPermission")

    @ec2_inbound_permission.setter
    def ec2_inbound_permission(
        self, value: typing.Optional[typing.List["GameliftFleetEc2InboundPermission"]]
    ) -> None:
        jsii.set(self, "ec2InboundPermission", value)

    @builtins.property
    @jsii.member(jsii_name="fleetType")
    def fleet_type(self) -> typing.Optional[str]:
        return jsii.get(self, "fleetType")

    @fleet_type.setter
    def fleet_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "fleetType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceRoleArn")
    def instance_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceRoleArn")

    @instance_role_arn.setter
    def instance_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="metricGroups")
    def metric_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "metricGroups")

    @metric_groups.setter
    def metric_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "metricGroups", value)

    @builtins.property
    @jsii.member(jsii_name="newGameSessionProtectionPolicy")
    def new_game_session_protection_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "newGameSessionProtectionPolicy")

    @new_game_session_protection_policy.setter
    def new_game_session_protection_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "newGameSessionProtectionPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="resourceCreationLimitPolicy")
    def resource_creation_limit_policy(
        self,
    ) -> typing.Optional[typing.List["GameliftFleetResourceCreationLimitPolicy"]]:
        return jsii.get(self, "resourceCreationLimitPolicy")

    @resource_creation_limit_policy.setter
    def resource_creation_limit_policy(
        self,
        value: typing.Optional[typing.List["GameliftFleetResourceCreationLimitPolicy"]],
    ) -> None:
        jsii.set(self, "resourceCreationLimitPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="runtimeConfiguration")
    def runtime_configuration(
        self,
    ) -> typing.Optional[typing.List["GameliftFleetRuntimeConfiguration"]]:
        return jsii.get(self, "runtimeConfiguration")

    @runtime_configuration.setter
    def runtime_configuration(
        self, value: typing.Optional[typing.List["GameliftFleetRuntimeConfiguration"]]
    ) -> None:
        jsii.set(self, "runtimeConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["GameliftFleetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["GameliftFleetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftFleetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "build_id": "buildId",
        "ec2_instance_type": "ec2InstanceType",
        "name": "name",
        "description": "description",
        "ec2_inbound_permission": "ec2InboundPermission",
        "fleet_type": "fleetType",
        "instance_role_arn": "instanceRoleArn",
        "metric_groups": "metricGroups",
        "new_game_session_protection_policy": "newGameSessionProtectionPolicy",
        "resource_creation_limit_policy": "resourceCreationLimitPolicy",
        "runtime_configuration": "runtimeConfiguration",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class GameliftFleetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        build_id: str,
        ec2_instance_type: str,
        name: str,
        description: typing.Optional[str] = None,
        ec2_inbound_permission: typing.Optional[
            typing.List["GameliftFleetEc2InboundPermission"]
        ] = None,
        fleet_type: typing.Optional[str] = None,
        instance_role_arn: typing.Optional[str] = None,
        metric_groups: typing.Optional[typing.List[str]] = None,
        new_game_session_protection_policy: typing.Optional[str] = None,
        resource_creation_limit_policy: typing.Optional[
            typing.List["GameliftFleetResourceCreationLimitPolicy"]
        ] = None,
        runtime_configuration: typing.Optional[
            typing.List["GameliftFleetRuntimeConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["GameliftFleetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param build_id: 
        :param ec2_instance_type: 
        :param name: 
        :param description: 
        :param ec2_inbound_permission: ec2_inbound_permission block.
        :param fleet_type: 
        :param instance_role_arn: 
        :param metric_groups: 
        :param new_game_session_protection_policy: 
        :param resource_creation_limit_policy: resource_creation_limit_policy block.
        :param runtime_configuration: runtime_configuration block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = GameliftFleetTimeouts(**timeouts)
        self._values = {
            "build_id": build_id,
            "ec2_instance_type": ec2_instance_type,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if ec2_inbound_permission is not None:
            self._values["ec2_inbound_permission"] = ec2_inbound_permission
        if fleet_type is not None:
            self._values["fleet_type"] = fleet_type
        if instance_role_arn is not None:
            self._values["instance_role_arn"] = instance_role_arn
        if metric_groups is not None:
            self._values["metric_groups"] = metric_groups
        if new_game_session_protection_policy is not None:
            self._values[
                "new_game_session_protection_policy"
            ] = new_game_session_protection_policy
        if resource_creation_limit_policy is not None:
            self._values[
                "resource_creation_limit_policy"
            ] = resource_creation_limit_policy
        if runtime_configuration is not None:
            self._values["runtime_configuration"] = runtime_configuration
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def build_id(self) -> str:
        return self._values.get("build_id")

    @builtins.property
    def ec2_instance_type(self) -> str:
        return self._values.get("ec2_instance_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def ec2_inbound_permission(
        self,
    ) -> typing.Optional[typing.List["GameliftFleetEc2InboundPermission"]]:
        """ec2_inbound_permission block."""
        return self._values.get("ec2_inbound_permission")

    @builtins.property
    def fleet_type(self) -> typing.Optional[str]:
        return self._values.get("fleet_type")

    @builtins.property
    def instance_role_arn(self) -> typing.Optional[str]:
        return self._values.get("instance_role_arn")

    @builtins.property
    def metric_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("metric_groups")

    @builtins.property
    def new_game_session_protection_policy(self) -> typing.Optional[str]:
        return self._values.get("new_game_session_protection_policy")

    @builtins.property
    def resource_creation_limit_policy(
        self,
    ) -> typing.Optional[typing.List["GameliftFleetResourceCreationLimitPolicy"]]:
        """resource_creation_limit_policy block."""
        return self._values.get("resource_creation_limit_policy")

    @builtins.property
    def runtime_configuration(
        self,
    ) -> typing.Optional[typing.List["GameliftFleetRuntimeConfiguration"]]:
        """runtime_configuration block."""
        return self._values.get("runtime_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["GameliftFleetTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftFleetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftFleetEc2InboundPermission",
    jsii_struct_bases=[],
    name_mapping={
        "from_port": "fromPort",
        "ip_range": "ipRange",
        "protocol": "protocol",
        "to_port": "toPort",
    },
)
class GameliftFleetEc2InboundPermission:
    def __init__(
        self,
        *,
        from_port: jsii.Number,
        ip_range: str,
        protocol: str,
        to_port: jsii.Number,
    ) -> None:
        """
        :param from_port: 
        :param ip_range: 
        :param protocol: 
        :param to_port: 
        """
        self._values = {
            "from_port": from_port,
            "ip_range": ip_range,
            "protocol": protocol,
            "to_port": to_port,
        }

    @builtins.property
    def from_port(self) -> jsii.Number:
        return self._values.get("from_port")

    @builtins.property
    def ip_range(self) -> str:
        return self._values.get("ip_range")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def to_port(self) -> jsii.Number:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftFleetEc2InboundPermission(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftFleetResourceCreationLimitPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "new_game_sessions_per_creator": "newGameSessionsPerCreator",
        "policy_period_in_minutes": "policyPeriodInMinutes",
    },
)
class GameliftFleetResourceCreationLimitPolicy:
    def __init__(
        self,
        *,
        new_game_sessions_per_creator: typing.Optional[jsii.Number] = None,
        policy_period_in_minutes: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param new_game_sessions_per_creator: 
        :param policy_period_in_minutes: 
        """
        self._values = {}
        if new_game_sessions_per_creator is not None:
            self._values[
                "new_game_sessions_per_creator"
            ] = new_game_sessions_per_creator
        if policy_period_in_minutes is not None:
            self._values["policy_period_in_minutes"] = policy_period_in_minutes

    @builtins.property
    def new_game_sessions_per_creator(self) -> typing.Optional[jsii.Number]:
        return self._values.get("new_game_sessions_per_creator")

    @builtins.property
    def policy_period_in_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("policy_period_in_minutes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftFleetResourceCreationLimitPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftFleetRuntimeConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "game_session_activation_timeout_seconds": "gameSessionActivationTimeoutSeconds",
        "max_concurrent_game_session_activations": "maxConcurrentGameSessionActivations",
        "server_process": "serverProcess",
    },
)
class GameliftFleetRuntimeConfiguration:
    def __init__(
        self,
        *,
        game_session_activation_timeout_seconds: typing.Optional[jsii.Number] = None,
        max_concurrent_game_session_activations: typing.Optional[jsii.Number] = None,
        server_process: typing.Optional[
            typing.List["GameliftFleetRuntimeConfigurationServerProcess"]
        ] = None,
    ) -> None:
        """
        :param game_session_activation_timeout_seconds: 
        :param max_concurrent_game_session_activations: 
        :param server_process: server_process block.
        """
        self._values = {}
        if game_session_activation_timeout_seconds is not None:
            self._values[
                "game_session_activation_timeout_seconds"
            ] = game_session_activation_timeout_seconds
        if max_concurrent_game_session_activations is not None:
            self._values[
                "max_concurrent_game_session_activations"
            ] = max_concurrent_game_session_activations
        if server_process is not None:
            self._values["server_process"] = server_process

    @builtins.property
    def game_session_activation_timeout_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("game_session_activation_timeout_seconds")

    @builtins.property
    def max_concurrent_game_session_activations(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_concurrent_game_session_activations")

    @builtins.property
    def server_process(
        self,
    ) -> typing.Optional[typing.List["GameliftFleetRuntimeConfigurationServerProcess"]]:
        """server_process block."""
        return self._values.get("server_process")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftFleetRuntimeConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftFleetRuntimeConfigurationServerProcess",
    jsii_struct_bases=[],
    name_mapping={
        "concurrent_executions": "concurrentExecutions",
        "launch_path": "launchPath",
        "parameters": "parameters",
    },
)
class GameliftFleetRuntimeConfigurationServerProcess:
    def __init__(
        self,
        *,
        concurrent_executions: jsii.Number,
        launch_path: str,
        parameters: typing.Optional[str] = None,
    ) -> None:
        """
        :param concurrent_executions: 
        :param launch_path: 
        :param parameters: 
        """
        self._values = {
            "concurrent_executions": concurrent_executions,
            "launch_path": launch_path,
        }
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def concurrent_executions(self) -> jsii.Number:
        return self._values.get("concurrent_executions")

    @builtins.property
    def launch_path(self) -> str:
        return self._values.get("launch_path")

    @builtins.property
    def parameters(self) -> typing.Optional[str]:
        return self._values.get("parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftFleetRuntimeConfigurationServerProcess(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftFleetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class GameliftFleetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftFleetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GameliftGameSessionQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftGameSessionQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        destinations: typing.Optional[typing.List[str]] = None,
        player_latency_policy: typing.Optional[
            typing.List["GameliftGameSessionQueuePlayerLatencyPolicy"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeout_in_seconds: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param destinations: 
        :param player_latency_policy: player_latency_policy block.
        :param tags: 
        :param timeout_in_seconds: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GameliftGameSessionQueueConfig(
            name=name,
            destinations=destinations,
            player_latency_policy=player_latency_policy,
            tags=tags,
            timeout_in_seconds=timeout_in_seconds,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GameliftGameSessionQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="destinations")
    def destinations(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "destinations")

    @destinations.setter
    def destinations(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "destinations", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="playerLatencyPolicy")
    def player_latency_policy(
        self,
    ) -> typing.Optional[typing.List["GameliftGameSessionQueuePlayerLatencyPolicy"]]:
        return jsii.get(self, "playerLatencyPolicy")

    @player_latency_policy.setter
    def player_latency_policy(
        self,
        value: typing.Optional[
            typing.List["GameliftGameSessionQueuePlayerLatencyPolicy"]
        ],
    ) -> None:
        jsii.set(self, "playerLatencyPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeoutInSeconds")
    def timeout_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "timeoutInSeconds")

    @timeout_in_seconds.setter
    def timeout_in_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "timeoutInSeconds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftGameSessionQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "destinations": "destinations",
        "player_latency_policy": "playerLatencyPolicy",
        "tags": "tags",
        "timeout_in_seconds": "timeoutInSeconds",
    },
)
class GameliftGameSessionQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        destinations: typing.Optional[typing.List[str]] = None,
        player_latency_policy: typing.Optional[
            typing.List["GameliftGameSessionQueuePlayerLatencyPolicy"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeout_in_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param destinations: 
        :param player_latency_policy: player_latency_policy block.
        :param tags: 
        :param timeout_in_seconds: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if destinations is not None:
            self._values["destinations"] = destinations
        if player_latency_policy is not None:
            self._values["player_latency_policy"] = player_latency_policy
        if tags is not None:
            self._values["tags"] = tags
        if timeout_in_seconds is not None:
            self._values["timeout_in_seconds"] = timeout_in_seconds

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def destinations(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("destinations")

    @builtins.property
    def player_latency_policy(
        self,
    ) -> typing.Optional[typing.List["GameliftGameSessionQueuePlayerLatencyPolicy"]]:
        """player_latency_policy block."""
        return self._values.get("player_latency_policy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeout_in_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout_in_seconds")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftGameSessionQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GameliftGameSessionQueuePlayerLatencyPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "maximum_individual_player_latency_milliseconds": "maximumIndividualPlayerLatencyMilliseconds",
        "policy_duration_seconds": "policyDurationSeconds",
    },
)
class GameliftGameSessionQueuePlayerLatencyPolicy:
    def __init__(
        self,
        *,
        maximum_individual_player_latency_milliseconds: jsii.Number,
        policy_duration_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param maximum_individual_player_latency_milliseconds: 
        :param policy_duration_seconds: 
        """
        self._values = {
            "maximum_individual_player_latency_milliseconds": maximum_individual_player_latency_milliseconds,
        }
        if policy_duration_seconds is not None:
            self._values["policy_duration_seconds"] = policy_duration_seconds

    @builtins.property
    def maximum_individual_player_latency_milliseconds(self) -> jsii.Number:
        return self._values.get("maximum_individual_player_latency_milliseconds")

    @builtins.property
    def policy_duration_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("policy_duration_seconds")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GameliftGameSessionQueuePlayerLatencyPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlacierVault(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlacierVault",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        access_policy: typing.Optional[str] = None,
        notification: typing.Optional[typing.List["GlacierVaultNotification"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param access_policy: 
        :param notification: notification block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlacierVaultConfig(
            name=name,
            access_policy=access_policy,
            notification=notification,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlacierVault, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="location")
    def location(self) -> str:
        return jsii.get(self, "location")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="accessPolicy")
    def access_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "accessPolicy")

    @access_policy.setter
    def access_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accessPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="notification")
    def notification(self) -> typing.Optional[typing.List["GlacierVaultNotification"]]:
        return jsii.get(self, "notification")

    @notification.setter
    def notification(
        self, value: typing.Optional[typing.List["GlacierVaultNotification"]]
    ) -> None:
        jsii.set(self, "notification", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlacierVaultConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "access_policy": "accessPolicy",
        "notification": "notification",
        "tags": "tags",
    },
)
class GlacierVaultConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        access_policy: typing.Optional[str] = None,
        notification: typing.Optional[typing.List["GlacierVaultNotification"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param access_policy: 
        :param notification: notification block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_policy is not None:
            self._values["access_policy"] = access_policy
        if notification is not None:
            self._values["notification"] = notification
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def access_policy(self) -> typing.Optional[str]:
        return self._values.get("access_policy")

    @builtins.property
    def notification(self) -> typing.Optional[typing.List["GlacierVaultNotification"]]:
        """notification block."""
        return self._values.get("notification")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlacierVaultConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlacierVaultLock(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlacierVaultLock",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        complete_lock: bool,
        policy: str,
        vault_name: str,
        ignore_deletion_error: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param complete_lock: 
        :param policy: 
        :param vault_name: 
        :param ignore_deletion_error: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlacierVaultLockConfig(
            complete_lock=complete_lock,
            policy=policy,
            vault_name=vault_name,
            ignore_deletion_error=ignore_deletion_error,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlacierVaultLock, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="completeLock")
    def complete_lock(self) -> bool:
        return jsii.get(self, "completeLock")

    @complete_lock.setter
    def complete_lock(self, value: bool) -> None:
        jsii.set(self, "completeLock", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="vaultName")
    def vault_name(self) -> str:
        return jsii.get(self, "vaultName")

    @vault_name.setter
    def vault_name(self, value: str) -> None:
        jsii.set(self, "vaultName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ignoreDeletionError")
    def ignore_deletion_error(self) -> typing.Optional[bool]:
        return jsii.get(self, "ignoreDeletionError")

    @ignore_deletion_error.setter
    def ignore_deletion_error(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ignoreDeletionError", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlacierVaultLockConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "complete_lock": "completeLock",
        "policy": "policy",
        "vault_name": "vaultName",
        "ignore_deletion_error": "ignoreDeletionError",
    },
)
class GlacierVaultLockConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        complete_lock: bool,
        policy: str,
        vault_name: str,
        ignore_deletion_error: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param complete_lock: 
        :param policy: 
        :param vault_name: 
        :param ignore_deletion_error: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "complete_lock": complete_lock,
            "policy": policy,
            "vault_name": vault_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ignore_deletion_error is not None:
            self._values["ignore_deletion_error"] = ignore_deletion_error

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def complete_lock(self) -> bool:
        return self._values.get("complete_lock")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def vault_name(self) -> str:
        return self._values.get("vault_name")

    @builtins.property
    def ignore_deletion_error(self) -> typing.Optional[bool]:
        return self._values.get("ignore_deletion_error")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlacierVaultLockConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlacierVaultNotification",
    jsii_struct_bases=[],
    name_mapping={"events": "events", "sns_topic": "snsTopic"},
)
class GlacierVaultNotification:
    def __init__(self, *, events: typing.List[str], sns_topic: str) -> None:
        """
        :param events: 
        :param sns_topic: 
        """
        self._values = {
            "events": events,
            "sns_topic": sns_topic,
        }

    @builtins.property
    def events(self) -> typing.List[str]:
        return self._values.get("events")

    @builtins.property
    def sns_topic(self) -> str:
        return self._values.get("sns_topic")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlacierVaultNotification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlobalacceleratorAccelerator(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorAccelerator",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        attributes: typing.Optional[
            typing.List["GlobalacceleratorAcceleratorAttributes"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        ip_address_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param attributes: attributes block.
        :param enabled: 
        :param ip_address_type: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlobalacceleratorAcceleratorConfig(
            name=name,
            attributes=attributes,
            enabled=enabled,
            ip_address_type=ip_address_type,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlobalacceleratorAccelerator, self, [scope, id, config])

    @jsii.member(jsii_name="ipSets")
    def ip_sets(self, index: str) -> "GlobalacceleratorAcceleratorIpSets":
        """
        :param index: -
        """
        return jsii.invoke(self, "ipSets", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="attributes")
    def attributes(
        self,
    ) -> typing.Optional[typing.List["GlobalacceleratorAcceleratorAttributes"]]:
        return jsii.get(self, "attributes")

    @attributes.setter
    def attributes(
        self,
        value: typing.Optional[typing.List["GlobalacceleratorAcceleratorAttributes"]],
    ) -> None:
        jsii.set(self, "attributes", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddressType")
    def ip_address_type(self) -> typing.Optional[str]:
        return jsii.get(self, "ipAddressType")

    @ip_address_type.setter
    def ip_address_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipAddressType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorAcceleratorAttributes",
    jsii_struct_bases=[],
    name_mapping={
        "flow_logs_enabled": "flowLogsEnabled",
        "flow_logs_s3_bucket": "flowLogsS3Bucket",
        "flow_logs_s3_prefix": "flowLogsS3Prefix",
    },
)
class GlobalacceleratorAcceleratorAttributes:
    def __init__(
        self,
        *,
        flow_logs_enabled: typing.Optional[bool] = None,
        flow_logs_s3_bucket: typing.Optional[str] = None,
        flow_logs_s3_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param flow_logs_enabled: 
        :param flow_logs_s3_bucket: 
        :param flow_logs_s3_prefix: 
        """
        self._values = {}
        if flow_logs_enabled is not None:
            self._values["flow_logs_enabled"] = flow_logs_enabled
        if flow_logs_s3_bucket is not None:
            self._values["flow_logs_s3_bucket"] = flow_logs_s3_bucket
        if flow_logs_s3_prefix is not None:
            self._values["flow_logs_s3_prefix"] = flow_logs_s3_prefix

    @builtins.property
    def flow_logs_enabled(self) -> typing.Optional[bool]:
        return self._values.get("flow_logs_enabled")

    @builtins.property
    def flow_logs_s3_bucket(self) -> typing.Optional[str]:
        return self._values.get("flow_logs_s3_bucket")

    @builtins.property
    def flow_logs_s3_prefix(self) -> typing.Optional[str]:
        return self._values.get("flow_logs_s3_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlobalacceleratorAcceleratorAttributes(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorAcceleratorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "attributes": "attributes",
        "enabled": "enabled",
        "ip_address_type": "ipAddressType",
        "tags": "tags",
    },
)
class GlobalacceleratorAcceleratorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        attributes: typing.Optional[
            typing.List["GlobalacceleratorAcceleratorAttributes"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        ip_address_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param attributes: attributes block.
        :param enabled: 
        :param ip_address_type: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attributes is not None:
            self._values["attributes"] = attributes
        if enabled is not None:
            self._values["enabled"] = enabled
        if ip_address_type is not None:
            self._values["ip_address_type"] = ip_address_type
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def attributes(
        self,
    ) -> typing.Optional[typing.List["GlobalacceleratorAcceleratorAttributes"]]:
        """attributes block."""
        return self._values.get("attributes")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def ip_address_type(self) -> typing.Optional[str]:
        return self._values.get("ip_address_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlobalacceleratorAcceleratorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlobalacceleratorAcceleratorIpSets(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorAcceleratorIpSets",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            GlobalacceleratorAcceleratorIpSets,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="ipAddresses")
    def ip_addresses(self) -> typing.List[str]:
        return jsii.get(self, "ipAddresses")

    @builtins.property
    @jsii.member(jsii_name="ipFamily")
    def ip_family(self) -> str:
        return jsii.get(self, "ipFamily")


class GlobalacceleratorEndpointGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorEndpointGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        listener_arn: str,
        endpoint_configuration: typing.Optional[
            typing.List["GlobalacceleratorEndpointGroupEndpointConfiguration"]
        ] = None,
        endpoint_group_region: typing.Optional[str] = None,
        health_check_interval_seconds: typing.Optional[jsii.Number] = None,
        health_check_path: typing.Optional[str] = None,
        health_check_port: typing.Optional[jsii.Number] = None,
        health_check_protocol: typing.Optional[str] = None,
        threshold_count: typing.Optional[jsii.Number] = None,
        traffic_dial_percentage: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param listener_arn: 
        :param endpoint_configuration: endpoint_configuration block.
        :param endpoint_group_region: 
        :param health_check_interval_seconds: 
        :param health_check_path: 
        :param health_check_port: 
        :param health_check_protocol: 
        :param threshold_count: 
        :param traffic_dial_percentage: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlobalacceleratorEndpointGroupConfig(
            listener_arn=listener_arn,
            endpoint_configuration=endpoint_configuration,
            endpoint_group_region=endpoint_group_region,
            health_check_interval_seconds=health_check_interval_seconds,
            health_check_path=health_check_path,
            health_check_port=health_check_port,
            health_check_protocol=health_check_protocol,
            threshold_count=threshold_count,
            traffic_dial_percentage=traffic_dial_percentage,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlobalacceleratorEndpointGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="listenerArn")
    def listener_arn(self) -> str:
        return jsii.get(self, "listenerArn")

    @listener_arn.setter
    def listener_arn(self, value: str) -> None:
        jsii.set(self, "listenerArn", value)

    @builtins.property
    @jsii.member(jsii_name="endpointConfiguration")
    def endpoint_configuration(
        self,
    ) -> typing.Optional[
        typing.List["GlobalacceleratorEndpointGroupEndpointConfiguration"]
    ]:
        return jsii.get(self, "endpointConfiguration")

    @endpoint_configuration.setter
    def endpoint_configuration(
        self,
        value: typing.Optional[
            typing.List["GlobalacceleratorEndpointGroupEndpointConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "endpointConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="endpointGroupRegion")
    def endpoint_group_region(self) -> typing.Optional[str]:
        return jsii.get(self, "endpointGroupRegion")

    @endpoint_group_region.setter
    def endpoint_group_region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endpointGroupRegion", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckIntervalSeconds")
    def health_check_interval_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "healthCheckIntervalSeconds")

    @health_check_interval_seconds.setter
    def health_check_interval_seconds(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "healthCheckIntervalSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckPath")
    def health_check_path(self) -> typing.Optional[str]:
        return jsii.get(self, "healthCheckPath")

    @health_check_path.setter
    def health_check_path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "healthCheckPath", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckPort")
    def health_check_port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "healthCheckPort")

    @health_check_port.setter
    def health_check_port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "healthCheckPort", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckProtocol")
    def health_check_protocol(self) -> typing.Optional[str]:
        return jsii.get(self, "healthCheckProtocol")

    @health_check_protocol.setter
    def health_check_protocol(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "healthCheckProtocol", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="thresholdCount")
    def threshold_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "thresholdCount")

    @threshold_count.setter
    def threshold_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "thresholdCount", value)

    @builtins.property
    @jsii.member(jsii_name="trafficDialPercentage")
    def traffic_dial_percentage(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "trafficDialPercentage")

    @traffic_dial_percentage.setter
    def traffic_dial_percentage(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "trafficDialPercentage", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorEndpointGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "listener_arn": "listenerArn",
        "endpoint_configuration": "endpointConfiguration",
        "endpoint_group_region": "endpointGroupRegion",
        "health_check_interval_seconds": "healthCheckIntervalSeconds",
        "health_check_path": "healthCheckPath",
        "health_check_port": "healthCheckPort",
        "health_check_protocol": "healthCheckProtocol",
        "threshold_count": "thresholdCount",
        "traffic_dial_percentage": "trafficDialPercentage",
    },
)
class GlobalacceleratorEndpointGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        listener_arn: str,
        endpoint_configuration: typing.Optional[
            typing.List["GlobalacceleratorEndpointGroupEndpointConfiguration"]
        ] = None,
        endpoint_group_region: typing.Optional[str] = None,
        health_check_interval_seconds: typing.Optional[jsii.Number] = None,
        health_check_path: typing.Optional[str] = None,
        health_check_port: typing.Optional[jsii.Number] = None,
        health_check_protocol: typing.Optional[str] = None,
        threshold_count: typing.Optional[jsii.Number] = None,
        traffic_dial_percentage: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param listener_arn: 
        :param endpoint_configuration: endpoint_configuration block.
        :param endpoint_group_region: 
        :param health_check_interval_seconds: 
        :param health_check_path: 
        :param health_check_port: 
        :param health_check_protocol: 
        :param threshold_count: 
        :param traffic_dial_percentage: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "listener_arn": listener_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if endpoint_configuration is not None:
            self._values["endpoint_configuration"] = endpoint_configuration
        if endpoint_group_region is not None:
            self._values["endpoint_group_region"] = endpoint_group_region
        if health_check_interval_seconds is not None:
            self._values[
                "health_check_interval_seconds"
            ] = health_check_interval_seconds
        if health_check_path is not None:
            self._values["health_check_path"] = health_check_path
        if health_check_port is not None:
            self._values["health_check_port"] = health_check_port
        if health_check_protocol is not None:
            self._values["health_check_protocol"] = health_check_protocol
        if threshold_count is not None:
            self._values["threshold_count"] = threshold_count
        if traffic_dial_percentage is not None:
            self._values["traffic_dial_percentage"] = traffic_dial_percentage

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def listener_arn(self) -> str:
        return self._values.get("listener_arn")

    @builtins.property
    def endpoint_configuration(
        self,
    ) -> typing.Optional[
        typing.List["GlobalacceleratorEndpointGroupEndpointConfiguration"]
    ]:
        """endpoint_configuration block."""
        return self._values.get("endpoint_configuration")

    @builtins.property
    def endpoint_group_region(self) -> typing.Optional[str]:
        return self._values.get("endpoint_group_region")

    @builtins.property
    def health_check_interval_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("health_check_interval_seconds")

    @builtins.property
    def health_check_path(self) -> typing.Optional[str]:
        return self._values.get("health_check_path")

    @builtins.property
    def health_check_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("health_check_port")

    @builtins.property
    def health_check_protocol(self) -> typing.Optional[str]:
        return self._values.get("health_check_protocol")

    @builtins.property
    def threshold_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("threshold_count")

    @builtins.property
    def traffic_dial_percentage(self) -> typing.Optional[jsii.Number]:
        return self._values.get("traffic_dial_percentage")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlobalacceleratorEndpointGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorEndpointGroupEndpointConfiguration",
    jsii_struct_bases=[],
    name_mapping={"endpoint_id": "endpointId", "weight": "weight"},
)
class GlobalacceleratorEndpointGroupEndpointConfiguration:
    def __init__(
        self,
        *,
        endpoint_id: typing.Optional[str] = None,
        weight: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param endpoint_id: 
        :param weight: 
        """
        self._values = {}
        if endpoint_id is not None:
            self._values["endpoint_id"] = endpoint_id
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def endpoint_id(self) -> typing.Optional[str]:
        return self._values.get("endpoint_id")

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlobalacceleratorEndpointGroupEndpointConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlobalacceleratorListener(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorListener",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        accelerator_arn: str,
        port_range: typing.List["GlobalacceleratorListenerPortRange"],
        protocol: str,
        client_affinity: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param accelerator_arn: 
        :param port_range: port_range block.
        :param protocol: 
        :param client_affinity: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlobalacceleratorListenerConfig(
            accelerator_arn=accelerator_arn,
            port_range=port_range,
            protocol=protocol,
            client_affinity=client_affinity,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlobalacceleratorListener, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="acceleratorArn")
    def accelerator_arn(self) -> str:
        return jsii.get(self, "acceleratorArn")

    @accelerator_arn.setter
    def accelerator_arn(self, value: str) -> None:
        jsii.set(self, "acceleratorArn", value)

    @builtins.property
    @jsii.member(jsii_name="portRange")
    def port_range(self) -> typing.List["GlobalacceleratorListenerPortRange"]:
        return jsii.get(self, "portRange")

    @port_range.setter
    def port_range(
        self, value: typing.List["GlobalacceleratorListenerPortRange"]
    ) -> None:
        jsii.set(self, "portRange", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="clientAffinity")
    def client_affinity(self) -> typing.Optional[str]:
        return jsii.get(self, "clientAffinity")

    @client_affinity.setter
    def client_affinity(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clientAffinity", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorListenerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "accelerator_arn": "acceleratorArn",
        "port_range": "portRange",
        "protocol": "protocol",
        "client_affinity": "clientAffinity",
    },
)
class GlobalacceleratorListenerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        accelerator_arn: str,
        port_range: typing.List["GlobalacceleratorListenerPortRange"],
        protocol: str,
        client_affinity: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param accelerator_arn: 
        :param port_range: port_range block.
        :param protocol: 
        :param client_affinity: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "accelerator_arn": accelerator_arn,
            "port_range": port_range,
            "protocol": protocol,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if client_affinity is not None:
            self._values["client_affinity"] = client_affinity

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def accelerator_arn(self) -> str:
        return self._values.get("accelerator_arn")

    @builtins.property
    def port_range(self) -> typing.List["GlobalacceleratorListenerPortRange"]:
        """port_range block."""
        return self._values.get("port_range")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def client_affinity(self) -> typing.Optional[str]:
        return self._values.get("client_affinity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlobalacceleratorListenerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlobalacceleratorListenerPortRange",
    jsii_struct_bases=[],
    name_mapping={"from_port": "fromPort", "to_port": "toPort"},
)
class GlobalacceleratorListenerPortRange:
    def __init__(
        self,
        *,
        from_port: typing.Optional[jsii.Number] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param from_port: 
        :param to_port: 
        """
        self._values = {}
        if from_port is not None:
            self._values["from_port"] = from_port
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlobalacceleratorListenerPortRange(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueCatalogDatabase(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogDatabase",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        catalog_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        location_uri: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param catalog_id: 
        :param description: 
        :param location_uri: 
        :param parameters: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueCatalogDatabaseConfig(
            name=name,
            catalog_id=catalog_id,
            description=description,
            location_uri=location_uri,
            parameters=parameters,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueCatalogDatabase, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="catalogId")
    def catalog_id(self) -> typing.Optional[str]:
        return jsii.get(self, "catalogId")

    @catalog_id.setter
    def catalog_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "catalogId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="locationUri")
    def location_uri(self) -> typing.Optional[str]:
        return jsii.get(self, "locationUri")

    @location_uri.setter
    def location_uri(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "locationUri", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "parameters", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogDatabaseConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "catalog_id": "catalogId",
        "description": "description",
        "location_uri": "locationUri",
        "parameters": "parameters",
    },
)
class GlueCatalogDatabaseConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        catalog_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        location_uri: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param catalog_id: 
        :param description: 
        :param location_uri: 
        :param parameters: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if catalog_id is not None:
            self._values["catalog_id"] = catalog_id
        if description is not None:
            self._values["description"] = description
        if location_uri is not None:
            self._values["location_uri"] = location_uri
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def catalog_id(self) -> typing.Optional[str]:
        return self._values.get("catalog_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def location_uri(self) -> typing.Optional[str]:
        return self._values.get("location_uri")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogDatabaseConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueCatalogTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        database_name: str,
        name: str,
        catalog_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        owner: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        partition_keys: typing.Optional[
            typing.List["GlueCatalogTablePartitionKeys"]
        ] = None,
        retention: typing.Optional[jsii.Number] = None,
        storage_descriptor: typing.Optional[
            typing.List["GlueCatalogTableStorageDescriptor"]
        ] = None,
        table_type: typing.Optional[str] = None,
        view_expanded_text: typing.Optional[str] = None,
        view_original_text: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param database_name: 
        :param name: 
        :param catalog_id: 
        :param description: 
        :param owner: 
        :param parameters: 
        :param partition_keys: partition_keys block.
        :param retention: 
        :param storage_descriptor: storage_descriptor block.
        :param table_type: 
        :param view_expanded_text: 
        :param view_original_text: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueCatalogTableConfig(
            database_name=database_name,
            name=name,
            catalog_id=catalog_id,
            description=description,
            owner=owner,
            parameters=parameters,
            partition_keys=partition_keys,
            retention=retention,
            storage_descriptor=storage_descriptor,
            table_type=table_type,
            view_expanded_text=view_expanded_text,
            view_original_text=view_original_text,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueCatalogTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> str:
        return jsii.get(self, "databaseName")

    @database_name.setter
    def database_name(self, value: str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="catalogId")
    def catalog_id(self) -> typing.Optional[str]:
        return jsii.get(self, "catalogId")

    @catalog_id.setter
    def catalog_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "catalogId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="owner")
    def owner(self) -> typing.Optional[str]:
        return jsii.get(self, "owner")

    @owner.setter
    def owner(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "owner", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="partitionKeys")
    def partition_keys(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTablePartitionKeys"]]:
        return jsii.get(self, "partitionKeys")

    @partition_keys.setter
    def partition_keys(
        self, value: typing.Optional[typing.List["GlueCatalogTablePartitionKeys"]]
    ) -> None:
        jsii.set(self, "partitionKeys", value)

    @builtins.property
    @jsii.member(jsii_name="retention")
    def retention(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "retention")

    @retention.setter
    def retention(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "retention", value)

    @builtins.property
    @jsii.member(jsii_name="storageDescriptor")
    def storage_descriptor(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTableStorageDescriptor"]]:
        return jsii.get(self, "storageDescriptor")

    @storage_descriptor.setter
    def storage_descriptor(
        self, value: typing.Optional[typing.List["GlueCatalogTableStorageDescriptor"]]
    ) -> None:
        jsii.set(self, "storageDescriptor", value)

    @builtins.property
    @jsii.member(jsii_name="tableType")
    def table_type(self) -> typing.Optional[str]:
        return jsii.get(self, "tableType")

    @table_type.setter
    def table_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tableType", value)

    @builtins.property
    @jsii.member(jsii_name="viewExpandedText")
    def view_expanded_text(self) -> typing.Optional[str]:
        return jsii.get(self, "viewExpandedText")

    @view_expanded_text.setter
    def view_expanded_text(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "viewExpandedText", value)

    @builtins.property
    @jsii.member(jsii_name="viewOriginalText")
    def view_original_text(self) -> typing.Optional[str]:
        return jsii.get(self, "viewOriginalText")

    @view_original_text.setter
    def view_original_text(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "viewOriginalText", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database_name": "databaseName",
        "name": "name",
        "catalog_id": "catalogId",
        "description": "description",
        "owner": "owner",
        "parameters": "parameters",
        "partition_keys": "partitionKeys",
        "retention": "retention",
        "storage_descriptor": "storageDescriptor",
        "table_type": "tableType",
        "view_expanded_text": "viewExpandedText",
        "view_original_text": "viewOriginalText",
    },
)
class GlueCatalogTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database_name: str,
        name: str,
        catalog_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        owner: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        partition_keys: typing.Optional[
            typing.List["GlueCatalogTablePartitionKeys"]
        ] = None,
        retention: typing.Optional[jsii.Number] = None,
        storage_descriptor: typing.Optional[
            typing.List["GlueCatalogTableStorageDescriptor"]
        ] = None,
        table_type: typing.Optional[str] = None,
        view_expanded_text: typing.Optional[str] = None,
        view_original_text: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database_name: 
        :param name: 
        :param catalog_id: 
        :param description: 
        :param owner: 
        :param parameters: 
        :param partition_keys: partition_keys block.
        :param retention: 
        :param storage_descriptor: storage_descriptor block.
        :param table_type: 
        :param view_expanded_text: 
        :param view_original_text: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "database_name": database_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if catalog_id is not None:
            self._values["catalog_id"] = catalog_id
        if description is not None:
            self._values["description"] = description
        if owner is not None:
            self._values["owner"] = owner
        if parameters is not None:
            self._values["parameters"] = parameters
        if partition_keys is not None:
            self._values["partition_keys"] = partition_keys
        if retention is not None:
            self._values["retention"] = retention
        if storage_descriptor is not None:
            self._values["storage_descriptor"] = storage_descriptor
        if table_type is not None:
            self._values["table_type"] = table_type
        if view_expanded_text is not None:
            self._values["view_expanded_text"] = view_expanded_text
        if view_original_text is not None:
            self._values["view_original_text"] = view_original_text

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def database_name(self) -> str:
        return self._values.get("database_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def catalog_id(self) -> typing.Optional[str]:
        return self._values.get("catalog_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def owner(self) -> typing.Optional[str]:
        return self._values.get("owner")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    @builtins.property
    def partition_keys(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTablePartitionKeys"]]:
        """partition_keys block."""
        return self._values.get("partition_keys")

    @builtins.property
    def retention(self) -> typing.Optional[jsii.Number]:
        return self._values.get("retention")

    @builtins.property
    def storage_descriptor(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTableStorageDescriptor"]]:
        """storage_descriptor block."""
        return self._values.get("storage_descriptor")

    @builtins.property
    def table_type(self) -> typing.Optional[str]:
        return self._values.get("table_type")

    @builtins.property
    def view_expanded_text(self) -> typing.Optional[str]:
        return self._values.get("view_expanded_text")

    @builtins.property
    def view_original_text(self) -> typing.Optional[str]:
        return self._values.get("view_original_text")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTablePartitionKeys",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "comment": "comment", "type": "type"},
)
class GlueCatalogTablePartitionKeys:
    def __init__(
        self,
        *,
        name: str,
        comment: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param name: 
        :param comment: 
        :param type: 
        """
        self._values = {
            "name": name,
        }
        if comment is not None:
            self._values["comment"] = comment
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def comment(self) -> typing.Optional[str]:
        return self._values.get("comment")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogTablePartitionKeys(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTableStorageDescriptor",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_columns": "bucketColumns",
        "columns": "columns",
        "compressed": "compressed",
        "input_format": "inputFormat",
        "location": "location",
        "number_of_buckets": "numberOfBuckets",
        "output_format": "outputFormat",
        "parameters": "parameters",
        "ser_de_info": "serDeInfo",
        "skewed_info": "skewedInfo",
        "sort_columns": "sortColumns",
        "stored_as_sub_directories": "storedAsSubDirectories",
    },
)
class GlueCatalogTableStorageDescriptor:
    def __init__(
        self,
        *,
        bucket_columns: typing.Optional[typing.List[str]] = None,
        columns: typing.Optional[
            typing.List["GlueCatalogTableStorageDescriptorColumns"]
        ] = None,
        compressed: typing.Optional[bool] = None,
        input_format: typing.Optional[str] = None,
        location: typing.Optional[str] = None,
        number_of_buckets: typing.Optional[jsii.Number] = None,
        output_format: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        ser_de_info: typing.Optional[
            typing.List["GlueCatalogTableStorageDescriptorSerDeInfo"]
        ] = None,
        skewed_info: typing.Optional[
            typing.List["GlueCatalogTableStorageDescriptorSkewedInfo"]
        ] = None,
        sort_columns: typing.Optional[
            typing.List["GlueCatalogTableStorageDescriptorSortColumns"]
        ] = None,
        stored_as_sub_directories: typing.Optional[bool] = None,
    ) -> None:
        """
        :param bucket_columns: 
        :param columns: columns block.
        :param compressed: 
        :param input_format: 
        :param location: 
        :param number_of_buckets: 
        :param output_format: 
        :param parameters: 
        :param ser_de_info: ser_de_info block.
        :param skewed_info: skewed_info block.
        :param sort_columns: sort_columns block.
        :param stored_as_sub_directories: 
        """
        self._values = {}
        if bucket_columns is not None:
            self._values["bucket_columns"] = bucket_columns
        if columns is not None:
            self._values["columns"] = columns
        if compressed is not None:
            self._values["compressed"] = compressed
        if input_format is not None:
            self._values["input_format"] = input_format
        if location is not None:
            self._values["location"] = location
        if number_of_buckets is not None:
            self._values["number_of_buckets"] = number_of_buckets
        if output_format is not None:
            self._values["output_format"] = output_format
        if parameters is not None:
            self._values["parameters"] = parameters
        if ser_de_info is not None:
            self._values["ser_de_info"] = ser_de_info
        if skewed_info is not None:
            self._values["skewed_info"] = skewed_info
        if sort_columns is not None:
            self._values["sort_columns"] = sort_columns
        if stored_as_sub_directories is not None:
            self._values["stored_as_sub_directories"] = stored_as_sub_directories

    @builtins.property
    def bucket_columns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("bucket_columns")

    @builtins.property
    def columns(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTableStorageDescriptorColumns"]]:
        """columns block."""
        return self._values.get("columns")

    @builtins.property
    def compressed(self) -> typing.Optional[bool]:
        return self._values.get("compressed")

    @builtins.property
    def input_format(self) -> typing.Optional[str]:
        return self._values.get("input_format")

    @builtins.property
    def location(self) -> typing.Optional[str]:
        return self._values.get("location")

    @builtins.property
    def number_of_buckets(self) -> typing.Optional[jsii.Number]:
        return self._values.get("number_of_buckets")

    @builtins.property
    def output_format(self) -> typing.Optional[str]:
        return self._values.get("output_format")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    @builtins.property
    def ser_de_info(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTableStorageDescriptorSerDeInfo"]]:
        """ser_de_info block."""
        return self._values.get("ser_de_info")

    @builtins.property
    def skewed_info(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTableStorageDescriptorSkewedInfo"]]:
        """skewed_info block."""
        return self._values.get("skewed_info")

    @builtins.property
    def sort_columns(
        self,
    ) -> typing.Optional[typing.List["GlueCatalogTableStorageDescriptorSortColumns"]]:
        """sort_columns block."""
        return self._values.get("sort_columns")

    @builtins.property
    def stored_as_sub_directories(self) -> typing.Optional[bool]:
        return self._values.get("stored_as_sub_directories")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogTableStorageDescriptor(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTableStorageDescriptorColumns",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "comment": "comment", "type": "type"},
)
class GlueCatalogTableStorageDescriptorColumns:
    def __init__(
        self,
        *,
        name: str,
        comment: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param name: 
        :param comment: 
        :param type: 
        """
        self._values = {
            "name": name,
        }
        if comment is not None:
            self._values["comment"] = comment
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def comment(self) -> typing.Optional[str]:
        return self._values.get("comment")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogTableStorageDescriptorColumns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTableStorageDescriptorSerDeInfo",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "parameters": "parameters",
        "serialization_library": "serializationLibrary",
    },
)
class GlueCatalogTableStorageDescriptorSerDeInfo:
    def __init__(
        self,
        *,
        name: typing.Optional[str] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        serialization_library: typing.Optional[str] = None,
    ) -> None:
        """
        :param name: 
        :param parameters: 
        :param serialization_library: 
        """
        self._values = {}
        if name is not None:
            self._values["name"] = name
        if parameters is not None:
            self._values["parameters"] = parameters
        if serialization_library is not None:
            self._values["serialization_library"] = serialization_library

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    @builtins.property
    def serialization_library(self) -> typing.Optional[str]:
        return self._values.get("serialization_library")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogTableStorageDescriptorSerDeInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTableStorageDescriptorSkewedInfo",
    jsii_struct_bases=[],
    name_mapping={
        "skewed_column_names": "skewedColumnNames",
        "skewed_column_value_location_maps": "skewedColumnValueLocationMaps",
        "skewed_column_values": "skewedColumnValues",
    },
)
class GlueCatalogTableStorageDescriptorSkewedInfo:
    def __init__(
        self,
        *,
        skewed_column_names: typing.Optional[typing.List[str]] = None,
        skewed_column_value_location_maps: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        skewed_column_values: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param skewed_column_names: 
        :param skewed_column_value_location_maps: 
        :param skewed_column_values: 
        """
        self._values = {}
        if skewed_column_names is not None:
            self._values["skewed_column_names"] = skewed_column_names
        if skewed_column_value_location_maps is not None:
            self._values[
                "skewed_column_value_location_maps"
            ] = skewed_column_value_location_maps
        if skewed_column_values is not None:
            self._values["skewed_column_values"] = skewed_column_values

    @builtins.property
    def skewed_column_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("skewed_column_names")

    @builtins.property
    def skewed_column_value_location_maps(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("skewed_column_value_location_maps")

    @builtins.property
    def skewed_column_values(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("skewed_column_values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogTableStorageDescriptorSkewedInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCatalogTableStorageDescriptorSortColumns",
    jsii_struct_bases=[],
    name_mapping={"column": "column", "sort_order": "sortOrder"},
)
class GlueCatalogTableStorageDescriptorSortColumns:
    def __init__(self, *, column: str, sort_order: jsii.Number) -> None:
        """
        :param column: 
        :param sort_order: 
        """
        self._values = {
            "column": column,
            "sort_order": sort_order,
        }

    @builtins.property
    def column(self) -> str:
        return self._values.get("column")

    @builtins.property
    def sort_order(self) -> jsii.Number:
        return self._values.get("sort_order")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCatalogTableStorageDescriptorSortColumns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueClassifier(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueClassifier",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        csv_classifier: typing.Optional[
            typing.List["GlueClassifierCsvClassifier"]
        ] = None,
        grok_classifier: typing.Optional[
            typing.List["GlueClassifierGrokClassifier"]
        ] = None,
        json_classifier: typing.Optional[
            typing.List["GlueClassifierJsonClassifier"]
        ] = None,
        xml_classifier: typing.Optional[
            typing.List["GlueClassifierXmlClassifier"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param csv_classifier: csv_classifier block.
        :param grok_classifier: grok_classifier block.
        :param json_classifier: json_classifier block.
        :param xml_classifier: xml_classifier block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueClassifierConfig(
            name=name,
            csv_classifier=csv_classifier,
            grok_classifier=grok_classifier,
            json_classifier=json_classifier,
            xml_classifier=xml_classifier,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueClassifier, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="csvClassifier")
    def csv_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierCsvClassifier"]]:
        return jsii.get(self, "csvClassifier")

    @csv_classifier.setter
    def csv_classifier(
        self, value: typing.Optional[typing.List["GlueClassifierCsvClassifier"]]
    ) -> None:
        jsii.set(self, "csvClassifier", value)

    @builtins.property
    @jsii.member(jsii_name="grokClassifier")
    def grok_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierGrokClassifier"]]:
        return jsii.get(self, "grokClassifier")

    @grok_classifier.setter
    def grok_classifier(
        self, value: typing.Optional[typing.List["GlueClassifierGrokClassifier"]]
    ) -> None:
        jsii.set(self, "grokClassifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="jsonClassifier")
    def json_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierJsonClassifier"]]:
        return jsii.get(self, "jsonClassifier")

    @json_classifier.setter
    def json_classifier(
        self, value: typing.Optional[typing.List["GlueClassifierJsonClassifier"]]
    ) -> None:
        jsii.set(self, "jsonClassifier", value)

    @builtins.property
    @jsii.member(jsii_name="xmlClassifier")
    def xml_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierXmlClassifier"]]:
        return jsii.get(self, "xmlClassifier")

    @xml_classifier.setter
    def xml_classifier(
        self, value: typing.Optional[typing.List["GlueClassifierXmlClassifier"]]
    ) -> None:
        jsii.set(self, "xmlClassifier", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueClassifierConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "csv_classifier": "csvClassifier",
        "grok_classifier": "grokClassifier",
        "json_classifier": "jsonClassifier",
        "xml_classifier": "xmlClassifier",
    },
)
class GlueClassifierConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        csv_classifier: typing.Optional[
            typing.List["GlueClassifierCsvClassifier"]
        ] = None,
        grok_classifier: typing.Optional[
            typing.List["GlueClassifierGrokClassifier"]
        ] = None,
        json_classifier: typing.Optional[
            typing.List["GlueClassifierJsonClassifier"]
        ] = None,
        xml_classifier: typing.Optional[
            typing.List["GlueClassifierXmlClassifier"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param csv_classifier: csv_classifier block.
        :param grok_classifier: grok_classifier block.
        :param json_classifier: json_classifier block.
        :param xml_classifier: xml_classifier block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if csv_classifier is not None:
            self._values["csv_classifier"] = csv_classifier
        if grok_classifier is not None:
            self._values["grok_classifier"] = grok_classifier
        if json_classifier is not None:
            self._values["json_classifier"] = json_classifier
        if xml_classifier is not None:
            self._values["xml_classifier"] = xml_classifier

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def csv_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierCsvClassifier"]]:
        """csv_classifier block."""
        return self._values.get("csv_classifier")

    @builtins.property
    def grok_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierGrokClassifier"]]:
        """grok_classifier block."""
        return self._values.get("grok_classifier")

    @builtins.property
    def json_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierJsonClassifier"]]:
        """json_classifier block."""
        return self._values.get("json_classifier")

    @builtins.property
    def xml_classifier(
        self,
    ) -> typing.Optional[typing.List["GlueClassifierXmlClassifier"]]:
        """xml_classifier block."""
        return self._values.get("xml_classifier")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueClassifierConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueClassifierCsvClassifier",
    jsii_struct_bases=[],
    name_mapping={
        "allow_single_column": "allowSingleColumn",
        "contains_header": "containsHeader",
        "delimiter": "delimiter",
        "disable_value_trimming": "disableValueTrimming",
        "header": "header",
        "quote_symbol": "quoteSymbol",
    },
)
class GlueClassifierCsvClassifier:
    def __init__(
        self,
        *,
        allow_single_column: typing.Optional[bool] = None,
        contains_header: typing.Optional[str] = None,
        delimiter: typing.Optional[str] = None,
        disable_value_trimming: typing.Optional[bool] = None,
        header: typing.Optional[typing.List[str]] = None,
        quote_symbol: typing.Optional[str] = None,
    ) -> None:
        """
        :param allow_single_column: 
        :param contains_header: 
        :param delimiter: 
        :param disable_value_trimming: 
        :param header: 
        :param quote_symbol: 
        """
        self._values = {}
        if allow_single_column is not None:
            self._values["allow_single_column"] = allow_single_column
        if contains_header is not None:
            self._values["contains_header"] = contains_header
        if delimiter is not None:
            self._values["delimiter"] = delimiter
        if disable_value_trimming is not None:
            self._values["disable_value_trimming"] = disable_value_trimming
        if header is not None:
            self._values["header"] = header
        if quote_symbol is not None:
            self._values["quote_symbol"] = quote_symbol

    @builtins.property
    def allow_single_column(self) -> typing.Optional[bool]:
        return self._values.get("allow_single_column")

    @builtins.property
    def contains_header(self) -> typing.Optional[str]:
        return self._values.get("contains_header")

    @builtins.property
    def delimiter(self) -> typing.Optional[str]:
        return self._values.get("delimiter")

    @builtins.property
    def disable_value_trimming(self) -> typing.Optional[bool]:
        return self._values.get("disable_value_trimming")

    @builtins.property
    def header(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("header")

    @builtins.property
    def quote_symbol(self) -> typing.Optional[str]:
        return self._values.get("quote_symbol")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueClassifierCsvClassifier(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueClassifierGrokClassifier",
    jsii_struct_bases=[],
    name_mapping={
        "classification": "classification",
        "grok_pattern": "grokPattern",
        "custom_patterns": "customPatterns",
    },
)
class GlueClassifierGrokClassifier:
    def __init__(
        self,
        *,
        classification: str,
        grok_pattern: str,
        custom_patterns: typing.Optional[str] = None,
    ) -> None:
        """
        :param classification: 
        :param grok_pattern: 
        :param custom_patterns: 
        """
        self._values = {
            "classification": classification,
            "grok_pattern": grok_pattern,
        }
        if custom_patterns is not None:
            self._values["custom_patterns"] = custom_patterns

    @builtins.property
    def classification(self) -> str:
        return self._values.get("classification")

    @builtins.property
    def grok_pattern(self) -> str:
        return self._values.get("grok_pattern")

    @builtins.property
    def custom_patterns(self) -> typing.Optional[str]:
        return self._values.get("custom_patterns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueClassifierGrokClassifier(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueClassifierJsonClassifier",
    jsii_struct_bases=[],
    name_mapping={"json_path": "jsonPath"},
)
class GlueClassifierJsonClassifier:
    def __init__(self, *, json_path: str) -> None:
        """
        :param json_path: 
        """
        self._values = {
            "json_path": json_path,
        }

    @builtins.property
    def json_path(self) -> str:
        return self._values.get("json_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueClassifierJsonClassifier(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueClassifierXmlClassifier",
    jsii_struct_bases=[],
    name_mapping={"classification": "classification", "row_tag": "rowTag"},
)
class GlueClassifierXmlClassifier:
    def __init__(self, *, classification: str, row_tag: str) -> None:
        """
        :param classification: 
        :param row_tag: 
        """
        self._values = {
            "classification": classification,
            "row_tag": row_tag,
        }

    @builtins.property
    def classification(self) -> str:
        return self._values.get("classification")

    @builtins.property
    def row_tag(self) -> str:
        return self._values.get("row_tag")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueClassifierXmlClassifier(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        connection_properties: typing.Mapping[str, str],
        name: str,
        catalog_id: typing.Optional[str] = None,
        connection_type: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        match_criteria: typing.Optional[typing.List[str]] = None,
        physical_connection_requirements: typing.Optional[
            typing.List["GlueConnectionPhysicalConnectionRequirements"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_properties: 
        :param name: 
        :param catalog_id: 
        :param connection_type: 
        :param description: 
        :param match_criteria: 
        :param physical_connection_requirements: physical_connection_requirements block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueConnectionConfig(
            connection_properties=connection_properties,
            name=name,
            catalog_id=catalog_id,
            connection_type=connection_type,
            description=description,
            match_criteria=match_criteria,
            physical_connection_requirements=physical_connection_requirements,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="connectionProperties")
    def connection_properties(self) -> typing.Mapping[str, str]:
        return jsii.get(self, "connectionProperties")

    @connection_properties.setter
    def connection_properties(self, value: typing.Mapping[str, str]) -> None:
        jsii.set(self, "connectionProperties", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="catalogId")
    def catalog_id(self) -> typing.Optional[str]:
        return jsii.get(self, "catalogId")

    @catalog_id.setter
    def catalog_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "catalogId", value)

    @builtins.property
    @jsii.member(jsii_name="connectionType")
    def connection_type(self) -> typing.Optional[str]:
        return jsii.get(self, "connectionType")

    @connection_type.setter
    def connection_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "connectionType", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="matchCriteria")
    def match_criteria(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "matchCriteria")

    @match_criteria.setter
    def match_criteria(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "matchCriteria", value)

    @builtins.property
    @jsii.member(jsii_name="physicalConnectionRequirements")
    def physical_connection_requirements(
        self,
    ) -> typing.Optional[typing.List["GlueConnectionPhysicalConnectionRequirements"]]:
        return jsii.get(self, "physicalConnectionRequirements")

    @physical_connection_requirements.setter
    def physical_connection_requirements(
        self,
        value: typing.Optional[
            typing.List["GlueConnectionPhysicalConnectionRequirements"]
        ],
    ) -> None:
        jsii.set(self, "physicalConnectionRequirements", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_properties": "connectionProperties",
        "name": "name",
        "catalog_id": "catalogId",
        "connection_type": "connectionType",
        "description": "description",
        "match_criteria": "matchCriteria",
        "physical_connection_requirements": "physicalConnectionRequirements",
    },
)
class GlueConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_properties: typing.Mapping[str, str],
        name: str,
        catalog_id: typing.Optional[str] = None,
        connection_type: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        match_criteria: typing.Optional[typing.List[str]] = None,
        physical_connection_requirements: typing.Optional[
            typing.List["GlueConnectionPhysicalConnectionRequirements"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_properties: 
        :param name: 
        :param catalog_id: 
        :param connection_type: 
        :param description: 
        :param match_criteria: 
        :param physical_connection_requirements: physical_connection_requirements block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "connection_properties": connection_properties,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if catalog_id is not None:
            self._values["catalog_id"] = catalog_id
        if connection_type is not None:
            self._values["connection_type"] = connection_type
        if description is not None:
            self._values["description"] = description
        if match_criteria is not None:
            self._values["match_criteria"] = match_criteria
        if physical_connection_requirements is not None:
            self._values[
                "physical_connection_requirements"
            ] = physical_connection_requirements

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def connection_properties(self) -> typing.Mapping[str, str]:
        return self._values.get("connection_properties")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def catalog_id(self) -> typing.Optional[str]:
        return self._values.get("catalog_id")

    @builtins.property
    def connection_type(self) -> typing.Optional[str]:
        return self._values.get("connection_type")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def match_criteria(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("match_criteria")

    @builtins.property
    def physical_connection_requirements(
        self,
    ) -> typing.Optional[typing.List["GlueConnectionPhysicalConnectionRequirements"]]:
        """physical_connection_requirements block."""
        return self._values.get("physical_connection_requirements")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueConnectionPhysicalConnectionRequirements",
    jsii_struct_bases=[],
    name_mapping={
        "availability_zone": "availabilityZone",
        "security_group_id_list": "securityGroupIdList",
        "subnet_id": "subnetId",
    },
)
class GlueConnectionPhysicalConnectionRequirements:
    def __init__(
        self,
        *,
        availability_zone: typing.Optional[str] = None,
        security_group_id_list: typing.Optional[typing.List[str]] = None,
        subnet_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param availability_zone: 
        :param security_group_id_list: 
        :param subnet_id: 
        """
        self._values = {}
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if security_group_id_list is not None:
            self._values["security_group_id_list"] = security_group_id_list
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def security_group_id_list(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_id_list")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueConnectionPhysicalConnectionRequirements(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueCrawler(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCrawler",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        database_name: str,
        name: str,
        role: str,
        catalog_target: typing.Optional[typing.List["GlueCrawlerCatalogTarget"]] = None,
        classifiers: typing.Optional[typing.List[str]] = None,
        configuration: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        dynamodb_target: typing.Optional[
            typing.List["GlueCrawlerDynamodbTarget"]
        ] = None,
        jdbc_target: typing.Optional[typing.List["GlueCrawlerJdbcTarget"]] = None,
        s3_target: typing.Optional[typing.List["GlueCrawlerS3Target"]] = None,
        schedule: typing.Optional[str] = None,
        schema_change_policy: typing.Optional[
            typing.List["GlueCrawlerSchemaChangePolicy"]
        ] = None,
        security_configuration: typing.Optional[str] = None,
        table_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param database_name: 
        :param name: 
        :param role: 
        :param catalog_target: catalog_target block.
        :param classifiers: 
        :param configuration: 
        :param description: 
        :param dynamodb_target: dynamodb_target block.
        :param jdbc_target: jdbc_target block.
        :param s3_target: s3_target block.
        :param schedule: 
        :param schema_change_policy: schema_change_policy block.
        :param security_configuration: 
        :param table_prefix: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueCrawlerConfig(
            database_name=database_name,
            name=name,
            role=role,
            catalog_target=catalog_target,
            classifiers=classifiers,
            configuration=configuration,
            description=description,
            dynamodb_target=dynamodb_target,
            jdbc_target=jdbc_target,
            s3_target=s3_target,
            schedule=schedule,
            schema_change_policy=schema_change_policy,
            security_configuration=security_configuration,
            table_prefix=table_prefix,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueCrawler, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> str:
        return jsii.get(self, "databaseName")

    @database_name.setter
    def database_name(self, value: str) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> str:
        return jsii.get(self, "role")

    @role.setter
    def role(self, value: str) -> None:
        jsii.set(self, "role", value)

    @builtins.property
    @jsii.member(jsii_name="catalogTarget")
    def catalog_target(
        self,
    ) -> typing.Optional[typing.List["GlueCrawlerCatalogTarget"]]:
        return jsii.get(self, "catalogTarget")

    @catalog_target.setter
    def catalog_target(
        self, value: typing.Optional[typing.List["GlueCrawlerCatalogTarget"]]
    ) -> None:
        jsii.set(self, "catalogTarget", value)

    @builtins.property
    @jsii.member(jsii_name="classifiers")
    def classifiers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "classifiers")

    @classifiers.setter
    def classifiers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "classifiers", value)

    @builtins.property
    @jsii.member(jsii_name="configuration")
    def configuration(self) -> typing.Optional[str]:
        return jsii.get(self, "configuration")

    @configuration.setter
    def configuration(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "configuration", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="dynamodbTarget")
    def dynamodb_target(
        self,
    ) -> typing.Optional[typing.List["GlueCrawlerDynamodbTarget"]]:
        return jsii.get(self, "dynamodbTarget")

    @dynamodb_target.setter
    def dynamodb_target(
        self, value: typing.Optional[typing.List["GlueCrawlerDynamodbTarget"]]
    ) -> None:
        jsii.set(self, "dynamodbTarget", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="jdbcTarget")
    def jdbc_target(self) -> typing.Optional[typing.List["GlueCrawlerJdbcTarget"]]:
        return jsii.get(self, "jdbcTarget")

    @jdbc_target.setter
    def jdbc_target(
        self, value: typing.Optional[typing.List["GlueCrawlerJdbcTarget"]]
    ) -> None:
        jsii.set(self, "jdbcTarget", value)

    @builtins.property
    @jsii.member(jsii_name="s3Target")
    def s3_target(self) -> typing.Optional[typing.List["GlueCrawlerS3Target"]]:
        return jsii.get(self, "s3Target")

    @s3_target.setter
    def s3_target(
        self, value: typing.Optional[typing.List["GlueCrawlerS3Target"]]
    ) -> None:
        jsii.set(self, "s3Target", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(self) -> typing.Optional[str]:
        return jsii.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "schedule", value)

    @builtins.property
    @jsii.member(jsii_name="schemaChangePolicy")
    def schema_change_policy(
        self,
    ) -> typing.Optional[typing.List["GlueCrawlerSchemaChangePolicy"]]:
        return jsii.get(self, "schemaChangePolicy")

    @schema_change_policy.setter
    def schema_change_policy(
        self, value: typing.Optional[typing.List["GlueCrawlerSchemaChangePolicy"]]
    ) -> None:
        jsii.set(self, "schemaChangePolicy", value)

    @builtins.property
    @jsii.member(jsii_name="securityConfiguration")
    def security_configuration(self) -> typing.Optional[str]:
        return jsii.get(self, "securityConfiguration")

    @security_configuration.setter
    def security_configuration(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "securityConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tablePrefix")
    def table_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "tablePrefix")

    @table_prefix.setter
    def table_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tablePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCrawlerCatalogTarget",
    jsii_struct_bases=[],
    name_mapping={"database_name": "databaseName", "tables": "tables"},
)
class GlueCrawlerCatalogTarget:
    def __init__(self, *, database_name: str, tables: typing.List[str]) -> None:
        """
        :param database_name: 
        :param tables: 
        """
        self._values = {
            "database_name": database_name,
            "tables": tables,
        }

    @builtins.property
    def database_name(self) -> str:
        return self._values.get("database_name")

    @builtins.property
    def tables(self) -> typing.List[str]:
        return self._values.get("tables")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCrawlerCatalogTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCrawlerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "database_name": "databaseName",
        "name": "name",
        "role": "role",
        "catalog_target": "catalogTarget",
        "classifiers": "classifiers",
        "configuration": "configuration",
        "description": "description",
        "dynamodb_target": "dynamodbTarget",
        "jdbc_target": "jdbcTarget",
        "s3_target": "s3Target",
        "schedule": "schedule",
        "schema_change_policy": "schemaChangePolicy",
        "security_configuration": "securityConfiguration",
        "table_prefix": "tablePrefix",
        "tags": "tags",
    },
)
class GlueCrawlerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        database_name: str,
        name: str,
        role: str,
        catalog_target: typing.Optional[typing.List["GlueCrawlerCatalogTarget"]] = None,
        classifiers: typing.Optional[typing.List[str]] = None,
        configuration: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        dynamodb_target: typing.Optional[
            typing.List["GlueCrawlerDynamodbTarget"]
        ] = None,
        jdbc_target: typing.Optional[typing.List["GlueCrawlerJdbcTarget"]] = None,
        s3_target: typing.Optional[typing.List["GlueCrawlerS3Target"]] = None,
        schedule: typing.Optional[str] = None,
        schema_change_policy: typing.Optional[
            typing.List["GlueCrawlerSchemaChangePolicy"]
        ] = None,
        security_configuration: typing.Optional[str] = None,
        table_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param database_name: 
        :param name: 
        :param role: 
        :param catalog_target: catalog_target block.
        :param classifiers: 
        :param configuration: 
        :param description: 
        :param dynamodb_target: dynamodb_target block.
        :param jdbc_target: jdbc_target block.
        :param s3_target: s3_target block.
        :param schedule: 
        :param schema_change_policy: schema_change_policy block.
        :param security_configuration: 
        :param table_prefix: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "database_name": database_name,
            "name": name,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if catalog_target is not None:
            self._values["catalog_target"] = catalog_target
        if classifiers is not None:
            self._values["classifiers"] = classifiers
        if configuration is not None:
            self._values["configuration"] = configuration
        if description is not None:
            self._values["description"] = description
        if dynamodb_target is not None:
            self._values["dynamodb_target"] = dynamodb_target
        if jdbc_target is not None:
            self._values["jdbc_target"] = jdbc_target
        if s3_target is not None:
            self._values["s3_target"] = s3_target
        if schedule is not None:
            self._values["schedule"] = schedule
        if schema_change_policy is not None:
            self._values["schema_change_policy"] = schema_change_policy
        if security_configuration is not None:
            self._values["security_configuration"] = security_configuration
        if table_prefix is not None:
            self._values["table_prefix"] = table_prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def database_name(self) -> str:
        return self._values.get("database_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role(self) -> str:
        return self._values.get("role")

    @builtins.property
    def catalog_target(
        self,
    ) -> typing.Optional[typing.List["GlueCrawlerCatalogTarget"]]:
        """catalog_target block."""
        return self._values.get("catalog_target")

    @builtins.property
    def classifiers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("classifiers")

    @builtins.property
    def configuration(self) -> typing.Optional[str]:
        return self._values.get("configuration")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def dynamodb_target(
        self,
    ) -> typing.Optional[typing.List["GlueCrawlerDynamodbTarget"]]:
        """dynamodb_target block."""
        return self._values.get("dynamodb_target")

    @builtins.property
    def jdbc_target(self) -> typing.Optional[typing.List["GlueCrawlerJdbcTarget"]]:
        """jdbc_target block."""
        return self._values.get("jdbc_target")

    @builtins.property
    def s3_target(self) -> typing.Optional[typing.List["GlueCrawlerS3Target"]]:
        """s3_target block."""
        return self._values.get("s3_target")

    @builtins.property
    def schedule(self) -> typing.Optional[str]:
        return self._values.get("schedule")

    @builtins.property
    def schema_change_policy(
        self,
    ) -> typing.Optional[typing.List["GlueCrawlerSchemaChangePolicy"]]:
        """schema_change_policy block."""
        return self._values.get("schema_change_policy")

    @builtins.property
    def security_configuration(self) -> typing.Optional[str]:
        return self._values.get("security_configuration")

    @builtins.property
    def table_prefix(self) -> typing.Optional[str]:
        return self._values.get("table_prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCrawlerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCrawlerDynamodbTarget",
    jsii_struct_bases=[],
    name_mapping={"path": "path"},
)
class GlueCrawlerDynamodbTarget:
    def __init__(self, *, path: str) -> None:
        """
        :param path: 
        """
        self._values = {
            "path": path,
        }

    @builtins.property
    def path(self) -> str:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCrawlerDynamodbTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCrawlerJdbcTarget",
    jsii_struct_bases=[],
    name_mapping={
        "connection_name": "connectionName",
        "path": "path",
        "exclusions": "exclusions",
    },
)
class GlueCrawlerJdbcTarget:
    def __init__(
        self,
        *,
        connection_name: str,
        path: str,
        exclusions: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param connection_name: 
        :param path: 
        :param exclusions: 
        """
        self._values = {
            "connection_name": connection_name,
            "path": path,
        }
        if exclusions is not None:
            self._values["exclusions"] = exclusions

    @builtins.property
    def connection_name(self) -> str:
        return self._values.get("connection_name")

    @builtins.property
    def path(self) -> str:
        return self._values.get("path")

    @builtins.property
    def exclusions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("exclusions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCrawlerJdbcTarget(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCrawlerS3Target",
    jsii_struct_bases=[],
    name_mapping={"path": "path", "exclusions": "exclusions"},
)
class GlueCrawlerS3Target:
    def __init__(
        self, *, path: str, exclusions: typing.Optional[typing.List[str]] = None
    ) -> None:
        """
        :param path: 
        :param exclusions: 
        """
        self._values = {
            "path": path,
        }
        if exclusions is not None:
            self._values["exclusions"] = exclusions

    @builtins.property
    def path(self) -> str:
        return self._values.get("path")

    @builtins.property
    def exclusions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("exclusions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCrawlerS3Target(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueCrawlerSchemaChangePolicy",
    jsii_struct_bases=[],
    name_mapping={
        "delete_behavior": "deleteBehavior",
        "update_behavior": "updateBehavior",
    },
)
class GlueCrawlerSchemaChangePolicy:
    def __init__(
        self,
        *,
        delete_behavior: typing.Optional[str] = None,
        update_behavior: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete_behavior: 
        :param update_behavior: 
        """
        self._values = {}
        if delete_behavior is not None:
            self._values["delete_behavior"] = delete_behavior
        if update_behavior is not None:
            self._values["update_behavior"] = update_behavior

    @builtins.property
    def delete_behavior(self) -> typing.Optional[str]:
        return self._values.get("delete_behavior")

    @builtins.property
    def update_behavior(self) -> typing.Optional[str]:
        return self._values.get("update_behavior")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueCrawlerSchemaChangePolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueJob(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueJob",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        command: typing.List["GlueJobCommand"],
        name: str,
        role_arn: str,
        allocated_capacity: typing.Optional[jsii.Number] = None,
        connections: typing.Optional[typing.List[str]] = None,
        default_arguments: typing.Optional[typing.Mapping[str, str]] = None,
        description: typing.Optional[str] = None,
        execution_property: typing.Optional[
            typing.List["GlueJobExecutionProperty"]
        ] = None,
        glue_version: typing.Optional[str] = None,
        max_capacity: typing.Optional[jsii.Number] = None,
        max_retries: typing.Optional[jsii.Number] = None,
        notification_property: typing.Optional[
            typing.List["GlueJobNotificationProperty"]
        ] = None,
        number_of_workers: typing.Optional[jsii.Number] = None,
        security_configuration: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeout: typing.Optional[jsii.Number] = None,
        worker_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param command: command block.
        :param name: 
        :param role_arn: 
        :param allocated_capacity: 
        :param connections: 
        :param default_arguments: 
        :param description: 
        :param execution_property: execution_property block.
        :param glue_version: 
        :param max_capacity: 
        :param max_retries: 
        :param notification_property: notification_property block.
        :param number_of_workers: 
        :param security_configuration: 
        :param tags: 
        :param timeout: 
        :param worker_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueJobConfig(
            command=command,
            name=name,
            role_arn=role_arn,
            allocated_capacity=allocated_capacity,
            connections=connections,
            default_arguments=default_arguments,
            description=description,
            execution_property=execution_property,
            glue_version=glue_version,
            max_capacity=max_capacity,
            max_retries=max_retries,
            notification_property=notification_property,
            number_of_workers=number_of_workers,
            security_configuration=security_configuration,
            tags=tags,
            timeout=timeout,
            worker_type=worker_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueJob, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="command")
    def command(self) -> typing.List["GlueJobCommand"]:
        return jsii.get(self, "command")

    @command.setter
    def command(self, value: typing.List["GlueJobCommand"]) -> None:
        jsii.set(self, "command", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="allocatedCapacity")
    def allocated_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "allocatedCapacity")

    @allocated_capacity.setter
    def allocated_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "allocatedCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="connections")
    def connections(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "connections")

    @connections.setter
    def connections(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "connections", value)

    @builtins.property
    @jsii.member(jsii_name="defaultArguments")
    def default_arguments(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "defaultArguments")

    @default_arguments.setter
    def default_arguments(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "defaultArguments", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="executionProperty")
    def execution_property(
        self,
    ) -> typing.Optional[typing.List["GlueJobExecutionProperty"]]:
        return jsii.get(self, "executionProperty")

    @execution_property.setter
    def execution_property(
        self, value: typing.Optional[typing.List["GlueJobExecutionProperty"]]
    ) -> None:
        jsii.set(self, "executionProperty", value)

    @builtins.property
    @jsii.member(jsii_name="glueVersion")
    def glue_version(self) -> typing.Optional[str]:
        return jsii.get(self, "glueVersion")

    @glue_version.setter
    def glue_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "glueVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maxCapacity")
    def max_capacity(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxCapacity")

    @max_capacity.setter
    def max_capacity(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="maxRetries")
    def max_retries(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxRetries")

    @max_retries.setter
    def max_retries(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxRetries", value)

    @builtins.property
    @jsii.member(jsii_name="notificationProperty")
    def notification_property(
        self,
    ) -> typing.Optional[typing.List["GlueJobNotificationProperty"]]:
        return jsii.get(self, "notificationProperty")

    @notification_property.setter
    def notification_property(
        self, value: typing.Optional[typing.List["GlueJobNotificationProperty"]]
    ) -> None:
        jsii.set(self, "notificationProperty", value)

    @builtins.property
    @jsii.member(jsii_name="numberOfWorkers")
    def number_of_workers(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "numberOfWorkers")

    @number_of_workers.setter
    def number_of_workers(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "numberOfWorkers", value)

    @builtins.property
    @jsii.member(jsii_name="securityConfiguration")
    def security_configuration(self) -> typing.Optional[str]:
        return jsii.get(self, "securityConfiguration")

    @security_configuration.setter
    def security_configuration(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "securityConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property
    @jsii.member(jsii_name="workerType")
    def worker_type(self) -> typing.Optional[str]:
        return jsii.get(self, "workerType")

    @worker_type.setter
    def worker_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "workerType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueJobCommand",
    jsii_struct_bases=[],
    name_mapping={
        "script_location": "scriptLocation",
        "name": "name",
        "python_version": "pythonVersion",
    },
)
class GlueJobCommand:
    def __init__(
        self,
        *,
        script_location: str,
        name: typing.Optional[str] = None,
        python_version: typing.Optional[str] = None,
    ) -> None:
        """
        :param script_location: 
        :param name: 
        :param python_version: 
        """
        self._values = {
            "script_location": script_location,
        }
        if name is not None:
            self._values["name"] = name
        if python_version is not None:
            self._values["python_version"] = python_version

    @builtins.property
    def script_location(self) -> str:
        return self._values.get("script_location")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def python_version(self) -> typing.Optional[str]:
        return self._values.get("python_version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueJobCommand(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueJobConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "command": "command",
        "name": "name",
        "role_arn": "roleArn",
        "allocated_capacity": "allocatedCapacity",
        "connections": "connections",
        "default_arguments": "defaultArguments",
        "description": "description",
        "execution_property": "executionProperty",
        "glue_version": "glueVersion",
        "max_capacity": "maxCapacity",
        "max_retries": "maxRetries",
        "notification_property": "notificationProperty",
        "number_of_workers": "numberOfWorkers",
        "security_configuration": "securityConfiguration",
        "tags": "tags",
        "timeout": "timeout",
        "worker_type": "workerType",
    },
)
class GlueJobConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        command: typing.List["GlueJobCommand"],
        name: str,
        role_arn: str,
        allocated_capacity: typing.Optional[jsii.Number] = None,
        connections: typing.Optional[typing.List[str]] = None,
        default_arguments: typing.Optional[typing.Mapping[str, str]] = None,
        description: typing.Optional[str] = None,
        execution_property: typing.Optional[
            typing.List["GlueJobExecutionProperty"]
        ] = None,
        glue_version: typing.Optional[str] = None,
        max_capacity: typing.Optional[jsii.Number] = None,
        max_retries: typing.Optional[jsii.Number] = None,
        notification_property: typing.Optional[
            typing.List["GlueJobNotificationProperty"]
        ] = None,
        number_of_workers: typing.Optional[jsii.Number] = None,
        security_configuration: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeout: typing.Optional[jsii.Number] = None,
        worker_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param command: command block.
        :param name: 
        :param role_arn: 
        :param allocated_capacity: 
        :param connections: 
        :param default_arguments: 
        :param description: 
        :param execution_property: execution_property block.
        :param glue_version: 
        :param max_capacity: 
        :param max_retries: 
        :param notification_property: notification_property block.
        :param number_of_workers: 
        :param security_configuration: 
        :param tags: 
        :param timeout: 
        :param worker_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "command": command,
            "name": name,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocated_capacity is not None:
            self._values["allocated_capacity"] = allocated_capacity
        if connections is not None:
            self._values["connections"] = connections
        if default_arguments is not None:
            self._values["default_arguments"] = default_arguments
        if description is not None:
            self._values["description"] = description
        if execution_property is not None:
            self._values["execution_property"] = execution_property
        if glue_version is not None:
            self._values["glue_version"] = glue_version
        if max_capacity is not None:
            self._values["max_capacity"] = max_capacity
        if max_retries is not None:
            self._values["max_retries"] = max_retries
        if notification_property is not None:
            self._values["notification_property"] = notification_property
        if number_of_workers is not None:
            self._values["number_of_workers"] = number_of_workers
        if security_configuration is not None:
            self._values["security_configuration"] = security_configuration
        if tags is not None:
            self._values["tags"] = tags
        if timeout is not None:
            self._values["timeout"] = timeout
        if worker_type is not None:
            self._values["worker_type"] = worker_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def command(self) -> typing.List["GlueJobCommand"]:
        """command block."""
        return self._values.get("command")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def allocated_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("allocated_capacity")

    @builtins.property
    def connections(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("connections")

    @builtins.property
    def default_arguments(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("default_arguments")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def execution_property(
        self,
    ) -> typing.Optional[typing.List["GlueJobExecutionProperty"]]:
        """execution_property block."""
        return self._values.get("execution_property")

    @builtins.property
    def glue_version(self) -> typing.Optional[str]:
        return self._values.get("glue_version")

    @builtins.property
    def max_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_capacity")

    @builtins.property
    def max_retries(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_retries")

    @builtins.property
    def notification_property(
        self,
    ) -> typing.Optional[typing.List["GlueJobNotificationProperty"]]:
        """notification_property block."""
        return self._values.get("notification_property")

    @builtins.property
    def number_of_workers(self) -> typing.Optional[jsii.Number]:
        return self._values.get("number_of_workers")

    @builtins.property
    def security_configuration(self) -> typing.Optional[str]:
        return self._values.get("security_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout")

    @builtins.property
    def worker_type(self) -> typing.Optional[str]:
        return self._values.get("worker_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueJobConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueJobExecutionProperty",
    jsii_struct_bases=[],
    name_mapping={"max_concurrent_runs": "maxConcurrentRuns"},
)
class GlueJobExecutionProperty:
    def __init__(
        self, *, max_concurrent_runs: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param max_concurrent_runs: 
        """
        self._values = {}
        if max_concurrent_runs is not None:
            self._values["max_concurrent_runs"] = max_concurrent_runs

    @builtins.property
    def max_concurrent_runs(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_concurrent_runs")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueJobExecutionProperty(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueJobNotificationProperty",
    jsii_struct_bases=[],
    name_mapping={"notify_delay_after": "notifyDelayAfter"},
)
class GlueJobNotificationProperty:
    def __init__(
        self, *, notify_delay_after: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param notify_delay_after: 
        """
        self._values = {}
        if notify_delay_after is not None:
            self._values["notify_delay_after"] = notify_delay_after

    @builtins.property
    def notify_delay_after(self) -> typing.Optional[jsii.Number]:
        return self._values.get("notify_delay_after")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueJobNotificationProperty(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueSecurityConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueSecurityConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        encryption_configuration: typing.List[
            "GlueSecurityConfigurationEncryptionConfiguration"
        ],
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param encryption_configuration: encryption_configuration block.
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueSecurityConfigurationConfig(
            encryption_configuration=encryption_configuration,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueSecurityConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="encryptionConfiguration")
    def encryption_configuration(
        self,
    ) -> typing.List["GlueSecurityConfigurationEncryptionConfiguration"]:
        return jsii.get(self, "encryptionConfiguration")

    @encryption_configuration.setter
    def encryption_configuration(
        self, value: typing.List["GlueSecurityConfigurationEncryptionConfiguration"]
    ) -> None:
        jsii.set(self, "encryptionConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueSecurityConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "encryption_configuration": "encryptionConfiguration",
        "name": "name",
    },
)
class GlueSecurityConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        encryption_configuration: typing.List[
            "GlueSecurityConfigurationEncryptionConfiguration"
        ],
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param encryption_configuration: encryption_configuration block.
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "encryption_configuration": encryption_configuration,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def encryption_configuration(
        self,
    ) -> typing.List["GlueSecurityConfigurationEncryptionConfiguration"]:
        """encryption_configuration block."""
        return self._values.get("encryption_configuration")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueSecurityConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueSecurityConfigurationEncryptionConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_encryption": "cloudwatchEncryption",
        "job_bookmarks_encryption": "jobBookmarksEncryption",
        "s3_encryption": "s3Encryption",
    },
)
class GlueSecurityConfigurationEncryptionConfiguration:
    def __init__(
        self,
        *,
        cloudwatch_encryption: typing.List[
            "GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption"
        ],
        job_bookmarks_encryption: typing.List[
            "GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption"
        ],
        s3_encryption: typing.List[
            "GlueSecurityConfigurationEncryptionConfigurationS3Encryption"
        ],
    ) -> None:
        """
        :param cloudwatch_encryption: cloudwatch_encryption block.
        :param job_bookmarks_encryption: job_bookmarks_encryption block.
        :param s3_encryption: s3_encryption block.
        """
        self._values = {
            "cloudwatch_encryption": cloudwatch_encryption,
            "job_bookmarks_encryption": job_bookmarks_encryption,
            "s3_encryption": s3_encryption,
        }

    @builtins.property
    def cloudwatch_encryption(
        self,
    ) -> typing.List[
        "GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption"
    ]:
        """cloudwatch_encryption block."""
        return self._values.get("cloudwatch_encryption")

    @builtins.property
    def job_bookmarks_encryption(
        self,
    ) -> typing.List[
        "GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption"
    ]:
        """job_bookmarks_encryption block."""
        return self._values.get("job_bookmarks_encryption")

    @builtins.property
    def s3_encryption(
        self,
    ) -> typing.List["GlueSecurityConfigurationEncryptionConfigurationS3Encryption"]:
        """s3_encryption block."""
        return self._values.get("s3_encryption")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueSecurityConfigurationEncryptionConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_encryption_mode": "cloudwatchEncryptionMode",
        "kms_key_arn": "kmsKeyArn",
    },
)
class GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption:
    def __init__(
        self,
        *,
        cloudwatch_encryption_mode: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param cloudwatch_encryption_mode: 
        :param kms_key_arn: 
        """
        self._values = {}
        if cloudwatch_encryption_mode is not None:
            self._values["cloudwatch_encryption_mode"] = cloudwatch_encryption_mode
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn

    @builtins.property
    def cloudwatch_encryption_mode(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_encryption_mode")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption",
    jsii_struct_bases=[],
    name_mapping={
        "job_bookmarks_encryption_mode": "jobBookmarksEncryptionMode",
        "kms_key_arn": "kmsKeyArn",
    },
)
class GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption:
    def __init__(
        self,
        *,
        job_bookmarks_encryption_mode: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param job_bookmarks_encryption_mode: 
        :param kms_key_arn: 
        """
        self._values = {}
        if job_bookmarks_encryption_mode is not None:
            self._values[
                "job_bookmarks_encryption_mode"
            ] = job_bookmarks_encryption_mode
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn

    @builtins.property
    def job_bookmarks_encryption_mode(self) -> typing.Optional[str]:
        return self._values.get("job_bookmarks_encryption_mode")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueSecurityConfigurationEncryptionConfigurationS3Encryption",
    jsii_struct_bases=[],
    name_mapping={"kms_key_arn": "kmsKeyArn", "s3_encryption_mode": "s3EncryptionMode"},
)
class GlueSecurityConfigurationEncryptionConfigurationS3Encryption:
    def __init__(
        self,
        *,
        kms_key_arn: typing.Optional[str] = None,
        s3_encryption_mode: typing.Optional[str] = None,
    ) -> None:
        """
        :param kms_key_arn: 
        :param s3_encryption_mode: 
        """
        self._values = {}
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if s3_encryption_mode is not None:
            self._values["s3_encryption_mode"] = s3_encryption_mode

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def s3_encryption_mode(self) -> typing.Optional[str]:
        return self._values.get("s3_encryption_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "GlueSecurityConfigurationEncryptionConfigurationS3Encryption(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class GlueTrigger(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueTrigger",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        actions: typing.List["GlueTriggerActions"],
        name: str,
        type: str,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        predicate: typing.Optional[typing.List["GlueTriggerPredicate"]] = None,
        schedule: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["GlueTriggerTimeouts"] = None,
        workflow_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param actions: actions block.
        :param name: 
        :param type: 
        :param description: 
        :param enabled: 
        :param predicate: predicate block.
        :param schedule: 
        :param tags: 
        :param timeouts: timeouts block.
        :param workflow_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueTriggerConfig(
            actions=actions,
            name=name,
            type=type,
            description=description,
            enabled=enabled,
            predicate=predicate,
            schedule=schedule,
            tags=tags,
            timeouts=timeouts,
            workflow_name=workflow_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueTrigger, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="actions")
    def actions(self) -> typing.List["GlueTriggerActions"]:
        return jsii.get(self, "actions")

    @actions.setter
    def actions(self, value: typing.List["GlueTriggerActions"]) -> None:
        jsii.set(self, "actions", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="predicate")
    def predicate(self) -> typing.Optional[typing.List["GlueTriggerPredicate"]]:
        return jsii.get(self, "predicate")

    @predicate.setter
    def predicate(
        self, value: typing.Optional[typing.List["GlueTriggerPredicate"]]
    ) -> None:
        jsii.set(self, "predicate", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(self) -> typing.Optional[str]:
        return jsii.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "schedule", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["GlueTriggerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["GlueTriggerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="workflowName")
    def workflow_name(self) -> typing.Optional[str]:
        return jsii.get(self, "workflowName")

    @workflow_name.setter
    def workflow_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "workflowName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueTriggerActions",
    jsii_struct_bases=[],
    name_mapping={
        "arguments": "arguments",
        "crawler_name": "crawlerName",
        "job_name": "jobName",
        "timeout": "timeout",
    },
)
class GlueTriggerActions:
    def __init__(
        self,
        *,
        arguments: typing.Optional[typing.Mapping[str, str]] = None,
        crawler_name: typing.Optional[str] = None,
        job_name: typing.Optional[str] = None,
        timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param arguments: 
        :param crawler_name: 
        :param job_name: 
        :param timeout: 
        """
        self._values = {}
        if arguments is not None:
            self._values["arguments"] = arguments
        if crawler_name is not None:
            self._values["crawler_name"] = crawler_name
        if job_name is not None:
            self._values["job_name"] = job_name
        if timeout is not None:
            self._values["timeout"] = timeout

    @builtins.property
    def arguments(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("arguments")

    @builtins.property
    def crawler_name(self) -> typing.Optional[str]:
        return self._values.get("crawler_name")

    @builtins.property
    def job_name(self) -> typing.Optional[str]:
        return self._values.get("job_name")

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueTriggerActions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueTriggerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "actions": "actions",
        "name": "name",
        "type": "type",
        "description": "description",
        "enabled": "enabled",
        "predicate": "predicate",
        "schedule": "schedule",
        "tags": "tags",
        "timeouts": "timeouts",
        "workflow_name": "workflowName",
    },
)
class GlueTriggerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        actions: typing.List["GlueTriggerActions"],
        name: str,
        type: str,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        predicate: typing.Optional[typing.List["GlueTriggerPredicate"]] = None,
        schedule: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["GlueTriggerTimeouts"] = None,
        workflow_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param actions: actions block.
        :param name: 
        :param type: 
        :param description: 
        :param enabled: 
        :param predicate: predicate block.
        :param schedule: 
        :param tags: 
        :param timeouts: timeouts block.
        :param workflow_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = GlueTriggerTimeouts(**timeouts)
        self._values = {
            "actions": actions,
            "name": name,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if enabled is not None:
            self._values["enabled"] = enabled
        if predicate is not None:
            self._values["predicate"] = predicate
        if schedule is not None:
            self._values["schedule"] = schedule
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if workflow_name is not None:
            self._values["workflow_name"] = workflow_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def actions(self) -> typing.List["GlueTriggerActions"]:
        """actions block."""
        return self._values.get("actions")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def predicate(self) -> typing.Optional[typing.List["GlueTriggerPredicate"]]:
        """predicate block."""
        return self._values.get("predicate")

    @builtins.property
    def schedule(self) -> typing.Optional[str]:
        return self._values.get("schedule")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["GlueTriggerTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def workflow_name(self) -> typing.Optional[str]:
        return self._values.get("workflow_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueTriggerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueTriggerPredicate",
    jsii_struct_bases=[],
    name_mapping={"conditions": "conditions", "logical": "logical"},
)
class GlueTriggerPredicate:
    def __init__(
        self,
        *,
        conditions: typing.List["GlueTriggerPredicateConditions"],
        logical: typing.Optional[str] = None,
    ) -> None:
        """
        :param conditions: conditions block.
        :param logical: 
        """
        self._values = {
            "conditions": conditions,
        }
        if logical is not None:
            self._values["logical"] = logical

    @builtins.property
    def conditions(self) -> typing.List["GlueTriggerPredicateConditions"]:
        """conditions block."""
        return self._values.get("conditions")

    @builtins.property
    def logical(self) -> typing.Optional[str]:
        return self._values.get("logical")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueTriggerPredicate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueTriggerPredicateConditions",
    jsii_struct_bases=[],
    name_mapping={
        "crawler_name": "crawlerName",
        "crawl_state": "crawlState",
        "job_name": "jobName",
        "logical_operator": "logicalOperator",
        "state": "state",
    },
)
class GlueTriggerPredicateConditions:
    def __init__(
        self,
        *,
        crawler_name: typing.Optional[str] = None,
        crawl_state: typing.Optional[str] = None,
        job_name: typing.Optional[str] = None,
        logical_operator: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
    ) -> None:
        """
        :param crawler_name: 
        :param crawl_state: 
        :param job_name: 
        :param logical_operator: 
        :param state: 
        """
        self._values = {}
        if crawler_name is not None:
            self._values["crawler_name"] = crawler_name
        if crawl_state is not None:
            self._values["crawl_state"] = crawl_state
        if job_name is not None:
            self._values["job_name"] = job_name
        if logical_operator is not None:
            self._values["logical_operator"] = logical_operator
        if state is not None:
            self._values["state"] = state

    @builtins.property
    def crawler_name(self) -> typing.Optional[str]:
        return self._values.get("crawler_name")

    @builtins.property
    def crawl_state(self) -> typing.Optional[str]:
        return self._values.get("crawl_state")

    @builtins.property
    def job_name(self) -> typing.Optional[str]:
        return self._values.get("job_name")

    @builtins.property
    def logical_operator(self) -> typing.Optional[str]:
        return self._values.get("logical_operator")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueTriggerPredicateConditions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueTriggerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class GlueTriggerTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueTriggerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GlueWorkflow(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GlueWorkflow",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_run_properties: typing.Optional[typing.Mapping[str, str]] = None,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_run_properties: 
        :param description: 
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GlueWorkflowConfig(
            default_run_properties=default_run_properties,
            description=description,
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GlueWorkflow, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="defaultRunProperties")
    def default_run_properties(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "defaultRunProperties")

    @default_run_properties.setter
    def default_run_properties(
        self, value: typing.Optional[typing.Mapping[str, str]]
    ) -> None:
        jsii.set(self, "defaultRunProperties", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GlueWorkflowConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_run_properties": "defaultRunProperties",
        "description": "description",
        "name": "name",
    },
)
class GlueWorkflowConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_run_properties: typing.Optional[typing.Mapping[str, str]] = None,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_run_properties: 
        :param description: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_run_properties is not None:
            self._values["default_run_properties"] = default_run_properties
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_run_properties(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("default_run_properties")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GlueWorkflowConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GuarddutyDetector(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyDetector",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        enable: typing.Optional[bool] = None,
        finding_publishing_frequency: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enable: 
        :param finding_publishing_frequency: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GuarddutyDetectorConfig(
            enable=enable,
            finding_publishing_frequency=finding_publishing_frequency,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GuarddutyDetector, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="enable")
    def enable(self) -> typing.Optional[bool]:
        return jsii.get(self, "enable")

    @enable.setter
    def enable(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enable", value)

    @builtins.property
    @jsii.member(jsii_name="findingPublishingFrequency")
    def finding_publishing_frequency(self) -> typing.Optional[str]:
        return jsii.get(self, "findingPublishingFrequency")

    @finding_publishing_frequency.setter
    def finding_publishing_frequency(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "findingPublishingFrequency", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyDetectorConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enable": "enable",
        "finding_publishing_frequency": "findingPublishingFrequency",
        "tags": "tags",
    },
)
class GuarddutyDetectorConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enable: typing.Optional[bool] = None,
        finding_publishing_frequency: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enable: 
        :param finding_publishing_frequency: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enable is not None:
            self._values["enable"] = enable
        if finding_publishing_frequency is not None:
            self._values["finding_publishing_frequency"] = finding_publishing_frequency
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def enable(self) -> typing.Optional[bool]:
        return self._values.get("enable")

    @builtins.property
    def finding_publishing_frequency(self) -> typing.Optional[str]:
        return self._values.get("finding_publishing_frequency")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyDetectorConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GuarddutyInviteAccepter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyInviteAccepter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        detector_id: str,
        master_account_id: str,
        timeouts: typing.Optional["GuarddutyInviteAccepterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param detector_id: 
        :param master_account_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GuarddutyInviteAccepterConfig(
            detector_id=detector_id,
            master_account_id=master_account_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GuarddutyInviteAccepter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="detectorId")
    def detector_id(self) -> str:
        return jsii.get(self, "detectorId")

    @detector_id.setter
    def detector_id(self, value: str) -> None:
        jsii.set(self, "detectorId", value)

    @builtins.property
    @jsii.member(jsii_name="masterAccountId")
    def master_account_id(self) -> str:
        return jsii.get(self, "masterAccountId")

    @master_account_id.setter
    def master_account_id(self, value: str) -> None:
        jsii.set(self, "masterAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["GuarddutyInviteAccepterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["GuarddutyInviteAccepterTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyInviteAccepterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "detector_id": "detectorId",
        "master_account_id": "masterAccountId",
        "timeouts": "timeouts",
    },
)
class GuarddutyInviteAccepterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        detector_id: str,
        master_account_id: str,
        timeouts: typing.Optional["GuarddutyInviteAccepterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param detector_id: 
        :param master_account_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = GuarddutyInviteAccepterTimeouts(**timeouts)
        self._values = {
            "detector_id": detector_id,
            "master_account_id": master_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def detector_id(self) -> str:
        return self._values.get("detector_id")

    @builtins.property
    def master_account_id(self) -> str:
        return self._values.get("master_account_id")

    @builtins.property
    def timeouts(self) -> typing.Optional["GuarddutyInviteAccepterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyInviteAccepterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyInviteAccepterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class GuarddutyInviteAccepterTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyInviteAccepterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GuarddutyIpset(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyIpset",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        activate: bool,
        detector_id: str,
        format: str,
        location: str,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param activate: 
        :param detector_id: 
        :param format: 
        :param location: 
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GuarddutyIpsetConfig(
            activate=activate,
            detector_id=detector_id,
            format=format,
            location=location,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GuarddutyIpset, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="activate")
    def activate(self) -> bool:
        return jsii.get(self, "activate")

    @activate.setter
    def activate(self, value: bool) -> None:
        jsii.set(self, "activate", value)

    @builtins.property
    @jsii.member(jsii_name="detectorId")
    def detector_id(self) -> str:
        return jsii.get(self, "detectorId")

    @detector_id.setter
    def detector_id(self, value: str) -> None:
        jsii.set(self, "detectorId", value)

    @builtins.property
    @jsii.member(jsii_name="format")
    def format(self) -> str:
        return jsii.get(self, "format")

    @format.setter
    def format(self, value: str) -> None:
        jsii.set(self, "format", value)

    @builtins.property
    @jsii.member(jsii_name="location")
    def location(self) -> str:
        return jsii.get(self, "location")

    @location.setter
    def location(self, value: str) -> None:
        jsii.set(self, "location", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyIpsetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "activate": "activate",
        "detector_id": "detectorId",
        "format": "format",
        "location": "location",
        "name": "name",
        "tags": "tags",
    },
)
class GuarddutyIpsetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        activate: bool,
        detector_id: str,
        format: str,
        location: str,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param activate: 
        :param detector_id: 
        :param format: 
        :param location: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "activate": activate,
            "detector_id": detector_id,
            "format": format,
            "location": location,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def activate(self) -> bool:
        return self._values.get("activate")

    @builtins.property
    def detector_id(self) -> str:
        return self._values.get("detector_id")

    @builtins.property
    def format(self) -> str:
        return self._values.get("format")

    @builtins.property
    def location(self) -> str:
        return self._values.get("location")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyIpsetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GuarddutyMember(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyMember",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_id: str,
        detector_id: str,
        email: str,
        disable_email_notification: typing.Optional[bool] = None,
        invitation_message: typing.Optional[str] = None,
        invite: typing.Optional[bool] = None,
        timeouts: typing.Optional["GuarddutyMemberTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_id: 
        :param detector_id: 
        :param email: 
        :param disable_email_notification: 
        :param invitation_message: 
        :param invite: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GuarddutyMemberConfig(
            account_id=account_id,
            detector_id=detector_id,
            email=email,
            disable_email_notification=disable_email_notification,
            invitation_message=invitation_message,
            invite=invite,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GuarddutyMember, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="relationshipStatus")
    def relationship_status(self) -> str:
        return jsii.get(self, "relationshipStatus")

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: str) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="detectorId")
    def detector_id(self) -> str:
        return jsii.get(self, "detectorId")

    @detector_id.setter
    def detector_id(self, value: str) -> None:
        jsii.set(self, "detectorId", value)

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @email.setter
    def email(self, value: str) -> None:
        jsii.set(self, "email", value)

    @builtins.property
    @jsii.member(jsii_name="disableEmailNotification")
    def disable_email_notification(self) -> typing.Optional[bool]:
        return jsii.get(self, "disableEmailNotification")

    @disable_email_notification.setter
    def disable_email_notification(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "disableEmailNotification", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="invitationMessage")
    def invitation_message(self) -> typing.Optional[str]:
        return jsii.get(self, "invitationMessage")

    @invitation_message.setter
    def invitation_message(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "invitationMessage", value)

    @builtins.property
    @jsii.member(jsii_name="invite")
    def invite(self) -> typing.Optional[bool]:
        return jsii.get(self, "invite")

    @invite.setter
    def invite(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "invite", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["GuarddutyMemberTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["GuarddutyMemberTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyMemberConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_id": "accountId",
        "detector_id": "detectorId",
        "email": "email",
        "disable_email_notification": "disableEmailNotification",
        "invitation_message": "invitationMessage",
        "invite": "invite",
        "timeouts": "timeouts",
    },
)
class GuarddutyMemberConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_id: str,
        detector_id: str,
        email: str,
        disable_email_notification: typing.Optional[bool] = None,
        invitation_message: typing.Optional[str] = None,
        invite: typing.Optional[bool] = None,
        timeouts: typing.Optional["GuarddutyMemberTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_id: 
        :param detector_id: 
        :param email: 
        :param disable_email_notification: 
        :param invitation_message: 
        :param invite: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = GuarddutyMemberTimeouts(**timeouts)
        self._values = {
            "account_id": account_id,
            "detector_id": detector_id,
            "email": email,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if disable_email_notification is not None:
            self._values["disable_email_notification"] = disable_email_notification
        if invitation_message is not None:
            self._values["invitation_message"] = invitation_message
        if invite is not None:
            self._values["invite"] = invite
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_id(self) -> str:
        return self._values.get("account_id")

    @builtins.property
    def detector_id(self) -> str:
        return self._values.get("detector_id")

    @builtins.property
    def email(self) -> str:
        return self._values.get("email")

    @builtins.property
    def disable_email_notification(self) -> typing.Optional[bool]:
        return self._values.get("disable_email_notification")

    @builtins.property
    def invitation_message(self) -> typing.Optional[str]:
        return self._values.get("invitation_message")

    @builtins.property
    def invite(self) -> typing.Optional[bool]:
        return self._values.get("invite")

    @builtins.property
    def timeouts(self) -> typing.Optional["GuarddutyMemberTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyMemberConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyMemberTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "update": "update"},
)
class GuarddutyMemberTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyMemberTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GuarddutyOrganizationAdminAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyOrganizationAdminAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        admin_account_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param admin_account_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GuarddutyOrganizationAdminAccountConfig(
            admin_account_id=admin_account_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GuarddutyOrganizationAdminAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="adminAccountId")
    def admin_account_id(self) -> str:
        return jsii.get(self, "adminAccountId")

    @admin_account_id.setter
    def admin_account_id(self, value: str) -> None:
        jsii.set(self, "adminAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyOrganizationAdminAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "admin_account_id": "adminAccountId",
    },
)
class GuarddutyOrganizationAdminAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        admin_account_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param admin_account_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "admin_account_id": admin_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def admin_account_id(self) -> str:
        return self._values.get("admin_account_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyOrganizationAdminAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GuarddutyOrganizationConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyOrganizationConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        auto_enable: bool,
        detector_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param auto_enable: 
        :param detector_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GuarddutyOrganizationConfigurationConfig(
            auto_enable=auto_enable,
            detector_id=detector_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GuarddutyOrganizationConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="autoEnable")
    def auto_enable(self) -> bool:
        return jsii.get(self, "autoEnable")

    @auto_enable.setter
    def auto_enable(self, value: bool) -> None:
        jsii.set(self, "autoEnable", value)

    @builtins.property
    @jsii.member(jsii_name="detectorId")
    def detector_id(self) -> str:
        return jsii.get(self, "detectorId")

    @detector_id.setter
    def detector_id(self, value: str) -> None:
        jsii.set(self, "detectorId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyOrganizationConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "auto_enable": "autoEnable",
        "detector_id": "detectorId",
    },
)
class GuarddutyOrganizationConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        auto_enable: bool,
        detector_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param auto_enable: 
        :param detector_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "auto_enable": auto_enable,
            "detector_id": detector_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def auto_enable(self) -> bool:
        return self._values.get("auto_enable")

    @builtins.property
    def detector_id(self) -> str:
        return self._values.get("detector_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyOrganizationConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class GuarddutyThreatintelset(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyThreatintelset",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        activate: bool,
        detector_id: str,
        format: str,
        location: str,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param activate: 
        :param detector_id: 
        :param format: 
        :param location: 
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = GuarddutyThreatintelsetConfig(
            activate=activate,
            detector_id=detector_id,
            format=format,
            location=location,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(GuarddutyThreatintelset, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="activate")
    def activate(self) -> bool:
        return jsii.get(self, "activate")

    @activate.setter
    def activate(self, value: bool) -> None:
        jsii.set(self, "activate", value)

    @builtins.property
    @jsii.member(jsii_name="detectorId")
    def detector_id(self) -> str:
        return jsii.get(self, "detectorId")

    @detector_id.setter
    def detector_id(self, value: str) -> None:
        jsii.set(self, "detectorId", value)

    @builtins.property
    @jsii.member(jsii_name="format")
    def format(self) -> str:
        return jsii.get(self, "format")

    @format.setter
    def format(self, value: str) -> None:
        jsii.set(self, "format", value)

    @builtins.property
    @jsii.member(jsii_name="location")
    def location(self) -> str:
        return jsii.get(self, "location")

    @location.setter
    def location(self, value: str) -> None:
        jsii.set(self, "location", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.GuarddutyThreatintelsetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "activate": "activate",
        "detector_id": "detectorId",
        "format": "format",
        "location": "location",
        "name": "name",
        "tags": "tags",
    },
)
class GuarddutyThreatintelsetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        activate: bool,
        detector_id: str,
        format: str,
        location: str,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param activate: 
        :param detector_id: 
        :param format: 
        :param location: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "activate": activate,
            "detector_id": detector_id,
            "format": format,
            "location": location,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def activate(self) -> bool:
        return self._values.get("activate")

    @builtins.property
    def detector_id(self) -> str:
        return self._values.get("detector_id")

    @builtins.property
    def format(self) -> str:
        return self._values.get("format")

    @builtins.property
    def location(self) -> str:
        return self._values.get("location")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "GuarddutyThreatintelsetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamAccessKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamAccessKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        user: str,
        pgp_key: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param user: 
        :param pgp_key: 
        :param status: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamAccessKeyConfig(
            user=user,
            pgp_key=pgp_key,
            status=status,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamAccessKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="encryptedSecret")
    def encrypted_secret(self) -> str:
        return jsii.get(self, "encryptedSecret")

    @builtins.property
    @jsii.member(jsii_name="keyFingerprint")
    def key_fingerprint(self) -> str:
        return jsii.get(self, "keyFingerprint")

    @builtins.property
    @jsii.member(jsii_name="secret")
    def secret(self) -> str:
        return jsii.get(self, "secret")

    @builtins.property
    @jsii.member(jsii_name="sesSmtpPassword")
    def ses_smtp_password(self) -> str:
        return jsii.get(self, "sesSmtpPassword")

    @builtins.property
    @jsii.member(jsii_name="sesSmtpPasswordV4")
    def ses_smtp_password_v4(self) -> str:
        return jsii.get(self, "sesSmtpPasswordV4")

    @builtins.property
    @jsii.member(jsii_name="user")
    def user(self) -> str:
        return jsii.get(self, "user")

    @user.setter
    def user(self, value: str) -> None:
        jsii.set(self, "user", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="pgpKey")
    def pgp_key(self) -> typing.Optional[str]:
        return jsii.get(self, "pgpKey")

    @pgp_key.setter
    def pgp_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "pgpKey", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[str]:
        return jsii.get(self, "status")

    @status.setter
    def status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "status", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamAccessKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "user": "user",
        "pgp_key": "pgpKey",
        "status": "status",
    },
)
class IamAccessKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        user: str,
        pgp_key: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param user: 
        :param pgp_key: 
        :param status: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if pgp_key is not None:
            self._values["pgp_key"] = pgp_key
        if status is not None:
            self._values["status"] = status

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def user(self) -> str:
        return self._values.get("user")

    @builtins.property
    def pgp_key(self) -> typing.Optional[str]:
        return self._values.get("pgp_key")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamAccessKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamAccountAlias(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamAccountAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_alias: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_alias: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamAccountAliasConfig(
            account_alias=account_alias,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamAccountAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountAlias")
    def account_alias(self) -> str:
        return jsii.get(self, "accountAlias")

    @account_alias.setter
    def account_alias(self, value: str) -> None:
        jsii.set(self, "accountAlias", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamAccountAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_alias": "accountAlias",
    },
)
class IamAccountAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_alias: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_alias: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "account_alias": account_alias,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_alias(self) -> str:
        return self._values.get("account_alias")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamAccountAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamAccountPasswordPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamAccountPasswordPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        allow_users_to_change_password: typing.Optional[bool] = None,
        hard_expiry: typing.Optional[bool] = None,
        max_password_age: typing.Optional[jsii.Number] = None,
        minimum_password_length: typing.Optional[jsii.Number] = None,
        password_reuse_prevention: typing.Optional[jsii.Number] = None,
        require_lowercase_characters: typing.Optional[bool] = None,
        require_numbers: typing.Optional[bool] = None,
        require_symbols: typing.Optional[bool] = None,
        require_uppercase_characters: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param allow_users_to_change_password: 
        :param hard_expiry: 
        :param max_password_age: 
        :param minimum_password_length: 
        :param password_reuse_prevention: 
        :param require_lowercase_characters: 
        :param require_numbers: 
        :param require_symbols: 
        :param require_uppercase_characters: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamAccountPasswordPolicyConfig(
            allow_users_to_change_password=allow_users_to_change_password,
            hard_expiry=hard_expiry,
            max_password_age=max_password_age,
            minimum_password_length=minimum_password_length,
            password_reuse_prevention=password_reuse_prevention,
            require_lowercase_characters=require_lowercase_characters,
            require_numbers=require_numbers,
            require_symbols=require_symbols,
            require_uppercase_characters=require_uppercase_characters,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamAccountPasswordPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="expirePasswords")
    def expire_passwords(self) -> bool:
        return jsii.get(self, "expirePasswords")

    @builtins.property
    @jsii.member(jsii_name="allowUsersToChangePassword")
    def allow_users_to_change_password(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowUsersToChangePassword")

    @allow_users_to_change_password.setter
    def allow_users_to_change_password(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowUsersToChangePassword", value)

    @builtins.property
    @jsii.member(jsii_name="hardExpiry")
    def hard_expiry(self) -> typing.Optional[bool]:
        return jsii.get(self, "hardExpiry")

    @hard_expiry.setter
    def hard_expiry(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "hardExpiry", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maxPasswordAge")
    def max_password_age(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxPasswordAge")

    @max_password_age.setter
    def max_password_age(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxPasswordAge", value)

    @builtins.property
    @jsii.member(jsii_name="minimumPasswordLength")
    def minimum_password_length(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "minimumPasswordLength")

    @minimum_password_length.setter
    def minimum_password_length(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "minimumPasswordLength", value)

    @builtins.property
    @jsii.member(jsii_name="passwordReusePrevention")
    def password_reuse_prevention(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "passwordReusePrevention")

    @password_reuse_prevention.setter
    def password_reuse_prevention(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "passwordReusePrevention", value)

    @builtins.property
    @jsii.member(jsii_name="requireLowercaseCharacters")
    def require_lowercase_characters(self) -> typing.Optional[bool]:
        return jsii.get(self, "requireLowercaseCharacters")

    @require_lowercase_characters.setter
    def require_lowercase_characters(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "requireLowercaseCharacters", value)

    @builtins.property
    @jsii.member(jsii_name="requireNumbers")
    def require_numbers(self) -> typing.Optional[bool]:
        return jsii.get(self, "requireNumbers")

    @require_numbers.setter
    def require_numbers(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "requireNumbers", value)

    @builtins.property
    @jsii.member(jsii_name="requireSymbols")
    def require_symbols(self) -> typing.Optional[bool]:
        return jsii.get(self, "requireSymbols")

    @require_symbols.setter
    def require_symbols(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "requireSymbols", value)

    @builtins.property
    @jsii.member(jsii_name="requireUppercaseCharacters")
    def require_uppercase_characters(self) -> typing.Optional[bool]:
        return jsii.get(self, "requireUppercaseCharacters")

    @require_uppercase_characters.setter
    def require_uppercase_characters(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "requireUppercaseCharacters", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamAccountPasswordPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "allow_users_to_change_password": "allowUsersToChangePassword",
        "hard_expiry": "hardExpiry",
        "max_password_age": "maxPasswordAge",
        "minimum_password_length": "minimumPasswordLength",
        "password_reuse_prevention": "passwordReusePrevention",
        "require_lowercase_characters": "requireLowercaseCharacters",
        "require_numbers": "requireNumbers",
        "require_symbols": "requireSymbols",
        "require_uppercase_characters": "requireUppercaseCharacters",
    },
)
class IamAccountPasswordPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        allow_users_to_change_password: typing.Optional[bool] = None,
        hard_expiry: typing.Optional[bool] = None,
        max_password_age: typing.Optional[jsii.Number] = None,
        minimum_password_length: typing.Optional[jsii.Number] = None,
        password_reuse_prevention: typing.Optional[jsii.Number] = None,
        require_lowercase_characters: typing.Optional[bool] = None,
        require_numbers: typing.Optional[bool] = None,
        require_symbols: typing.Optional[bool] = None,
        require_uppercase_characters: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param allow_users_to_change_password: 
        :param hard_expiry: 
        :param max_password_age: 
        :param minimum_password_length: 
        :param password_reuse_prevention: 
        :param require_lowercase_characters: 
        :param require_numbers: 
        :param require_symbols: 
        :param require_uppercase_characters: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_users_to_change_password is not None:
            self._values[
                "allow_users_to_change_password"
            ] = allow_users_to_change_password
        if hard_expiry is not None:
            self._values["hard_expiry"] = hard_expiry
        if max_password_age is not None:
            self._values["max_password_age"] = max_password_age
        if minimum_password_length is not None:
            self._values["minimum_password_length"] = minimum_password_length
        if password_reuse_prevention is not None:
            self._values["password_reuse_prevention"] = password_reuse_prevention
        if require_lowercase_characters is not None:
            self._values["require_lowercase_characters"] = require_lowercase_characters
        if require_numbers is not None:
            self._values["require_numbers"] = require_numbers
        if require_symbols is not None:
            self._values["require_symbols"] = require_symbols
        if require_uppercase_characters is not None:
            self._values["require_uppercase_characters"] = require_uppercase_characters

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def allow_users_to_change_password(self) -> typing.Optional[bool]:
        return self._values.get("allow_users_to_change_password")

    @builtins.property
    def hard_expiry(self) -> typing.Optional[bool]:
        return self._values.get("hard_expiry")

    @builtins.property
    def max_password_age(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_password_age")

    @builtins.property
    def minimum_password_length(self) -> typing.Optional[jsii.Number]:
        return self._values.get("minimum_password_length")

    @builtins.property
    def password_reuse_prevention(self) -> typing.Optional[jsii.Number]:
        return self._values.get("password_reuse_prevention")

    @builtins.property
    def require_lowercase_characters(self) -> typing.Optional[bool]:
        return self._values.get("require_lowercase_characters")

    @builtins.property
    def require_numbers(self) -> typing.Optional[bool]:
        return self._values.get("require_numbers")

    @builtins.property
    def require_symbols(self) -> typing.Optional[bool]:
        return self._values.get("require_symbols")

    @builtins.property
    def require_uppercase_characters(self) -> typing.Optional[bool]:
        return self._values.get("require_uppercase_characters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamAccountPasswordPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        path: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param path: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamGroupConfig(
            name=name,
            path=path,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> str:
        return jsii.get(self, "uniqueId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> typing.Optional[str]:
        return jsii.get(self, "path")

    @path.setter
    def path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "path", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "path": "path",
    },
)
class IamGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        path: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param path: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamGroupMembership(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroupMembership",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        group: str,
        name: str,
        users: typing.List[str],
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group: 
        :param name: 
        :param users: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamGroupMembershipConfig(
            group=group,
            name=name,
            users=users,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamGroupMembership, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="group")
    def group(self) -> str:
        return jsii.get(self, "group")

    @group.setter
    def group(self, value: str) -> None:
        jsii.set(self, "group", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="users")
    def users(self) -> typing.List[str]:
        return jsii.get(self, "users")

    @users.setter
    def users(self, value: typing.List[str]) -> None:
        jsii.set(self, "users", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroupMembershipConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group": "group",
        "name": "name",
        "users": "users",
    },
)
class IamGroupMembershipConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group: str,
        name: str,
        users: typing.List[str],
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group: 
        :param name: 
        :param users: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "group": group,
            "name": name,
            "users": users,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def group(self) -> str:
        return self._values.get("group")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def users(self) -> typing.List[str]:
        return self._values.get("users")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamGroupMembershipConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamGroupPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroupPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        group: str,
        policy: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group: 
        :param policy: 
        :param name: 
        :param name_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamGroupPolicyConfig(
            group=group,
            policy=policy,
            name=name,
            name_prefix=name_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamGroupPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="group")
    def group(self) -> str:
        return jsii.get(self, "group")

    @group.setter
    def group(self, value: str) -> None:
        jsii.set(self, "group", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)


class IamGroupPolicyAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroupPolicyAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        group: str,
        policy_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group: 
        :param policy_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamGroupPolicyAttachmentConfig(
            group=group,
            policy_arn=policy_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamGroupPolicyAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="group")
    def group(self) -> str:
        return jsii.get(self, "group")

    @group.setter
    def group(self, value: str) -> None:
        jsii.set(self, "group", value)

    @builtins.property
    @jsii.member(jsii_name="policyArn")
    def policy_arn(self) -> str:
        return jsii.get(self, "policyArn")

    @policy_arn.setter
    def policy_arn(self, value: str) -> None:
        jsii.set(self, "policyArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroupPolicyAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group": "group",
        "policy_arn": "policyArn",
    },
)
class IamGroupPolicyAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group: str,
        policy_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group: 
        :param policy_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "group": group,
            "policy_arn": policy_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def group(self) -> str:
        return self._values.get("group")

    @builtins.property
    def policy_arn(self) -> str:
        return self._values.get("policy_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamGroupPolicyAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamGroupPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group": "group",
        "policy": "policy",
        "name": "name",
        "name_prefix": "namePrefix",
    },
)
class IamGroupPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group: str,
        policy: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group: 
        :param policy: 
        :param name: 
        :param name_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "group": group,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def group(self) -> str:
        return self._values.get("group")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamGroupPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamInstanceProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamInstanceProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        role: typing.Optional[str] = None,
        roles: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param name_prefix: 
        :param path: 
        :param role: 
        :param roles: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamInstanceProfileConfig(
            name=name,
            name_prefix=name_prefix,
            path=path,
            role=role,
            roles=roles,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamInstanceProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createDate")
    def create_date(self) -> str:
        return jsii.get(self, "createDate")

    @builtins.property
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> str:
        return jsii.get(self, "uniqueId")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> typing.Optional[str]:
        return jsii.get(self, "path")

    @path.setter
    def path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "path", value)

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> typing.Optional[str]:
        return jsii.get(self, "role")

    @role.setter
    def role(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "role", value)

    @builtins.property
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "roles")

    @roles.setter
    def roles(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "roles", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamInstanceProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "name_prefix": "namePrefix",
        "path": "path",
        "role": "role",
        "roles": "roles",
    },
)
class IamInstanceProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        role: typing.Optional[str] = None,
        roles: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param name_prefix: 
        :param path: 
        :param role: 
        :param roles: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if path is not None:
            self._values["path"] = path
        if role is not None:
            self._values["role"] = role
        if roles is not None:
            self._values["roles"] = roles

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def role(self) -> typing.Optional[str]:
        return self._values.get("role")

    @builtins.property
    def roles(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("roles")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamInstanceProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamOpenidConnectProvider(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamOpenidConnectProvider",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        client_id_list: typing.List[str],
        thumbprint_list: typing.List[str],
        url: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param client_id_list: 
        :param thumbprint_list: 
        :param url: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamOpenidConnectProviderConfig(
            client_id_list=client_id_list,
            thumbprint_list=thumbprint_list,
            url=url,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamOpenidConnectProvider, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="clientIdList")
    def client_id_list(self) -> typing.List[str]:
        return jsii.get(self, "clientIdList")

    @client_id_list.setter
    def client_id_list(self, value: typing.List[str]) -> None:
        jsii.set(self, "clientIdList", value)

    @builtins.property
    @jsii.member(jsii_name="thumbprintList")
    def thumbprint_list(self) -> typing.List[str]:
        return jsii.get(self, "thumbprintList")

    @thumbprint_list.setter
    def thumbprint_list(self, value: typing.List[str]) -> None:
        jsii.set(self, "thumbprintList", value)

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> str:
        return jsii.get(self, "url")

    @url.setter
    def url(self, value: str) -> None:
        jsii.set(self, "url", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamOpenidConnectProviderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "client_id_list": "clientIdList",
        "thumbprint_list": "thumbprintList",
        "url": "url",
    },
)
class IamOpenidConnectProviderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        client_id_list: typing.List[str],
        thumbprint_list: typing.List[str],
        url: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param client_id_list: 
        :param thumbprint_list: 
        :param url: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "client_id_list": client_id_list,
            "thumbprint_list": thumbprint_list,
            "url": url,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def client_id_list(self) -> typing.List[str]:
        return self._values.get("client_id_list")

    @builtins.property
    def thumbprint_list(self) -> typing.List[str]:
        return self._values.get("thumbprint_list")

    @builtins.property
    def url(self) -> str:
        return self._values.get("url")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamOpenidConnectProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param path: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamPolicyConfig(
            policy=policy,
            description=description,
            name=name,
            name_prefix=name_prefix,
            path=path,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> typing.Optional[str]:
        return jsii.get(self, "path")

    @path.setter
    def path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "path", value)


class IamPolicyAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamPolicyAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        policy_arn: str,
        groups: typing.Optional[typing.List[str]] = None,
        roles: typing.Optional[typing.List[str]] = None,
        users: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param policy_arn: 
        :param groups: 
        :param roles: 
        :param users: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamPolicyAttachmentConfig(
            name=name,
            policy_arn=policy_arn,
            groups=groups,
            roles=roles,
            users=users,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamPolicyAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="policyArn")
    def policy_arn(self) -> str:
        return jsii.get(self, "policyArn")

    @policy_arn.setter
    def policy_arn(self, value: str) -> None:
        jsii.set(self, "policyArn", value)

    @builtins.property
    @jsii.member(jsii_name="groups")
    def groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "groups")

    @groups.setter
    def groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "groups", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="roles")
    def roles(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "roles")

    @roles.setter
    def roles(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "roles", value)

    @builtins.property
    @jsii.member(jsii_name="users")
    def users(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "users")

    @users.setter
    def users(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "users", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamPolicyAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "policy_arn": "policyArn",
        "groups": "groups",
        "roles": "roles",
        "users": "users",
    },
)
class IamPolicyAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        policy_arn: str,
        groups: typing.Optional[typing.List[str]] = None,
        roles: typing.Optional[typing.List[str]] = None,
        users: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param policy_arn: 
        :param groups: 
        :param roles: 
        :param users: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "policy_arn": policy_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if groups is not None:
            self._values["groups"] = groups
        if roles is not None:
            self._values["roles"] = roles
        if users is not None:
            self._values["users"] = users

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def policy_arn(self) -> str:
        return self._values.get("policy_arn")

    @builtins.property
    def groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("groups")

    @builtins.property
    def roles(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("roles")

    @builtins.property
    def users(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("users")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamPolicyAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy": "policy",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "path": "path",
    },
)
class IamPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param path: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamRole(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamRole",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        assume_role_policy: str,
        description: typing.Optional[str] = None,
        force_detach_policies: typing.Optional[bool] = None,
        max_session_duration: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        permissions_boundary: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param assume_role_policy: 
        :param description: 
        :param force_detach_policies: 
        :param max_session_duration: 
        :param name: 
        :param name_prefix: 
        :param path: 
        :param permissions_boundary: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamRoleConfig(
            assume_role_policy=assume_role_policy,
            description=description,
            force_detach_policies=force_detach_policies,
            max_session_duration=max_session_duration,
            name=name,
            name_prefix=name_prefix,
            path=path,
            permissions_boundary=permissions_boundary,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamRole, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createDate")
    def create_date(self) -> str:
        return jsii.get(self, "createDate")

    @builtins.property
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> str:
        return jsii.get(self, "uniqueId")

    @builtins.property
    @jsii.member(jsii_name="assumeRolePolicy")
    def assume_role_policy(self) -> str:
        return jsii.get(self, "assumeRolePolicy")

    @assume_role_policy.setter
    def assume_role_policy(self, value: str) -> None:
        jsii.set(self, "assumeRolePolicy", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="forceDetachPolicies")
    def force_detach_policies(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDetachPolicies")

    @force_detach_policies.setter
    def force_detach_policies(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDetachPolicies", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maxSessionDuration")
    def max_session_duration(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxSessionDuration")

    @max_session_duration.setter
    def max_session_duration(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxSessionDuration", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> typing.Optional[str]:
        return jsii.get(self, "path")

    @path.setter
    def path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "path", value)

    @builtins.property
    @jsii.member(jsii_name="permissionsBoundary")
    def permissions_boundary(self) -> typing.Optional[str]:
        return jsii.get(self, "permissionsBoundary")

    @permissions_boundary.setter
    def permissions_boundary(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "permissionsBoundary", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamRoleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "assume_role_policy": "assumeRolePolicy",
        "description": "description",
        "force_detach_policies": "forceDetachPolicies",
        "max_session_duration": "maxSessionDuration",
        "name": "name",
        "name_prefix": "namePrefix",
        "path": "path",
        "permissions_boundary": "permissionsBoundary",
        "tags": "tags",
    },
)
class IamRoleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        assume_role_policy: str,
        description: typing.Optional[str] = None,
        force_detach_policies: typing.Optional[bool] = None,
        max_session_duration: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        permissions_boundary: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param assume_role_policy: 
        :param description: 
        :param force_detach_policies: 
        :param max_session_duration: 
        :param name: 
        :param name_prefix: 
        :param path: 
        :param permissions_boundary: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "assume_role_policy": assume_role_policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if force_detach_policies is not None:
            self._values["force_detach_policies"] = force_detach_policies
        if max_session_duration is not None:
            self._values["max_session_duration"] = max_session_duration
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if path is not None:
            self._values["path"] = path
        if permissions_boundary is not None:
            self._values["permissions_boundary"] = permissions_boundary
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def assume_role_policy(self) -> str:
        return self._values.get("assume_role_policy")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def force_detach_policies(self) -> typing.Optional[bool]:
        return self._values.get("force_detach_policies")

    @builtins.property
    def max_session_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_session_duration")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def permissions_boundary(self) -> typing.Optional[str]:
        return self._values.get("permissions_boundary")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamRoleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamRolePolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamRolePolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy: str,
        role: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy: 
        :param role: 
        :param name: 
        :param name_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamRolePolicyConfig(
            policy=policy,
            role=role,
            name=name,
            name_prefix=name_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamRolePolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> str:
        return jsii.get(self, "role")

    @role.setter
    def role(self, value: str) -> None:
        jsii.set(self, "role", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)


class IamRolePolicyAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamRolePolicyAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy_arn: str,
        role: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy_arn: 
        :param role: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamRolePolicyAttachmentConfig(
            policy_arn=policy_arn,
            role=role,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamRolePolicyAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policyArn")
    def policy_arn(self) -> str:
        return jsii.get(self, "policyArn")

    @policy_arn.setter
    def policy_arn(self, value: str) -> None:
        jsii.set(self, "policyArn", value)

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> str:
        return jsii.get(self, "role")

    @role.setter
    def role(self, value: str) -> None:
        jsii.set(self, "role", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamRolePolicyAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy_arn": "policyArn",
        "role": "role",
    },
)
class IamRolePolicyAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy_arn: str,
        role: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy_arn: 
        :param role: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy_arn": policy_arn,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy_arn(self) -> str:
        return self._values.get("policy_arn")

    @builtins.property
    def role(self) -> str:
        return self._values.get("role")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamRolePolicyAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamRolePolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy": "policy",
        "role": "role",
        "name": "name",
        "name_prefix": "namePrefix",
    },
)
class IamRolePolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy: str,
        role: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy: 
        :param role: 
        :param name: 
        :param name_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy": policy,
            "role": role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def role(self) -> str:
        return self._values.get("role")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamRolePolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamSamlProvider(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamSamlProvider",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        saml_metadata_document: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param saml_metadata_document: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamSamlProviderConfig(
            name=name,
            saml_metadata_document=saml_metadata_document,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamSamlProvider, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="validUntil")
    def valid_until(self) -> str:
        return jsii.get(self, "validUntil")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="samlMetadataDocument")
    def saml_metadata_document(self) -> str:
        return jsii.get(self, "samlMetadataDocument")

    @saml_metadata_document.setter
    def saml_metadata_document(self, value: str) -> None:
        jsii.set(self, "samlMetadataDocument", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamSamlProviderConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "saml_metadata_document": "samlMetadataDocument",
    },
)
class IamSamlProviderConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        saml_metadata_document: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param saml_metadata_document: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "saml_metadata_document": saml_metadata_document,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def saml_metadata_document(self) -> str:
        return self._values.get("saml_metadata_document")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamSamlProviderConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServerCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamServerCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate_body: str,
        private_key: str,
        certificate_chain: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_body: 
        :param private_key: 
        :param certificate_chain: 
        :param name: 
        :param name_prefix: 
        :param path: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamServerCertificateConfig(
            certificate_body=certificate_body,
            private_key=private_key,
            certificate_chain=certificate_chain,
            name=name,
            name_prefix=name_prefix,
            path=path,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamServerCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificateBody")
    def certificate_body(self) -> str:
        return jsii.get(self, "certificateBody")

    @certificate_body.setter
    def certificate_body(self, value: str) -> None:
        jsii.set(self, "certificateBody", value)

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> str:
        return jsii.get(self, "privateKey")

    @private_key.setter
    def private_key(self, value: str) -> None:
        jsii.set(self, "privateKey", value)

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="certificateChain")
    def certificate_chain(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateChain")

    @certificate_chain.setter
    def certificate_chain(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateChain", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> typing.Optional[str]:
        return jsii.get(self, "path")

    @path.setter
    def path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "path", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamServerCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_body": "certificateBody",
        "private_key": "privateKey",
        "certificate_chain": "certificateChain",
        "name": "name",
        "name_prefix": "namePrefix",
        "path": "path",
    },
)
class IamServerCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_body: str,
        private_key: str,
        certificate_chain: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_body: 
        :param private_key: 
        :param certificate_chain: 
        :param name: 
        :param name_prefix: 
        :param path: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "certificate_body": certificate_body,
            "private_key": private_key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_chain is not None:
            self._values["certificate_chain"] = certificate_chain
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if path is not None:
            self._values["path"] = path

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate_body(self) -> str:
        return self._values.get("certificate_body")

    @builtins.property
    def private_key(self) -> str:
        return self._values.get("private_key")

    @builtins.property
    def certificate_chain(self) -> typing.Optional[str]:
        return self._values.get("certificate_chain")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServerCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamServiceLinkedRole(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamServiceLinkedRole",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        aws_service_name: str,
        custom_suffix: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param aws_service_name: 
        :param custom_suffix: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamServiceLinkedRoleConfig(
            aws_service_name=aws_service_name,
            custom_suffix=custom_suffix,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamServiceLinkedRole, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createDate")
    def create_date(self) -> str:
        return jsii.get(self, "createDate")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> str:
        return jsii.get(self, "uniqueId")

    @builtins.property
    @jsii.member(jsii_name="awsServiceName")
    def aws_service_name(self) -> str:
        return jsii.get(self, "awsServiceName")

    @aws_service_name.setter
    def aws_service_name(self, value: str) -> None:
        jsii.set(self, "awsServiceName", value)

    @builtins.property
    @jsii.member(jsii_name="customSuffix")
    def custom_suffix(self) -> typing.Optional[str]:
        return jsii.get(self, "customSuffix")

    @custom_suffix.setter
    def custom_suffix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customSuffix", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamServiceLinkedRoleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "aws_service_name": "awsServiceName",
        "custom_suffix": "customSuffix",
        "description": "description",
    },
)
class IamServiceLinkedRoleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        aws_service_name: str,
        custom_suffix: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param aws_service_name: 
        :param custom_suffix: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "aws_service_name": aws_service_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if custom_suffix is not None:
            self._values["custom_suffix"] = custom_suffix
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def aws_service_name(self) -> str:
        return self._values.get("aws_service_name")

    @builtins.property
    def custom_suffix(self) -> typing.Optional[str]:
        return self._values.get("custom_suffix")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamServiceLinkedRoleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamUser(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamUser",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        force_destroy: typing.Optional[bool] = None,
        path: typing.Optional[str] = None,
        permissions_boundary: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param force_destroy: Delete user even if it has non-Terraform-managed IAM access keys, login profile or MFA devices.
        :param path: 
        :param permissions_boundary: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamUserConfig(
            name=name,
            force_destroy=force_destroy,
            path=path,
            permissions_boundary=permissions_boundary,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamUser, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="uniqueId")
    def unique_id(self) -> str:
        return jsii.get(self, "uniqueId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> typing.Optional[str]:
        return jsii.get(self, "path")

    @path.setter
    def path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "path", value)

    @builtins.property
    @jsii.member(jsii_name="permissionsBoundary")
    def permissions_boundary(self) -> typing.Optional[str]:
        return jsii.get(self, "permissionsBoundary")

    @permissions_boundary.setter
    def permissions_boundary(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "permissionsBoundary", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "force_destroy": "forceDestroy",
        "path": "path",
        "permissions_boundary": "permissionsBoundary",
        "tags": "tags",
    },
)
class IamUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        force_destroy: typing.Optional[bool] = None,
        path: typing.Optional[str] = None,
        permissions_boundary: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param force_destroy: Delete user even if it has non-Terraform-managed IAM access keys, login profile or MFA devices.
        :param path: 
        :param permissions_boundary: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if path is not None:
            self._values["path"] = path
        if permissions_boundary is not None:
            self._values["permissions_boundary"] = permissions_boundary
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        """Delete user even if it has non-Terraform-managed IAM access keys, login profile or MFA devices."""
        return self._values.get("force_destroy")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def permissions_boundary(self) -> typing.Optional[str]:
        return self._values.get("permissions_boundary")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamUserGroupMembership(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserGroupMembership",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        groups: typing.List[str],
        user: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param groups: 
        :param user: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamUserGroupMembershipConfig(
            groups=groups,
            user=user,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamUserGroupMembership, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="groups")
    def groups(self) -> typing.List[str]:
        return jsii.get(self, "groups")

    @groups.setter
    def groups(self, value: typing.List[str]) -> None:
        jsii.set(self, "groups", value)

    @builtins.property
    @jsii.member(jsii_name="user")
    def user(self) -> str:
        return jsii.get(self, "user")

    @user.setter
    def user(self, value: str) -> None:
        jsii.set(self, "user", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserGroupMembershipConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "groups": "groups",
        "user": "user",
    },
)
class IamUserGroupMembershipConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        groups: typing.List[str],
        user: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param groups: 
        :param user: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "groups": groups,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def groups(self) -> typing.List[str]:
        return self._values.get("groups")

    @builtins.property
    def user(self) -> str:
        return self._values.get("user")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamUserGroupMembershipConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamUserLoginProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserLoginProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        pgp_key: str,
        user: str,
        password_length: typing.Optional[jsii.Number] = None,
        password_reset_required: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param pgp_key: 
        :param user: 
        :param password_length: 
        :param password_reset_required: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamUserLoginProfileConfig(
            pgp_key=pgp_key,
            user=user,
            password_length=password_length,
            password_reset_required=password_reset_required,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamUserLoginProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="encryptedPassword")
    def encrypted_password(self) -> str:
        return jsii.get(self, "encryptedPassword")

    @builtins.property
    @jsii.member(jsii_name="keyFingerprint")
    def key_fingerprint(self) -> str:
        return jsii.get(self, "keyFingerprint")

    @builtins.property
    @jsii.member(jsii_name="pgpKey")
    def pgp_key(self) -> str:
        return jsii.get(self, "pgpKey")

    @pgp_key.setter
    def pgp_key(self, value: str) -> None:
        jsii.set(self, "pgpKey", value)

    @builtins.property
    @jsii.member(jsii_name="user")
    def user(self) -> str:
        return jsii.get(self, "user")

    @user.setter
    def user(self, value: str) -> None:
        jsii.set(self, "user", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="passwordLength")
    def password_length(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "passwordLength")

    @password_length.setter
    def password_length(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "passwordLength", value)

    @builtins.property
    @jsii.member(jsii_name="passwordResetRequired")
    def password_reset_required(self) -> typing.Optional[bool]:
        return jsii.get(self, "passwordResetRequired")

    @password_reset_required.setter
    def password_reset_required(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "passwordResetRequired", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserLoginProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "pgp_key": "pgpKey",
        "user": "user",
        "password_length": "passwordLength",
        "password_reset_required": "passwordResetRequired",
    },
)
class IamUserLoginProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        pgp_key: str,
        user: str,
        password_length: typing.Optional[jsii.Number] = None,
        password_reset_required: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param pgp_key: 
        :param user: 
        :param password_length: 
        :param password_reset_required: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "pgp_key": pgp_key,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if password_length is not None:
            self._values["password_length"] = password_length
        if password_reset_required is not None:
            self._values["password_reset_required"] = password_reset_required

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def pgp_key(self) -> str:
        return self._values.get("pgp_key")

    @builtins.property
    def user(self) -> str:
        return self._values.get("user")

    @builtins.property
    def password_length(self) -> typing.Optional[jsii.Number]:
        return self._values.get("password_length")

    @builtins.property
    def password_reset_required(self) -> typing.Optional[bool]:
        return self._values.get("password_reset_required")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamUserLoginProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamUserPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy: str,
        user: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy: 
        :param user: 
        :param name: 
        :param name_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamUserPolicyConfig(
            policy=policy,
            user=user,
            name=name,
            name_prefix=name_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamUserPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="user")
    def user(self) -> str:
        return jsii.get(self, "user")

    @user.setter
    def user(self, value: str) -> None:
        jsii.set(self, "user", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)


class IamUserPolicyAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserPolicyAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy_arn: str,
        user: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy_arn: 
        :param user: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamUserPolicyAttachmentConfig(
            policy_arn=policy_arn,
            user=user,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamUserPolicyAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policyArn")
    def policy_arn(self) -> str:
        return jsii.get(self, "policyArn")

    @policy_arn.setter
    def policy_arn(self, value: str) -> None:
        jsii.set(self, "policyArn", value)

    @builtins.property
    @jsii.member(jsii_name="user")
    def user(self) -> str:
        return jsii.get(self, "user")

    @user.setter
    def user(self, value: str) -> None:
        jsii.set(self, "user", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserPolicyAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy_arn": "policyArn",
        "user": "user",
    },
)
class IamUserPolicyAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy_arn: str,
        user: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy_arn: 
        :param user: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy_arn": policy_arn,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy_arn(self) -> str:
        return self._values.get("policy_arn")

    @builtins.property
    def user(self) -> str:
        return self._values.get("user")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamUserPolicyAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy": "policy",
        "user": "user",
        "name": "name",
        "name_prefix": "namePrefix",
    },
)
class IamUserPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy: str,
        user: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy: 
        :param user: 
        :param name: 
        :param name_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy": policy,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def user(self) -> str:
        return self._values.get("user")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamUserPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IamUserSshKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserSshKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        encoding: str,
        public_key: str,
        username: str,
        status: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param encoding: 
        :param public_key: 
        :param username: 
        :param status: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IamUserSshKeyConfig(
            encoding=encoding,
            public_key=public_key,
            username=username,
            status=status,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IamUserSshKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="fingerprint")
    def fingerprint(self) -> str:
        return jsii.get(self, "fingerprint")

    @builtins.property
    @jsii.member(jsii_name="sshPublicKeyId")
    def ssh_public_key_id(self) -> str:
        return jsii.get(self, "sshPublicKeyId")

    @builtins.property
    @jsii.member(jsii_name="encoding")
    def encoding(self) -> str:
        return jsii.get(self, "encoding")

    @encoding.setter
    def encoding(self, value: str) -> None:
        jsii.set(self, "encoding", value)

    @builtins.property
    @jsii.member(jsii_name="publicKey")
    def public_key(self) -> str:
        return jsii.get(self, "publicKey")

    @public_key.setter
    def public_key(self, value: str) -> None:
        jsii.set(self, "publicKey", value)

    @builtins.property
    @jsii.member(jsii_name="username")
    def username(self) -> str:
        return jsii.get(self, "username")

    @username.setter
    def username(self, value: str) -> None:
        jsii.set(self, "username", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[str]:
        return jsii.get(self, "status")

    @status.setter
    def status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "status", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IamUserSshKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "encoding": "encoding",
        "public_key": "publicKey",
        "username": "username",
        "status": "status",
    },
)
class IamUserSshKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        encoding: str,
        public_key: str,
        username: str,
        status: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param encoding: 
        :param public_key: 
        :param username: 
        :param status: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "encoding": encoding,
            "public_key": public_key,
            "username": username,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if status is not None:
            self._values["status"] = status

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def encoding(self) -> str:
        return self._values.get("encoding")

    @builtins.property
    def public_key(self) -> str:
        return self._values.get("public_key")

    @builtins.property
    def username(self) -> str:
        return self._values.get("username")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IamUserSshKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class InspectorAssessmentTarget(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.InspectorAssessmentTarget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        resource_group_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_group_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = InspectorAssessmentTargetConfig(
            name=name,
            resource_group_arn=resource_group_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(InspectorAssessmentTarget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="resourceGroupArn")
    def resource_group_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "resourceGroupArn")

    @resource_group_arn.setter
    def resource_group_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resourceGroupArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InspectorAssessmentTargetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_group_arn": "resourceGroupArn",
    },
)
class InspectorAssessmentTargetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        resource_group_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_group_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if resource_group_arn is not None:
            self._values["resource_group_arn"] = resource_group_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def resource_group_arn(self) -> typing.Optional[str]:
        return self._values.get("resource_group_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InspectorAssessmentTargetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class InspectorAssessmentTemplate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.InspectorAssessmentTemplate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        duration: jsii.Number,
        name: str,
        rules_package_arns: typing.List[str],
        target_arn: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param duration: 
        :param name: 
        :param rules_package_arns: 
        :param target_arn: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = InspectorAssessmentTemplateConfig(
            duration=duration,
            name=name,
            rules_package_arns=rules_package_arns,
            target_arn=target_arn,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(InspectorAssessmentTemplate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="duration")
    def duration(self) -> jsii.Number:
        return jsii.get(self, "duration")

    @duration.setter
    def duration(self, value: jsii.Number) -> None:
        jsii.set(self, "duration", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="rulesPackageArns")
    def rules_package_arns(self) -> typing.List[str]:
        return jsii.get(self, "rulesPackageArns")

    @rules_package_arns.setter
    def rules_package_arns(self, value: typing.List[str]) -> None:
        jsii.set(self, "rulesPackageArns", value)

    @builtins.property
    @jsii.member(jsii_name="targetArn")
    def target_arn(self) -> str:
        return jsii.get(self, "targetArn")

    @target_arn.setter
    def target_arn(self, value: str) -> None:
        jsii.set(self, "targetArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InspectorAssessmentTemplateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "duration": "duration",
        "name": "name",
        "rules_package_arns": "rulesPackageArns",
        "target_arn": "targetArn",
        "tags": "tags",
    },
)
class InspectorAssessmentTemplateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        duration: jsii.Number,
        name: str,
        rules_package_arns: typing.List[str],
        target_arn: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param duration: 
        :param name: 
        :param rules_package_arns: 
        :param target_arn: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "duration": duration,
            "name": name,
            "rules_package_arns": rules_package_arns,
            "target_arn": target_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def duration(self) -> jsii.Number:
        return self._values.get("duration")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rules_package_arns(self) -> typing.List[str]:
        return self._values.get("rules_package_arns")

    @builtins.property
    def target_arn(self) -> str:
        return self._values.get("target_arn")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InspectorAssessmentTemplateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class InspectorResourceGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.InspectorResourceGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        tags: typing.Mapping[str, str],
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = InspectorResourceGroupConfig(
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(InspectorResourceGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Mapping[str, str]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Mapping[str, str]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InspectorResourceGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "tags": "tags",
    },
)
class InspectorResourceGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        tags: typing.Mapping[str, str],
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "tags": tags,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def tags(self) -> typing.Mapping[str, str]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InspectorResourceGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Instance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Instance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        ami: str,
        instance_type: str,
        associate_public_ip_address: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        cpu_core_count: typing.Optional[jsii.Number] = None,
        cpu_threads_per_core: typing.Optional[jsii.Number] = None,
        credit_specification: typing.Optional[
            typing.List["InstanceCreditSpecification"]
        ] = None,
        disable_api_termination: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[typing.List["InstanceEbsBlockDevice"]] = None,
        ebs_optimized: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["InstanceEphemeralBlockDevice"]
        ] = None,
        fetch_password_data: typing.Optional[bool] = None,
        hibernation: typing.Optional[bool] = None,
        host_id: typing.Optional[str] = None,
        iam_instance_profile: typing.Optional[str] = None,
        instance_initiated_shutdown_behavior: typing.Optional[str] = None,
        ipv6_address_count: typing.Optional[jsii.Number] = None,
        ipv6_addresses: typing.Optional[typing.List[str]] = None,
        key_name: typing.Optional[str] = None,
        metadata_options: typing.Optional[
            typing.List["InstanceMetadataOptions"]
        ] = None,
        monitoring: typing.Optional[bool] = None,
        network_interface: typing.Optional[
            typing.List["InstanceNetworkInterface"]
        ] = None,
        placement_group: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["InstanceRootBlockDevice"]
        ] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_dest_check: typing.Optional[bool] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tenancy: typing.Optional[str] = None,
        timeouts: typing.Optional["InstanceTimeouts"] = None,
        user_data: typing.Optional[str] = None,
        user_data_base64: typing.Optional[str] = None,
        volume_tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ami: 
        :param instance_type: 
        :param associate_public_ip_address: 
        :param availability_zone: 
        :param cpu_core_count: 
        :param cpu_threads_per_core: 
        :param credit_specification: credit_specification block.
        :param disable_api_termination: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param fetch_password_data: 
        :param hibernation: 
        :param host_id: 
        :param iam_instance_profile: 
        :param instance_initiated_shutdown_behavior: 
        :param ipv6_address_count: 
        :param ipv6_addresses: 
        :param key_name: 
        :param metadata_options: metadata_options block.
        :param monitoring: 
        :param network_interface: network_interface block.
        :param placement_group: 
        :param private_ip: 
        :param root_block_device: root_block_device block.
        :param security_groups: 
        :param source_dest_check: 
        :param subnet_id: 
        :param tags: 
        :param tenancy: 
        :param timeouts: timeouts block.
        :param user_data: 
        :param user_data_base64: 
        :param volume_tags: 
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = InstanceConfig(
            ami=ami,
            instance_type=instance_type,
            associate_public_ip_address=associate_public_ip_address,
            availability_zone=availability_zone,
            cpu_core_count=cpu_core_count,
            cpu_threads_per_core=cpu_threads_per_core,
            credit_specification=credit_specification,
            disable_api_termination=disable_api_termination,
            ebs_block_device=ebs_block_device,
            ebs_optimized=ebs_optimized,
            ephemeral_block_device=ephemeral_block_device,
            fetch_password_data=fetch_password_data,
            hibernation=hibernation,
            host_id=host_id,
            iam_instance_profile=iam_instance_profile,
            instance_initiated_shutdown_behavior=instance_initiated_shutdown_behavior,
            ipv6_address_count=ipv6_address_count,
            ipv6_addresses=ipv6_addresses,
            key_name=key_name,
            metadata_options=metadata_options,
            monitoring=monitoring,
            network_interface=network_interface,
            placement_group=placement_group,
            private_ip=private_ip,
            root_block_device=root_block_device,
            security_groups=security_groups,
            source_dest_check=source_dest_check,
            subnet_id=subnet_id,
            tags=tags,
            tenancy=tenancy,
            timeouts=timeouts,
            user_data=user_data,
            user_data_base64=user_data_base64,
            volume_tags=volume_tags,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Instance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="instanceState")
    def instance_state(self) -> str:
        return jsii.get(self, "instanceState")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="passwordData")
    def password_data(self) -> str:
        return jsii.get(self, "passwordData")

    @builtins.property
    @jsii.member(jsii_name="primaryNetworkInterfaceId")
    def primary_network_interface_id(self) -> str:
        return jsii.get(self, "primaryNetworkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="privateDns")
    def private_dns(self) -> str:
        return jsii.get(self, "privateDns")

    @builtins.property
    @jsii.member(jsii_name="publicDns")
    def public_dns(self) -> str:
        return jsii.get(self, "publicDns")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")

    @builtins.property
    @jsii.member(jsii_name="ami")
    def ami(self) -> str:
        return jsii.get(self, "ami")

    @ami.setter
    def ami(self, value: str) -> None:
        jsii.set(self, "ami", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: str) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> typing.Optional[bool]:
        return jsii.get(self, "associatePublicIpAddress")

    @associate_public_ip_address.setter
    def associate_public_ip_address(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "associatePublicIpAddress", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="cpuCoreCount")
    def cpu_core_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cpuCoreCount")

    @cpu_core_count.setter
    def cpu_core_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cpuCoreCount", value)

    @builtins.property
    @jsii.member(jsii_name="cpuThreadsPerCore")
    def cpu_threads_per_core(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cpuThreadsPerCore")

    @cpu_threads_per_core.setter
    def cpu_threads_per_core(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cpuThreadsPerCore", value)

    @builtins.property
    @jsii.member(jsii_name="creditSpecification")
    def credit_specification(
        self,
    ) -> typing.Optional[typing.List["InstanceCreditSpecification"]]:
        return jsii.get(self, "creditSpecification")

    @credit_specification.setter
    def credit_specification(
        self, value: typing.Optional[typing.List["InstanceCreditSpecification"]]
    ) -> None:
        jsii.set(self, "creditSpecification", value)

    @builtins.property
    @jsii.member(jsii_name="disableApiTermination")
    def disable_api_termination(self) -> typing.Optional[bool]:
        return jsii.get(self, "disableApiTermination")

    @disable_api_termination.setter
    def disable_api_termination(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "disableApiTermination", value)

    @builtins.property
    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["InstanceEbsBlockDevice"]]:
        return jsii.get(self, "ebsBlockDevice")

    @ebs_block_device.setter
    def ebs_block_device(
        self, value: typing.Optional[typing.List["InstanceEbsBlockDevice"]]
    ) -> None:
        jsii.set(self, "ebsBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> typing.Optional[bool]:
        return jsii.get(self, "ebsOptimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ebsOptimized", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["InstanceEphemeralBlockDevice"]]:
        return jsii.get(self, "ephemeralBlockDevice")

    @ephemeral_block_device.setter
    def ephemeral_block_device(
        self, value: typing.Optional[typing.List["InstanceEphemeralBlockDevice"]]
    ) -> None:
        jsii.set(self, "ephemeralBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="fetchPasswordData")
    def fetch_password_data(self) -> typing.Optional[bool]:
        return jsii.get(self, "fetchPasswordData")

    @fetch_password_data.setter
    def fetch_password_data(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "fetchPasswordData", value)

    @builtins.property
    @jsii.member(jsii_name="hibernation")
    def hibernation(self) -> typing.Optional[bool]:
        return jsii.get(self, "hibernation")

    @hibernation.setter
    def hibernation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "hibernation", value)

    @builtins.property
    @jsii.member(jsii_name="hostId")
    def host_id(self) -> typing.Optional[str]:
        return jsii.get(self, "hostId")

    @host_id.setter
    def host_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "hostId", value)

    @builtins.property
    @jsii.member(jsii_name="iamInstanceProfile")
    def iam_instance_profile(self) -> typing.Optional[str]:
        return jsii.get(self, "iamInstanceProfile")

    @iam_instance_profile.setter
    def iam_instance_profile(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamInstanceProfile", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceInitiatedShutdownBehavior")
    def instance_initiated_shutdown_behavior(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceInitiatedShutdownBehavior")

    @instance_initiated_shutdown_behavior.setter
    def instance_initiated_shutdown_behavior(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceInitiatedShutdownBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6AddressCount")
    def ipv6_address_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "ipv6AddressCount")

    @ipv6_address_count.setter
    def ipv6_address_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "ipv6AddressCount", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6Addresses")
    def ipv6_addresses(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "ipv6Addresses")

    @ipv6_addresses.setter
    def ipv6_addresses(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "ipv6Addresses", value)

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> typing.Optional[str]:
        return jsii.get(self, "keyName")

    @key_name.setter
    def key_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyName", value)

    @builtins.property
    @jsii.member(jsii_name="metadataOptions")
    def metadata_options(
        self,
    ) -> typing.Optional[typing.List["InstanceMetadataOptions"]]:
        return jsii.get(self, "metadataOptions")

    @metadata_options.setter
    def metadata_options(
        self, value: typing.Optional[typing.List["InstanceMetadataOptions"]]
    ) -> None:
        jsii.set(self, "metadataOptions", value)

    @builtins.property
    @jsii.member(jsii_name="monitoring")
    def monitoring(self) -> typing.Optional[bool]:
        return jsii.get(self, "monitoring")

    @monitoring.setter
    def monitoring(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "monitoring", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> typing.Optional[typing.List["InstanceNetworkInterface"]]:
        return jsii.get(self, "networkInterface")

    @network_interface.setter
    def network_interface(
        self, value: typing.Optional[typing.List["InstanceNetworkInterface"]]
    ) -> None:
        jsii.set(self, "networkInterface", value)

    @builtins.property
    @jsii.member(jsii_name="placementGroup")
    def placement_group(self) -> typing.Optional[str]:
        return jsii.get(self, "placementGroup")

    @placement_group.setter
    def placement_group(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "placementGroup", value)

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "privateIp")

    @private_ip.setter
    def private_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateIp", value)

    @builtins.property
    @jsii.member(jsii_name="rootBlockDevice")
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["InstanceRootBlockDevice"]]:
        return jsii.get(self, "rootBlockDevice")

    @root_block_device.setter
    def root_block_device(
        self, value: typing.Optional[typing.List["InstanceRootBlockDevice"]]
    ) -> None:
        jsii.set(self, "rootBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="sourceDestCheck")
    def source_dest_check(self) -> typing.Optional[bool]:
        return jsii.get(self, "sourceDestCheck")

    @source_dest_check.setter
    def source_dest_check(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "sourceDestCheck", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="tenancy")
    def tenancy(self) -> typing.Optional[str]:
        return jsii.get(self, "tenancy")

    @tenancy.setter
    def tenancy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tenancy", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["InstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["InstanceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> typing.Optional[str]:
        return jsii.get(self, "userData")

    @user_data.setter
    def user_data(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userData", value)

    @builtins.property
    @jsii.member(jsii_name="userDataBase64")
    def user_data_base64(self) -> typing.Optional[str]:
        return jsii.get(self, "userDataBase64")

    @user_data_base64.setter
    def user_data_base64(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userDataBase64", value)

    @builtins.property
    @jsii.member(jsii_name="volumeTags")
    def volume_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "volumeTags")

    @volume_tags.setter
    def volume_tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "volumeTags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ami": "ami",
        "instance_type": "instanceType",
        "associate_public_ip_address": "associatePublicIpAddress",
        "availability_zone": "availabilityZone",
        "cpu_core_count": "cpuCoreCount",
        "cpu_threads_per_core": "cpuThreadsPerCore",
        "credit_specification": "creditSpecification",
        "disable_api_termination": "disableApiTermination",
        "ebs_block_device": "ebsBlockDevice",
        "ebs_optimized": "ebsOptimized",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "fetch_password_data": "fetchPasswordData",
        "hibernation": "hibernation",
        "host_id": "hostId",
        "iam_instance_profile": "iamInstanceProfile",
        "instance_initiated_shutdown_behavior": "instanceInitiatedShutdownBehavior",
        "ipv6_address_count": "ipv6AddressCount",
        "ipv6_addresses": "ipv6Addresses",
        "key_name": "keyName",
        "metadata_options": "metadataOptions",
        "monitoring": "monitoring",
        "network_interface": "networkInterface",
        "placement_group": "placementGroup",
        "private_ip": "privateIp",
        "root_block_device": "rootBlockDevice",
        "security_groups": "securityGroups",
        "source_dest_check": "sourceDestCheck",
        "subnet_id": "subnetId",
        "tags": "tags",
        "tenancy": "tenancy",
        "timeouts": "timeouts",
        "user_data": "userData",
        "user_data_base64": "userDataBase64",
        "volume_tags": "volumeTags",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class InstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ami: str,
        instance_type: str,
        associate_public_ip_address: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        cpu_core_count: typing.Optional[jsii.Number] = None,
        cpu_threads_per_core: typing.Optional[jsii.Number] = None,
        credit_specification: typing.Optional[
            typing.List["InstanceCreditSpecification"]
        ] = None,
        disable_api_termination: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[typing.List["InstanceEbsBlockDevice"]] = None,
        ebs_optimized: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["InstanceEphemeralBlockDevice"]
        ] = None,
        fetch_password_data: typing.Optional[bool] = None,
        hibernation: typing.Optional[bool] = None,
        host_id: typing.Optional[str] = None,
        iam_instance_profile: typing.Optional[str] = None,
        instance_initiated_shutdown_behavior: typing.Optional[str] = None,
        ipv6_address_count: typing.Optional[jsii.Number] = None,
        ipv6_addresses: typing.Optional[typing.List[str]] = None,
        key_name: typing.Optional[str] = None,
        metadata_options: typing.Optional[
            typing.List["InstanceMetadataOptions"]
        ] = None,
        monitoring: typing.Optional[bool] = None,
        network_interface: typing.Optional[
            typing.List["InstanceNetworkInterface"]
        ] = None,
        placement_group: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["InstanceRootBlockDevice"]
        ] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_dest_check: typing.Optional[bool] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tenancy: typing.Optional[str] = None,
        timeouts: typing.Optional["InstanceTimeouts"] = None,
        user_data: typing.Optional[str] = None,
        user_data_base64: typing.Optional[str] = None,
        volume_tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ami: 
        :param instance_type: 
        :param associate_public_ip_address: 
        :param availability_zone: 
        :param cpu_core_count: 
        :param cpu_threads_per_core: 
        :param credit_specification: credit_specification block.
        :param disable_api_termination: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param fetch_password_data: 
        :param hibernation: 
        :param host_id: 
        :param iam_instance_profile: 
        :param instance_initiated_shutdown_behavior: 
        :param ipv6_address_count: 
        :param ipv6_addresses: 
        :param key_name: 
        :param metadata_options: metadata_options block.
        :param monitoring: 
        :param network_interface: network_interface block.
        :param placement_group: 
        :param private_ip: 
        :param root_block_device: root_block_device block.
        :param security_groups: 
        :param source_dest_check: 
        :param subnet_id: 
        :param tags: 
        :param tenancy: 
        :param timeouts: timeouts block.
        :param user_data: 
        :param user_data_base64: 
        :param volume_tags: 
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = InstanceTimeouts(**timeouts)
        self._values = {
            "ami": ami,
            "instance_type": instance_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if associate_public_ip_address is not None:
            self._values["associate_public_ip_address"] = associate_public_ip_address
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if cpu_core_count is not None:
            self._values["cpu_core_count"] = cpu_core_count
        if cpu_threads_per_core is not None:
            self._values["cpu_threads_per_core"] = cpu_threads_per_core
        if credit_specification is not None:
            self._values["credit_specification"] = credit_specification
        if disable_api_termination is not None:
            self._values["disable_api_termination"] = disable_api_termination
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if fetch_password_data is not None:
            self._values["fetch_password_data"] = fetch_password_data
        if hibernation is not None:
            self._values["hibernation"] = hibernation
        if host_id is not None:
            self._values["host_id"] = host_id
        if iam_instance_profile is not None:
            self._values["iam_instance_profile"] = iam_instance_profile
        if instance_initiated_shutdown_behavior is not None:
            self._values[
                "instance_initiated_shutdown_behavior"
            ] = instance_initiated_shutdown_behavior
        if ipv6_address_count is not None:
            self._values["ipv6_address_count"] = ipv6_address_count
        if ipv6_addresses is not None:
            self._values["ipv6_addresses"] = ipv6_addresses
        if key_name is not None:
            self._values["key_name"] = key_name
        if metadata_options is not None:
            self._values["metadata_options"] = metadata_options
        if monitoring is not None:
            self._values["monitoring"] = monitoring
        if network_interface is not None:
            self._values["network_interface"] = network_interface
        if placement_group is not None:
            self._values["placement_group"] = placement_group
        if private_ip is not None:
            self._values["private_ip"] = private_ip
        if root_block_device is not None:
            self._values["root_block_device"] = root_block_device
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if source_dest_check is not None:
            self._values["source_dest_check"] = source_dest_check
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags
        if tenancy is not None:
            self._values["tenancy"] = tenancy
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if user_data is not None:
            self._values["user_data"] = user_data
        if user_data_base64 is not None:
            self._values["user_data_base64"] = user_data_base64
        if volume_tags is not None:
            self._values["volume_tags"] = volume_tags
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def ami(self) -> str:
        return self._values.get("ami")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def associate_public_ip_address(self) -> typing.Optional[bool]:
        return self._values.get("associate_public_ip_address")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def cpu_core_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cpu_core_count")

    @builtins.property
    def cpu_threads_per_core(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cpu_threads_per_core")

    @builtins.property
    def credit_specification(
        self,
    ) -> typing.Optional[typing.List["InstanceCreditSpecification"]]:
        """credit_specification block."""
        return self._values.get("credit_specification")

    @builtins.property
    def disable_api_termination(self) -> typing.Optional[bool]:
        return self._values.get("disable_api_termination")

    @builtins.property
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["InstanceEbsBlockDevice"]]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[bool]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["InstanceEphemeralBlockDevice"]]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def fetch_password_data(self) -> typing.Optional[bool]:
        return self._values.get("fetch_password_data")

    @builtins.property
    def hibernation(self) -> typing.Optional[bool]:
        return self._values.get("hibernation")

    @builtins.property
    def host_id(self) -> typing.Optional[str]:
        return self._values.get("host_id")

    @builtins.property
    def iam_instance_profile(self) -> typing.Optional[str]:
        return self._values.get("iam_instance_profile")

    @builtins.property
    def instance_initiated_shutdown_behavior(self) -> typing.Optional[str]:
        return self._values.get("instance_initiated_shutdown_behavior")

    @builtins.property
    def ipv6_address_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("ipv6_address_count")

    @builtins.property
    def ipv6_addresses(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_addresses")

    @builtins.property
    def key_name(self) -> typing.Optional[str]:
        return self._values.get("key_name")

    @builtins.property
    def metadata_options(
        self,
    ) -> typing.Optional[typing.List["InstanceMetadataOptions"]]:
        """metadata_options block."""
        return self._values.get("metadata_options")

    @builtins.property
    def monitoring(self) -> typing.Optional[bool]:
        return self._values.get("monitoring")

    @builtins.property
    def network_interface(
        self,
    ) -> typing.Optional[typing.List["InstanceNetworkInterface"]]:
        """network_interface block."""
        return self._values.get("network_interface")

    @builtins.property
    def placement_group(self) -> typing.Optional[str]:
        return self._values.get("placement_group")

    @builtins.property
    def private_ip(self) -> typing.Optional[str]:
        return self._values.get("private_ip")

    @builtins.property
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["InstanceRootBlockDevice"]]:
        """root_block_device block."""
        return self._values.get("root_block_device")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def source_dest_check(self) -> typing.Optional[bool]:
        return self._values.get("source_dest_check")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def tenancy(self) -> typing.Optional[str]:
        return self._values.get("tenancy")

    @builtins.property
    def timeouts(self) -> typing.Optional["InstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def user_data(self) -> typing.Optional[str]:
        return self._values.get("user_data")

    @builtins.property
    def user_data_base64(self) -> typing.Optional[str]:
        return self._values.get("user_data_base64")

    @builtins.property
    def volume_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("volume_tags")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceCreditSpecification",
    jsii_struct_bases=[],
    name_mapping={"cpu_credits": "cpuCredits"},
)
class InstanceCreditSpecification:
    def __init__(self, *, cpu_credits: typing.Optional[str] = None) -> None:
        """
        :param cpu_credits: 
        """
        self._values = {}
        if cpu_credits is not None:
            self._values["cpu_credits"] = cpu_credits

    @builtins.property
    def cpu_credits(self) -> typing.Optional[str]:
        return self._values.get("cpu_credits")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceCreditSpecification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "snapshot_id": "snapshotId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class InstanceEbsBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        snapshot_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param snapshot_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {
            "device_name": device_name,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "no_device": "noDevice",
        "virtual_name": "virtualName",
    },
)
class InstanceEphemeralBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        no_device: typing.Optional[bool] = None,
        virtual_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param no_device: 
        :param virtual_name: 
        """
        self._values = {
            "device_name": device_name,
        }
        if no_device is not None:
            self._values["no_device"] = no_device
        if virtual_name is not None:
            self._values["virtual_name"] = virtual_name

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def no_device(self) -> typing.Optional[bool]:
        return self._values.get("no_device")

    @builtins.property
    def virtual_name(self) -> typing.Optional[str]:
        return self._values.get("virtual_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceEphemeralBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceMetadataOptions",
    jsii_struct_bases=[],
    name_mapping={
        "http_endpoint": "httpEndpoint",
        "http_put_response_hop_limit": "httpPutResponseHopLimit",
        "http_tokens": "httpTokens",
    },
)
class InstanceMetadataOptions:
    def __init__(
        self,
        *,
        http_endpoint: typing.Optional[str] = None,
        http_put_response_hop_limit: typing.Optional[jsii.Number] = None,
        http_tokens: typing.Optional[str] = None,
    ) -> None:
        """
        :param http_endpoint: 
        :param http_put_response_hop_limit: 
        :param http_tokens: 
        """
        self._values = {}
        if http_endpoint is not None:
            self._values["http_endpoint"] = http_endpoint
        if http_put_response_hop_limit is not None:
            self._values["http_put_response_hop_limit"] = http_put_response_hop_limit
        if http_tokens is not None:
            self._values["http_tokens"] = http_tokens

    @builtins.property
    def http_endpoint(self) -> typing.Optional[str]:
        return self._values.get("http_endpoint")

    @builtins.property
    def http_put_response_hop_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("http_put_response_hop_limit")

    @builtins.property
    def http_tokens(self) -> typing.Optional[str]:
        return self._values.get("http_tokens")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceMetadataOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={
        "device_index": "deviceIndex",
        "network_interface_id": "networkInterfaceId",
        "delete_on_termination": "deleteOnTermination",
    },
)
class InstanceNetworkInterface:
    def __init__(
        self,
        *,
        device_index: jsii.Number,
        network_interface_id: str,
        delete_on_termination: typing.Optional[bool] = None,
    ) -> None:
        """
        :param device_index: 
        :param network_interface_id: 
        :param delete_on_termination: 
        """
        self._values = {
            "device_index": device_index,
            "network_interface_id": network_interface_id,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination

    @builtins.property
    def device_index(self) -> jsii.Number:
        return self._values.get("device_index")

    @builtins.property
    def network_interface_id(self) -> str:
        return self._values.get("network_interface_id")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceRootBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class InstanceRootBlockDevice:
    def __init__(
        self,
        *,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {}
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceRootBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class InstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class InternetGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.InternetGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = InternetGatewayConfig(
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(InternetGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.InternetGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class InternetGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "InternetGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        active: bool,
        csr: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param active: 
        :param csr: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotCertificateConfig(
            active=active,
            csr=csr,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="certificatePem")
    def certificate_pem(self) -> str:
        return jsii.get(self, "certificatePem")

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> str:
        return jsii.get(self, "privateKey")

    @builtins.property
    @jsii.member(jsii_name="publicKey")
    def public_key(self) -> str:
        return jsii.get(self, "publicKey")

    @builtins.property
    @jsii.member(jsii_name="active")
    def active(self) -> bool:
        return jsii.get(self, "active")

    @active.setter
    def active(self, value: bool) -> None:
        jsii.set(self, "active", value)

    @builtins.property
    @jsii.member(jsii_name="csr")
    def csr(self) -> typing.Optional[str]:
        return jsii.get(self, "csr")

    @csr.setter
    def csr(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "csr", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "active": "active",
        "csr": "csr",
    },
)
class IotCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        active: bool,
        csr: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param active: 
        :param csr: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "active": active,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if csr is not None:
            self._values["csr"] = csr

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def active(self) -> bool:
        return self._values.get("active")

    @builtins.property
    def csr(self) -> typing.Optional[str]:
        return self._values.get("csr")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        policy: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param policy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotPolicyConfig(
            name=name,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultVersionId")
    def default_version_id(self) -> str:
        return jsii.get(self, "defaultVersionId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class IotPolicyAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotPolicyAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy: str,
        target: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy: 
        :param target: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotPolicyAttachmentConfig(
            policy=policy,
            target=target,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotPolicyAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="target")
    def target(self) -> str:
        return jsii.get(self, "target")

    @target.setter
    def target(self, value: str) -> None:
        jsii.set(self, "target", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotPolicyAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy": "policy",
        "target": "target",
    },
)
class IotPolicyAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy: str,
        target: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy: 
        :param target: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy": policy,
            "target": target,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def target(self) -> str:
        return self._values.get("target")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotPolicyAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "policy": "policy",
    },
)
class IotPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        policy: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param policy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotRoleAlias(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotRoleAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        alias: str,
        role_arn: str,
        credential_duration: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param alias: 
        :param role_arn: 
        :param credential_duration: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotRoleAliasConfig(
            alias=alias,
            role_arn=role_arn,
            credential_duration=credential_duration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotRoleAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> str:
        return jsii.get(self, "alias")

    @alias.setter
    def alias(self, value: str) -> None:
        jsii.set(self, "alias", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="credentialDuration")
    def credential_duration(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "credentialDuration")

    @credential_duration.setter
    def credential_duration(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "credentialDuration", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotRoleAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "alias": "alias",
        "role_arn": "roleArn",
        "credential_duration": "credentialDuration",
    },
)
class IotRoleAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        alias: str,
        role_arn: str,
        credential_duration: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param alias: 
        :param role_arn: 
        :param credential_duration: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "alias": alias,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if credential_duration is not None:
            self._values["credential_duration"] = credential_duration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def alias(self) -> str:
        return self._values.get("alias")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def credential_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("credential_duration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotRoleAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotThing(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotThing",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        attributes: typing.Optional[typing.Mapping[str, str]] = None,
        thing_type_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param attributes: 
        :param thing_type_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotThingConfig(
            name=name,
            attributes=attributes,
            thing_type_name=thing_type_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotThing, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultClientId")
    def default_client_id(self) -> str:
        return jsii.get(self, "defaultClientId")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> jsii.Number:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="attributes")
    def attributes(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "attributes")

    @attributes.setter
    def attributes(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "attributes", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="thingTypeName")
    def thing_type_name(self) -> typing.Optional[str]:
        return jsii.get(self, "thingTypeName")

    @thing_type_name.setter
    def thing_type_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "thingTypeName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotThingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "attributes": "attributes",
        "thing_type_name": "thingTypeName",
    },
)
class IotThingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        attributes: typing.Optional[typing.Mapping[str, str]] = None,
        thing_type_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param attributes: 
        :param thing_type_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attributes is not None:
            self._values["attributes"] = attributes
        if thing_type_name is not None:
            self._values["thing_type_name"] = thing_type_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def attributes(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("attributes")

    @builtins.property
    def thing_type_name(self) -> typing.Optional[str]:
        return self._values.get("thing_type_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotThingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotThingPrincipalAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotThingPrincipalAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        principal: str,
        thing: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param principal: 
        :param thing: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotThingPrincipalAttachmentConfig(
            principal=principal,
            thing=thing,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotThingPrincipalAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="principal")
    def principal(self) -> str:
        return jsii.get(self, "principal")

    @principal.setter
    def principal(self, value: str) -> None:
        jsii.set(self, "principal", value)

    @builtins.property
    @jsii.member(jsii_name="thing")
    def thing(self) -> str:
        return jsii.get(self, "thing")

    @thing.setter
    def thing(self, value: str) -> None:
        jsii.set(self, "thing", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotThingPrincipalAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "principal": "principal",
        "thing": "thing",
    },
)
class IotThingPrincipalAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        principal: str,
        thing: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param principal: 
        :param thing: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "principal": principal,
            "thing": thing,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def principal(self) -> str:
        return self._values.get("principal")

    @builtins.property
    def thing(self) -> str:
        return self._values.get("thing")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotThingPrincipalAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotThingType(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotThingType",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        deprecated: typing.Optional[bool] = None,
        properties: typing.Optional[typing.List["IotThingTypeProperties"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param deprecated: 
        :param properties: properties block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotThingTypeConfig(
            name=name,
            deprecated=deprecated,
            properties=properties,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotThingType, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="deprecated")
    def deprecated(self) -> typing.Optional[bool]:
        return jsii.get(self, "deprecated")

    @deprecated.setter
    def deprecated(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deprecated", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="properties")
    def properties(self) -> typing.Optional[typing.List["IotThingTypeProperties"]]:
        return jsii.get(self, "properties")

    @properties.setter
    def properties(
        self, value: typing.Optional[typing.List["IotThingTypeProperties"]]
    ) -> None:
        jsii.set(self, "properties", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotThingTypeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "deprecated": "deprecated",
        "properties": "properties",
    },
)
class IotThingTypeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        deprecated: typing.Optional[bool] = None,
        properties: typing.Optional[typing.List["IotThingTypeProperties"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param deprecated: 
        :param properties: properties block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deprecated is not None:
            self._values["deprecated"] = deprecated
        if properties is not None:
            self._values["properties"] = properties

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def deprecated(self) -> typing.Optional[bool]:
        return self._values.get("deprecated")

    @builtins.property
    def properties(self) -> typing.Optional[typing.List["IotThingTypeProperties"]]:
        """properties block."""
        return self._values.get("properties")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotThingTypeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotThingTypeProperties",
    jsii_struct_bases=[],
    name_mapping={
        "description": "description",
        "searchable_attributes": "searchableAttributes",
    },
)
class IotThingTypeProperties:
    def __init__(
        self,
        *,
        description: typing.Optional[str] = None,
        searchable_attributes: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param description: 
        :param searchable_attributes: 
        """
        self._values = {}
        if description is not None:
            self._values["description"] = description
        if searchable_attributes is not None:
            self._values["searchable_attributes"] = searchable_attributes

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def searchable_attributes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("searchable_attributes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotThingTypeProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class IotTopicRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        enabled: bool,
        name: str,
        sql: str,
        sql_version: str,
        cloudwatch_alarm: typing.Optional[
            typing.List["IotTopicRuleCloudwatchAlarm"]
        ] = None,
        cloudwatch_metric: typing.Optional[
            typing.List["IotTopicRuleCloudwatchMetric"]
        ] = None,
        description: typing.Optional[str] = None,
        dynamodb: typing.Optional[typing.List["IotTopicRuleDynamodb"]] = None,
        dynamodbv2: typing.Optional[typing.List["IotTopicRuleDynamodbv2"]] = None,
        elasticsearch: typing.Optional[typing.List["IotTopicRuleElasticsearch"]] = None,
        error_action: typing.Optional[typing.List["IotTopicRuleErrorAction"]] = None,
        firehose: typing.Optional[typing.List["IotTopicRuleFirehose"]] = None,
        iot_analytics: typing.Optional[typing.List["IotTopicRuleIotAnalytics"]] = None,
        iot_events: typing.Optional[typing.List["IotTopicRuleIotEvents"]] = None,
        kinesis: typing.Optional[typing.List["IotTopicRuleKinesis"]] = None,
        lambda_: typing.Optional[typing.List["IotTopicRuleLambda"]] = None,
        republish: typing.Optional[typing.List["IotTopicRuleRepublish"]] = None,
        s3: typing.Optional[typing.List["IotTopicRuleS3"]] = None,
        sns: typing.Optional[typing.List["IotTopicRuleSns"]] = None,
        sqs: typing.Optional[typing.List["IotTopicRuleSqs"]] = None,
        step_functions: typing.Optional[
            typing.List["IotTopicRuleStepFunctions"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param enabled: 
        :param name: 
        :param sql: 
        :param sql_version: 
        :param cloudwatch_alarm: cloudwatch_alarm block.
        :param cloudwatch_metric: cloudwatch_metric block.
        :param description: 
        :param dynamodb: dynamodb block.
        :param dynamodbv2: dynamodbv2 block.
        :param elasticsearch: elasticsearch block.
        :param error_action: error_action block.
        :param firehose: firehose block.
        :param iot_analytics: iot_analytics block.
        :param iot_events: iot_events block.
        :param kinesis: kinesis block.
        :param lambda_: lambda block.
        :param republish: republish block.
        :param s3: s3 block.
        :param sns: sns block.
        :param sqs: sqs block.
        :param step_functions: step_functions block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = IotTopicRuleConfig(
            enabled=enabled,
            name=name,
            sql=sql,
            sql_version=sql_version,
            cloudwatch_alarm=cloudwatch_alarm,
            cloudwatch_metric=cloudwatch_metric,
            description=description,
            dynamodb=dynamodb,
            dynamodbv2=dynamodbv2,
            elasticsearch=elasticsearch,
            error_action=error_action,
            firehose=firehose,
            iot_analytics=iot_analytics,
            iot_events=iot_events,
            kinesis=kinesis,
            lambda_=lambda_,
            republish=republish,
            s3=s3,
            sns=sns,
            sqs=sqs,
            step_functions=step_functions,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(IotTopicRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> bool:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: bool) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="sql")
    def sql(self) -> str:
        return jsii.get(self, "sql")

    @sql.setter
    def sql(self, value: str) -> None:
        jsii.set(self, "sql", value)

    @builtins.property
    @jsii.member(jsii_name="sqlVersion")
    def sql_version(self) -> str:
        return jsii.get(self, "sqlVersion")

    @sql_version.setter
    def sql_version(self, value: str) -> None:
        jsii.set(self, "sqlVersion", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchAlarm")
    def cloudwatch_alarm(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleCloudwatchAlarm"]]:
        return jsii.get(self, "cloudwatchAlarm")

    @cloudwatch_alarm.setter
    def cloudwatch_alarm(
        self, value: typing.Optional[typing.List["IotTopicRuleCloudwatchAlarm"]]
    ) -> None:
        jsii.set(self, "cloudwatchAlarm", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchMetric")
    def cloudwatch_metric(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleCloudwatchMetric"]]:
        return jsii.get(self, "cloudwatchMetric")

    @cloudwatch_metric.setter
    def cloudwatch_metric(
        self, value: typing.Optional[typing.List["IotTopicRuleCloudwatchMetric"]]
    ) -> None:
        jsii.set(self, "cloudwatchMetric", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="dynamodb")
    def dynamodb(self) -> typing.Optional[typing.List["IotTopicRuleDynamodb"]]:
        return jsii.get(self, "dynamodb")

    @dynamodb.setter
    def dynamodb(
        self, value: typing.Optional[typing.List["IotTopicRuleDynamodb"]]
    ) -> None:
        jsii.set(self, "dynamodb", value)

    @builtins.property
    @jsii.member(jsii_name="dynamodbv2")
    def dynamodbv2(self) -> typing.Optional[typing.List["IotTopicRuleDynamodbv2"]]:
        return jsii.get(self, "dynamodbv2")

    @dynamodbv2.setter
    def dynamodbv2(
        self, value: typing.Optional[typing.List["IotTopicRuleDynamodbv2"]]
    ) -> None:
        jsii.set(self, "dynamodbv2", value)

    @builtins.property
    @jsii.member(jsii_name="elasticsearch")
    def elasticsearch(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleElasticsearch"]]:
        return jsii.get(self, "elasticsearch")

    @elasticsearch.setter
    def elasticsearch(
        self, value: typing.Optional[typing.List["IotTopicRuleElasticsearch"]]
    ) -> None:
        jsii.set(self, "elasticsearch", value)

    @builtins.property
    @jsii.member(jsii_name="errorAction")
    def error_action(self) -> typing.Optional[typing.List["IotTopicRuleErrorAction"]]:
        return jsii.get(self, "errorAction")

    @error_action.setter
    def error_action(
        self, value: typing.Optional[typing.List["IotTopicRuleErrorAction"]]
    ) -> None:
        jsii.set(self, "errorAction", value)

    @builtins.property
    @jsii.member(jsii_name="firehose")
    def firehose(self) -> typing.Optional[typing.List["IotTopicRuleFirehose"]]:
        return jsii.get(self, "firehose")

    @firehose.setter
    def firehose(
        self, value: typing.Optional[typing.List["IotTopicRuleFirehose"]]
    ) -> None:
        jsii.set(self, "firehose", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="iotAnalytics")
    def iot_analytics(self) -> typing.Optional[typing.List["IotTopicRuleIotAnalytics"]]:
        return jsii.get(self, "iotAnalytics")

    @iot_analytics.setter
    def iot_analytics(
        self, value: typing.Optional[typing.List["IotTopicRuleIotAnalytics"]]
    ) -> None:
        jsii.set(self, "iotAnalytics", value)

    @builtins.property
    @jsii.member(jsii_name="iotEvents")
    def iot_events(self) -> typing.Optional[typing.List["IotTopicRuleIotEvents"]]:
        return jsii.get(self, "iotEvents")

    @iot_events.setter
    def iot_events(
        self, value: typing.Optional[typing.List["IotTopicRuleIotEvents"]]
    ) -> None:
        jsii.set(self, "iotEvents", value)

    @builtins.property
    @jsii.member(jsii_name="kinesis")
    def kinesis(self) -> typing.Optional[typing.List["IotTopicRuleKinesis"]]:
        return jsii.get(self, "kinesis")

    @kinesis.setter
    def kinesis(
        self, value: typing.Optional[typing.List["IotTopicRuleKinesis"]]
    ) -> None:
        jsii.set(self, "kinesis", value)

    @builtins.property
    @jsii.member(jsii_name="lambda")
    def lambda_(self) -> typing.Optional[typing.List["IotTopicRuleLambda"]]:
        return jsii.get(self, "lambda")

    @lambda_.setter
    def lambda_(
        self, value: typing.Optional[typing.List["IotTopicRuleLambda"]]
    ) -> None:
        jsii.set(self, "lambda", value)

    @builtins.property
    @jsii.member(jsii_name="republish")
    def republish(self) -> typing.Optional[typing.List["IotTopicRuleRepublish"]]:
        return jsii.get(self, "republish")

    @republish.setter
    def republish(
        self, value: typing.Optional[typing.List["IotTopicRuleRepublish"]]
    ) -> None:
        jsii.set(self, "republish", value)

    @builtins.property
    @jsii.member(jsii_name="s3")
    def s3(self) -> typing.Optional[typing.List["IotTopicRuleS3"]]:
        return jsii.get(self, "s3")

    @s3.setter
    def s3(self, value: typing.Optional[typing.List["IotTopicRuleS3"]]) -> None:
        jsii.set(self, "s3", value)

    @builtins.property
    @jsii.member(jsii_name="sns")
    def sns(self) -> typing.Optional[typing.List["IotTopicRuleSns"]]:
        return jsii.get(self, "sns")

    @sns.setter
    def sns(self, value: typing.Optional[typing.List["IotTopicRuleSns"]]) -> None:
        jsii.set(self, "sns", value)

    @builtins.property
    @jsii.member(jsii_name="sqs")
    def sqs(self) -> typing.Optional[typing.List["IotTopicRuleSqs"]]:
        return jsii.get(self, "sqs")

    @sqs.setter
    def sqs(self, value: typing.Optional[typing.List["IotTopicRuleSqs"]]) -> None:
        jsii.set(self, "sqs", value)

    @builtins.property
    @jsii.member(jsii_name="stepFunctions")
    def step_functions(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleStepFunctions"]]:
        return jsii.get(self, "stepFunctions")

    @step_functions.setter
    def step_functions(
        self, value: typing.Optional[typing.List["IotTopicRuleStepFunctions"]]
    ) -> None:
        jsii.set(self, "stepFunctions", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleCloudwatchAlarm",
    jsii_struct_bases=[],
    name_mapping={
        "alarm_name": "alarmName",
        "role_arn": "roleArn",
        "state_reason": "stateReason",
        "state_value": "stateValue",
    },
)
class IotTopicRuleCloudwatchAlarm:
    def __init__(
        self, *, alarm_name: str, role_arn: str, state_reason: str, state_value: str
    ) -> None:
        """
        :param alarm_name: 
        :param role_arn: 
        :param state_reason: 
        :param state_value: 
        """
        self._values = {
            "alarm_name": alarm_name,
            "role_arn": role_arn,
            "state_reason": state_reason,
            "state_value": state_value,
        }

    @builtins.property
    def alarm_name(self) -> str:
        return self._values.get("alarm_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def state_reason(self) -> str:
        return self._values.get("state_reason")

    @builtins.property
    def state_value(self) -> str:
        return self._values.get("state_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleCloudwatchAlarm(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleCloudwatchMetric",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "metric_namespace": "metricNamespace",
        "metric_unit": "metricUnit",
        "metric_value": "metricValue",
        "role_arn": "roleArn",
        "metric_timestamp": "metricTimestamp",
    },
)
class IotTopicRuleCloudwatchMetric:
    def __init__(
        self,
        *,
        metric_name: str,
        metric_namespace: str,
        metric_unit: str,
        metric_value: str,
        role_arn: str,
        metric_timestamp: typing.Optional[str] = None,
    ) -> None:
        """
        :param metric_name: 
        :param metric_namespace: 
        :param metric_unit: 
        :param metric_value: 
        :param role_arn: 
        :param metric_timestamp: 
        """
        self._values = {
            "metric_name": metric_name,
            "metric_namespace": metric_namespace,
            "metric_unit": metric_unit,
            "metric_value": metric_value,
            "role_arn": role_arn,
        }
        if metric_timestamp is not None:
            self._values["metric_timestamp"] = metric_timestamp

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def metric_namespace(self) -> str:
        return self._values.get("metric_namespace")

    @builtins.property
    def metric_unit(self) -> str:
        return self._values.get("metric_unit")

    @builtins.property
    def metric_value(self) -> str:
        return self._values.get("metric_value")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def metric_timestamp(self) -> typing.Optional[str]:
        return self._values.get("metric_timestamp")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleCloudwatchMetric(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "enabled": "enabled",
        "name": "name",
        "sql": "sql",
        "sql_version": "sqlVersion",
        "cloudwatch_alarm": "cloudwatchAlarm",
        "cloudwatch_metric": "cloudwatchMetric",
        "description": "description",
        "dynamodb": "dynamodb",
        "dynamodbv2": "dynamodbv2",
        "elasticsearch": "elasticsearch",
        "error_action": "errorAction",
        "firehose": "firehose",
        "iot_analytics": "iotAnalytics",
        "iot_events": "iotEvents",
        "kinesis": "kinesis",
        "lambda_": "lambda",
        "republish": "republish",
        "s3": "s3",
        "sns": "sns",
        "sqs": "sqs",
        "step_functions": "stepFunctions",
        "tags": "tags",
    },
)
class IotTopicRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        enabled: bool,
        name: str,
        sql: str,
        sql_version: str,
        cloudwatch_alarm: typing.Optional[
            typing.List["IotTopicRuleCloudwatchAlarm"]
        ] = None,
        cloudwatch_metric: typing.Optional[
            typing.List["IotTopicRuleCloudwatchMetric"]
        ] = None,
        description: typing.Optional[str] = None,
        dynamodb: typing.Optional[typing.List["IotTopicRuleDynamodb"]] = None,
        dynamodbv2: typing.Optional[typing.List["IotTopicRuleDynamodbv2"]] = None,
        elasticsearch: typing.Optional[typing.List["IotTopicRuleElasticsearch"]] = None,
        error_action: typing.Optional[typing.List["IotTopicRuleErrorAction"]] = None,
        firehose: typing.Optional[typing.List["IotTopicRuleFirehose"]] = None,
        iot_analytics: typing.Optional[typing.List["IotTopicRuleIotAnalytics"]] = None,
        iot_events: typing.Optional[typing.List["IotTopicRuleIotEvents"]] = None,
        kinesis: typing.Optional[typing.List["IotTopicRuleKinesis"]] = None,
        lambda_: typing.Optional[typing.List["IotTopicRuleLambda"]] = None,
        republish: typing.Optional[typing.List["IotTopicRuleRepublish"]] = None,
        s3: typing.Optional[typing.List["IotTopicRuleS3"]] = None,
        sns: typing.Optional[typing.List["IotTopicRuleSns"]] = None,
        sqs: typing.Optional[typing.List["IotTopicRuleSqs"]] = None,
        step_functions: typing.Optional[
            typing.List["IotTopicRuleStepFunctions"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param enabled: 
        :param name: 
        :param sql: 
        :param sql_version: 
        :param cloudwatch_alarm: cloudwatch_alarm block.
        :param cloudwatch_metric: cloudwatch_metric block.
        :param description: 
        :param dynamodb: dynamodb block.
        :param dynamodbv2: dynamodbv2 block.
        :param elasticsearch: elasticsearch block.
        :param error_action: error_action block.
        :param firehose: firehose block.
        :param iot_analytics: iot_analytics block.
        :param iot_events: iot_events block.
        :param kinesis: kinesis block.
        :param lambda_: lambda block.
        :param republish: republish block.
        :param s3: s3 block.
        :param sns: sns block.
        :param sqs: sqs block.
        :param step_functions: step_functions block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "enabled": enabled,
            "name": name,
            "sql": sql,
            "sql_version": sql_version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloudwatch_alarm is not None:
            self._values["cloudwatch_alarm"] = cloudwatch_alarm
        if cloudwatch_metric is not None:
            self._values["cloudwatch_metric"] = cloudwatch_metric
        if description is not None:
            self._values["description"] = description
        if dynamodb is not None:
            self._values["dynamodb"] = dynamodb
        if dynamodbv2 is not None:
            self._values["dynamodbv2"] = dynamodbv2
        if elasticsearch is not None:
            self._values["elasticsearch"] = elasticsearch
        if error_action is not None:
            self._values["error_action"] = error_action
        if firehose is not None:
            self._values["firehose"] = firehose
        if iot_analytics is not None:
            self._values["iot_analytics"] = iot_analytics
        if iot_events is not None:
            self._values["iot_events"] = iot_events
        if kinesis is not None:
            self._values["kinesis"] = kinesis
        if lambda_ is not None:
            self._values["lambda_"] = lambda_
        if republish is not None:
            self._values["republish"] = republish
        if s3 is not None:
            self._values["s3"] = s3
        if sns is not None:
            self._values["sns"] = sns
        if sqs is not None:
            self._values["sqs"] = sqs
        if step_functions is not None:
            self._values["step_functions"] = step_functions
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def sql(self) -> str:
        return self._values.get("sql")

    @builtins.property
    def sql_version(self) -> str:
        return self._values.get("sql_version")

    @builtins.property
    def cloudwatch_alarm(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleCloudwatchAlarm"]]:
        """cloudwatch_alarm block."""
        return self._values.get("cloudwatch_alarm")

    @builtins.property
    def cloudwatch_metric(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleCloudwatchMetric"]]:
        """cloudwatch_metric block."""
        return self._values.get("cloudwatch_metric")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def dynamodb(self) -> typing.Optional[typing.List["IotTopicRuleDynamodb"]]:
        """dynamodb block."""
        return self._values.get("dynamodb")

    @builtins.property
    def dynamodbv2(self) -> typing.Optional[typing.List["IotTopicRuleDynamodbv2"]]:
        """dynamodbv2 block."""
        return self._values.get("dynamodbv2")

    @builtins.property
    def elasticsearch(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleElasticsearch"]]:
        """elasticsearch block."""
        return self._values.get("elasticsearch")

    @builtins.property
    def error_action(self) -> typing.Optional[typing.List["IotTopicRuleErrorAction"]]:
        """error_action block."""
        return self._values.get("error_action")

    @builtins.property
    def firehose(self) -> typing.Optional[typing.List["IotTopicRuleFirehose"]]:
        """firehose block."""
        return self._values.get("firehose")

    @builtins.property
    def iot_analytics(self) -> typing.Optional[typing.List["IotTopicRuleIotAnalytics"]]:
        """iot_analytics block."""
        return self._values.get("iot_analytics")

    @builtins.property
    def iot_events(self) -> typing.Optional[typing.List["IotTopicRuleIotEvents"]]:
        """iot_events block."""
        return self._values.get("iot_events")

    @builtins.property
    def kinesis(self) -> typing.Optional[typing.List["IotTopicRuleKinesis"]]:
        """kinesis block."""
        return self._values.get("kinesis")

    @builtins.property
    def lambda_(self) -> typing.Optional[typing.List["IotTopicRuleLambda"]]:
        """lambda block."""
        return self._values.get("lambda_")

    @builtins.property
    def republish(self) -> typing.Optional[typing.List["IotTopicRuleRepublish"]]:
        """republish block."""
        return self._values.get("republish")

    @builtins.property
    def s3(self) -> typing.Optional[typing.List["IotTopicRuleS3"]]:
        """s3 block."""
        return self._values.get("s3")

    @builtins.property
    def sns(self) -> typing.Optional[typing.List["IotTopicRuleSns"]]:
        """sns block."""
        return self._values.get("sns")

    @builtins.property
    def sqs(self) -> typing.Optional[typing.List["IotTopicRuleSqs"]]:
        """sqs block."""
        return self._values.get("sqs")

    @builtins.property
    def step_functions(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleStepFunctions"]]:
        """step_functions block."""
        return self._values.get("step_functions")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleDynamodb",
    jsii_struct_bases=[],
    name_mapping={
        "hash_key_field": "hashKeyField",
        "hash_key_value": "hashKeyValue",
        "role_arn": "roleArn",
        "table_name": "tableName",
        "hash_key_type": "hashKeyType",
        "operation": "operation",
        "payload_field": "payloadField",
        "range_key_field": "rangeKeyField",
        "range_key_type": "rangeKeyType",
        "range_key_value": "rangeKeyValue",
    },
)
class IotTopicRuleDynamodb:
    def __init__(
        self,
        *,
        hash_key_field: str,
        hash_key_value: str,
        role_arn: str,
        table_name: str,
        hash_key_type: typing.Optional[str] = None,
        operation: typing.Optional[str] = None,
        payload_field: typing.Optional[str] = None,
        range_key_field: typing.Optional[str] = None,
        range_key_type: typing.Optional[str] = None,
        range_key_value: typing.Optional[str] = None,
    ) -> None:
        """
        :param hash_key_field: 
        :param hash_key_value: 
        :param role_arn: 
        :param table_name: 
        :param hash_key_type: 
        :param operation: 
        :param payload_field: 
        :param range_key_field: 
        :param range_key_type: 
        :param range_key_value: 
        """
        self._values = {
            "hash_key_field": hash_key_field,
            "hash_key_value": hash_key_value,
            "role_arn": role_arn,
            "table_name": table_name,
        }
        if hash_key_type is not None:
            self._values["hash_key_type"] = hash_key_type
        if operation is not None:
            self._values["operation"] = operation
        if payload_field is not None:
            self._values["payload_field"] = payload_field
        if range_key_field is not None:
            self._values["range_key_field"] = range_key_field
        if range_key_type is not None:
            self._values["range_key_type"] = range_key_type
        if range_key_value is not None:
            self._values["range_key_value"] = range_key_value

    @builtins.property
    def hash_key_field(self) -> str:
        return self._values.get("hash_key_field")

    @builtins.property
    def hash_key_value(self) -> str:
        return self._values.get("hash_key_value")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    @builtins.property
    def hash_key_type(self) -> typing.Optional[str]:
        return self._values.get("hash_key_type")

    @builtins.property
    def operation(self) -> typing.Optional[str]:
        return self._values.get("operation")

    @builtins.property
    def payload_field(self) -> typing.Optional[str]:
        return self._values.get("payload_field")

    @builtins.property
    def range_key_field(self) -> typing.Optional[str]:
        return self._values.get("range_key_field")

    @builtins.property
    def range_key_type(self) -> typing.Optional[str]:
        return self._values.get("range_key_type")

    @builtins.property
    def range_key_value(self) -> typing.Optional[str]:
        return self._values.get("range_key_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleDynamodb(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleDynamodbv2",
    jsii_struct_bases=[],
    name_mapping={"role_arn": "roleArn", "put_item": "putItem"},
)
class IotTopicRuleDynamodbv2:
    def __init__(
        self,
        *,
        role_arn: str,
        put_item: typing.Optional[typing.List["IotTopicRuleDynamodbv2PutItem"]] = None,
    ) -> None:
        """
        :param role_arn: 
        :param put_item: put_item block.
        """
        self._values = {
            "role_arn": role_arn,
        }
        if put_item is not None:
            self._values["put_item"] = put_item

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def put_item(self) -> typing.Optional[typing.List["IotTopicRuleDynamodbv2PutItem"]]:
        """put_item block."""
        return self._values.get("put_item")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleDynamodbv2(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleDynamodbv2PutItem",
    jsii_struct_bases=[],
    name_mapping={"table_name": "tableName"},
)
class IotTopicRuleDynamodbv2PutItem:
    def __init__(self, *, table_name: str) -> None:
        """
        :param table_name: 
        """
        self._values = {
            "table_name": table_name,
        }

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleDynamodbv2PutItem(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleElasticsearch",
    jsii_struct_bases=[],
    name_mapping={
        "endpoint": "endpoint",
        "id": "id",
        "index": "index",
        "role_arn": "roleArn",
        "type": "type",
    },
)
class IotTopicRuleElasticsearch:
    def __init__(
        self, *, endpoint: str, id: str, index: str, role_arn: str, type: str
    ) -> None:
        """
        :param endpoint: 
        :param id: 
        :param index: 
        :param role_arn: 
        :param type: 
        """
        self._values = {
            "endpoint": endpoint,
            "id": id,
            "index": index,
            "role_arn": role_arn,
            "type": type,
        }

    @builtins.property
    def endpoint(self) -> str:
        return self._values.get("endpoint")

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    @builtins.property
    def index(self) -> str:
        return self._values.get("index")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleElasticsearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorAction",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_alarm": "cloudwatchAlarm",
        "cloudwatch_metric": "cloudwatchMetric",
        "dynamodb": "dynamodb",
        "dynamodbv2": "dynamodbv2",
        "elasticsearch": "elasticsearch",
        "firehose": "firehose",
        "iot_analytics": "iotAnalytics",
        "iot_events": "iotEvents",
        "kinesis": "kinesis",
        "lambda_": "lambda",
        "republish": "republish",
        "s3": "s3",
        "sns": "sns",
        "sqs": "sqs",
        "step_functions": "stepFunctions",
    },
)
class IotTopicRuleErrorAction:
    def __init__(
        self,
        *,
        cloudwatch_alarm: typing.Optional[
            typing.List["IotTopicRuleErrorActionCloudwatchAlarm"]
        ] = None,
        cloudwatch_metric: typing.Optional[
            typing.List["IotTopicRuleErrorActionCloudwatchMetric"]
        ] = None,
        dynamodb: typing.Optional[
            typing.List["IotTopicRuleErrorActionDynamodb"]
        ] = None,
        dynamodbv2: typing.Optional[
            typing.List["IotTopicRuleErrorActionDynamodbv2"]
        ] = None,
        elasticsearch: typing.Optional[
            typing.List["IotTopicRuleErrorActionElasticsearch"]
        ] = None,
        firehose: typing.Optional[
            typing.List["IotTopicRuleErrorActionFirehose"]
        ] = None,
        iot_analytics: typing.Optional[
            typing.List["IotTopicRuleErrorActionIotAnalytics"]
        ] = None,
        iot_events: typing.Optional[
            typing.List["IotTopicRuleErrorActionIotEvents"]
        ] = None,
        kinesis: typing.Optional[typing.List["IotTopicRuleErrorActionKinesis"]] = None,
        lambda_: typing.Optional[typing.List["IotTopicRuleErrorActionLambda"]] = None,
        republish: typing.Optional[
            typing.List["IotTopicRuleErrorActionRepublish"]
        ] = None,
        s3: typing.Optional[typing.List["IotTopicRuleErrorActionS3"]] = None,
        sns: typing.Optional[typing.List["IotTopicRuleErrorActionSns"]] = None,
        sqs: typing.Optional[typing.List["IotTopicRuleErrorActionSqs"]] = None,
        step_functions: typing.Optional[
            typing.List["IotTopicRuleErrorActionStepFunctions"]
        ] = None,
    ) -> None:
        """
        :param cloudwatch_alarm: cloudwatch_alarm block.
        :param cloudwatch_metric: cloudwatch_metric block.
        :param dynamodb: dynamodb block.
        :param dynamodbv2: dynamodbv2 block.
        :param elasticsearch: elasticsearch block.
        :param firehose: firehose block.
        :param iot_analytics: iot_analytics block.
        :param iot_events: iot_events block.
        :param kinesis: kinesis block.
        :param lambda_: lambda block.
        :param republish: republish block.
        :param s3: s3 block.
        :param sns: sns block.
        :param sqs: sqs block.
        :param step_functions: step_functions block.
        """
        self._values = {}
        if cloudwatch_alarm is not None:
            self._values["cloudwatch_alarm"] = cloudwatch_alarm
        if cloudwatch_metric is not None:
            self._values["cloudwatch_metric"] = cloudwatch_metric
        if dynamodb is not None:
            self._values["dynamodb"] = dynamodb
        if dynamodbv2 is not None:
            self._values["dynamodbv2"] = dynamodbv2
        if elasticsearch is not None:
            self._values["elasticsearch"] = elasticsearch
        if firehose is not None:
            self._values["firehose"] = firehose
        if iot_analytics is not None:
            self._values["iot_analytics"] = iot_analytics
        if iot_events is not None:
            self._values["iot_events"] = iot_events
        if kinesis is not None:
            self._values["kinesis"] = kinesis
        if lambda_ is not None:
            self._values["lambda_"] = lambda_
        if republish is not None:
            self._values["republish"] = republish
        if s3 is not None:
            self._values["s3"] = s3
        if sns is not None:
            self._values["sns"] = sns
        if sqs is not None:
            self._values["sqs"] = sqs
        if step_functions is not None:
            self._values["step_functions"] = step_functions

    @builtins.property
    def cloudwatch_alarm(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionCloudwatchAlarm"]]:
        """cloudwatch_alarm block."""
        return self._values.get("cloudwatch_alarm")

    @builtins.property
    def cloudwatch_metric(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionCloudwatchMetric"]]:
        """cloudwatch_metric block."""
        return self._values.get("cloudwatch_metric")

    @builtins.property
    def dynamodb(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionDynamodb"]]:
        """dynamodb block."""
        return self._values.get("dynamodb")

    @builtins.property
    def dynamodbv2(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionDynamodbv2"]]:
        """dynamodbv2 block."""
        return self._values.get("dynamodbv2")

    @builtins.property
    def elasticsearch(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionElasticsearch"]]:
        """elasticsearch block."""
        return self._values.get("elasticsearch")

    @builtins.property
    def firehose(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionFirehose"]]:
        """firehose block."""
        return self._values.get("firehose")

    @builtins.property
    def iot_analytics(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionIotAnalytics"]]:
        """iot_analytics block."""
        return self._values.get("iot_analytics")

    @builtins.property
    def iot_events(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionIotEvents"]]:
        """iot_events block."""
        return self._values.get("iot_events")

    @builtins.property
    def kinesis(self) -> typing.Optional[typing.List["IotTopicRuleErrorActionKinesis"]]:
        """kinesis block."""
        return self._values.get("kinesis")

    @builtins.property
    def lambda_(self) -> typing.Optional[typing.List["IotTopicRuleErrorActionLambda"]]:
        """lambda block."""
        return self._values.get("lambda_")

    @builtins.property
    def republish(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionRepublish"]]:
        """republish block."""
        return self._values.get("republish")

    @builtins.property
    def s3(self) -> typing.Optional[typing.List["IotTopicRuleErrorActionS3"]]:
        """s3 block."""
        return self._values.get("s3")

    @builtins.property
    def sns(self) -> typing.Optional[typing.List["IotTopicRuleErrorActionSns"]]:
        """sns block."""
        return self._values.get("sns")

    @builtins.property
    def sqs(self) -> typing.Optional[typing.List["IotTopicRuleErrorActionSqs"]]:
        """sqs block."""
        return self._values.get("sqs")

    @builtins.property
    def step_functions(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionStepFunctions"]]:
        """step_functions block."""
        return self._values.get("step_functions")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionCloudwatchAlarm",
    jsii_struct_bases=[],
    name_mapping={
        "alarm_name": "alarmName",
        "role_arn": "roleArn",
        "state_reason": "stateReason",
        "state_value": "stateValue",
    },
)
class IotTopicRuleErrorActionCloudwatchAlarm:
    def __init__(
        self, *, alarm_name: str, role_arn: str, state_reason: str, state_value: str
    ) -> None:
        """
        :param alarm_name: 
        :param role_arn: 
        :param state_reason: 
        :param state_value: 
        """
        self._values = {
            "alarm_name": alarm_name,
            "role_arn": role_arn,
            "state_reason": state_reason,
            "state_value": state_value,
        }

    @builtins.property
    def alarm_name(self) -> str:
        return self._values.get("alarm_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def state_reason(self) -> str:
        return self._values.get("state_reason")

    @builtins.property
    def state_value(self) -> str:
        return self._values.get("state_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionCloudwatchAlarm(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionCloudwatchMetric",
    jsii_struct_bases=[],
    name_mapping={
        "metric_name": "metricName",
        "metric_namespace": "metricNamespace",
        "metric_unit": "metricUnit",
        "metric_value": "metricValue",
        "role_arn": "roleArn",
        "metric_timestamp": "metricTimestamp",
    },
)
class IotTopicRuleErrorActionCloudwatchMetric:
    def __init__(
        self,
        *,
        metric_name: str,
        metric_namespace: str,
        metric_unit: str,
        metric_value: str,
        role_arn: str,
        metric_timestamp: typing.Optional[str] = None,
    ) -> None:
        """
        :param metric_name: 
        :param metric_namespace: 
        :param metric_unit: 
        :param metric_value: 
        :param role_arn: 
        :param metric_timestamp: 
        """
        self._values = {
            "metric_name": metric_name,
            "metric_namespace": metric_namespace,
            "metric_unit": metric_unit,
            "metric_value": metric_value,
            "role_arn": role_arn,
        }
        if metric_timestamp is not None:
            self._values["metric_timestamp"] = metric_timestamp

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def metric_namespace(self) -> str:
        return self._values.get("metric_namespace")

    @builtins.property
    def metric_unit(self) -> str:
        return self._values.get("metric_unit")

    @builtins.property
    def metric_value(self) -> str:
        return self._values.get("metric_value")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def metric_timestamp(self) -> typing.Optional[str]:
        return self._values.get("metric_timestamp")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionCloudwatchMetric(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionDynamodb",
    jsii_struct_bases=[],
    name_mapping={
        "hash_key_field": "hashKeyField",
        "hash_key_value": "hashKeyValue",
        "role_arn": "roleArn",
        "table_name": "tableName",
        "hash_key_type": "hashKeyType",
        "operation": "operation",
        "payload_field": "payloadField",
        "range_key_field": "rangeKeyField",
        "range_key_type": "rangeKeyType",
        "range_key_value": "rangeKeyValue",
    },
)
class IotTopicRuleErrorActionDynamodb:
    def __init__(
        self,
        *,
        hash_key_field: str,
        hash_key_value: str,
        role_arn: str,
        table_name: str,
        hash_key_type: typing.Optional[str] = None,
        operation: typing.Optional[str] = None,
        payload_field: typing.Optional[str] = None,
        range_key_field: typing.Optional[str] = None,
        range_key_type: typing.Optional[str] = None,
        range_key_value: typing.Optional[str] = None,
    ) -> None:
        """
        :param hash_key_field: 
        :param hash_key_value: 
        :param role_arn: 
        :param table_name: 
        :param hash_key_type: 
        :param operation: 
        :param payload_field: 
        :param range_key_field: 
        :param range_key_type: 
        :param range_key_value: 
        """
        self._values = {
            "hash_key_field": hash_key_field,
            "hash_key_value": hash_key_value,
            "role_arn": role_arn,
            "table_name": table_name,
        }
        if hash_key_type is not None:
            self._values["hash_key_type"] = hash_key_type
        if operation is not None:
            self._values["operation"] = operation
        if payload_field is not None:
            self._values["payload_field"] = payload_field
        if range_key_field is not None:
            self._values["range_key_field"] = range_key_field
        if range_key_type is not None:
            self._values["range_key_type"] = range_key_type
        if range_key_value is not None:
            self._values["range_key_value"] = range_key_value

    @builtins.property
    def hash_key_field(self) -> str:
        return self._values.get("hash_key_field")

    @builtins.property
    def hash_key_value(self) -> str:
        return self._values.get("hash_key_value")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    @builtins.property
    def hash_key_type(self) -> typing.Optional[str]:
        return self._values.get("hash_key_type")

    @builtins.property
    def operation(self) -> typing.Optional[str]:
        return self._values.get("operation")

    @builtins.property
    def payload_field(self) -> typing.Optional[str]:
        return self._values.get("payload_field")

    @builtins.property
    def range_key_field(self) -> typing.Optional[str]:
        return self._values.get("range_key_field")

    @builtins.property
    def range_key_type(self) -> typing.Optional[str]:
        return self._values.get("range_key_type")

    @builtins.property
    def range_key_value(self) -> typing.Optional[str]:
        return self._values.get("range_key_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionDynamodb(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionDynamodbv2",
    jsii_struct_bases=[],
    name_mapping={"role_arn": "roleArn", "put_item": "putItem"},
)
class IotTopicRuleErrorActionDynamodbv2:
    def __init__(
        self,
        *,
        role_arn: str,
        put_item: typing.Optional[
            typing.List["IotTopicRuleErrorActionDynamodbv2PutItem"]
        ] = None,
    ) -> None:
        """
        :param role_arn: 
        :param put_item: put_item block.
        """
        self._values = {
            "role_arn": role_arn,
        }
        if put_item is not None:
            self._values["put_item"] = put_item

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def put_item(
        self,
    ) -> typing.Optional[typing.List["IotTopicRuleErrorActionDynamodbv2PutItem"]]:
        """put_item block."""
        return self._values.get("put_item")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionDynamodbv2(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionDynamodbv2PutItem",
    jsii_struct_bases=[],
    name_mapping={"table_name": "tableName"},
)
class IotTopicRuleErrorActionDynamodbv2PutItem:
    def __init__(self, *, table_name: str) -> None:
        """
        :param table_name: 
        """
        self._values = {
            "table_name": table_name,
        }

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionDynamodbv2PutItem(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionElasticsearch",
    jsii_struct_bases=[],
    name_mapping={
        "endpoint": "endpoint",
        "id": "id",
        "index": "index",
        "role_arn": "roleArn",
        "type": "type",
    },
)
class IotTopicRuleErrorActionElasticsearch:
    def __init__(
        self, *, endpoint: str, id: str, index: str, role_arn: str, type: str
    ) -> None:
        """
        :param endpoint: 
        :param id: 
        :param index: 
        :param role_arn: 
        :param type: 
        """
        self._values = {
            "endpoint": endpoint,
            "id": id,
            "index": index,
            "role_arn": role_arn,
            "type": type,
        }

    @builtins.property
    def endpoint(self) -> str:
        return self._values.get("endpoint")

    @builtins.property
    def id(self) -> str:
        return self._values.get("id")

    @builtins.property
    def index(self) -> str:
        return self._values.get("index")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionElasticsearch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionFirehose",
    jsii_struct_bases=[],
    name_mapping={
        "delivery_stream_name": "deliveryStreamName",
        "role_arn": "roleArn",
        "separator": "separator",
    },
)
class IotTopicRuleErrorActionFirehose:
    def __init__(
        self,
        *,
        delivery_stream_name: str,
        role_arn: str,
        separator: typing.Optional[str] = None,
    ) -> None:
        """
        :param delivery_stream_name: 
        :param role_arn: 
        :param separator: 
        """
        self._values = {
            "delivery_stream_name": delivery_stream_name,
            "role_arn": role_arn,
        }
        if separator is not None:
            self._values["separator"] = separator

    @builtins.property
    def delivery_stream_name(self) -> str:
        return self._values.get("delivery_stream_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def separator(self) -> typing.Optional[str]:
        return self._values.get("separator")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionFirehose(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionIotAnalytics",
    jsii_struct_bases=[],
    name_mapping={"channel_name": "channelName", "role_arn": "roleArn"},
)
class IotTopicRuleErrorActionIotAnalytics:
    def __init__(self, *, channel_name: str, role_arn: str) -> None:
        """
        :param channel_name: 
        :param role_arn: 
        """
        self._values = {
            "channel_name": channel_name,
            "role_arn": role_arn,
        }

    @builtins.property
    def channel_name(self) -> str:
        return self._values.get("channel_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionIotAnalytics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionIotEvents",
    jsii_struct_bases=[],
    name_mapping={
        "input_name": "inputName",
        "role_arn": "roleArn",
        "message_id": "messageId",
    },
)
class IotTopicRuleErrorActionIotEvents:
    def __init__(
        self, *, input_name: str, role_arn: str, message_id: typing.Optional[str] = None
    ) -> None:
        """
        :param input_name: 
        :param role_arn: 
        :param message_id: 
        """
        self._values = {
            "input_name": input_name,
            "role_arn": role_arn,
        }
        if message_id is not None:
            self._values["message_id"] = message_id

    @builtins.property
    def input_name(self) -> str:
        return self._values.get("input_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def message_id(self) -> typing.Optional[str]:
        return self._values.get("message_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionIotEvents(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionKinesis",
    jsii_struct_bases=[],
    name_mapping={
        "role_arn": "roleArn",
        "stream_name": "streamName",
        "partition_key": "partitionKey",
    },
)
class IotTopicRuleErrorActionKinesis:
    def __init__(
        self,
        *,
        role_arn: str,
        stream_name: str,
        partition_key: typing.Optional[str] = None,
    ) -> None:
        """
        :param role_arn: 
        :param stream_name: 
        :param partition_key: 
        """
        self._values = {
            "role_arn": role_arn,
            "stream_name": stream_name,
        }
        if partition_key is not None:
            self._values["partition_key"] = partition_key

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def stream_name(self) -> str:
        return self._values.get("stream_name")

    @builtins.property
    def partition_key(self) -> typing.Optional[str]:
        return self._values.get("partition_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionKinesis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionLambda",
    jsii_struct_bases=[],
    name_mapping={"function_arn": "functionArn"},
)
class IotTopicRuleErrorActionLambda:
    def __init__(self, *, function_arn: str) -> None:
        """
        :param function_arn: 
        """
        self._values = {
            "function_arn": function_arn,
        }

    @builtins.property
    def function_arn(self) -> str:
        return self._values.get("function_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionLambda(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionRepublish",
    jsii_struct_bases=[],
    name_mapping={"role_arn": "roleArn", "topic": "topic", "qos": "qos"},
)
class IotTopicRuleErrorActionRepublish:
    def __init__(
        self, *, role_arn: str, topic: str, qos: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param role_arn: 
        :param topic: 
        :param qos: 
        """
        self._values = {
            "role_arn": role_arn,
            "topic": topic,
        }
        if qos is not None:
            self._values["qos"] = qos

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def topic(self) -> str:
        return self._values.get("topic")

    @builtins.property
    def qos(self) -> typing.Optional[jsii.Number]:
        return self._values.get("qos")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionRepublish(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionS3",
    jsii_struct_bases=[],
    name_mapping={"bucket_name": "bucketName", "key": "key", "role_arn": "roleArn"},
)
class IotTopicRuleErrorActionS3:
    def __init__(self, *, bucket_name: str, key: str, role_arn: str) -> None:
        """
        :param bucket_name: 
        :param key: 
        :param role_arn: 
        """
        self._values = {
            "bucket_name": bucket_name,
            "key": key,
            "role_arn": role_arn,
        }

    @builtins.property
    def bucket_name(self) -> str:
        return self._values.get("bucket_name")

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionS3(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionSns",
    jsii_struct_bases=[],
    name_mapping={
        "role_arn": "roleArn",
        "target_arn": "targetArn",
        "message_format": "messageFormat",
    },
)
class IotTopicRuleErrorActionSns:
    def __init__(
        self,
        *,
        role_arn: str,
        target_arn: str,
        message_format: typing.Optional[str] = None,
    ) -> None:
        """
        :param role_arn: 
        :param target_arn: 
        :param message_format: 
        """
        self._values = {
            "role_arn": role_arn,
            "target_arn": target_arn,
        }
        if message_format is not None:
            self._values["message_format"] = message_format

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def target_arn(self) -> str:
        return self._values.get("target_arn")

    @builtins.property
    def message_format(self) -> typing.Optional[str]:
        return self._values.get("message_format")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionSns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionSqs",
    jsii_struct_bases=[],
    name_mapping={
        "queue_url": "queueUrl",
        "role_arn": "roleArn",
        "use_base64": "useBase64",
    },
)
class IotTopicRuleErrorActionSqs:
    def __init__(self, *, queue_url: str, role_arn: str, use_base64: bool) -> None:
        """
        :param queue_url: 
        :param role_arn: 
        :param use_base64: 
        """
        self._values = {
            "queue_url": queue_url,
            "role_arn": role_arn,
            "use_base64": use_base64,
        }

    @builtins.property
    def queue_url(self) -> str:
        return self._values.get("queue_url")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def use_base64(self) -> bool:
        return self._values.get("use_base64")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionSqs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleErrorActionStepFunctions",
    jsii_struct_bases=[],
    name_mapping={
        "role_arn": "roleArn",
        "state_machine_name": "stateMachineName",
        "execution_name_prefix": "executionNamePrefix",
    },
)
class IotTopicRuleErrorActionStepFunctions:
    def __init__(
        self,
        *,
        role_arn: str,
        state_machine_name: str,
        execution_name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param role_arn: 
        :param state_machine_name: 
        :param execution_name_prefix: 
        """
        self._values = {
            "role_arn": role_arn,
            "state_machine_name": state_machine_name,
        }
        if execution_name_prefix is not None:
            self._values["execution_name_prefix"] = execution_name_prefix

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def state_machine_name(self) -> str:
        return self._values.get("state_machine_name")

    @builtins.property
    def execution_name_prefix(self) -> typing.Optional[str]:
        return self._values.get("execution_name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleErrorActionStepFunctions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleFirehose",
    jsii_struct_bases=[],
    name_mapping={
        "delivery_stream_name": "deliveryStreamName",
        "role_arn": "roleArn",
        "separator": "separator",
    },
)
class IotTopicRuleFirehose:
    def __init__(
        self,
        *,
        delivery_stream_name: str,
        role_arn: str,
        separator: typing.Optional[str] = None,
    ) -> None:
        """
        :param delivery_stream_name: 
        :param role_arn: 
        :param separator: 
        """
        self._values = {
            "delivery_stream_name": delivery_stream_name,
            "role_arn": role_arn,
        }
        if separator is not None:
            self._values["separator"] = separator

    @builtins.property
    def delivery_stream_name(self) -> str:
        return self._values.get("delivery_stream_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def separator(self) -> typing.Optional[str]:
        return self._values.get("separator")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleFirehose(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleIotAnalytics",
    jsii_struct_bases=[],
    name_mapping={"channel_name": "channelName", "role_arn": "roleArn"},
)
class IotTopicRuleIotAnalytics:
    def __init__(self, *, channel_name: str, role_arn: str) -> None:
        """
        :param channel_name: 
        :param role_arn: 
        """
        self._values = {
            "channel_name": channel_name,
            "role_arn": role_arn,
        }

    @builtins.property
    def channel_name(self) -> str:
        return self._values.get("channel_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleIotAnalytics(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleIotEvents",
    jsii_struct_bases=[],
    name_mapping={
        "input_name": "inputName",
        "role_arn": "roleArn",
        "message_id": "messageId",
    },
)
class IotTopicRuleIotEvents:
    def __init__(
        self, *, input_name: str, role_arn: str, message_id: typing.Optional[str] = None
    ) -> None:
        """
        :param input_name: 
        :param role_arn: 
        :param message_id: 
        """
        self._values = {
            "input_name": input_name,
            "role_arn": role_arn,
        }
        if message_id is not None:
            self._values["message_id"] = message_id

    @builtins.property
    def input_name(self) -> str:
        return self._values.get("input_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def message_id(self) -> typing.Optional[str]:
        return self._values.get("message_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleIotEvents(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleKinesis",
    jsii_struct_bases=[],
    name_mapping={
        "role_arn": "roleArn",
        "stream_name": "streamName",
        "partition_key": "partitionKey",
    },
)
class IotTopicRuleKinesis:
    def __init__(
        self,
        *,
        role_arn: str,
        stream_name: str,
        partition_key: typing.Optional[str] = None,
    ) -> None:
        """
        :param role_arn: 
        :param stream_name: 
        :param partition_key: 
        """
        self._values = {
            "role_arn": role_arn,
            "stream_name": stream_name,
        }
        if partition_key is not None:
            self._values["partition_key"] = partition_key

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def stream_name(self) -> str:
        return self._values.get("stream_name")

    @builtins.property
    def partition_key(self) -> typing.Optional[str]:
        return self._values.get("partition_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleKinesis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleLambda",
    jsii_struct_bases=[],
    name_mapping={"function_arn": "functionArn"},
)
class IotTopicRuleLambda:
    def __init__(self, *, function_arn: str) -> None:
        """
        :param function_arn: 
        """
        self._values = {
            "function_arn": function_arn,
        }

    @builtins.property
    def function_arn(self) -> str:
        return self._values.get("function_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleLambda(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleRepublish",
    jsii_struct_bases=[],
    name_mapping={"role_arn": "roleArn", "topic": "topic", "qos": "qos"},
)
class IotTopicRuleRepublish:
    def __init__(
        self, *, role_arn: str, topic: str, qos: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param role_arn: 
        :param topic: 
        :param qos: 
        """
        self._values = {
            "role_arn": role_arn,
            "topic": topic,
        }
        if qos is not None:
            self._values["qos"] = qos

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def topic(self) -> str:
        return self._values.get("topic")

    @builtins.property
    def qos(self) -> typing.Optional[jsii.Number]:
        return self._values.get("qos")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleRepublish(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleS3",
    jsii_struct_bases=[],
    name_mapping={"bucket_name": "bucketName", "key": "key", "role_arn": "roleArn"},
)
class IotTopicRuleS3:
    def __init__(self, *, bucket_name: str, key: str, role_arn: str) -> None:
        """
        :param bucket_name: 
        :param key: 
        :param role_arn: 
        """
        self._values = {
            "bucket_name": bucket_name,
            "key": key,
            "role_arn": role_arn,
        }

    @builtins.property
    def bucket_name(self) -> str:
        return self._values.get("bucket_name")

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleS3(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleSns",
    jsii_struct_bases=[],
    name_mapping={
        "role_arn": "roleArn",
        "target_arn": "targetArn",
        "message_format": "messageFormat",
    },
)
class IotTopicRuleSns:
    def __init__(
        self,
        *,
        role_arn: str,
        target_arn: str,
        message_format: typing.Optional[str] = None,
    ) -> None:
        """
        :param role_arn: 
        :param target_arn: 
        :param message_format: 
        """
        self._values = {
            "role_arn": role_arn,
            "target_arn": target_arn,
        }
        if message_format is not None:
            self._values["message_format"] = message_format

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def target_arn(self) -> str:
        return self._values.get("target_arn")

    @builtins.property
    def message_format(self) -> typing.Optional[str]:
        return self._values.get("message_format")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleSns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleSqs",
    jsii_struct_bases=[],
    name_mapping={
        "queue_url": "queueUrl",
        "role_arn": "roleArn",
        "use_base64": "useBase64",
    },
)
class IotTopicRuleSqs:
    def __init__(self, *, queue_url: str, role_arn: str, use_base64: bool) -> None:
        """
        :param queue_url: 
        :param role_arn: 
        :param use_base64: 
        """
        self._values = {
            "queue_url": queue_url,
            "role_arn": role_arn,
            "use_base64": use_base64,
        }

    @builtins.property
    def queue_url(self) -> str:
        return self._values.get("queue_url")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def use_base64(self) -> bool:
        return self._values.get("use_base64")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleSqs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.IotTopicRuleStepFunctions",
    jsii_struct_bases=[],
    name_mapping={
        "role_arn": "roleArn",
        "state_machine_name": "stateMachineName",
        "execution_name_prefix": "executionNamePrefix",
    },
)
class IotTopicRuleStepFunctions:
    def __init__(
        self,
        *,
        role_arn: str,
        state_machine_name: str,
        execution_name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param role_arn: 
        :param state_machine_name: 
        :param execution_name_prefix: 
        """
        self._values = {
            "role_arn": role_arn,
            "state_machine_name": state_machine_name,
        }
        if execution_name_prefix is not None:
            self._values["execution_name_prefix"] = execution_name_prefix

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def state_machine_name(self) -> str:
        return self._values.get("state_machine_name")

    @builtins.property
    def execution_name_prefix(self) -> typing.Optional[str]:
        return self._values.get("execution_name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "IotTopicRuleStepFunctions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KeyPair(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KeyPair",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        public_key: str,
        key_name: typing.Optional[str] = None,
        key_name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param public_key: 
        :param key_name: 
        :param key_name_prefix: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KeyPairConfig(
            public_key=public_key,
            key_name=key_name,
            key_name_prefix=key_name_prefix,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KeyPair, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="fingerprint")
    def fingerprint(self) -> str:
        return jsii.get(self, "fingerprint")

    @builtins.property
    @jsii.member(jsii_name="keyPairId")
    def key_pair_id(self) -> str:
        return jsii.get(self, "keyPairId")

    @builtins.property
    @jsii.member(jsii_name="publicKey")
    def public_key(self) -> str:
        return jsii.get(self, "publicKey")

    @public_key.setter
    def public_key(self, value: str) -> None:
        jsii.set(self, "publicKey", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> typing.Optional[str]:
        return jsii.get(self, "keyName")

    @key_name.setter
    def key_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyName", value)

    @builtins.property
    @jsii.member(jsii_name="keyNamePrefix")
    def key_name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "keyNamePrefix")

    @key_name_prefix.setter
    def key_name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyNamePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KeyPairConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "public_key": "publicKey",
        "key_name": "keyName",
        "key_name_prefix": "keyNamePrefix",
        "tags": "tags",
    },
)
class KeyPairConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        public_key: str,
        key_name: typing.Optional[str] = None,
        key_name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param public_key: 
        :param key_name: 
        :param key_name_prefix: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "public_key": public_key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if key_name is not None:
            self._values["key_name"] = key_name
        if key_name_prefix is not None:
            self._values["key_name_prefix"] = key_name_prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def public_key(self) -> str:
        return self._values.get("public_key")

    @builtins.property
    def key_name(self) -> typing.Optional[str]:
        return self._values.get("key_name")

    @builtins.property
    def key_name_prefix(self) -> typing.Optional[str]:
        return self._values.get("key_name_prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KeyPairConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KinesisAnalyticsApplication(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplication",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        cloudwatch_logging_options: typing.Optional[
            typing.List["KinesisAnalyticsApplicationCloudwatchLoggingOptions"]
        ] = None,
        code: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        inputs: typing.Optional[
            typing.List["KinesisAnalyticsApplicationInputs"]
        ] = None,
        outputs: typing.Optional[
            typing.List["KinesisAnalyticsApplicationOutputs"]
        ] = None,
        reference_data_sources: typing.Optional[
            typing.List["KinesisAnalyticsApplicationReferenceDataSources"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param code: 
        :param description: 
        :param inputs: inputs block.
        :param outputs: outputs block.
        :param reference_data_sources: reference_data_sources block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KinesisAnalyticsApplicationConfig(
            name=name,
            cloudwatch_logging_options=cloudwatch_logging_options,
            code=code,
            description=description,
            inputs=inputs,
            outputs=outputs,
            reference_data_sources=reference_data_sources,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KinesisAnalyticsApplication, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createTimestamp")
    def create_timestamp(self) -> str:
        return jsii.get(self, "createTimestamp")

    @builtins.property
    @jsii.member(jsii_name="lastUpdateTimestamp")
    def last_update_timestamp(self) -> str:
        return jsii.get(self, "lastUpdateTimestamp")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> jsii.Number:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchLoggingOptions")
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationCloudwatchLoggingOptions"]
    ]:
        return jsii.get(self, "cloudwatchLoggingOptions")

    @cloudwatch_logging_options.setter
    def cloudwatch_logging_options(
        self,
        value: typing.Optional[
            typing.List["KinesisAnalyticsApplicationCloudwatchLoggingOptions"]
        ],
    ) -> None:
        jsii.set(self, "cloudwatchLoggingOptions", value)

    @builtins.property
    @jsii.member(jsii_name="code")
    def code(self) -> typing.Optional[str]:
        return jsii.get(self, "code")

    @code.setter
    def code(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "code", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="inputs")
    def inputs(
        self,
    ) -> typing.Optional[typing.List["KinesisAnalyticsApplicationInputs"]]:
        return jsii.get(self, "inputs")

    @inputs.setter
    def inputs(
        self, value: typing.Optional[typing.List["KinesisAnalyticsApplicationInputs"]]
    ) -> None:
        jsii.set(self, "inputs", value)

    @builtins.property
    @jsii.member(jsii_name="outputs")
    def outputs(
        self,
    ) -> typing.Optional[typing.List["KinesisAnalyticsApplicationOutputs"]]:
        return jsii.get(self, "outputs")

    @outputs.setter
    def outputs(
        self, value: typing.Optional[typing.List["KinesisAnalyticsApplicationOutputs"]]
    ) -> None:
        jsii.set(self, "outputs", value)

    @builtins.property
    @jsii.member(jsii_name="referenceDataSources")
    def reference_data_sources(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationReferenceDataSources"]
    ]:
        return jsii.get(self, "referenceDataSources")

    @reference_data_sources.setter
    def reference_data_sources(
        self,
        value: typing.Optional[
            typing.List["KinesisAnalyticsApplicationReferenceDataSources"]
        ],
    ) -> None:
        jsii.set(self, "referenceDataSources", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={"log_stream_arn": "logStreamArn", "role_arn": "roleArn"},
)
class KinesisAnalyticsApplicationCloudwatchLoggingOptions:
    def __init__(self, *, log_stream_arn: str, role_arn: str) -> None:
        """
        :param log_stream_arn: 
        :param role_arn: 
        """
        self._values = {
            "log_stream_arn": log_stream_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def log_stream_arn(self) -> str:
        return self._values.get("log_stream_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationCloudwatchLoggingOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "code": "code",
        "description": "description",
        "inputs": "inputs",
        "outputs": "outputs",
        "reference_data_sources": "referenceDataSources",
        "tags": "tags",
    },
)
class KinesisAnalyticsApplicationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        cloudwatch_logging_options: typing.Optional[
            typing.List["KinesisAnalyticsApplicationCloudwatchLoggingOptions"]
        ] = None,
        code: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        inputs: typing.Optional[
            typing.List["KinesisAnalyticsApplicationInputs"]
        ] = None,
        outputs: typing.Optional[
            typing.List["KinesisAnalyticsApplicationOutputs"]
        ] = None,
        reference_data_sources: typing.Optional[
            typing.List["KinesisAnalyticsApplicationReferenceDataSources"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param code: 
        :param description: 
        :param inputs: inputs block.
        :param outputs: outputs block.
        :param reference_data_sources: reference_data_sources block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if code is not None:
            self._values["code"] = code
        if description is not None:
            self._values["description"] = description
        if inputs is not None:
            self._values["inputs"] = inputs
        if outputs is not None:
            self._values["outputs"] = outputs
        if reference_data_sources is not None:
            self._values["reference_data_sources"] = reference_data_sources
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationCloudwatchLoggingOptions"]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def code(self) -> typing.Optional[str]:
        return self._values.get("code")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def inputs(
        self,
    ) -> typing.Optional[typing.List["KinesisAnalyticsApplicationInputs"]]:
        """inputs block."""
        return self._values.get("inputs")

    @builtins.property
    def outputs(
        self,
    ) -> typing.Optional[typing.List["KinesisAnalyticsApplicationOutputs"]]:
        """outputs block."""
        return self._values.get("outputs")

    @builtins.property
    def reference_data_sources(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationReferenceDataSources"]
    ]:
        """reference_data_sources block."""
        return self._values.get("reference_data_sources")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputs",
    jsii_struct_bases=[],
    name_mapping={
        "name_prefix": "namePrefix",
        "schema": "schema",
        "kinesis_firehose": "kinesisFirehose",
        "kinesis_stream": "kinesisStream",
        "parallelism": "parallelism",
        "processing_configuration": "processingConfiguration",
    },
)
class KinesisAnalyticsApplicationInputs:
    def __init__(
        self,
        *,
        name_prefix: str,
        schema: typing.List["KinesisAnalyticsApplicationInputsSchema"],
        kinesis_firehose: typing.Optional[
            typing.List["KinesisAnalyticsApplicationInputsKinesisFirehose"]
        ] = None,
        kinesis_stream: typing.Optional[
            typing.List["KinesisAnalyticsApplicationInputsKinesisStream"]
        ] = None,
        parallelism: typing.Optional[
            typing.List["KinesisAnalyticsApplicationInputsParallelism"]
        ] = None,
        processing_configuration: typing.Optional[
            typing.List["KinesisAnalyticsApplicationInputsProcessingConfiguration"]
        ] = None,
    ) -> None:
        """
        :param name_prefix: 
        :param schema: schema block.
        :param kinesis_firehose: kinesis_firehose block.
        :param kinesis_stream: kinesis_stream block.
        :param parallelism: parallelism block.
        :param processing_configuration: processing_configuration block.
        """
        self._values = {
            "name_prefix": name_prefix,
            "schema": schema,
        }
        if kinesis_firehose is not None:
            self._values["kinesis_firehose"] = kinesis_firehose
        if kinesis_stream is not None:
            self._values["kinesis_stream"] = kinesis_stream
        if parallelism is not None:
            self._values["parallelism"] = parallelism
        if processing_configuration is not None:
            self._values["processing_configuration"] = processing_configuration

    @builtins.property
    def name_prefix(self) -> str:
        return self._values.get("name_prefix")

    @builtins.property
    def schema(self) -> typing.List["KinesisAnalyticsApplicationInputsSchema"]:
        """schema block."""
        return self._values.get("schema")

    @builtins.property
    def kinesis_firehose(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationInputsKinesisFirehose"]
    ]:
        """kinesis_firehose block."""
        return self._values.get("kinesis_firehose")

    @builtins.property
    def kinesis_stream(
        self,
    ) -> typing.Optional[typing.List["KinesisAnalyticsApplicationInputsKinesisStream"]]:
        """kinesis_stream block."""
        return self._values.get("kinesis_stream")

    @builtins.property
    def parallelism(
        self,
    ) -> typing.Optional[typing.List["KinesisAnalyticsApplicationInputsParallelism"]]:
        """parallelism block."""
        return self._values.get("parallelism")

    @builtins.property
    def processing_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationInputsProcessingConfiguration"]
    ]:
        """processing_configuration block."""
        return self._values.get("processing_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationInputs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsKinesisFirehose",
    jsii_struct_bases=[],
    name_mapping={"resource_arn": "resourceArn", "role_arn": "roleArn"},
)
class KinesisAnalyticsApplicationInputsKinesisFirehose:
    def __init__(self, *, resource_arn: str, role_arn: str) -> None:
        """
        :param resource_arn: 
        :param role_arn: 
        """
        self._values = {
            "resource_arn": resource_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationInputsKinesisFirehose(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsKinesisStream",
    jsii_struct_bases=[],
    name_mapping={"resource_arn": "resourceArn", "role_arn": "roleArn"},
)
class KinesisAnalyticsApplicationInputsKinesisStream:
    def __init__(self, *, resource_arn: str, role_arn: str) -> None:
        """
        :param resource_arn: 
        :param role_arn: 
        """
        self._values = {
            "resource_arn": resource_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationInputsKinesisStream(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsParallelism",
    jsii_struct_bases=[],
    name_mapping={"count": "count"},
)
class KinesisAnalyticsApplicationInputsParallelism:
    def __init__(self, *, count: jsii.Number) -> None:
        """
        :param count: 
        """
        self._values = {
            "count": count,
        }

    @builtins.property
    def count(self) -> jsii.Number:
        return self._values.get("count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationInputsParallelism(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsProcessingConfiguration",
    jsii_struct_bases=[],
    name_mapping={"lambda_": "lambda"},
)
class KinesisAnalyticsApplicationInputsProcessingConfiguration:
    def __init__(
        self,
        *,
        lambda_: typing.List[
            "KinesisAnalyticsApplicationInputsProcessingConfigurationLambda"
        ],
    ) -> None:
        """
        :param lambda_: lambda block.
        """
        self._values = {
            "lambda_": lambda_,
        }

    @builtins.property
    def lambda_(
        self,
    ) -> typing.List["KinesisAnalyticsApplicationInputsProcessingConfigurationLambda"]:
        """lambda block."""
        return self._values.get("lambda_")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationInputsProcessingConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsProcessingConfigurationLambda",
    jsii_struct_bases=[],
    name_mapping={"resource_arn": "resourceArn", "role_arn": "roleArn"},
)
class KinesisAnalyticsApplicationInputsProcessingConfigurationLambda:
    def __init__(self, *, resource_arn: str, role_arn: str) -> None:
        """
        :param resource_arn: 
        :param role_arn: 
        """
        self._values = {
            "resource_arn": resource_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationInputsProcessingConfigurationLambda(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsSchema",
    jsii_struct_bases=[],
    name_mapping={
        "record_columns": "recordColumns",
        "record_format": "recordFormat",
        "record_encoding": "recordEncoding",
    },
)
class KinesisAnalyticsApplicationInputsSchema:
    def __init__(
        self,
        *,
        record_columns: typing.List[
            "KinesisAnalyticsApplicationInputsSchemaRecordColumns"
        ],
        record_format: typing.List[
            "KinesisAnalyticsApplicationInputsSchemaRecordFormat"
        ],
        record_encoding: typing.Optional[str] = None,
    ) -> None:
        """
        :param record_columns: record_columns block.
        :param record_format: record_format block.
        :param record_encoding: 
        """
        self._values = {
            "record_columns": record_columns,
            "record_format": record_format,
        }
        if record_encoding is not None:
            self._values["record_encoding"] = record_encoding

    @builtins.property
    def record_columns(
        self,
    ) -> typing.List["KinesisAnalyticsApplicationInputsSchemaRecordColumns"]:
        """record_columns block."""
        return self._values.get("record_columns")

    @builtins.property
    def record_format(
        self,
    ) -> typing.List["KinesisAnalyticsApplicationInputsSchemaRecordFormat"]:
        """record_format block."""
        return self._values.get("record_format")

    @builtins.property
    def record_encoding(self) -> typing.Optional[str]:
        return self._values.get("record_encoding")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationInputsSchema(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsSchemaRecordColumns",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "sql_type": "sqlType", "mapping": "mapping"},
)
class KinesisAnalyticsApplicationInputsSchemaRecordColumns:
    def __init__(
        self, *, name: str, sql_type: str, mapping: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param sql_type: 
        :param mapping: 
        """
        self._values = {
            "name": name,
            "sql_type": sql_type,
        }
        if mapping is not None:
            self._values["mapping"] = mapping

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def sql_type(self) -> str:
        return self._values.get("sql_type")

    @builtins.property
    def mapping(self) -> typing.Optional[str]:
        return self._values.get("mapping")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationInputsSchemaRecordColumns(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsSchemaRecordFormat",
    jsii_struct_bases=[],
    name_mapping={"mapping_parameters": "mappingParameters"},
)
class KinesisAnalyticsApplicationInputsSchemaRecordFormat:
    def __init__(
        self,
        *,
        mapping_parameters: typing.Optional[
            typing.List[
                "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters"
            ]
        ] = None,
    ) -> None:
        """
        :param mapping_parameters: mapping_parameters block.
        """
        self._values = {}
        if mapping_parameters is not None:
            self._values["mapping_parameters"] = mapping_parameters

    @builtins.property
    def mapping_parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters"
        ]
    ]:
        """mapping_parameters block."""
        return self._values.get("mapping_parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationInputsSchemaRecordFormat(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters",
    jsii_struct_bases=[],
    name_mapping={"csv": "csv", "json": "json"},
)
class KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters:
    def __init__(
        self,
        *,
        csv: typing.Optional[
            typing.List[
                "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv"
            ]
        ] = None,
        json: typing.Optional[
            typing.List[
                "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson"
            ]
        ] = None,
    ) -> None:
        """
        :param csv: csv block.
        :param json: json block.
        """
        self._values = {}
        if csv is not None:
            self._values["csv"] = csv
        if json is not None:
            self._values["json"] = json

    @builtins.property
    def csv(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv"
        ]
    ]:
        """csv block."""
        return self._values.get("csv")

    @builtins.property
    def json(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson"
        ]
    ]:
        """json block."""
        return self._values.get("json")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv",
    jsii_struct_bases=[],
    name_mapping={
        "record_column_delimiter": "recordColumnDelimiter",
        "record_row_delimiter": "recordRowDelimiter",
    },
)
class KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv:
    def __init__(
        self, *, record_column_delimiter: str, record_row_delimiter: str
    ) -> None:
        """
        :param record_column_delimiter: 
        :param record_row_delimiter: 
        """
        self._values = {
            "record_column_delimiter": record_column_delimiter,
            "record_row_delimiter": record_row_delimiter,
        }

    @builtins.property
    def record_column_delimiter(self) -> str:
        return self._values.get("record_column_delimiter")

    @builtins.property
    def record_row_delimiter(self) -> str:
        return self._values.get("record_row_delimiter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson",
    jsii_struct_bases=[],
    name_mapping={"record_row_path": "recordRowPath"},
)
class KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson:
    def __init__(self, *, record_row_path: str) -> None:
        """
        :param record_row_path: 
        """
        self._values = {
            "record_row_path": record_row_path,
        }

    @builtins.property
    def record_row_path(self) -> str:
        return self._values.get("record_row_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationOutputs",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "schema": "schema",
        "kinesis_firehose": "kinesisFirehose",
        "kinesis_stream": "kinesisStream",
        "lambda_": "lambda",
    },
)
class KinesisAnalyticsApplicationOutputs:
    def __init__(
        self,
        *,
        name: str,
        schema: typing.List["KinesisAnalyticsApplicationOutputsSchema"],
        kinesis_firehose: typing.Optional[
            typing.List["KinesisAnalyticsApplicationOutputsKinesisFirehose"]
        ] = None,
        kinesis_stream: typing.Optional[
            typing.List["KinesisAnalyticsApplicationOutputsKinesisStream"]
        ] = None,
        lambda_: typing.Optional[
            typing.List["KinesisAnalyticsApplicationOutputsLambda"]
        ] = None,
    ) -> None:
        """
        :param name: 
        :param schema: schema block.
        :param kinesis_firehose: kinesis_firehose block.
        :param kinesis_stream: kinesis_stream block.
        :param lambda_: lambda block.
        """
        self._values = {
            "name": name,
            "schema": schema,
        }
        if kinesis_firehose is not None:
            self._values["kinesis_firehose"] = kinesis_firehose
        if kinesis_stream is not None:
            self._values["kinesis_stream"] = kinesis_stream
        if lambda_ is not None:
            self._values["lambda_"] = lambda_

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def schema(self) -> typing.List["KinesisAnalyticsApplicationOutputsSchema"]:
        """schema block."""
        return self._values.get("schema")

    @builtins.property
    def kinesis_firehose(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationOutputsKinesisFirehose"]
    ]:
        """kinesis_firehose block."""
        return self._values.get("kinesis_firehose")

    @builtins.property
    def kinesis_stream(
        self,
    ) -> typing.Optional[
        typing.List["KinesisAnalyticsApplicationOutputsKinesisStream"]
    ]:
        """kinesis_stream block."""
        return self._values.get("kinesis_stream")

    @builtins.property
    def lambda_(
        self,
    ) -> typing.Optional[typing.List["KinesisAnalyticsApplicationOutputsLambda"]]:
        """lambda block."""
        return self._values.get("lambda_")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationOutputs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationOutputsKinesisFirehose",
    jsii_struct_bases=[],
    name_mapping={"resource_arn": "resourceArn", "role_arn": "roleArn"},
)
class KinesisAnalyticsApplicationOutputsKinesisFirehose:
    def __init__(self, *, resource_arn: str, role_arn: str) -> None:
        """
        :param resource_arn: 
        :param role_arn: 
        """
        self._values = {
            "resource_arn": resource_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationOutputsKinesisFirehose(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationOutputsKinesisStream",
    jsii_struct_bases=[],
    name_mapping={"resource_arn": "resourceArn", "role_arn": "roleArn"},
)
class KinesisAnalyticsApplicationOutputsKinesisStream:
    def __init__(self, *, resource_arn: str, role_arn: str) -> None:
        """
        :param resource_arn: 
        :param role_arn: 
        """
        self._values = {
            "resource_arn": resource_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationOutputsKinesisStream(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationOutputsLambda",
    jsii_struct_bases=[],
    name_mapping={"resource_arn": "resourceArn", "role_arn": "roleArn"},
)
class KinesisAnalyticsApplicationOutputsLambda:
    def __init__(self, *, resource_arn: str, role_arn: str) -> None:
        """
        :param resource_arn: 
        :param role_arn: 
        """
        self._values = {
            "resource_arn": resource_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationOutputsLambda(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationOutputsSchema",
    jsii_struct_bases=[],
    name_mapping={"record_format_type": "recordFormatType"},
)
class KinesisAnalyticsApplicationOutputsSchema:
    def __init__(self, *, record_format_type: typing.Optional[str] = None) -> None:
        """
        :param record_format_type: 
        """
        self._values = {}
        if record_format_type is not None:
            self._values["record_format_type"] = record_format_type

    @builtins.property
    def record_format_type(self) -> typing.Optional[str]:
        return self._values.get("record_format_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationOutputsSchema(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSources",
    jsii_struct_bases=[],
    name_mapping={"s3": "s3", "schema": "schema", "table_name": "tableName"},
)
class KinesisAnalyticsApplicationReferenceDataSources:
    def __init__(
        self,
        *,
        s3: typing.List["KinesisAnalyticsApplicationReferenceDataSourcesS3"],
        schema: typing.List["KinesisAnalyticsApplicationReferenceDataSourcesSchema"],
        table_name: str,
    ) -> None:
        """
        :param s3: s3 block.
        :param schema: schema block.
        :param table_name: 
        """
        self._values = {
            "s3": s3,
            "schema": schema,
            "table_name": table_name,
        }

    @builtins.property
    def s3(self) -> typing.List["KinesisAnalyticsApplicationReferenceDataSourcesS3"]:
        """s3 block."""
        return self._values.get("s3")

    @builtins.property
    def schema(
        self,
    ) -> typing.List["KinesisAnalyticsApplicationReferenceDataSourcesSchema"]:
        """schema block."""
        return self._values.get("schema")

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationReferenceDataSources(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSourcesS3",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_arn": "bucketArn",
        "file_key": "fileKey",
        "role_arn": "roleArn",
    },
)
class KinesisAnalyticsApplicationReferenceDataSourcesS3:
    def __init__(self, *, bucket_arn: str, file_key: str, role_arn: str) -> None:
        """
        :param bucket_arn: 
        :param file_key: 
        :param role_arn: 
        """
        self._values = {
            "bucket_arn": bucket_arn,
            "file_key": file_key,
            "role_arn": role_arn,
        }

    @builtins.property
    def bucket_arn(self) -> str:
        return self._values.get("bucket_arn")

    @builtins.property
    def file_key(self) -> str:
        return self._values.get("file_key")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationReferenceDataSourcesS3(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSourcesSchema",
    jsii_struct_bases=[],
    name_mapping={
        "record_columns": "recordColumns",
        "record_format": "recordFormat",
        "record_encoding": "recordEncoding",
    },
)
class KinesisAnalyticsApplicationReferenceDataSourcesSchema:
    def __init__(
        self,
        *,
        record_columns: typing.List[
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns"
        ],
        record_format: typing.List[
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat"
        ],
        record_encoding: typing.Optional[str] = None,
    ) -> None:
        """
        :param record_columns: record_columns block.
        :param record_format: record_format block.
        :param record_encoding: 
        """
        self._values = {
            "record_columns": record_columns,
            "record_format": record_format,
        }
        if record_encoding is not None:
            self._values["record_encoding"] = record_encoding

    @builtins.property
    def record_columns(
        self,
    ) -> typing.List[
        "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns"
    ]:
        """record_columns block."""
        return self._values.get("record_columns")

    @builtins.property
    def record_format(
        self,
    ) -> typing.List[
        "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat"
    ]:
        """record_format block."""
        return self._values.get("record_format")

    @builtins.property
    def record_encoding(self) -> typing.Optional[str]:
        return self._values.get("record_encoding")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisAnalyticsApplicationReferenceDataSourcesSchema(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "sql_type": "sqlType", "mapping": "mapping"},
)
class KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns:
    def __init__(
        self, *, name: str, sql_type: str, mapping: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param sql_type: 
        :param mapping: 
        """
        self._values = {
            "name": name,
            "sql_type": sql_type,
        }
        if mapping is not None:
            self._values["mapping"] = mapping

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def sql_type(self) -> str:
        return self._values.get("sql_type")

    @builtins.property
    def mapping(self) -> typing.Optional[str]:
        return self._values.get("mapping")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat",
    jsii_struct_bases=[],
    name_mapping={"mapping_parameters": "mappingParameters"},
)
class KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat:
    def __init__(
        self,
        *,
        mapping_parameters: typing.Optional[
            typing.List[
                "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters"
            ]
        ] = None,
    ) -> None:
        """
        :param mapping_parameters: mapping_parameters block.
        """
        self._values = {}
        if mapping_parameters is not None:
            self._values["mapping_parameters"] = mapping_parameters

    @builtins.property
    def mapping_parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters"
        ]
    ]:
        """mapping_parameters block."""
        return self._values.get("mapping_parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters",
    jsii_struct_bases=[],
    name_mapping={"csv": "csv", "json": "json"},
)
class KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters:
    def __init__(
        self,
        *,
        csv: typing.Optional[
            typing.List[
                "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv"
            ]
        ] = None,
        json: typing.Optional[
            typing.List[
                "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson"
            ]
        ] = None,
    ) -> None:
        """
        :param csv: csv block.
        :param json: json block.
        """
        self._values = {}
        if csv is not None:
            self._values["csv"] = csv
        if json is not None:
            self._values["json"] = json

    @builtins.property
    def csv(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv"
        ]
    ]:
        """csv block."""
        return self._values.get("csv")

    @builtins.property
    def json(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson"
        ]
    ]:
        """json block."""
        return self._values.get("json")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv",
    jsii_struct_bases=[],
    name_mapping={
        "record_column_delimiter": "recordColumnDelimiter",
        "record_row_delimiter": "recordRowDelimiter",
    },
)
class KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv:
    def __init__(
        self, *, record_column_delimiter: str, record_row_delimiter: str
    ) -> None:
        """
        :param record_column_delimiter: 
        :param record_row_delimiter: 
        """
        self._values = {
            "record_column_delimiter": record_column_delimiter,
            "record_row_delimiter": record_row_delimiter,
        }

    @builtins.property
    def record_column_delimiter(self) -> str:
        return self._values.get("record_column_delimiter")

    @builtins.property
    def record_row_delimiter(self) -> str:
        return self._values.get("record_row_delimiter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson",
    jsii_struct_bases=[],
    name_mapping={"record_row_path": "recordRowPath"},
)
class KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson:
    def __init__(self, *, record_row_path: str) -> None:
        """
        :param record_row_path: 
        """
        self._values = {
            "record_row_path": record_row_path,
        }

    @builtins.property
    def record_row_path(self) -> str:
        return self._values.get("record_row_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class KinesisFirehoseDeliveryStream(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStream",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        destination: str,
        name: str,
        destination_id: typing.Optional[str] = None,
        elasticsearch_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamElasticsearchConfiguration"]
        ] = None,
        extended_s3_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamExtendedS3Configuration"]
        ] = None,
        kinesis_source_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamKinesisSourceConfiguration"]
        ] = None,
        redshift_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamRedshiftConfiguration"]
        ] = None,
        s3_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamS3Configuration"]
        ] = None,
        server_side_encryption: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamServerSideEncryption"]
        ] = None,
        splunk_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamSplunkConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        version_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination: 
        :param name: 
        :param destination_id: 
        :param elasticsearch_configuration: elasticsearch_configuration block.
        :param extended_s3_configuration: extended_s3_configuration block.
        :param kinesis_source_configuration: kinesis_source_configuration block.
        :param redshift_configuration: redshift_configuration block.
        :param s3_configuration: s3_configuration block.
        :param server_side_encryption: server_side_encryption block.
        :param splunk_configuration: splunk_configuration block.
        :param tags: 
        :param version_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KinesisFirehoseDeliveryStreamConfig(
            destination=destination,
            name=name,
            destination_id=destination_id,
            elasticsearch_configuration=elasticsearch_configuration,
            extended_s3_configuration=extended_s3_configuration,
            kinesis_source_configuration=kinesis_source_configuration,
            redshift_configuration=redshift_configuration,
            s3_configuration=s3_configuration,
            server_side_encryption=server_side_encryption,
            splunk_configuration=splunk_configuration,
            tags=tags,
            version_id=version_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KinesisFirehoseDeliveryStream, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="destination")
    def destination(self) -> str:
        return jsii.get(self, "destination")

    @destination.setter
    def destination(self, value: str) -> None:
        jsii.set(self, "destination", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="destinationId")
    def destination_id(self) -> typing.Optional[str]:
        return jsii.get(self, "destinationId")

    @destination_id.setter
    def destination_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "destinationId", value)

    @builtins.property
    @jsii.member(jsii_name="elasticsearchConfiguration")
    def elasticsearch_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamElasticsearchConfiguration"]
    ]:
        return jsii.get(self, "elasticsearchConfiguration")

    @elasticsearch_configuration.setter
    def elasticsearch_configuration(
        self,
        value: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamElasticsearchConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "elasticsearchConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="extendedS3Configuration")
    def extended_s3_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamExtendedS3Configuration"]
    ]:
        return jsii.get(self, "extendedS3Configuration")

    @extended_s3_configuration.setter
    def extended_s3_configuration(
        self,
        value: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamExtendedS3Configuration"]
        ],
    ) -> None:
        jsii.set(self, "extendedS3Configuration", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kinesisSourceConfiguration")
    def kinesis_source_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamKinesisSourceConfiguration"]
    ]:
        return jsii.get(self, "kinesisSourceConfiguration")

    @kinesis_source_configuration.setter
    def kinesis_source_configuration(
        self,
        value: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamKinesisSourceConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "kinesisSourceConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="redshiftConfiguration")
    def redshift_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamRedshiftConfiguration"]
    ]:
        return jsii.get(self, "redshiftConfiguration")

    @redshift_configuration.setter
    def redshift_configuration(
        self,
        value: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamRedshiftConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "redshiftConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="s3Configuration")
    def s3_configuration(
        self,
    ) -> typing.Optional[typing.List["KinesisFirehoseDeliveryStreamS3Configuration"]]:
        return jsii.get(self, "s3Configuration")

    @s3_configuration.setter
    def s3_configuration(
        self,
        value: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamS3Configuration"]
        ],
    ) -> None:
        jsii.set(self, "s3Configuration", value)

    @builtins.property
    @jsii.member(jsii_name="serverSideEncryption")
    def server_side_encryption(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamServerSideEncryption"]
    ]:
        return jsii.get(self, "serverSideEncryption")

    @server_side_encryption.setter
    def server_side_encryption(
        self,
        value: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamServerSideEncryption"]
        ],
    ) -> None:
        jsii.set(self, "serverSideEncryption", value)

    @builtins.property
    @jsii.member(jsii_name="splunkConfiguration")
    def splunk_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamSplunkConfiguration"]
    ]:
        return jsii.get(self, "splunkConfiguration")

    @splunk_configuration.setter
    def splunk_configuration(
        self,
        value: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamSplunkConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "splunkConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="versionId")
    def version_id(self) -> typing.Optional[str]:
        return jsii.get(self, "versionId")

    @version_id.setter
    def version_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "versionId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination": "destination",
        "name": "name",
        "destination_id": "destinationId",
        "elasticsearch_configuration": "elasticsearchConfiguration",
        "extended_s3_configuration": "extendedS3Configuration",
        "kinesis_source_configuration": "kinesisSourceConfiguration",
        "redshift_configuration": "redshiftConfiguration",
        "s3_configuration": "s3Configuration",
        "server_side_encryption": "serverSideEncryption",
        "splunk_configuration": "splunkConfiguration",
        "tags": "tags",
        "version_id": "versionId",
    },
)
class KinesisFirehoseDeliveryStreamConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination: str,
        name: str,
        destination_id: typing.Optional[str] = None,
        elasticsearch_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamElasticsearchConfiguration"]
        ] = None,
        extended_s3_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamExtendedS3Configuration"]
        ] = None,
        kinesis_source_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamKinesisSourceConfiguration"]
        ] = None,
        redshift_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamRedshiftConfiguration"]
        ] = None,
        s3_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamS3Configuration"]
        ] = None,
        server_side_encryption: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamServerSideEncryption"]
        ] = None,
        splunk_configuration: typing.Optional[
            typing.List["KinesisFirehoseDeliveryStreamSplunkConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        version_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination: 
        :param name: 
        :param destination_id: 
        :param elasticsearch_configuration: elasticsearch_configuration block.
        :param extended_s3_configuration: extended_s3_configuration block.
        :param kinesis_source_configuration: kinesis_source_configuration block.
        :param redshift_configuration: redshift_configuration block.
        :param s3_configuration: s3_configuration block.
        :param server_side_encryption: server_side_encryption block.
        :param splunk_configuration: splunk_configuration block.
        :param tags: 
        :param version_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "destination": destination,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if destination_id is not None:
            self._values["destination_id"] = destination_id
        if elasticsearch_configuration is not None:
            self._values["elasticsearch_configuration"] = elasticsearch_configuration
        if extended_s3_configuration is not None:
            self._values["extended_s3_configuration"] = extended_s3_configuration
        if kinesis_source_configuration is not None:
            self._values["kinesis_source_configuration"] = kinesis_source_configuration
        if redshift_configuration is not None:
            self._values["redshift_configuration"] = redshift_configuration
        if s3_configuration is not None:
            self._values["s3_configuration"] = s3_configuration
        if server_side_encryption is not None:
            self._values["server_side_encryption"] = server_side_encryption
        if splunk_configuration is not None:
            self._values["splunk_configuration"] = splunk_configuration
        if tags is not None:
            self._values["tags"] = tags
        if version_id is not None:
            self._values["version_id"] = version_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def destination(self) -> str:
        return self._values.get("destination")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def destination_id(self) -> typing.Optional[str]:
        return self._values.get("destination_id")

    @builtins.property
    def elasticsearch_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamElasticsearchConfiguration"]
    ]:
        """elasticsearch_configuration block."""
        return self._values.get("elasticsearch_configuration")

    @builtins.property
    def extended_s3_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamExtendedS3Configuration"]
    ]:
        """extended_s3_configuration block."""
        return self._values.get("extended_s3_configuration")

    @builtins.property
    def kinesis_source_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamKinesisSourceConfiguration"]
    ]:
        """kinesis_source_configuration block."""
        return self._values.get("kinesis_source_configuration")

    @builtins.property
    def redshift_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamRedshiftConfiguration"]
    ]:
        """redshift_configuration block."""
        return self._values.get("redshift_configuration")

    @builtins.property
    def s3_configuration(
        self,
    ) -> typing.Optional[typing.List["KinesisFirehoseDeliveryStreamS3Configuration"]]:
        """s3_configuration block."""
        return self._values.get("s3_configuration")

    @builtins.property
    def server_side_encryption(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamServerSideEncryption"]
    ]:
        """server_side_encryption block."""
        return self._values.get("server_side_encryption")

    @builtins.property
    def splunk_configuration(
        self,
    ) -> typing.Optional[
        typing.List["KinesisFirehoseDeliveryStreamSplunkConfiguration"]
    ]:
        """splunk_configuration block."""
        return self._values.get("splunk_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def version_id(self) -> typing.Optional[str]:
        return self._values.get("version_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseDeliveryStreamConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamElasticsearchConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "domain_arn": "domainArn",
        "index_name": "indexName",
        "role_arn": "roleArn",
        "buffering_interval": "bufferingInterval",
        "buffering_size": "bufferingSize",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "index_rotation_period": "indexRotationPeriod",
        "processing_configuration": "processingConfiguration",
        "retry_duration": "retryDuration",
        "s3_backup_mode": "s3BackupMode",
        "type_name": "typeName",
    },
)
class KinesisFirehoseDeliveryStreamElasticsearchConfiguration:
    def __init__(
        self,
        *,
        domain_arn: str,
        index_name: str,
        role_arn: str,
        buffering_interval: typing.Optional[jsii.Number] = None,
        buffering_size: typing.Optional[jsii.Number] = None,
        cloudwatch_logging_options: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamElasticsearchConfigurationCloudwatchLoggingOptions"
            ]
        ] = None,
        index_rotation_period: typing.Optional[str] = None,
        processing_configuration: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfiguration"
            ]
        ] = None,
        retry_duration: typing.Optional[jsii.Number] = None,
        s3_backup_mode: typing.Optional[str] = None,
        type_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param domain_arn: 
        :param index_name: 
        :param role_arn: 
        :param buffering_interval: 
        :param buffering_size: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param index_rotation_period: 
        :param processing_configuration: processing_configuration block.
        :param retry_duration: 
        :param s3_backup_mode: 
        :param type_name: 
        """
        self._values = {
            "domain_arn": domain_arn,
            "index_name": index_name,
            "role_arn": role_arn,
        }
        if buffering_interval is not None:
            self._values["buffering_interval"] = buffering_interval
        if buffering_size is not None:
            self._values["buffering_size"] = buffering_size
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if index_rotation_period is not None:
            self._values["index_rotation_period"] = index_rotation_period
        if processing_configuration is not None:
            self._values["processing_configuration"] = processing_configuration
        if retry_duration is not None:
            self._values["retry_duration"] = retry_duration
        if s3_backup_mode is not None:
            self._values["s3_backup_mode"] = s3_backup_mode
        if type_name is not None:
            self._values["type_name"] = type_name

    @builtins.property
    def domain_arn(self) -> str:
        return self._values.get("domain_arn")

    @builtins.property
    def index_name(self) -> str:
        return self._values.get("index_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def buffering_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffering_interval")

    @builtins.property
    def buffering_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffering_size")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationCloudwatchLoggingOptions"
        ]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def index_rotation_period(self) -> typing.Optional[str]:
        return self._values.get("index_rotation_period")

    @builtins.property
    def processing_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfiguration"
        ]
    ]:
        """processing_configuration block."""
        return self._values.get("processing_configuration")

    @builtins.property
    def retry_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("retry_duration")

    @builtins.property
    def s3_backup_mode(self) -> typing.Optional[str]:
        return self._values.get("s3_backup_mode")

    @builtins.property
    def type_name(self) -> typing.Optional[str]:
        return self._values.get("type_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamElasticsearchConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamElasticsearchConfigurationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_group_name": "logGroupName",
        "log_stream_name": "logStreamName",
    },
)
class KinesisFirehoseDeliveryStreamElasticsearchConfigurationCloudwatchLoggingOptions:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        log_group_name: typing.Optional[str] = None,
        log_stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_group_name: 
        :param log_stream_name: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if log_stream_name is not None:
            self._values["log_stream_name"] = log_stream_name

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def log_stream_name(self) -> typing.Optional[str]:
        return self._values.get("log_stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationCloudwatchLoggingOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfiguration",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "processors": "processors"},
)
class KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfiguration:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        processors: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessors"
            ]
        ] = None,
    ) -> None:
        """
        :param enabled: 
        :param processors: processors block.
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if processors is not None:
            self._values["processors"] = processors

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def processors(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessors"
        ]
    ]:
        """processors block."""
        return self._values.get("processors")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessors",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "parameters": "parameters"},
)
class KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessors:
    def __init__(
        self,
        *,
        type: str,
        parameters: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessorsParameters"
            ]
        ] = None,
    ) -> None:
        """
        :param type: 
        :param parameters: parameters block.
        """
        self._values = {
            "type": type,
        }
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessorsParameters"
        ]
    ]:
        """parameters block."""
        return self._values.get("parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessors(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessorsParameters",
    jsii_struct_bases=[],
    name_mapping={
        "parameter_name": "parameterName",
        "parameter_value": "parameterValue",
    },
)
class KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessorsParameters:
    def __init__(self, *, parameter_name: str, parameter_value: str) -> None:
        """
        :param parameter_name: 
        :param parameter_value: 
        """
        self._values = {
            "parameter_name": parameter_name,
            "parameter_value": parameter_value,
        }

    @builtins.property
    def parameter_name(self) -> str:
        return self._values.get("parameter_name")

    @builtins.property
    def parameter_value(self) -> str:
        return self._values.get("parameter_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessorsParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3Configuration",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_arn": "bucketArn",
        "role_arn": "roleArn",
        "buffer_interval": "bufferInterval",
        "buffer_size": "bufferSize",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "compression_format": "compressionFormat",
        "data_format_conversion_configuration": "dataFormatConversionConfiguration",
        "error_output_prefix": "errorOutputPrefix",
        "kms_key_arn": "kmsKeyArn",
        "prefix": "prefix",
        "processing_configuration": "processingConfiguration",
        "s3_backup_configuration": "s3BackupConfiguration",
        "s3_backup_mode": "s3BackupMode",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3Configuration:
    def __init__(
        self,
        *,
        bucket_arn: str,
        role_arn: str,
        buffer_interval: typing.Optional[jsii.Number] = None,
        buffer_size: typing.Optional[jsii.Number] = None,
        cloudwatch_logging_options: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationCloudwatchLoggingOptions"
            ]
        ] = None,
        compression_format: typing.Optional[str] = None,
        data_format_conversion_configuration: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfiguration"
            ]
        ] = None,
        error_output_prefix: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
        processing_configuration: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfiguration"
            ]
        ] = None,
        s3_backup_configuration: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfiguration"
            ]
        ] = None,
        s3_backup_mode: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_arn: 
        :param role_arn: 
        :param buffer_interval: 
        :param buffer_size: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param compression_format: 
        :param data_format_conversion_configuration: data_format_conversion_configuration block.
        :param error_output_prefix: 
        :param kms_key_arn: 
        :param prefix: 
        :param processing_configuration: processing_configuration block.
        :param s3_backup_configuration: s3_backup_configuration block.
        :param s3_backup_mode: 
        """
        self._values = {
            "bucket_arn": bucket_arn,
            "role_arn": role_arn,
        }
        if buffer_interval is not None:
            self._values["buffer_interval"] = buffer_interval
        if buffer_size is not None:
            self._values["buffer_size"] = buffer_size
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if compression_format is not None:
            self._values["compression_format"] = compression_format
        if data_format_conversion_configuration is not None:
            self._values[
                "data_format_conversion_configuration"
            ] = data_format_conversion_configuration
        if error_output_prefix is not None:
            self._values["error_output_prefix"] = error_output_prefix
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if prefix is not None:
            self._values["prefix"] = prefix
        if processing_configuration is not None:
            self._values["processing_configuration"] = processing_configuration
        if s3_backup_configuration is not None:
            self._values["s3_backup_configuration"] = s3_backup_configuration
        if s3_backup_mode is not None:
            self._values["s3_backup_mode"] = s3_backup_mode

    @builtins.property
    def bucket_arn(self) -> str:
        return self._values.get("bucket_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def buffer_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_interval")

    @builtins.property
    def buffer_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_size")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationCloudwatchLoggingOptions"
        ]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def compression_format(self) -> typing.Optional[str]:
        return self._values.get("compression_format")

    @builtins.property
    def data_format_conversion_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfiguration"
        ]
    ]:
        """data_format_conversion_configuration block."""
        return self._values.get("data_format_conversion_configuration")

    @builtins.property
    def error_output_prefix(self) -> typing.Optional[str]:
        return self._values.get("error_output_prefix")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def processing_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfiguration"
        ]
    ]:
        """processing_configuration block."""
        return self._values.get("processing_configuration")

    @builtins.property
    def s3_backup_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfiguration"
        ]
    ]:
        """s3_backup_configuration block."""
        return self._values.get("s3_backup_configuration")

    @builtins.property
    def s3_backup_mode(self) -> typing.Optional[str]:
        return self._values.get("s3_backup_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseDeliveryStreamExtendedS3Configuration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_group_name": "logGroupName",
        "log_stream_name": "logStreamName",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationCloudwatchLoggingOptions:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        log_group_name: typing.Optional[str] = None,
        log_stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_group_name: 
        :param log_stream_name: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if log_stream_name is not None:
            self._values["log_stream_name"] = log_stream_name

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def log_stream_name(self) -> typing.Optional[str]:
        return self._values.get("log_stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationCloudwatchLoggingOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "input_format_configuration": "inputFormatConfiguration",
        "output_format_configuration": "outputFormatConfiguration",
        "schema_configuration": "schemaConfiguration",
        "enabled": "enabled",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfiguration:
    def __init__(
        self,
        *,
        input_format_configuration: typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfiguration"
        ],
        output_format_configuration: typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfiguration"
        ],
        schema_configuration: typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationSchemaConfiguration"
        ],
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param input_format_configuration: input_format_configuration block.
        :param output_format_configuration: output_format_configuration block.
        :param schema_configuration: schema_configuration block.
        :param enabled: 
        """
        self._values = {
            "input_format_configuration": input_format_configuration,
            "output_format_configuration": output_format_configuration,
            "schema_configuration": schema_configuration,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def input_format_configuration(
        self,
    ) -> typing.List[
        "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfiguration"
    ]:
        """input_format_configuration block."""
        return self._values.get("input_format_configuration")

    @builtins.property
    def output_format_configuration(
        self,
    ) -> typing.List[
        "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfiguration"
    ]:
        """output_format_configuration block."""
        return self._values.get("output_format_configuration")

    @builtins.property
    def schema_configuration(
        self,
    ) -> typing.List[
        "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationSchemaConfiguration"
    ]:
        """schema_configuration block."""
        return self._values.get("schema_configuration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfiguration",
    jsii_struct_bases=[],
    name_mapping={"deserializer": "deserializer"},
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfiguration:
    def __init__(
        self,
        *,
        deserializer: typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializer"
        ],
    ) -> None:
        """
        :param deserializer: deserializer block.
        """
        self._values = {
            "deserializer": deserializer,
        }

    @builtins.property
    def deserializer(
        self,
    ) -> typing.List[
        "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializer"
    ]:
        """deserializer block."""
        return self._values.get("deserializer")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializer",
    jsii_struct_bases=[],
    name_mapping={
        "hive_json_ser_de": "hiveJsonSerDe",
        "open_x_json_ser_de": "openXJsonSerDe",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializer:
    def __init__(
        self,
        *,
        hive_json_ser_de: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerHiveJsonSerDe"
            ]
        ] = None,
        open_x_json_ser_de: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerOpenXJsonSerDe"
            ]
        ] = None,
    ) -> None:
        """
        :param hive_json_ser_de: hive_json_ser_de block.
        :param open_x_json_ser_de: open_x_json_ser_de block.
        """
        self._values = {}
        if hive_json_ser_de is not None:
            self._values["hive_json_ser_de"] = hive_json_ser_de
        if open_x_json_ser_de is not None:
            self._values["open_x_json_ser_de"] = open_x_json_ser_de

    @builtins.property
    def hive_json_ser_de(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerHiveJsonSerDe"
        ]
    ]:
        """hive_json_ser_de block."""
        return self._values.get("hive_json_ser_de")

    @builtins.property
    def open_x_json_ser_de(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerOpenXJsonSerDe"
        ]
    ]:
        """open_x_json_ser_de block."""
        return self._values.get("open_x_json_ser_de")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializer(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerHiveJsonSerDe",
    jsii_struct_bases=[],
    name_mapping={"timestamp_formats": "timestampFormats"},
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerHiveJsonSerDe:
    def __init__(
        self, *, timestamp_formats: typing.Optional[typing.List[str]] = None
    ) -> None:
        """
        :param timestamp_formats: 
        """
        self._values = {}
        if timestamp_formats is not None:
            self._values["timestamp_formats"] = timestamp_formats

    @builtins.property
    def timestamp_formats(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("timestamp_formats")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerHiveJsonSerDe(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerOpenXJsonSerDe",
    jsii_struct_bases=[],
    name_mapping={
        "case_insensitive": "caseInsensitive",
        "column_to_json_key_mappings": "columnToJsonKeyMappings",
        "convert_dots_in_json_keys_to_underscores": "convertDotsInJsonKeysToUnderscores",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerOpenXJsonSerDe:
    def __init__(
        self,
        *,
        case_insensitive: typing.Optional[bool] = None,
        column_to_json_key_mappings: typing.Optional[typing.Mapping[str, str]] = None,
        convert_dots_in_json_keys_to_underscores: typing.Optional[bool] = None,
    ) -> None:
        """
        :param case_insensitive: 
        :param column_to_json_key_mappings: 
        :param convert_dots_in_json_keys_to_underscores: 
        """
        self._values = {}
        if case_insensitive is not None:
            self._values["case_insensitive"] = case_insensitive
        if column_to_json_key_mappings is not None:
            self._values["column_to_json_key_mappings"] = column_to_json_key_mappings
        if convert_dots_in_json_keys_to_underscores is not None:
            self._values[
                "convert_dots_in_json_keys_to_underscores"
            ] = convert_dots_in_json_keys_to_underscores

    @builtins.property
    def case_insensitive(self) -> typing.Optional[bool]:
        return self._values.get("case_insensitive")

    @builtins.property
    def column_to_json_key_mappings(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("column_to_json_key_mappings")

    @builtins.property
    def convert_dots_in_json_keys_to_underscores(self) -> typing.Optional[bool]:
        return self._values.get("convert_dots_in_json_keys_to_underscores")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerOpenXJsonSerDe(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfiguration",
    jsii_struct_bases=[],
    name_mapping={"serializer": "serializer"},
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfiguration:
    def __init__(
        self,
        *,
        serializer: typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializer"
        ],
    ) -> None:
        """
        :param serializer: serializer block.
        """
        self._values = {
            "serializer": serializer,
        }

    @builtins.property
    def serializer(
        self,
    ) -> typing.List[
        "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializer"
    ]:
        """serializer block."""
        return self._values.get("serializer")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializer",
    jsii_struct_bases=[],
    name_mapping={"orc_ser_de": "orcSerDe", "parquet_ser_de": "parquetSerDe"},
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializer:
    def __init__(
        self,
        *,
        orc_ser_de: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerOrcSerDe"
            ]
        ] = None,
        parquet_ser_de: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerParquetSerDe"
            ]
        ] = None,
    ) -> None:
        """
        :param orc_ser_de: orc_ser_de block.
        :param parquet_ser_de: parquet_ser_de block.
        """
        self._values = {}
        if orc_ser_de is not None:
            self._values["orc_ser_de"] = orc_ser_de
        if parquet_ser_de is not None:
            self._values["parquet_ser_de"] = parquet_ser_de

    @builtins.property
    def orc_ser_de(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerOrcSerDe"
        ]
    ]:
        """orc_ser_de block."""
        return self._values.get("orc_ser_de")

    @builtins.property
    def parquet_ser_de(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerParquetSerDe"
        ]
    ]:
        """parquet_ser_de block."""
        return self._values.get("parquet_ser_de")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializer(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerOrcSerDe",
    jsii_struct_bases=[],
    name_mapping={
        "block_size_bytes": "blockSizeBytes",
        "bloom_filter_columns": "bloomFilterColumns",
        "bloom_filter_false_positive_probability": "bloomFilterFalsePositiveProbability",
        "compression": "compression",
        "dictionary_key_threshold": "dictionaryKeyThreshold",
        "enable_padding": "enablePadding",
        "format_version": "formatVersion",
        "padding_tolerance": "paddingTolerance",
        "row_index_stride": "rowIndexStride",
        "stripe_size_bytes": "stripeSizeBytes",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerOrcSerDe:
    def __init__(
        self,
        *,
        block_size_bytes: typing.Optional[jsii.Number] = None,
        bloom_filter_columns: typing.Optional[typing.List[str]] = None,
        bloom_filter_false_positive_probability: typing.Optional[jsii.Number] = None,
        compression: typing.Optional[str] = None,
        dictionary_key_threshold: typing.Optional[jsii.Number] = None,
        enable_padding: typing.Optional[bool] = None,
        format_version: typing.Optional[str] = None,
        padding_tolerance: typing.Optional[jsii.Number] = None,
        row_index_stride: typing.Optional[jsii.Number] = None,
        stripe_size_bytes: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param block_size_bytes: 
        :param bloom_filter_columns: 
        :param bloom_filter_false_positive_probability: 
        :param compression: 
        :param dictionary_key_threshold: 
        :param enable_padding: 
        :param format_version: 
        :param padding_tolerance: 
        :param row_index_stride: 
        :param stripe_size_bytes: 
        """
        self._values = {}
        if block_size_bytes is not None:
            self._values["block_size_bytes"] = block_size_bytes
        if bloom_filter_columns is not None:
            self._values["bloom_filter_columns"] = bloom_filter_columns
        if bloom_filter_false_positive_probability is not None:
            self._values[
                "bloom_filter_false_positive_probability"
            ] = bloom_filter_false_positive_probability
        if compression is not None:
            self._values["compression"] = compression
        if dictionary_key_threshold is not None:
            self._values["dictionary_key_threshold"] = dictionary_key_threshold
        if enable_padding is not None:
            self._values["enable_padding"] = enable_padding
        if format_version is not None:
            self._values["format_version"] = format_version
        if padding_tolerance is not None:
            self._values["padding_tolerance"] = padding_tolerance
        if row_index_stride is not None:
            self._values["row_index_stride"] = row_index_stride
        if stripe_size_bytes is not None:
            self._values["stripe_size_bytes"] = stripe_size_bytes

    @builtins.property
    def block_size_bytes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("block_size_bytes")

    @builtins.property
    def bloom_filter_columns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("bloom_filter_columns")

    @builtins.property
    def bloom_filter_false_positive_probability(self) -> typing.Optional[jsii.Number]:
        return self._values.get("bloom_filter_false_positive_probability")

    @builtins.property
    def compression(self) -> typing.Optional[str]:
        return self._values.get("compression")

    @builtins.property
    def dictionary_key_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("dictionary_key_threshold")

    @builtins.property
    def enable_padding(self) -> typing.Optional[bool]:
        return self._values.get("enable_padding")

    @builtins.property
    def format_version(self) -> typing.Optional[str]:
        return self._values.get("format_version")

    @builtins.property
    def padding_tolerance(self) -> typing.Optional[jsii.Number]:
        return self._values.get("padding_tolerance")

    @builtins.property
    def row_index_stride(self) -> typing.Optional[jsii.Number]:
        return self._values.get("row_index_stride")

    @builtins.property
    def stripe_size_bytes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("stripe_size_bytes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerOrcSerDe(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerParquetSerDe",
    jsii_struct_bases=[],
    name_mapping={
        "block_size_bytes": "blockSizeBytes",
        "compression": "compression",
        "enable_dictionary_compression": "enableDictionaryCompression",
        "max_padding_bytes": "maxPaddingBytes",
        "page_size_bytes": "pageSizeBytes",
        "writer_version": "writerVersion",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerParquetSerDe:
    def __init__(
        self,
        *,
        block_size_bytes: typing.Optional[jsii.Number] = None,
        compression: typing.Optional[str] = None,
        enable_dictionary_compression: typing.Optional[bool] = None,
        max_padding_bytes: typing.Optional[jsii.Number] = None,
        page_size_bytes: typing.Optional[jsii.Number] = None,
        writer_version: typing.Optional[str] = None,
    ) -> None:
        """
        :param block_size_bytes: 
        :param compression: 
        :param enable_dictionary_compression: 
        :param max_padding_bytes: 
        :param page_size_bytes: 
        :param writer_version: 
        """
        self._values = {}
        if block_size_bytes is not None:
            self._values["block_size_bytes"] = block_size_bytes
        if compression is not None:
            self._values["compression"] = compression
        if enable_dictionary_compression is not None:
            self._values[
                "enable_dictionary_compression"
            ] = enable_dictionary_compression
        if max_padding_bytes is not None:
            self._values["max_padding_bytes"] = max_padding_bytes
        if page_size_bytes is not None:
            self._values["page_size_bytes"] = page_size_bytes
        if writer_version is not None:
            self._values["writer_version"] = writer_version

    @builtins.property
    def block_size_bytes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("block_size_bytes")

    @builtins.property
    def compression(self) -> typing.Optional[str]:
        return self._values.get("compression")

    @builtins.property
    def enable_dictionary_compression(self) -> typing.Optional[bool]:
        return self._values.get("enable_dictionary_compression")

    @builtins.property
    def max_padding_bytes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_padding_bytes")

    @builtins.property
    def page_size_bytes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("page_size_bytes")

    @builtins.property
    def writer_version(self) -> typing.Optional[str]:
        return self._values.get("writer_version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerParquetSerDe(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationSchemaConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "database_name": "databaseName",
        "role_arn": "roleArn",
        "table_name": "tableName",
        "catalog_id": "catalogId",
        "region": "region",
        "version_id": "versionId",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationSchemaConfiguration:
    def __init__(
        self,
        *,
        database_name: str,
        role_arn: str,
        table_name: str,
        catalog_id: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        version_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param database_name: 
        :param role_arn: 
        :param table_name: 
        :param catalog_id: 
        :param region: 
        :param version_id: 
        """
        self._values = {
            "database_name": database_name,
            "role_arn": role_arn,
            "table_name": table_name,
        }
        if catalog_id is not None:
            self._values["catalog_id"] = catalog_id
        if region is not None:
            self._values["region"] = region
        if version_id is not None:
            self._values["version_id"] = version_id

    @builtins.property
    def database_name(self) -> str:
        return self._values.get("database_name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def table_name(self) -> str:
        return self._values.get("table_name")

    @builtins.property
    def catalog_id(self) -> typing.Optional[str]:
        return self._values.get("catalog_id")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    @builtins.property
    def version_id(self) -> typing.Optional[str]:
        return self._values.get("version_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationSchemaConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfiguration",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "processors": "processors"},
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfiguration:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        processors: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessors"
            ]
        ] = None,
    ) -> None:
        """
        :param enabled: 
        :param processors: processors block.
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if processors is not None:
            self._values["processors"] = processors

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def processors(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessors"
        ]
    ]:
        """processors block."""
        return self._values.get("processors")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessors",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "parameters": "parameters"},
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessors:
    def __init__(
        self,
        *,
        type: str,
        parameters: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessorsParameters"
            ]
        ] = None,
    ) -> None:
        """
        :param type: 
        :param parameters: parameters block.
        """
        self._values = {
            "type": type,
        }
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessorsParameters"
        ]
    ]:
        """parameters block."""
        return self._values.get("parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessors(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessorsParameters",
    jsii_struct_bases=[],
    name_mapping={
        "parameter_name": "parameterName",
        "parameter_value": "parameterValue",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessorsParameters:
    def __init__(self, *, parameter_name: str, parameter_value: str) -> None:
        """
        :param parameter_name: 
        :param parameter_value: 
        """
        self._values = {
            "parameter_name": parameter_name,
            "parameter_value": parameter_value,
        }

    @builtins.property
    def parameter_name(self) -> str:
        return self._values.get("parameter_name")

    @builtins.property
    def parameter_value(self) -> str:
        return self._values.get("parameter_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessorsParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_arn": "bucketArn",
        "role_arn": "roleArn",
        "buffer_interval": "bufferInterval",
        "buffer_size": "bufferSize",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "compression_format": "compressionFormat",
        "kms_key_arn": "kmsKeyArn",
        "prefix": "prefix",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfiguration:
    def __init__(
        self,
        *,
        bucket_arn: str,
        role_arn: str,
        buffer_interval: typing.Optional[jsii.Number] = None,
        buffer_size: typing.Optional[jsii.Number] = None,
        cloudwatch_logging_options: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfigurationCloudwatchLoggingOptions"
            ]
        ] = None,
        compression_format: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_arn: 
        :param role_arn: 
        :param buffer_interval: 
        :param buffer_size: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param compression_format: 
        :param kms_key_arn: 
        :param prefix: 
        """
        self._values = {
            "bucket_arn": bucket_arn,
            "role_arn": role_arn,
        }
        if buffer_interval is not None:
            self._values["buffer_interval"] = buffer_interval
        if buffer_size is not None:
            self._values["buffer_size"] = buffer_size
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if compression_format is not None:
            self._values["compression_format"] = compression_format
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket_arn(self) -> str:
        return self._values.get("bucket_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def buffer_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_interval")

    @builtins.property
    def buffer_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_size")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfigurationCloudwatchLoggingOptions"
        ]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def compression_format(self) -> typing.Optional[str]:
        return self._values.get("compression_format")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfigurationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_group_name": "logGroupName",
        "log_stream_name": "logStreamName",
    },
)
class KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfigurationCloudwatchLoggingOptions:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        log_group_name: typing.Optional[str] = None,
        log_stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_group_name: 
        :param log_stream_name: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if log_stream_name is not None:
            self._values["log_stream_name"] = log_stream_name

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def log_stream_name(self) -> typing.Optional[str]:
        return self._values.get("log_stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfigurationCloudwatchLoggingOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamKinesisSourceConfiguration",
    jsii_struct_bases=[],
    name_mapping={"kinesis_stream_arn": "kinesisStreamArn", "role_arn": "roleArn"},
)
class KinesisFirehoseDeliveryStreamKinesisSourceConfiguration:
    def __init__(self, *, kinesis_stream_arn: str, role_arn: str) -> None:
        """
        :param kinesis_stream_arn: 
        :param role_arn: 
        """
        self._values = {
            "kinesis_stream_arn": kinesis_stream_arn,
            "role_arn": role_arn,
        }

    @builtins.property
    def kinesis_stream_arn(self) -> str:
        return self._values.get("kinesis_stream_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamKinesisSourceConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamRedshiftConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "cluster_jdbcurl": "clusterJdbcurl",
        "data_table_name": "dataTableName",
        "password": "password",
        "role_arn": "roleArn",
        "username": "username",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "copy_options": "copyOptions",
        "data_table_columns": "dataTableColumns",
        "processing_configuration": "processingConfiguration",
        "retry_duration": "retryDuration",
        "s3_backup_configuration": "s3BackupConfiguration",
        "s3_backup_mode": "s3BackupMode",
    },
)
class KinesisFirehoseDeliveryStreamRedshiftConfiguration:
    def __init__(
        self,
        *,
        cluster_jdbcurl: str,
        data_table_name: str,
        password: str,
        role_arn: str,
        username: str,
        cloudwatch_logging_options: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamRedshiftConfigurationCloudwatchLoggingOptions"
            ]
        ] = None,
        copy_options: typing.Optional[str] = None,
        data_table_columns: typing.Optional[str] = None,
        processing_configuration: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfiguration"
            ]
        ] = None,
        retry_duration: typing.Optional[jsii.Number] = None,
        s3_backup_configuration: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfiguration"
            ]
        ] = None,
        s3_backup_mode: typing.Optional[str] = None,
    ) -> None:
        """
        :param cluster_jdbcurl: 
        :param data_table_name: 
        :param password: 
        :param role_arn: 
        :param username: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param copy_options: 
        :param data_table_columns: 
        :param processing_configuration: processing_configuration block.
        :param retry_duration: 
        :param s3_backup_configuration: s3_backup_configuration block.
        :param s3_backup_mode: 
        """
        self._values = {
            "cluster_jdbcurl": cluster_jdbcurl,
            "data_table_name": data_table_name,
            "password": password,
            "role_arn": role_arn,
            "username": username,
        }
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if copy_options is not None:
            self._values["copy_options"] = copy_options
        if data_table_columns is not None:
            self._values["data_table_columns"] = data_table_columns
        if processing_configuration is not None:
            self._values["processing_configuration"] = processing_configuration
        if retry_duration is not None:
            self._values["retry_duration"] = retry_duration
        if s3_backup_configuration is not None:
            self._values["s3_backup_configuration"] = s3_backup_configuration
        if s3_backup_mode is not None:
            self._values["s3_backup_mode"] = s3_backup_mode

    @builtins.property
    def cluster_jdbcurl(self) -> str:
        return self._values.get("cluster_jdbcurl")

    @builtins.property
    def data_table_name(self) -> str:
        return self._values.get("data_table_name")

    @builtins.property
    def password(self) -> str:
        return self._values.get("password")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def username(self) -> str:
        return self._values.get("username")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationCloudwatchLoggingOptions"
        ]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def copy_options(self) -> typing.Optional[str]:
        return self._values.get("copy_options")

    @builtins.property
    def data_table_columns(self) -> typing.Optional[str]:
        return self._values.get("data_table_columns")

    @builtins.property
    def processing_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfiguration"
        ]
    ]:
        """processing_configuration block."""
        return self._values.get("processing_configuration")

    @builtins.property
    def retry_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("retry_duration")

    @builtins.property
    def s3_backup_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfiguration"
        ]
    ]:
        """s3_backup_configuration block."""
        return self._values.get("s3_backup_configuration")

    @builtins.property
    def s3_backup_mode(self) -> typing.Optional[str]:
        return self._values.get("s3_backup_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseDeliveryStreamRedshiftConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamRedshiftConfigurationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_group_name": "logGroupName",
        "log_stream_name": "logStreamName",
    },
)
class KinesisFirehoseDeliveryStreamRedshiftConfigurationCloudwatchLoggingOptions:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        log_group_name: typing.Optional[str] = None,
        log_stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_group_name: 
        :param log_stream_name: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if log_stream_name is not None:
            self._values["log_stream_name"] = log_stream_name

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def log_stream_name(self) -> typing.Optional[str]:
        return self._values.get("log_stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationCloudwatchLoggingOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfiguration",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "processors": "processors"},
)
class KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfiguration:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        processors: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessors"
            ]
        ] = None,
    ) -> None:
        """
        :param enabled: 
        :param processors: processors block.
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if processors is not None:
            self._values["processors"] = processors

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def processors(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessors"
        ]
    ]:
        """processors block."""
        return self._values.get("processors")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessors",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "parameters": "parameters"},
)
class KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessors:
    def __init__(
        self,
        *,
        type: str,
        parameters: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessorsParameters"
            ]
        ] = None,
    ) -> None:
        """
        :param type: 
        :param parameters: parameters block.
        """
        self._values = {
            "type": type,
        }
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessorsParameters"
        ]
    ]:
        """parameters block."""
        return self._values.get("parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessors(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessorsParameters",
    jsii_struct_bases=[],
    name_mapping={
        "parameter_name": "parameterName",
        "parameter_value": "parameterValue",
    },
)
class KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessorsParameters:
    def __init__(self, *, parameter_name: str, parameter_value: str) -> None:
        """
        :param parameter_name: 
        :param parameter_value: 
        """
        self._values = {
            "parameter_name": parameter_name,
            "parameter_value": parameter_value,
        }

    @builtins.property
    def parameter_name(self) -> str:
        return self._values.get("parameter_name")

    @builtins.property
    def parameter_value(self) -> str:
        return self._values.get("parameter_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessorsParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_arn": "bucketArn",
        "role_arn": "roleArn",
        "buffer_interval": "bufferInterval",
        "buffer_size": "bufferSize",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "compression_format": "compressionFormat",
        "kms_key_arn": "kmsKeyArn",
        "prefix": "prefix",
    },
)
class KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfiguration:
    def __init__(
        self,
        *,
        bucket_arn: str,
        role_arn: str,
        buffer_interval: typing.Optional[jsii.Number] = None,
        buffer_size: typing.Optional[jsii.Number] = None,
        cloudwatch_logging_options: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfigurationCloudwatchLoggingOptions"
            ]
        ] = None,
        compression_format: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_arn: 
        :param role_arn: 
        :param buffer_interval: 
        :param buffer_size: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param compression_format: 
        :param kms_key_arn: 
        :param prefix: 
        """
        self._values = {
            "bucket_arn": bucket_arn,
            "role_arn": role_arn,
        }
        if buffer_interval is not None:
            self._values["buffer_interval"] = buffer_interval
        if buffer_size is not None:
            self._values["buffer_size"] = buffer_size
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if compression_format is not None:
            self._values["compression_format"] = compression_format
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket_arn(self) -> str:
        return self._values.get("bucket_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def buffer_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_interval")

    @builtins.property
    def buffer_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_size")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfigurationCloudwatchLoggingOptions"
        ]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def compression_format(self) -> typing.Optional[str]:
        return self._values.get("compression_format")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfigurationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_group_name": "logGroupName",
        "log_stream_name": "logStreamName",
    },
)
class KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfigurationCloudwatchLoggingOptions:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        log_group_name: typing.Optional[str] = None,
        log_stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_group_name: 
        :param log_stream_name: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if log_stream_name is not None:
            self._values["log_stream_name"] = log_stream_name

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def log_stream_name(self) -> typing.Optional[str]:
        return self._values.get("log_stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfigurationCloudwatchLoggingOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamS3Configuration",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_arn": "bucketArn",
        "role_arn": "roleArn",
        "buffer_interval": "bufferInterval",
        "buffer_size": "bufferSize",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "compression_format": "compressionFormat",
        "kms_key_arn": "kmsKeyArn",
        "prefix": "prefix",
    },
)
class KinesisFirehoseDeliveryStreamS3Configuration:
    def __init__(
        self,
        *,
        bucket_arn: str,
        role_arn: str,
        buffer_interval: typing.Optional[jsii.Number] = None,
        buffer_size: typing.Optional[jsii.Number] = None,
        cloudwatch_logging_options: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamS3ConfigurationCloudwatchLoggingOptions"
            ]
        ] = None,
        compression_format: typing.Optional[str] = None,
        kms_key_arn: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_arn: 
        :param role_arn: 
        :param buffer_interval: 
        :param buffer_size: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param compression_format: 
        :param kms_key_arn: 
        :param prefix: 
        """
        self._values = {
            "bucket_arn": bucket_arn,
            "role_arn": role_arn,
        }
        if buffer_interval is not None:
            self._values["buffer_interval"] = buffer_interval
        if buffer_size is not None:
            self._values["buffer_size"] = buffer_size
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if compression_format is not None:
            self._values["compression_format"] = compression_format
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket_arn(self) -> str:
        return self._values.get("bucket_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def buffer_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_interval")

    @builtins.property
    def buffer_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("buffer_size")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamS3ConfigurationCloudwatchLoggingOptions"
        ]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def compression_format(self) -> typing.Optional[str]:
        return self._values.get("compression_format")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseDeliveryStreamS3Configuration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamS3ConfigurationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_group_name": "logGroupName",
        "log_stream_name": "logStreamName",
    },
)
class KinesisFirehoseDeliveryStreamS3ConfigurationCloudwatchLoggingOptions:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        log_group_name: typing.Optional[str] = None,
        log_stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_group_name: 
        :param log_stream_name: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if log_stream_name is not None:
            self._values["log_stream_name"] = log_stream_name

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def log_stream_name(self) -> typing.Optional[str]:
        return self._values.get("log_stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamS3ConfigurationCloudwatchLoggingOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamServerSideEncryption",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class KinesisFirehoseDeliveryStreamServerSideEncryption:
    def __init__(self, *, enabled: typing.Optional[bool] = None) -> None:
        """
        :param enabled: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseDeliveryStreamServerSideEncryption(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamSplunkConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "hec_endpoint": "hecEndpoint",
        "hec_token": "hecToken",
        "cloudwatch_logging_options": "cloudwatchLoggingOptions",
        "hec_acknowledgment_timeout": "hecAcknowledgmentTimeout",
        "hec_endpoint_type": "hecEndpointType",
        "processing_configuration": "processingConfiguration",
        "retry_duration": "retryDuration",
        "s3_backup_mode": "s3BackupMode",
    },
)
class KinesisFirehoseDeliveryStreamSplunkConfiguration:
    def __init__(
        self,
        *,
        hec_endpoint: str,
        hec_token: str,
        cloudwatch_logging_options: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamSplunkConfigurationCloudwatchLoggingOptions"
            ]
        ] = None,
        hec_acknowledgment_timeout: typing.Optional[jsii.Number] = None,
        hec_endpoint_type: typing.Optional[str] = None,
        processing_configuration: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfiguration"
            ]
        ] = None,
        retry_duration: typing.Optional[jsii.Number] = None,
        s3_backup_mode: typing.Optional[str] = None,
    ) -> None:
        """
        :param hec_endpoint: 
        :param hec_token: 
        :param cloudwatch_logging_options: cloudwatch_logging_options block.
        :param hec_acknowledgment_timeout: 
        :param hec_endpoint_type: 
        :param processing_configuration: processing_configuration block.
        :param retry_duration: 
        :param s3_backup_mode: 
        """
        self._values = {
            "hec_endpoint": hec_endpoint,
            "hec_token": hec_token,
        }
        if cloudwatch_logging_options is not None:
            self._values["cloudwatch_logging_options"] = cloudwatch_logging_options
        if hec_acknowledgment_timeout is not None:
            self._values["hec_acknowledgment_timeout"] = hec_acknowledgment_timeout
        if hec_endpoint_type is not None:
            self._values["hec_endpoint_type"] = hec_endpoint_type
        if processing_configuration is not None:
            self._values["processing_configuration"] = processing_configuration
        if retry_duration is not None:
            self._values["retry_duration"] = retry_duration
        if s3_backup_mode is not None:
            self._values["s3_backup_mode"] = s3_backup_mode

    @builtins.property
    def hec_endpoint(self) -> str:
        return self._values.get("hec_endpoint")

    @builtins.property
    def hec_token(self) -> str:
        return self._values.get("hec_token")

    @builtins.property
    def cloudwatch_logging_options(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamSplunkConfigurationCloudwatchLoggingOptions"
        ]
    ]:
        """cloudwatch_logging_options block."""
        return self._values.get("cloudwatch_logging_options")

    @builtins.property
    def hec_acknowledgment_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("hec_acknowledgment_timeout")

    @builtins.property
    def hec_endpoint_type(self) -> typing.Optional[str]:
        return self._values.get("hec_endpoint_type")

    @builtins.property
    def processing_configuration(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfiguration"
        ]
    ]:
        """processing_configuration block."""
        return self._values.get("processing_configuration")

    @builtins.property
    def retry_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("retry_duration")

    @builtins.property
    def s3_backup_mode(self) -> typing.Optional[str]:
        return self._values.get("s3_backup_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisFirehoseDeliveryStreamSplunkConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamSplunkConfigurationCloudwatchLoggingOptions",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "log_group_name": "logGroupName",
        "log_stream_name": "logStreamName",
    },
)
class KinesisFirehoseDeliveryStreamSplunkConfigurationCloudwatchLoggingOptions:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        log_group_name: typing.Optional[str] = None,
        log_stream_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param log_group_name: 
        :param log_stream_name: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if log_group_name is not None:
            self._values["log_group_name"] = log_group_name
        if log_stream_name is not None:
            self._values["log_stream_name"] = log_stream_name

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def log_group_name(self) -> typing.Optional[str]:
        return self._values.get("log_group_name")

    @builtins.property
    def log_stream_name(self) -> typing.Optional[str]:
        return self._values.get("log_stream_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamSplunkConfigurationCloudwatchLoggingOptions(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfiguration",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "processors": "processors"},
)
class KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfiguration:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        processors: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessors"
            ]
        ] = None,
    ) -> None:
        """
        :param enabled: 
        :param processors: processors block.
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if processors is not None:
            self._values["processors"] = processors

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def processors(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessors"
        ]
    ]:
        """processors block."""
        return self._values.get("processors")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfiguration(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessors",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "parameters": "parameters"},
)
class KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessors:
    def __init__(
        self,
        *,
        type: str,
        parameters: typing.Optional[
            typing.List[
                "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessorsParameters"
            ]
        ] = None,
    ) -> None:
        """
        :param type: 
        :param parameters: parameters block.
        """
        self._values = {
            "type": type,
        }
        if parameters is not None:
            self._values["parameters"] = parameters

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessorsParameters"
        ]
    ]:
        """parameters block."""
        return self._values.get("parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessors(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessorsParameters",
    jsii_struct_bases=[],
    name_mapping={
        "parameter_name": "parameterName",
        "parameter_value": "parameterValue",
    },
)
class KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessorsParameters:
    def __init__(self, *, parameter_name: str, parameter_value: str) -> None:
        """
        :param parameter_name: 
        :param parameter_value: 
        """
        self._values = {
            "parameter_name": parameter_name,
            "parameter_value": parameter_value,
        }

    @builtins.property
    def parameter_name(self) -> str:
        return self._values.get("parameter_name")

    @builtins.property
    def parameter_value(self) -> str:
        return self._values.get("parameter_value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessorsParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class KinesisStream(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisStream",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        shard_count: jsii.Number,
        encryption_type: typing.Optional[str] = None,
        enforce_consumer_deletion: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        retention_period: typing.Optional[jsii.Number] = None,
        shard_level_metrics: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["KinesisStreamTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param shard_count: 
        :param encryption_type: 
        :param enforce_consumer_deletion: 
        :param kms_key_id: 
        :param retention_period: 
        :param shard_level_metrics: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KinesisStreamConfig(
            name=name,
            shard_count=shard_count,
            encryption_type=encryption_type,
            enforce_consumer_deletion=enforce_consumer_deletion,
            kms_key_id=kms_key_id,
            retention_period=retention_period,
            shard_level_metrics=shard_level_metrics,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KinesisStream, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="shardCount")
    def shard_count(self) -> jsii.Number:
        return jsii.get(self, "shardCount")

    @shard_count.setter
    def shard_count(self, value: jsii.Number) -> None:
        jsii.set(self, "shardCount", value)

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="encryptionType")
    def encryption_type(self) -> typing.Optional[str]:
        return jsii.get(self, "encryptionType")

    @encryption_type.setter
    def encryption_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "encryptionType", value)

    @builtins.property
    @jsii.member(jsii_name="enforceConsumerDeletion")
    def enforce_consumer_deletion(self) -> typing.Optional[bool]:
        return jsii.get(self, "enforceConsumerDeletion")

    @enforce_consumer_deletion.setter
    def enforce_consumer_deletion(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enforceConsumerDeletion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="retentionPeriod")
    def retention_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "retentionPeriod")

    @retention_period.setter
    def retention_period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "retentionPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="shardLevelMetrics")
    def shard_level_metrics(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "shardLevelMetrics")

    @shard_level_metrics.setter
    def shard_level_metrics(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "shardLevelMetrics", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KinesisStreamTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["KinesisStreamTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisStreamConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "shard_count": "shardCount",
        "encryption_type": "encryptionType",
        "enforce_consumer_deletion": "enforceConsumerDeletion",
        "kms_key_id": "kmsKeyId",
        "retention_period": "retentionPeriod",
        "shard_level_metrics": "shardLevelMetrics",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class KinesisStreamConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        shard_count: jsii.Number,
        encryption_type: typing.Optional[str] = None,
        enforce_consumer_deletion: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        retention_period: typing.Optional[jsii.Number] = None,
        shard_level_metrics: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["KinesisStreamTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param shard_count: 
        :param encryption_type: 
        :param enforce_consumer_deletion: 
        :param kms_key_id: 
        :param retention_period: 
        :param shard_level_metrics: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KinesisStreamTimeouts(**timeouts)
        self._values = {
            "name": name,
            "shard_count": shard_count,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if encryption_type is not None:
            self._values["encryption_type"] = encryption_type
        if enforce_consumer_deletion is not None:
            self._values["enforce_consumer_deletion"] = enforce_consumer_deletion
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if retention_period is not None:
            self._values["retention_period"] = retention_period
        if shard_level_metrics is not None:
            self._values["shard_level_metrics"] = shard_level_metrics
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def shard_count(self) -> jsii.Number:
        return self._values.get("shard_count")

    @builtins.property
    def encryption_type(self) -> typing.Optional[str]:
        return self._values.get("encryption_type")

    @builtins.property
    def enforce_consumer_deletion(self) -> typing.Optional[bool]:
        return self._values.get("enforce_consumer_deletion")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("retention_period")

    @builtins.property
    def shard_level_metrics(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("shard_level_metrics")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["KinesisStreamTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisStreamConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisStreamTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class KinesisStreamTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisStreamTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KinesisVideoStream(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisVideoStream",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        data_retention_in_hours: typing.Optional[jsii.Number] = None,
        device_name: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        media_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["KinesisVideoStreamTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param data_retention_in_hours: 
        :param device_name: 
        :param kms_key_id: 
        :param media_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KinesisVideoStreamConfig(
            name=name,
            data_retention_in_hours=data_retention_in_hours,
            device_name=device_name,
            kms_key_id=kms_key_id,
            media_type=media_type,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KinesisVideoStream, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="creationTime")
    def creation_time(self) -> str:
        return jsii.get(self, "creationTime")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="dataRetentionInHours")
    def data_retention_in_hours(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "dataRetentionInHours")

    @data_retention_in_hours.setter
    def data_retention_in_hours(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "dataRetentionInHours", value)

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> typing.Optional[str]:
        return jsii.get(self, "deviceName")

    @device_name.setter
    def device_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deviceName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="mediaType")
    def media_type(self) -> typing.Optional[str]:
        return jsii.get(self, "mediaType")

    @media_type.setter
    def media_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "mediaType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["KinesisVideoStreamTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["KinesisVideoStreamTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisVideoStreamConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "data_retention_in_hours": "dataRetentionInHours",
        "device_name": "deviceName",
        "kms_key_id": "kmsKeyId",
        "media_type": "mediaType",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class KinesisVideoStreamConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        data_retention_in_hours: typing.Optional[jsii.Number] = None,
        device_name: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        media_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["KinesisVideoStreamTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param data_retention_in_hours: 
        :param device_name: 
        :param kms_key_id: 
        :param media_type: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = KinesisVideoStreamTimeouts(**timeouts)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if data_retention_in_hours is not None:
            self._values["data_retention_in_hours"] = data_retention_in_hours
        if device_name is not None:
            self._values["device_name"] = device_name
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if media_type is not None:
            self._values["media_type"] = media_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def data_retention_in_hours(self) -> typing.Optional[jsii.Number]:
        return self._values.get("data_retention_in_hours")

    @builtins.property
    def device_name(self) -> typing.Optional[str]:
        return self._values.get("device_name")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def media_type(self) -> typing.Optional[str]:
        return self._values.get("media_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["KinesisVideoStreamTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisVideoStreamConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KinesisVideoStreamTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class KinesisVideoStreamTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KinesisVideoStreamTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsAlias(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KmsAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        target_key_id: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param target_key_id: 
        :param name: 
        :param name_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KmsAliasConfig(
            target_key_id=target_key_id,
            name=name,
            name_prefix=name_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KmsAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="targetKeyArn")
    def target_key_arn(self) -> str:
        return jsii.get(self, "targetKeyArn")

    @builtins.property
    @jsii.member(jsii_name="targetKeyId")
    def target_key_id(self) -> str:
        return jsii.get(self, "targetKeyId")

    @target_key_id.setter
    def target_key_id(self, value: str) -> None:
        jsii.set(self, "targetKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KmsAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "target_key_id": "targetKeyId",
        "name": "name",
        "name_prefix": "namePrefix",
    },
)
class KmsAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        target_key_id: str,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param target_key_id: 
        :param name: 
        :param name_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "target_key_id": target_key_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def target_key_id(self) -> str:
        return self._values.get("target_key_id")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsCiphertext(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KmsCiphertext",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        key_id: str,
        plaintext: str,
        context: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param key_id: 
        :param plaintext: 
        :param context: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KmsCiphertextConfig(
            key_id=key_id,
            plaintext=plaintext,
            context=context,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KmsCiphertext, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ciphertextBlob")
    def ciphertext_blob(self) -> str:
        return jsii.get(self, "ciphertextBlob")

    @builtins.property
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> str:
        return jsii.get(self, "keyId")

    @key_id.setter
    def key_id(self, value: str) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property
    @jsii.member(jsii_name="plaintext")
    def plaintext(self) -> str:
        return jsii.get(self, "plaintext")

    @plaintext.setter
    def plaintext(self, value: str) -> None:
        jsii.set(self, "plaintext", value)

    @builtins.property
    @jsii.member(jsii_name="context")
    def context(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "context")

    @context.setter
    def context(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "context", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KmsCiphertextConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "key_id": "keyId",
        "plaintext": "plaintext",
        "context": "context",
    },
)
class KmsCiphertextConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        key_id: str,
        plaintext: str,
        context: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param key_id: 
        :param plaintext: 
        :param context: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "key_id": key_id,
            "plaintext": plaintext,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if context is not None:
            self._values["context"] = context

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def key_id(self) -> str:
        return self._values.get("key_id")

    @builtins.property
    def plaintext(self) -> str:
        return self._values.get("plaintext")

    @builtins.property
    def context(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("context")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsCiphertextConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsExternalKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KmsExternalKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        deletion_window_in_days: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        key_material_base64: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        valid_to: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param deletion_window_in_days: 
        :param description: 
        :param enabled: 
        :param key_material_base64: 
        :param policy: 
        :param tags: 
        :param valid_to: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KmsExternalKeyConfig(
            deletion_window_in_days=deletion_window_in_days,
            description=description,
            enabled=enabled,
            key_material_base64=key_material_base64,
            policy=policy,
            tags=tags,
            valid_to=valid_to,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KmsExternalKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="expirationModel")
    def expiration_model(self) -> str:
        return jsii.get(self, "expirationModel")

    @builtins.property
    @jsii.member(jsii_name="keyState")
    def key_state(self) -> str:
        return jsii.get(self, "keyState")

    @builtins.property
    @jsii.member(jsii_name="keyUsage")
    def key_usage(self) -> str:
        return jsii.get(self, "keyUsage")

    @builtins.property
    @jsii.member(jsii_name="deletionWindowInDays")
    def deletion_window_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "deletionWindowInDays")

    @deletion_window_in_days.setter
    def deletion_window_in_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "deletionWindowInDays", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="keyMaterialBase64")
    def key_material_base64(self) -> typing.Optional[str]:
        return jsii.get(self, "keyMaterialBase64")

    @key_material_base64.setter
    def key_material_base64(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyMaterialBase64", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="validTo")
    def valid_to(self) -> typing.Optional[str]:
        return jsii.get(self, "validTo")

    @valid_to.setter
    def valid_to(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "validTo", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KmsExternalKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "deletion_window_in_days": "deletionWindowInDays",
        "description": "description",
        "enabled": "enabled",
        "key_material_base64": "keyMaterialBase64",
        "policy": "policy",
        "tags": "tags",
        "valid_to": "validTo",
    },
)
class KmsExternalKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        deletion_window_in_days: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        key_material_base64: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        valid_to: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param deletion_window_in_days: 
        :param description: 
        :param enabled: 
        :param key_material_base64: 
        :param policy: 
        :param tags: 
        :param valid_to: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deletion_window_in_days is not None:
            self._values["deletion_window_in_days"] = deletion_window_in_days
        if description is not None:
            self._values["description"] = description
        if enabled is not None:
            self._values["enabled"] = enabled
        if key_material_base64 is not None:
            self._values["key_material_base64"] = key_material_base64
        if policy is not None:
            self._values["policy"] = policy
        if tags is not None:
            self._values["tags"] = tags
        if valid_to is not None:
            self._values["valid_to"] = valid_to

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def deletion_window_in_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("deletion_window_in_days")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def key_material_base64(self) -> typing.Optional[str]:
        return self._values.get("key_material_base64")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def valid_to(self) -> typing.Optional[str]:
        return self._values.get("valid_to")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsExternalKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsGrant(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KmsGrant",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        grantee_principal: str,
        key_id: str,
        operations: typing.List[str],
        constraints: typing.Optional[typing.List["KmsGrantConstraints"]] = None,
        grant_creation_tokens: typing.Optional[typing.List[str]] = None,
        name: typing.Optional[str] = None,
        retire_on_delete: typing.Optional[bool] = None,
        retiring_principal: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param grantee_principal: 
        :param key_id: 
        :param operations: 
        :param constraints: constraints block.
        :param grant_creation_tokens: 
        :param name: 
        :param retire_on_delete: 
        :param retiring_principal: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KmsGrantConfig(
            grantee_principal=grantee_principal,
            key_id=key_id,
            operations=operations,
            constraints=constraints,
            grant_creation_tokens=grant_creation_tokens,
            name=name,
            retire_on_delete=retire_on_delete,
            retiring_principal=retiring_principal,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KmsGrant, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="grantId")
    def grant_id(self) -> str:
        return jsii.get(self, "grantId")

    @builtins.property
    @jsii.member(jsii_name="grantToken")
    def grant_token(self) -> str:
        return jsii.get(self, "grantToken")

    @builtins.property
    @jsii.member(jsii_name="granteePrincipal")
    def grantee_principal(self) -> str:
        return jsii.get(self, "granteePrincipal")

    @grantee_principal.setter
    def grantee_principal(self, value: str) -> None:
        jsii.set(self, "granteePrincipal", value)

    @builtins.property
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> str:
        return jsii.get(self, "keyId")

    @key_id.setter
    def key_id(self, value: str) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property
    @jsii.member(jsii_name="operations")
    def operations(self) -> typing.List[str]:
        return jsii.get(self, "operations")

    @operations.setter
    def operations(self, value: typing.List[str]) -> None:
        jsii.set(self, "operations", value)

    @builtins.property
    @jsii.member(jsii_name="constraints")
    def constraints(self) -> typing.Optional[typing.List["KmsGrantConstraints"]]:
        return jsii.get(self, "constraints")

    @constraints.setter
    def constraints(
        self, value: typing.Optional[typing.List["KmsGrantConstraints"]]
    ) -> None:
        jsii.set(self, "constraints", value)

    @builtins.property
    @jsii.member(jsii_name="grantCreationTokens")
    def grant_creation_tokens(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "grantCreationTokens")

    @grant_creation_tokens.setter
    def grant_creation_tokens(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "grantCreationTokens", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="retireOnDelete")
    def retire_on_delete(self) -> typing.Optional[bool]:
        return jsii.get(self, "retireOnDelete")

    @retire_on_delete.setter
    def retire_on_delete(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "retireOnDelete", value)

    @builtins.property
    @jsii.member(jsii_name="retiringPrincipal")
    def retiring_principal(self) -> typing.Optional[str]:
        return jsii.get(self, "retiringPrincipal")

    @retiring_principal.setter
    def retiring_principal(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "retiringPrincipal", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KmsGrantConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "grantee_principal": "granteePrincipal",
        "key_id": "keyId",
        "operations": "operations",
        "constraints": "constraints",
        "grant_creation_tokens": "grantCreationTokens",
        "name": "name",
        "retire_on_delete": "retireOnDelete",
        "retiring_principal": "retiringPrincipal",
    },
)
class KmsGrantConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        grantee_principal: str,
        key_id: str,
        operations: typing.List[str],
        constraints: typing.Optional[typing.List["KmsGrantConstraints"]] = None,
        grant_creation_tokens: typing.Optional[typing.List[str]] = None,
        name: typing.Optional[str] = None,
        retire_on_delete: typing.Optional[bool] = None,
        retiring_principal: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param grantee_principal: 
        :param key_id: 
        :param operations: 
        :param constraints: constraints block.
        :param grant_creation_tokens: 
        :param name: 
        :param retire_on_delete: 
        :param retiring_principal: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "grantee_principal": grantee_principal,
            "key_id": key_id,
            "operations": operations,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if constraints is not None:
            self._values["constraints"] = constraints
        if grant_creation_tokens is not None:
            self._values["grant_creation_tokens"] = grant_creation_tokens
        if name is not None:
            self._values["name"] = name
        if retire_on_delete is not None:
            self._values["retire_on_delete"] = retire_on_delete
        if retiring_principal is not None:
            self._values["retiring_principal"] = retiring_principal

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def grantee_principal(self) -> str:
        return self._values.get("grantee_principal")

    @builtins.property
    def key_id(self) -> str:
        return self._values.get("key_id")

    @builtins.property
    def operations(self) -> typing.List[str]:
        return self._values.get("operations")

    @builtins.property
    def constraints(self) -> typing.Optional[typing.List["KmsGrantConstraints"]]:
        """constraints block."""
        return self._values.get("constraints")

    @builtins.property
    def grant_creation_tokens(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("grant_creation_tokens")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def retire_on_delete(self) -> typing.Optional[bool]:
        return self._values.get("retire_on_delete")

    @builtins.property
    def retiring_principal(self) -> typing.Optional[str]:
        return self._values.get("retiring_principal")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsGrantConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KmsGrantConstraints",
    jsii_struct_bases=[],
    name_mapping={
        "encryption_context_equals": "encryptionContextEquals",
        "encryption_context_subset": "encryptionContextSubset",
    },
)
class KmsGrantConstraints:
    def __init__(
        self,
        *,
        encryption_context_equals: typing.Optional[typing.Mapping[str, str]] = None,
        encryption_context_subset: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param encryption_context_equals: 
        :param encryption_context_subset: 
        """
        self._values = {}
        if encryption_context_equals is not None:
            self._values["encryption_context_equals"] = encryption_context_equals
        if encryption_context_subset is not None:
            self._values["encryption_context_subset"] = encryption_context_subset

    @builtins.property
    def encryption_context_equals(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("encryption_context_equals")

    @builtins.property
    def encryption_context_subset(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("encryption_context_subset")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsGrantConstraints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class KmsKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.KmsKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        customer_master_key_spec: typing.Optional[str] = None,
        deletion_window_in_days: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        enable_key_rotation: typing.Optional[bool] = None,
        is_enabled: typing.Optional[bool] = None,
        key_usage: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param customer_master_key_spec: 
        :param deletion_window_in_days: 
        :param description: 
        :param enable_key_rotation: 
        :param is_enabled: 
        :param key_usage: 
        :param policy: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = KmsKeyConfig(
            customer_master_key_spec=customer_master_key_spec,
            deletion_window_in_days=deletion_window_in_days,
            description=description,
            enable_key_rotation=enable_key_rotation,
            is_enabled=is_enabled,
            key_usage=key_usage,
            policy=policy,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(KmsKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> str:
        return jsii.get(self, "keyId")

    @builtins.property
    @jsii.member(jsii_name="customerMasterKeySpec")
    def customer_master_key_spec(self) -> typing.Optional[str]:
        return jsii.get(self, "customerMasterKeySpec")

    @customer_master_key_spec.setter
    def customer_master_key_spec(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customerMasterKeySpec", value)

    @builtins.property
    @jsii.member(jsii_name="deletionWindowInDays")
    def deletion_window_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "deletionWindowInDays")

    @deletion_window_in_days.setter
    def deletion_window_in_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "deletionWindowInDays", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="enableKeyRotation")
    def enable_key_rotation(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableKeyRotation")

    @enable_key_rotation.setter
    def enable_key_rotation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableKeyRotation", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="isEnabled")
    def is_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "isEnabled")

    @is_enabled.setter
    def is_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "isEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="keyUsage")
    def key_usage(self) -> typing.Optional[str]:
        return jsii.get(self, "keyUsage")

    @key_usage.setter
    def key_usage(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyUsage", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.KmsKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "customer_master_key_spec": "customerMasterKeySpec",
        "deletion_window_in_days": "deletionWindowInDays",
        "description": "description",
        "enable_key_rotation": "enableKeyRotation",
        "is_enabled": "isEnabled",
        "key_usage": "keyUsage",
        "policy": "policy",
        "tags": "tags",
    },
)
class KmsKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        customer_master_key_spec: typing.Optional[str] = None,
        deletion_window_in_days: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        enable_key_rotation: typing.Optional[bool] = None,
        is_enabled: typing.Optional[bool] = None,
        key_usage: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param customer_master_key_spec: 
        :param deletion_window_in_days: 
        :param description: 
        :param enable_key_rotation: 
        :param is_enabled: 
        :param key_usage: 
        :param policy: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if customer_master_key_spec is not None:
            self._values["customer_master_key_spec"] = customer_master_key_spec
        if deletion_window_in_days is not None:
            self._values["deletion_window_in_days"] = deletion_window_in_days
        if description is not None:
            self._values["description"] = description
        if enable_key_rotation is not None:
            self._values["enable_key_rotation"] = enable_key_rotation
        if is_enabled is not None:
            self._values["is_enabled"] = is_enabled
        if key_usage is not None:
            self._values["key_usage"] = key_usage
        if policy is not None:
            self._values["policy"] = policy
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def customer_master_key_spec(self) -> typing.Optional[str]:
        return self._values.get("customer_master_key_spec")

    @builtins.property
    def deletion_window_in_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("deletion_window_in_days")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def enable_key_rotation(self) -> typing.Optional[bool]:
        return self._values.get("enable_key_rotation")

    @builtins.property
    def is_enabled(self) -> typing.Optional[bool]:
        return self._values.get("is_enabled")

    @builtins.property
    def key_usage(self) -> typing.Optional[str]:
        return self._values.get("key_usage")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "KmsKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaAlias(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaAlias",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        function_name: str,
        function_version: str,
        name: str,
        description: typing.Optional[str] = None,
        routing_config: typing.Optional[typing.List["LambdaAliasRoutingConfig"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param function_name: 
        :param function_version: 
        :param name: 
        :param description: 
        :param routing_config: routing_config block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LambdaAliasConfig(
            function_name=function_name,
            function_version=function_version,
            name=name,
            description=description,
            routing_config=routing_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LambdaAlias, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="invokeArn")
    def invoke_arn(self) -> str:
        return jsii.get(self, "invokeArn")

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="functionVersion")
    def function_version(self) -> str:
        return jsii.get(self, "functionVersion")

    @function_version.setter
    def function_version(self, value: str) -> None:
        jsii.set(self, "functionVersion", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="routingConfig")
    def routing_config(
        self,
    ) -> typing.Optional[typing.List["LambdaAliasRoutingConfig"]]:
        return jsii.get(self, "routingConfig")

    @routing_config.setter
    def routing_config(
        self, value: typing.Optional[typing.List["LambdaAliasRoutingConfig"]]
    ) -> None:
        jsii.set(self, "routingConfig", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaAliasConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_name": "functionName",
        "function_version": "functionVersion",
        "name": "name",
        "description": "description",
        "routing_config": "routingConfig",
    },
)
class LambdaAliasConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_name: str,
        function_version: str,
        name: str,
        description: typing.Optional[str] = None,
        routing_config: typing.Optional[typing.List["LambdaAliasRoutingConfig"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_name: 
        :param function_version: 
        :param name: 
        :param description: 
        :param routing_config: routing_config block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "function_name": function_name,
            "function_version": function_version,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if routing_config is not None:
            self._values["routing_config"] = routing_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def function_version(self) -> str:
        return self._values.get("function_version")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def routing_config(
        self,
    ) -> typing.Optional[typing.List["LambdaAliasRoutingConfig"]]:
        """routing_config block."""
        return self._values.get("routing_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaAliasConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaAliasRoutingConfig",
    jsii_struct_bases=[],
    name_mapping={"additional_version_weights": "additionalVersionWeights"},
)
class LambdaAliasRoutingConfig:
    def __init__(
        self,
        *,
        additional_version_weights: typing.Optional[
            typing.Mapping[str, jsii.Number]
        ] = None,
    ) -> None:
        """
        :param additional_version_weights: 
        """
        self._values = {}
        if additional_version_weights is not None:
            self._values["additional_version_weights"] = additional_version_weights

    @builtins.property
    def additional_version_weights(
        self,
    ) -> typing.Optional[typing.Mapping[str, jsii.Number]]:
        return self._values.get("additional_version_weights")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaAliasRoutingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaEventSourceMapping(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaEventSourceMapping",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        event_source_arn: str,
        function_name: str,
        batch_size: typing.Optional[jsii.Number] = None,
        bisect_batch_on_function_error: typing.Optional[bool] = None,
        destination_config: typing.Optional[
            typing.List["LambdaEventSourceMappingDestinationConfig"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        maximum_batching_window_in_seconds: typing.Optional[jsii.Number] = None,
        maximum_record_age_in_seconds: typing.Optional[jsii.Number] = None,
        maximum_retry_attempts: typing.Optional[jsii.Number] = None,
        parallelization_factor: typing.Optional[jsii.Number] = None,
        starting_position: typing.Optional[str] = None,
        starting_position_timestamp: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param event_source_arn: 
        :param function_name: 
        :param batch_size: 
        :param bisect_batch_on_function_error: 
        :param destination_config: destination_config block.
        :param enabled: 
        :param maximum_batching_window_in_seconds: 
        :param maximum_record_age_in_seconds: 
        :param maximum_retry_attempts: 
        :param parallelization_factor: 
        :param starting_position: 
        :param starting_position_timestamp: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LambdaEventSourceMappingConfig(
            event_source_arn=event_source_arn,
            function_name=function_name,
            batch_size=batch_size,
            bisect_batch_on_function_error=bisect_batch_on_function_error,
            destination_config=destination_config,
            enabled=enabled,
            maximum_batching_window_in_seconds=maximum_batching_window_in_seconds,
            maximum_record_age_in_seconds=maximum_record_age_in_seconds,
            maximum_retry_attempts=maximum_retry_attempts,
            parallelization_factor=parallelization_factor,
            starting_position=starting_position,
            starting_position_timestamp=starting_position_timestamp,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LambdaEventSourceMapping, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="functionArn")
    def function_arn(self) -> str:
        return jsii.get(self, "functionArn")

    @builtins.property
    @jsii.member(jsii_name="lastModified")
    def last_modified(self) -> str:
        return jsii.get(self, "lastModified")

    @builtins.property
    @jsii.member(jsii_name="lastProcessingResult")
    def last_processing_result(self) -> str:
        return jsii.get(self, "lastProcessingResult")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="stateTransitionReason")
    def state_transition_reason(self) -> str:
        return jsii.get(self, "stateTransitionReason")

    @builtins.property
    @jsii.member(jsii_name="uuid")
    def uuid(self) -> str:
        return jsii.get(self, "uuid")

    @builtins.property
    @jsii.member(jsii_name="eventSourceArn")
    def event_source_arn(self) -> str:
        return jsii.get(self, "eventSourceArn")

    @event_source_arn.setter
    def event_source_arn(self, value: str) -> None:
        jsii.set(self, "eventSourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="batchSize")
    def batch_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "batchSize")

    @batch_size.setter
    def batch_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "batchSize", value)

    @builtins.property
    @jsii.member(jsii_name="bisectBatchOnFunctionError")
    def bisect_batch_on_function_error(self) -> typing.Optional[bool]:
        return jsii.get(self, "bisectBatchOnFunctionError")

    @bisect_batch_on_function_error.setter
    def bisect_batch_on_function_error(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "bisectBatchOnFunctionError", value)

    @builtins.property
    @jsii.member(jsii_name="destinationConfig")
    def destination_config(
        self,
    ) -> typing.Optional[typing.List["LambdaEventSourceMappingDestinationConfig"]]:
        return jsii.get(self, "destinationConfig")

    @destination_config.setter
    def destination_config(
        self,
        value: typing.Optional[
            typing.List["LambdaEventSourceMappingDestinationConfig"]
        ],
    ) -> None:
        jsii.set(self, "destinationConfig", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maximumBatchingWindowInSeconds")
    def maximum_batching_window_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumBatchingWindowInSeconds")

    @maximum_batching_window_in_seconds.setter
    def maximum_batching_window_in_seconds(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "maximumBatchingWindowInSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="maximumRecordAgeInSeconds")
    def maximum_record_age_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumRecordAgeInSeconds")

    @maximum_record_age_in_seconds.setter
    def maximum_record_age_in_seconds(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "maximumRecordAgeInSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumRetryAttempts")

    @maximum_retry_attempts.setter
    def maximum_retry_attempts(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumRetryAttempts", value)

    @builtins.property
    @jsii.member(jsii_name="parallelizationFactor")
    def parallelization_factor(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "parallelizationFactor")

    @parallelization_factor.setter
    def parallelization_factor(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "parallelizationFactor", value)

    @builtins.property
    @jsii.member(jsii_name="startingPosition")
    def starting_position(self) -> typing.Optional[str]:
        return jsii.get(self, "startingPosition")

    @starting_position.setter
    def starting_position(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "startingPosition", value)

    @builtins.property
    @jsii.member(jsii_name="startingPositionTimestamp")
    def starting_position_timestamp(self) -> typing.Optional[str]:
        return jsii.get(self, "startingPositionTimestamp")

    @starting_position_timestamp.setter
    def starting_position_timestamp(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "startingPositionTimestamp", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaEventSourceMappingConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "event_source_arn": "eventSourceArn",
        "function_name": "functionName",
        "batch_size": "batchSize",
        "bisect_batch_on_function_error": "bisectBatchOnFunctionError",
        "destination_config": "destinationConfig",
        "enabled": "enabled",
        "maximum_batching_window_in_seconds": "maximumBatchingWindowInSeconds",
        "maximum_record_age_in_seconds": "maximumRecordAgeInSeconds",
        "maximum_retry_attempts": "maximumRetryAttempts",
        "parallelization_factor": "parallelizationFactor",
        "starting_position": "startingPosition",
        "starting_position_timestamp": "startingPositionTimestamp",
    },
)
class LambdaEventSourceMappingConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        event_source_arn: str,
        function_name: str,
        batch_size: typing.Optional[jsii.Number] = None,
        bisect_batch_on_function_error: typing.Optional[bool] = None,
        destination_config: typing.Optional[
            typing.List["LambdaEventSourceMappingDestinationConfig"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        maximum_batching_window_in_seconds: typing.Optional[jsii.Number] = None,
        maximum_record_age_in_seconds: typing.Optional[jsii.Number] = None,
        maximum_retry_attempts: typing.Optional[jsii.Number] = None,
        parallelization_factor: typing.Optional[jsii.Number] = None,
        starting_position: typing.Optional[str] = None,
        starting_position_timestamp: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param event_source_arn: 
        :param function_name: 
        :param batch_size: 
        :param bisect_batch_on_function_error: 
        :param destination_config: destination_config block.
        :param enabled: 
        :param maximum_batching_window_in_seconds: 
        :param maximum_record_age_in_seconds: 
        :param maximum_retry_attempts: 
        :param parallelization_factor: 
        :param starting_position: 
        :param starting_position_timestamp: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "event_source_arn": event_source_arn,
            "function_name": function_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if batch_size is not None:
            self._values["batch_size"] = batch_size
        if bisect_batch_on_function_error is not None:
            self._values[
                "bisect_batch_on_function_error"
            ] = bisect_batch_on_function_error
        if destination_config is not None:
            self._values["destination_config"] = destination_config
        if enabled is not None:
            self._values["enabled"] = enabled
        if maximum_batching_window_in_seconds is not None:
            self._values[
                "maximum_batching_window_in_seconds"
            ] = maximum_batching_window_in_seconds
        if maximum_record_age_in_seconds is not None:
            self._values[
                "maximum_record_age_in_seconds"
            ] = maximum_record_age_in_seconds
        if maximum_retry_attempts is not None:
            self._values["maximum_retry_attempts"] = maximum_retry_attempts
        if parallelization_factor is not None:
            self._values["parallelization_factor"] = parallelization_factor
        if starting_position is not None:
            self._values["starting_position"] = starting_position
        if starting_position_timestamp is not None:
            self._values["starting_position_timestamp"] = starting_position_timestamp

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def event_source_arn(self) -> str:
        return self._values.get("event_source_arn")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def batch_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("batch_size")

    @builtins.property
    def bisect_batch_on_function_error(self) -> typing.Optional[bool]:
        return self._values.get("bisect_batch_on_function_error")

    @builtins.property
    def destination_config(
        self,
    ) -> typing.Optional[typing.List["LambdaEventSourceMappingDestinationConfig"]]:
        """destination_config block."""
        return self._values.get("destination_config")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def maximum_batching_window_in_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("maximum_batching_window_in_seconds")

    @builtins.property
    def maximum_record_age_in_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("maximum_record_age_in_seconds")

    @builtins.property
    def maximum_retry_attempts(self) -> typing.Optional[jsii.Number]:
        return self._values.get("maximum_retry_attempts")

    @builtins.property
    def parallelization_factor(self) -> typing.Optional[jsii.Number]:
        return self._values.get("parallelization_factor")

    @builtins.property
    def starting_position(self) -> typing.Optional[str]:
        return self._values.get("starting_position")

    @builtins.property
    def starting_position_timestamp(self) -> typing.Optional[str]:
        return self._values.get("starting_position_timestamp")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaEventSourceMappingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaEventSourceMappingDestinationConfig",
    jsii_struct_bases=[],
    name_mapping={"on_failure": "onFailure"},
)
class LambdaEventSourceMappingDestinationConfig:
    def __init__(
        self,
        *,
        on_failure: typing.Optional[
            typing.List["LambdaEventSourceMappingDestinationConfigOnFailure"]
        ] = None,
    ) -> None:
        """
        :param on_failure: on_failure block.
        """
        self._values = {}
        if on_failure is not None:
            self._values["on_failure"] = on_failure

    @builtins.property
    def on_failure(
        self,
    ) -> typing.Optional[
        typing.List["LambdaEventSourceMappingDestinationConfigOnFailure"]
    ]:
        """on_failure block."""
        return self._values.get("on_failure")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaEventSourceMappingDestinationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaEventSourceMappingDestinationConfigOnFailure",
    jsii_struct_bases=[],
    name_mapping={"destination_arn": "destinationArn"},
)
class LambdaEventSourceMappingDestinationConfigOnFailure:
    def __init__(self, *, destination_arn: str) -> None:
        """
        :param destination_arn: 
        """
        self._values = {
            "destination_arn": destination_arn,
        }

    @builtins.property
    def destination_arn(self) -> str:
        return self._values.get("destination_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaEventSourceMappingDestinationConfigOnFailure(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaFunction(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunction",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        function_name: str,
        handler: str,
        role: str,
        runtime: str,
        dead_letter_config: typing.Optional[
            typing.List["LambdaFunctionDeadLetterConfig"]
        ] = None,
        description: typing.Optional[str] = None,
        environment: typing.Optional[typing.List["LambdaFunctionEnvironment"]] = None,
        filename: typing.Optional[str] = None,
        file_system_config: typing.Optional[
            typing.List["LambdaFunctionFileSystemConfig"]
        ] = None,
        kms_key_arn: typing.Optional[str] = None,
        layers: typing.Optional[typing.List[str]] = None,
        memory_size: typing.Optional[jsii.Number] = None,
        publish: typing.Optional[bool] = None,
        reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
        s3_bucket: typing.Optional[str] = None,
        s3_key: typing.Optional[str] = None,
        s3_object_version: typing.Optional[str] = None,
        source_code_hash: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeout: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["LambdaFunctionTimeouts"] = None,
        tracing_config: typing.Optional[
            typing.List["LambdaFunctionTracingConfig"]
        ] = None,
        vpc_config: typing.Optional[typing.List["LambdaFunctionVpcConfig"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param function_name: 
        :param handler: 
        :param role: 
        :param runtime: 
        :param dead_letter_config: dead_letter_config block.
        :param description: 
        :param environment: environment block.
        :param filename: 
        :param file_system_config: file_system_config block.
        :param kms_key_arn: 
        :param layers: 
        :param memory_size: 
        :param publish: 
        :param reserved_concurrent_executions: 
        :param s3_bucket: 
        :param s3_key: 
        :param s3_object_version: 
        :param source_code_hash: 
        :param tags: 
        :param timeout: 
        :param timeouts: timeouts block.
        :param tracing_config: tracing_config block.
        :param vpc_config: vpc_config block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LambdaFunctionConfig(
            function_name=function_name,
            handler=handler,
            role=role,
            runtime=runtime,
            dead_letter_config=dead_letter_config,
            description=description,
            environment=environment,
            filename=filename,
            file_system_config=file_system_config,
            kms_key_arn=kms_key_arn,
            layers=layers,
            memory_size=memory_size,
            publish=publish,
            reserved_concurrent_executions=reserved_concurrent_executions,
            s3_bucket=s3_bucket,
            s3_key=s3_key,
            s3_object_version=s3_object_version,
            source_code_hash=source_code_hash,
            tags=tags,
            timeout=timeout,
            timeouts=timeouts,
            tracing_config=tracing_config,
            vpc_config=vpc_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LambdaFunction, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="invokeArn")
    def invoke_arn(self) -> str:
        return jsii.get(self, "invokeArn")

    @builtins.property
    @jsii.member(jsii_name="lastModified")
    def last_modified(self) -> str:
        return jsii.get(self, "lastModified")

    @builtins.property
    @jsii.member(jsii_name="qualifiedArn")
    def qualified_arn(self) -> str:
        return jsii.get(self, "qualifiedArn")

    @builtins.property
    @jsii.member(jsii_name="sourceCodeSize")
    def source_code_size(self) -> jsii.Number:
        return jsii.get(self, "sourceCodeSize")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="handler")
    def handler(self) -> str:
        return jsii.get(self, "handler")

    @handler.setter
    def handler(self, value: str) -> None:
        jsii.set(self, "handler", value)

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> str:
        return jsii.get(self, "role")

    @role.setter
    def role(self, value: str) -> None:
        jsii.set(self, "role", value)

    @builtins.property
    @jsii.member(jsii_name="runtime")
    def runtime(self) -> str:
        return jsii.get(self, "runtime")

    @runtime.setter
    def runtime(self, value: str) -> None:
        jsii.set(self, "runtime", value)

    @builtins.property
    @jsii.member(jsii_name="deadLetterConfig")
    def dead_letter_config(
        self,
    ) -> typing.Optional[typing.List["LambdaFunctionDeadLetterConfig"]]:
        return jsii.get(self, "deadLetterConfig")

    @dead_letter_config.setter
    def dead_letter_config(
        self, value: typing.Optional[typing.List["LambdaFunctionDeadLetterConfig"]]
    ) -> None:
        jsii.set(self, "deadLetterConfig", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="environment")
    def environment(self) -> typing.Optional[typing.List["LambdaFunctionEnvironment"]]:
        return jsii.get(self, "environment")

    @environment.setter
    def environment(
        self, value: typing.Optional[typing.List["LambdaFunctionEnvironment"]]
    ) -> None:
        jsii.set(self, "environment", value)

    @builtins.property
    @jsii.member(jsii_name="filename")
    def filename(self) -> typing.Optional[str]:
        return jsii.get(self, "filename")

    @filename.setter
    def filename(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "filename", value)

    @builtins.property
    @jsii.member(jsii_name="fileSystemConfig")
    def file_system_config(
        self,
    ) -> typing.Optional[typing.List["LambdaFunctionFileSystemConfig"]]:
        return jsii.get(self, "fileSystemConfig")

    @file_system_config.setter
    def file_system_config(
        self, value: typing.Optional[typing.List["LambdaFunctionFileSystemConfig"]]
    ) -> None:
        jsii.set(self, "fileSystemConfig", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="layers")
    def layers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "layers")

    @layers.setter
    def layers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "layers", value)

    @builtins.property
    @jsii.member(jsii_name="memorySize")
    def memory_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "memorySize")

    @memory_size.setter
    def memory_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "memorySize", value)

    @builtins.property
    @jsii.member(jsii_name="publish")
    def publish(self) -> typing.Optional[bool]:
        return jsii.get(self, "publish")

    @publish.setter
    def publish(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "publish", value)

    @builtins.property
    @jsii.member(jsii_name="reservedConcurrentExecutions")
    def reserved_concurrent_executions(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "reservedConcurrentExecutions")

    @reserved_concurrent_executions.setter
    def reserved_concurrent_executions(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "reservedConcurrentExecutions", value)

    @builtins.property
    @jsii.member(jsii_name="s3Bucket")
    def s3_bucket(self) -> typing.Optional[str]:
        return jsii.get(self, "s3Bucket")

    @s3_bucket.setter
    def s3_bucket(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3Bucket", value)

    @builtins.property
    @jsii.member(jsii_name="s3Key")
    def s3_key(self) -> typing.Optional[str]:
        return jsii.get(self, "s3Key")

    @s3_key.setter
    def s3_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3Key", value)

    @builtins.property
    @jsii.member(jsii_name="s3ObjectVersion")
    def s3_object_version(self) -> typing.Optional[str]:
        return jsii.get(self, "s3ObjectVersion")

    @s3_object_version.setter
    def s3_object_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3ObjectVersion", value)

    @builtins.property
    @jsii.member(jsii_name="sourceCodeHash")
    def source_code_hash(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceCodeHash")

    @source_code_hash.setter
    def source_code_hash(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceCodeHash", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeout")
    def timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "timeout")

    @timeout.setter
    def timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "timeout", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LambdaFunctionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["LambdaFunctionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="tracingConfig")
    def tracing_config(
        self,
    ) -> typing.Optional[typing.List["LambdaFunctionTracingConfig"]]:
        return jsii.get(self, "tracingConfig")

    @tracing_config.setter
    def tracing_config(
        self, value: typing.Optional[typing.List["LambdaFunctionTracingConfig"]]
    ) -> None:
        jsii.set(self, "tracingConfig", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConfig")
    def vpc_config(self) -> typing.Optional[typing.List["LambdaFunctionVpcConfig"]]:
        return jsii.get(self, "vpcConfig")

    @vpc_config.setter
    def vpc_config(
        self, value: typing.Optional[typing.List["LambdaFunctionVpcConfig"]]
    ) -> None:
        jsii.set(self, "vpcConfig", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_name": "functionName",
        "handler": "handler",
        "role": "role",
        "runtime": "runtime",
        "dead_letter_config": "deadLetterConfig",
        "description": "description",
        "environment": "environment",
        "filename": "filename",
        "file_system_config": "fileSystemConfig",
        "kms_key_arn": "kmsKeyArn",
        "layers": "layers",
        "memory_size": "memorySize",
        "publish": "publish",
        "reserved_concurrent_executions": "reservedConcurrentExecutions",
        "s3_bucket": "s3Bucket",
        "s3_key": "s3Key",
        "s3_object_version": "s3ObjectVersion",
        "source_code_hash": "sourceCodeHash",
        "tags": "tags",
        "timeout": "timeout",
        "timeouts": "timeouts",
        "tracing_config": "tracingConfig",
        "vpc_config": "vpcConfig",
    },
)
class LambdaFunctionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_name: str,
        handler: str,
        role: str,
        runtime: str,
        dead_letter_config: typing.Optional[
            typing.List["LambdaFunctionDeadLetterConfig"]
        ] = None,
        description: typing.Optional[str] = None,
        environment: typing.Optional[typing.List["LambdaFunctionEnvironment"]] = None,
        filename: typing.Optional[str] = None,
        file_system_config: typing.Optional[
            typing.List["LambdaFunctionFileSystemConfig"]
        ] = None,
        kms_key_arn: typing.Optional[str] = None,
        layers: typing.Optional[typing.List[str]] = None,
        memory_size: typing.Optional[jsii.Number] = None,
        publish: typing.Optional[bool] = None,
        reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
        s3_bucket: typing.Optional[str] = None,
        s3_key: typing.Optional[str] = None,
        s3_object_version: typing.Optional[str] = None,
        source_code_hash: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeout: typing.Optional[jsii.Number] = None,
        timeouts: typing.Optional["LambdaFunctionTimeouts"] = None,
        tracing_config: typing.Optional[
            typing.List["LambdaFunctionTracingConfig"]
        ] = None,
        vpc_config: typing.Optional[typing.List["LambdaFunctionVpcConfig"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_name: 
        :param handler: 
        :param role: 
        :param runtime: 
        :param dead_letter_config: dead_letter_config block.
        :param description: 
        :param environment: environment block.
        :param filename: 
        :param file_system_config: file_system_config block.
        :param kms_key_arn: 
        :param layers: 
        :param memory_size: 
        :param publish: 
        :param reserved_concurrent_executions: 
        :param s3_bucket: 
        :param s3_key: 
        :param s3_object_version: 
        :param source_code_hash: 
        :param tags: 
        :param timeout: 
        :param timeouts: timeouts block.
        :param tracing_config: tracing_config block.
        :param vpc_config: vpc_config block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LambdaFunctionTimeouts(**timeouts)
        self._values = {
            "function_name": function_name,
            "handler": handler,
            "role": role,
            "runtime": runtime,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if dead_letter_config is not None:
            self._values["dead_letter_config"] = dead_letter_config
        if description is not None:
            self._values["description"] = description
        if environment is not None:
            self._values["environment"] = environment
        if filename is not None:
            self._values["filename"] = filename
        if file_system_config is not None:
            self._values["file_system_config"] = file_system_config
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if layers is not None:
            self._values["layers"] = layers
        if memory_size is not None:
            self._values["memory_size"] = memory_size
        if publish is not None:
            self._values["publish"] = publish
        if reserved_concurrent_executions is not None:
            self._values[
                "reserved_concurrent_executions"
            ] = reserved_concurrent_executions
        if s3_bucket is not None:
            self._values["s3_bucket"] = s3_bucket
        if s3_key is not None:
            self._values["s3_key"] = s3_key
        if s3_object_version is not None:
            self._values["s3_object_version"] = s3_object_version
        if source_code_hash is not None:
            self._values["source_code_hash"] = source_code_hash
        if tags is not None:
            self._values["tags"] = tags
        if timeout is not None:
            self._values["timeout"] = timeout
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if tracing_config is not None:
            self._values["tracing_config"] = tracing_config
        if vpc_config is not None:
            self._values["vpc_config"] = vpc_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def handler(self) -> str:
        return self._values.get("handler")

    @builtins.property
    def role(self) -> str:
        return self._values.get("role")

    @builtins.property
    def runtime(self) -> str:
        return self._values.get("runtime")

    @builtins.property
    def dead_letter_config(
        self,
    ) -> typing.Optional[typing.List["LambdaFunctionDeadLetterConfig"]]:
        """dead_letter_config block."""
        return self._values.get("dead_letter_config")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def environment(self) -> typing.Optional[typing.List["LambdaFunctionEnvironment"]]:
        """environment block."""
        return self._values.get("environment")

    @builtins.property
    def filename(self) -> typing.Optional[str]:
        return self._values.get("filename")

    @builtins.property
    def file_system_config(
        self,
    ) -> typing.Optional[typing.List["LambdaFunctionFileSystemConfig"]]:
        """file_system_config block."""
        return self._values.get("file_system_config")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def layers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("layers")

    @builtins.property
    def memory_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("memory_size")

    @builtins.property
    def publish(self) -> typing.Optional[bool]:
        return self._values.get("publish")

    @builtins.property
    def reserved_concurrent_executions(self) -> typing.Optional[jsii.Number]:
        return self._values.get("reserved_concurrent_executions")

    @builtins.property
    def s3_bucket(self) -> typing.Optional[str]:
        return self._values.get("s3_bucket")

    @builtins.property
    def s3_key(self) -> typing.Optional[str]:
        return self._values.get("s3_key")

    @builtins.property
    def s3_object_version(self) -> typing.Optional[str]:
        return self._values.get("s3_object_version")

    @builtins.property
    def source_code_hash(self) -> typing.Optional[str]:
        return self._values.get("source_code_hash")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout")

    @builtins.property
    def timeouts(self) -> typing.Optional["LambdaFunctionTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def tracing_config(
        self,
    ) -> typing.Optional[typing.List["LambdaFunctionTracingConfig"]]:
        """tracing_config block."""
        return self._values.get("tracing_config")

    @builtins.property
    def vpc_config(self) -> typing.Optional[typing.List["LambdaFunctionVpcConfig"]]:
        """vpc_config block."""
        return self._values.get("vpc_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionDeadLetterConfig",
    jsii_struct_bases=[],
    name_mapping={"target_arn": "targetArn"},
)
class LambdaFunctionDeadLetterConfig:
    def __init__(self, *, target_arn: str) -> None:
        """
        :param target_arn: 
        """
        self._values = {
            "target_arn": target_arn,
        }

    @builtins.property
    def target_arn(self) -> str:
        return self._values.get("target_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionDeadLetterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionEnvironment",
    jsii_struct_bases=[],
    name_mapping={"variables": "variables"},
)
class LambdaFunctionEnvironment:
    def __init__(
        self, *, variables: typing.Optional[typing.Mapping[str, str]] = None
    ) -> None:
        """
        :param variables: 
        """
        self._values = {}
        if variables is not None:
            self._values["variables"] = variables

    @builtins.property
    def variables(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("variables")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionEnvironment(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaFunctionEventInvokeConfig(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionEventInvokeConfig",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        function_name: str,
        destination_config: typing.Optional[
            typing.List["LambdaFunctionEventInvokeConfigDestinationConfig"]
        ] = None,
        maximum_event_age_in_seconds: typing.Optional[jsii.Number] = None,
        maximum_retry_attempts: typing.Optional[jsii.Number] = None,
        qualifier: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param function_name: 
        :param destination_config: destination_config block.
        :param maximum_event_age_in_seconds: 
        :param maximum_retry_attempts: 
        :param qualifier: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LambdaFunctionEventInvokeConfigConfig(
            function_name=function_name,
            destination_config=destination_config,
            maximum_event_age_in_seconds=maximum_event_age_in_seconds,
            maximum_retry_attempts=maximum_retry_attempts,
            qualifier=qualifier,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LambdaFunctionEventInvokeConfig, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="destinationConfig")
    def destination_config(
        self,
    ) -> typing.Optional[
        typing.List["LambdaFunctionEventInvokeConfigDestinationConfig"]
    ]:
        return jsii.get(self, "destinationConfig")

    @destination_config.setter
    def destination_config(
        self,
        value: typing.Optional[
            typing.List["LambdaFunctionEventInvokeConfigDestinationConfig"]
        ],
    ) -> None:
        jsii.set(self, "destinationConfig", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="maximumEventAgeInSeconds")
    def maximum_event_age_in_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumEventAgeInSeconds")

    @maximum_event_age_in_seconds.setter
    def maximum_event_age_in_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumEventAgeInSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="maximumRetryAttempts")
    def maximum_retry_attempts(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maximumRetryAttempts")

    @maximum_retry_attempts.setter
    def maximum_retry_attempts(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maximumRetryAttempts", value)

    @builtins.property
    @jsii.member(jsii_name="qualifier")
    def qualifier(self) -> typing.Optional[str]:
        return jsii.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "qualifier", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionEventInvokeConfigConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_name": "functionName",
        "destination_config": "destinationConfig",
        "maximum_event_age_in_seconds": "maximumEventAgeInSeconds",
        "maximum_retry_attempts": "maximumRetryAttempts",
        "qualifier": "qualifier",
    },
)
class LambdaFunctionEventInvokeConfigConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_name: str,
        destination_config: typing.Optional[
            typing.List["LambdaFunctionEventInvokeConfigDestinationConfig"]
        ] = None,
        maximum_event_age_in_seconds: typing.Optional[jsii.Number] = None,
        maximum_retry_attempts: typing.Optional[jsii.Number] = None,
        qualifier: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_name: 
        :param destination_config: destination_config block.
        :param maximum_event_age_in_seconds: 
        :param maximum_retry_attempts: 
        :param qualifier: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "function_name": function_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if destination_config is not None:
            self._values["destination_config"] = destination_config
        if maximum_event_age_in_seconds is not None:
            self._values["maximum_event_age_in_seconds"] = maximum_event_age_in_seconds
        if maximum_retry_attempts is not None:
            self._values["maximum_retry_attempts"] = maximum_retry_attempts
        if qualifier is not None:
            self._values["qualifier"] = qualifier

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def destination_config(
        self,
    ) -> typing.Optional[
        typing.List["LambdaFunctionEventInvokeConfigDestinationConfig"]
    ]:
        """destination_config block."""
        return self._values.get("destination_config")

    @builtins.property
    def maximum_event_age_in_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("maximum_event_age_in_seconds")

    @builtins.property
    def maximum_retry_attempts(self) -> typing.Optional[jsii.Number]:
        return self._values.get("maximum_retry_attempts")

    @builtins.property
    def qualifier(self) -> typing.Optional[str]:
        return self._values.get("qualifier")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionEventInvokeConfigConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionEventInvokeConfigDestinationConfig",
    jsii_struct_bases=[],
    name_mapping={"on_failure": "onFailure", "on_success": "onSuccess"},
)
class LambdaFunctionEventInvokeConfigDestinationConfig:
    def __init__(
        self,
        *,
        on_failure: typing.Optional[
            typing.List["LambdaFunctionEventInvokeConfigDestinationConfigOnFailure"]
        ] = None,
        on_success: typing.Optional[
            typing.List["LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess"]
        ] = None,
    ) -> None:
        """
        :param on_failure: on_failure block.
        :param on_success: on_success block.
        """
        self._values = {}
        if on_failure is not None:
            self._values["on_failure"] = on_failure
        if on_success is not None:
            self._values["on_success"] = on_success

    @builtins.property
    def on_failure(
        self,
    ) -> typing.Optional[
        typing.List["LambdaFunctionEventInvokeConfigDestinationConfigOnFailure"]
    ]:
        """on_failure block."""
        return self._values.get("on_failure")

    @builtins.property
    def on_success(
        self,
    ) -> typing.Optional[
        typing.List["LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess"]
    ]:
        """on_success block."""
        return self._values.get("on_success")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionEventInvokeConfigDestinationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionEventInvokeConfigDestinationConfigOnFailure",
    jsii_struct_bases=[],
    name_mapping={"destination": "destination"},
)
class LambdaFunctionEventInvokeConfigDestinationConfigOnFailure:
    def __init__(self, *, destination: str) -> None:
        """
        :param destination: 
        """
        self._values = {
            "destination": destination,
        }

    @builtins.property
    def destination(self) -> str:
        return self._values.get("destination")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "LambdaFunctionEventInvokeConfigDestinationConfigOnFailure(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess",
    jsii_struct_bases=[],
    name_mapping={"destination": "destination"},
)
class LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess:
    def __init__(self, *, destination: str) -> None:
        """
        :param destination: 
        """
        self._values = {
            "destination": destination,
        }

    @builtins.property
    def destination(self) -> str:
        return self._values.get("destination")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionFileSystemConfig",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "local_mount_path": "localMountPath"},
)
class LambdaFunctionFileSystemConfig:
    def __init__(self, *, arn: str, local_mount_path: str) -> None:
        """
        :param arn: 
        :param local_mount_path: 
        """
        self._values = {
            "arn": arn,
            "local_mount_path": local_mount_path,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def local_mount_path(self) -> str:
        return self._values.get("local_mount_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionFileSystemConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class LambdaFunctionTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionTracingConfig",
    jsii_struct_bases=[],
    name_mapping={"mode": "mode"},
)
class LambdaFunctionTracingConfig:
    def __init__(self, *, mode: str) -> None:
        """
        :param mode: 
        """
        self._values = {
            "mode": mode,
        }

    @builtins.property
    def mode(self) -> str:
        return self._values.get("mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionTracingConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaFunctionVpcConfig",
    jsii_struct_bases=[],
    name_mapping={"security_group_ids": "securityGroupIds", "subnet_ids": "subnetIds"},
)
class LambdaFunctionVpcConfig:
    def __init__(
        self, *, security_group_ids: typing.List[str], subnet_ids: typing.List[str]
    ) -> None:
        """
        :param security_group_ids: 
        :param subnet_ids: 
        """
        self._values = {
            "security_group_ids": security_group_ids,
            "subnet_ids": subnet_ids,
        }

    @builtins.property
    def security_group_ids(self) -> typing.List[str]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaFunctionVpcConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaLayerVersion(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaLayerVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        layer_name: str,
        compatible_runtimes: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        filename: typing.Optional[str] = None,
        license_info: typing.Optional[str] = None,
        s3_bucket: typing.Optional[str] = None,
        s3_key: typing.Optional[str] = None,
        s3_object_version: typing.Optional[str] = None,
        source_code_hash: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param layer_name: 
        :param compatible_runtimes: 
        :param description: 
        :param filename: 
        :param license_info: 
        :param s3_bucket: 
        :param s3_key: 
        :param s3_object_version: 
        :param source_code_hash: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LambdaLayerVersionConfig(
            layer_name=layer_name,
            compatible_runtimes=compatible_runtimes,
            description=description,
            filename=filename,
            license_info=license_info,
            s3_bucket=s3_bucket,
            s3_key=s3_key,
            s3_object_version=s3_object_version,
            source_code_hash=source_code_hash,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LambdaLayerVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="layerArn")
    def layer_arn(self) -> str:
        return jsii.get(self, "layerArn")

    @builtins.property
    @jsii.member(jsii_name="sourceCodeSize")
    def source_code_size(self) -> jsii.Number:
        return jsii.get(self, "sourceCodeSize")

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> str:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="layerName")
    def layer_name(self) -> str:
        return jsii.get(self, "layerName")

    @layer_name.setter
    def layer_name(self, value: str) -> None:
        jsii.set(self, "layerName", value)

    @builtins.property
    @jsii.member(jsii_name="compatibleRuntimes")
    def compatible_runtimes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "compatibleRuntimes")

    @compatible_runtimes.setter
    def compatible_runtimes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "compatibleRuntimes", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="filename")
    def filename(self) -> typing.Optional[str]:
        return jsii.get(self, "filename")

    @filename.setter
    def filename(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "filename", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="licenseInfo")
    def license_info(self) -> typing.Optional[str]:
        return jsii.get(self, "licenseInfo")

    @license_info.setter
    def license_info(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "licenseInfo", value)

    @builtins.property
    @jsii.member(jsii_name="s3Bucket")
    def s3_bucket(self) -> typing.Optional[str]:
        return jsii.get(self, "s3Bucket")

    @s3_bucket.setter
    def s3_bucket(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3Bucket", value)

    @builtins.property
    @jsii.member(jsii_name="s3Key")
    def s3_key(self) -> typing.Optional[str]:
        return jsii.get(self, "s3Key")

    @s3_key.setter
    def s3_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3Key", value)

    @builtins.property
    @jsii.member(jsii_name="s3ObjectVersion")
    def s3_object_version(self) -> typing.Optional[str]:
        return jsii.get(self, "s3ObjectVersion")

    @s3_object_version.setter
    def s3_object_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3ObjectVersion", value)

    @builtins.property
    @jsii.member(jsii_name="sourceCodeHash")
    def source_code_hash(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceCodeHash")

    @source_code_hash.setter
    def source_code_hash(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceCodeHash", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaLayerVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "layer_name": "layerName",
        "compatible_runtimes": "compatibleRuntimes",
        "description": "description",
        "filename": "filename",
        "license_info": "licenseInfo",
        "s3_bucket": "s3Bucket",
        "s3_key": "s3Key",
        "s3_object_version": "s3ObjectVersion",
        "source_code_hash": "sourceCodeHash",
    },
)
class LambdaLayerVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        layer_name: str,
        compatible_runtimes: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        filename: typing.Optional[str] = None,
        license_info: typing.Optional[str] = None,
        s3_bucket: typing.Optional[str] = None,
        s3_key: typing.Optional[str] = None,
        s3_object_version: typing.Optional[str] = None,
        source_code_hash: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param layer_name: 
        :param compatible_runtimes: 
        :param description: 
        :param filename: 
        :param license_info: 
        :param s3_bucket: 
        :param s3_key: 
        :param s3_object_version: 
        :param source_code_hash: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "layer_name": layer_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if compatible_runtimes is not None:
            self._values["compatible_runtimes"] = compatible_runtimes
        if description is not None:
            self._values["description"] = description
        if filename is not None:
            self._values["filename"] = filename
        if license_info is not None:
            self._values["license_info"] = license_info
        if s3_bucket is not None:
            self._values["s3_bucket"] = s3_bucket
        if s3_key is not None:
            self._values["s3_key"] = s3_key
        if s3_object_version is not None:
            self._values["s3_object_version"] = s3_object_version
        if source_code_hash is not None:
            self._values["source_code_hash"] = source_code_hash

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def layer_name(self) -> str:
        return self._values.get("layer_name")

    @builtins.property
    def compatible_runtimes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("compatible_runtimes")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def filename(self) -> typing.Optional[str]:
        return self._values.get("filename")

    @builtins.property
    def license_info(self) -> typing.Optional[str]:
        return self._values.get("license_info")

    @builtins.property
    def s3_bucket(self) -> typing.Optional[str]:
        return self._values.get("s3_bucket")

    @builtins.property
    def s3_key(self) -> typing.Optional[str]:
        return self._values.get("s3_key")

    @builtins.property
    def s3_object_version(self) -> typing.Optional[str]:
        return self._values.get("s3_object_version")

    @builtins.property
    def source_code_hash(self) -> typing.Optional[str]:
        return self._values.get("source_code_hash")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaLayerVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaPermission(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaPermission",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        action: str,
        function_name: str,
        principal: str,
        event_source_token: typing.Optional[str] = None,
        qualifier: typing.Optional[str] = None,
        source_account: typing.Optional[str] = None,
        source_arn: typing.Optional[str] = None,
        statement_id: typing.Optional[str] = None,
        statement_id_prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param action: 
        :param function_name: 
        :param principal: 
        :param event_source_token: 
        :param qualifier: 
        :param source_account: 
        :param source_arn: 
        :param statement_id: 
        :param statement_id_prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LambdaPermissionConfig(
            action=action,
            function_name=function_name,
            principal=principal,
            event_source_token=event_source_token,
            qualifier=qualifier,
            source_account=source_account,
            source_arn=source_arn,
            statement_id=statement_id,
            statement_id_prefix=statement_id_prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LambdaPermission, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="action")
    def action(self) -> str:
        return jsii.get(self, "action")

    @action.setter
    def action(self, value: str) -> None:
        jsii.set(self, "action", value)

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="principal")
    def principal(self) -> str:
        return jsii.get(self, "principal")

    @principal.setter
    def principal(self, value: str) -> None:
        jsii.set(self, "principal", value)

    @builtins.property
    @jsii.member(jsii_name="eventSourceToken")
    def event_source_token(self) -> typing.Optional[str]:
        return jsii.get(self, "eventSourceToken")

    @event_source_token.setter
    def event_source_token(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "eventSourceToken", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="qualifier")
    def qualifier(self) -> typing.Optional[str]:
        return jsii.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "qualifier", value)

    @builtins.property
    @jsii.member(jsii_name="sourceAccount")
    def source_account(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceAccount")

    @source_account.setter
    def source_account(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceAccount", value)

    @builtins.property
    @jsii.member(jsii_name="sourceArn")
    def source_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceArn")

    @source_arn.setter
    def source_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="statementId")
    def statement_id(self) -> typing.Optional[str]:
        return jsii.get(self, "statementId")

    @statement_id.setter
    def statement_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "statementId", value)

    @builtins.property
    @jsii.member(jsii_name="statementIdPrefix")
    def statement_id_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "statementIdPrefix")

    @statement_id_prefix.setter
    def statement_id_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "statementIdPrefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaPermissionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "action": "action",
        "function_name": "functionName",
        "principal": "principal",
        "event_source_token": "eventSourceToken",
        "qualifier": "qualifier",
        "source_account": "sourceAccount",
        "source_arn": "sourceArn",
        "statement_id": "statementId",
        "statement_id_prefix": "statementIdPrefix",
    },
)
class LambdaPermissionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        action: str,
        function_name: str,
        principal: str,
        event_source_token: typing.Optional[str] = None,
        qualifier: typing.Optional[str] = None,
        source_account: typing.Optional[str] = None,
        source_arn: typing.Optional[str] = None,
        statement_id: typing.Optional[str] = None,
        statement_id_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param action: 
        :param function_name: 
        :param principal: 
        :param event_source_token: 
        :param qualifier: 
        :param source_account: 
        :param source_arn: 
        :param statement_id: 
        :param statement_id_prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "action": action,
            "function_name": function_name,
            "principal": principal,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if event_source_token is not None:
            self._values["event_source_token"] = event_source_token
        if qualifier is not None:
            self._values["qualifier"] = qualifier
        if source_account is not None:
            self._values["source_account"] = source_account
        if source_arn is not None:
            self._values["source_arn"] = source_arn
        if statement_id is not None:
            self._values["statement_id"] = statement_id
        if statement_id_prefix is not None:
            self._values["statement_id_prefix"] = statement_id_prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def action(self) -> str:
        return self._values.get("action")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def principal(self) -> str:
        return self._values.get("principal")

    @builtins.property
    def event_source_token(self) -> typing.Optional[str]:
        return self._values.get("event_source_token")

    @builtins.property
    def qualifier(self) -> typing.Optional[str]:
        return self._values.get("qualifier")

    @builtins.property
    def source_account(self) -> typing.Optional[str]:
        return self._values.get("source_account")

    @builtins.property
    def source_arn(self) -> typing.Optional[str]:
        return self._values.get("source_arn")

    @builtins.property
    def statement_id(self) -> typing.Optional[str]:
        return self._values.get("statement_id")

    @builtins.property
    def statement_id_prefix(self) -> typing.Optional[str]:
        return self._values.get("statement_id_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaPermissionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LambdaProvisionedConcurrencyConfig(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaProvisionedConcurrencyConfig",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        function_name: str,
        provisioned_concurrent_executions: jsii.Number,
        qualifier: str,
        timeouts: typing.Optional["LambdaProvisionedConcurrencyConfigTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param function_name: 
        :param provisioned_concurrent_executions: 
        :param qualifier: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LambdaProvisionedConcurrencyConfigConfig(
            function_name=function_name,
            provisioned_concurrent_executions=provisioned_concurrent_executions,
            qualifier=qualifier,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LambdaProvisionedConcurrencyConfig, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="functionName")
    def function_name(self) -> str:
        return jsii.get(self, "functionName")

    @function_name.setter
    def function_name(self, value: str) -> None:
        jsii.set(self, "functionName", value)

    @builtins.property
    @jsii.member(jsii_name="provisionedConcurrentExecutions")
    def provisioned_concurrent_executions(self) -> jsii.Number:
        return jsii.get(self, "provisionedConcurrentExecutions")

    @provisioned_concurrent_executions.setter
    def provisioned_concurrent_executions(self, value: jsii.Number) -> None:
        jsii.set(self, "provisionedConcurrentExecutions", value)

    @builtins.property
    @jsii.member(jsii_name="qualifier")
    def qualifier(self) -> str:
        return jsii.get(self, "qualifier")

    @qualifier.setter
    def qualifier(self, value: str) -> None:
        jsii.set(self, "qualifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LambdaProvisionedConcurrencyConfigTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["LambdaProvisionedConcurrencyConfigTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaProvisionedConcurrencyConfigConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "function_name": "functionName",
        "provisioned_concurrent_executions": "provisionedConcurrentExecutions",
        "qualifier": "qualifier",
        "timeouts": "timeouts",
    },
)
class LambdaProvisionedConcurrencyConfigConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        function_name: str,
        provisioned_concurrent_executions: jsii.Number,
        qualifier: str,
        timeouts: typing.Optional["LambdaProvisionedConcurrencyConfigTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param function_name: 
        :param provisioned_concurrent_executions: 
        :param qualifier: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LambdaProvisionedConcurrencyConfigTimeouts(**timeouts)
        self._values = {
            "function_name": function_name,
            "provisioned_concurrent_executions": provisioned_concurrent_executions,
            "qualifier": qualifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def function_name(self) -> str:
        return self._values.get("function_name")

    @builtins.property
    def provisioned_concurrent_executions(self) -> jsii.Number:
        return self._values.get("provisioned_concurrent_executions")

    @builtins.property
    def qualifier(self) -> str:
        return self._values.get("qualifier")

    @builtins.property
    def timeouts(self) -> typing.Optional["LambdaProvisionedConcurrencyConfigTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaProvisionedConcurrencyConfigConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LambdaProvisionedConcurrencyConfigTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "update": "update"},
)
class LambdaProvisionedConcurrencyConfigTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LambdaProvisionedConcurrencyConfigTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LaunchConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        image_id: str,
        instance_type: str,
        associate_public_ip_address: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[
            typing.List["LaunchConfigurationEbsBlockDevice"]
        ] = None,
        ebs_optimized: typing.Optional[bool] = None,
        enable_monitoring: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["LaunchConfigurationEphemeralBlockDevice"]
        ] = None,
        iam_instance_profile: typing.Optional[str] = None,
        key_name: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        placement_tenancy: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["LaunchConfigurationRootBlockDevice"]
        ] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        spot_price: typing.Optional[str] = None,
        user_data: typing.Optional[str] = None,
        user_data_base64: typing.Optional[str] = None,
        vpc_classic_link_id: typing.Optional[str] = None,
        vpc_classic_link_security_groups: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param image_id: 
        :param instance_type: 
        :param associate_public_ip_address: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param enable_monitoring: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param iam_instance_profile: 
        :param key_name: 
        :param name: 
        :param name_prefix: 
        :param placement_tenancy: 
        :param root_block_device: root_block_device block.
        :param security_groups: 
        :param spot_price: 
        :param user_data: 
        :param user_data_base64: 
        :param vpc_classic_link_id: 
        :param vpc_classic_link_security_groups: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LaunchConfigurationConfig(
            image_id=image_id,
            instance_type=instance_type,
            associate_public_ip_address=associate_public_ip_address,
            ebs_block_device=ebs_block_device,
            ebs_optimized=ebs_optimized,
            enable_monitoring=enable_monitoring,
            ephemeral_block_device=ephemeral_block_device,
            iam_instance_profile=iam_instance_profile,
            key_name=key_name,
            name=name,
            name_prefix=name_prefix,
            placement_tenancy=placement_tenancy,
            root_block_device=root_block_device,
            security_groups=security_groups,
            spot_price=spot_price,
            user_data=user_data,
            user_data_base64=user_data_base64,
            vpc_classic_link_id=vpc_classic_link_id,
            vpc_classic_link_security_groups=vpc_classic_link_security_groups,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LaunchConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> str:
        return jsii.get(self, "imageId")

    @image_id.setter
    def image_id(self, value: str) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: str) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> typing.Optional[bool]:
        return jsii.get(self, "associatePublicIpAddress")

    @associate_public_ip_address.setter
    def associate_public_ip_address(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "associatePublicIpAddress", value)

    @builtins.property
    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["LaunchConfigurationEbsBlockDevice"]]:
        return jsii.get(self, "ebsBlockDevice")

    @ebs_block_device.setter
    def ebs_block_device(
        self, value: typing.Optional[typing.List["LaunchConfigurationEbsBlockDevice"]]
    ) -> None:
        jsii.set(self, "ebsBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> typing.Optional[bool]:
        return jsii.get(self, "ebsOptimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ebsOptimized", value)

    @builtins.property
    @jsii.member(jsii_name="enableMonitoring")
    def enable_monitoring(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableMonitoring")

    @enable_monitoring.setter
    def enable_monitoring(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableMonitoring", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["LaunchConfigurationEphemeralBlockDevice"]]:
        return jsii.get(self, "ephemeralBlockDevice")

    @ephemeral_block_device.setter
    def ephemeral_block_device(
        self,
        value: typing.Optional[typing.List["LaunchConfigurationEphemeralBlockDevice"]],
    ) -> None:
        jsii.set(self, "ephemeralBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="iamInstanceProfile")
    def iam_instance_profile(self) -> typing.Optional[str]:
        return jsii.get(self, "iamInstanceProfile")

    @iam_instance_profile.setter
    def iam_instance_profile(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamInstanceProfile", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> typing.Optional[str]:
        return jsii.get(self, "keyName")

    @key_name.setter
    def key_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="placementTenancy")
    def placement_tenancy(self) -> typing.Optional[str]:
        return jsii.get(self, "placementTenancy")

    @placement_tenancy.setter
    def placement_tenancy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "placementTenancy", value)

    @builtins.property
    @jsii.member(jsii_name="rootBlockDevice")
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["LaunchConfigurationRootBlockDevice"]]:
        return jsii.get(self, "rootBlockDevice")

    @root_block_device.setter
    def root_block_device(
        self, value: typing.Optional[typing.List["LaunchConfigurationRootBlockDevice"]]
    ) -> None:
        jsii.set(self, "rootBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="spotPrice")
    def spot_price(self) -> typing.Optional[str]:
        return jsii.get(self, "spotPrice")

    @spot_price.setter
    def spot_price(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "spotPrice", value)

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> typing.Optional[str]:
        return jsii.get(self, "userData")

    @user_data.setter
    def user_data(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userData", value)

    @builtins.property
    @jsii.member(jsii_name="userDataBase64")
    def user_data_base64(self) -> typing.Optional[str]:
        return jsii.get(self, "userDataBase64")

    @user_data_base64.setter
    def user_data_base64(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userDataBase64", value)

    @builtins.property
    @jsii.member(jsii_name="vpcClassicLinkId")
    def vpc_classic_link_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcClassicLinkId")

    @vpc_classic_link_id.setter
    def vpc_classic_link_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcClassicLinkId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcClassicLinkSecurityGroups")
    def vpc_classic_link_security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcClassicLinkSecurityGroups")

    @vpc_classic_link_security_groups.setter
    def vpc_classic_link_security_groups(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "vpcClassicLinkSecurityGroups", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "image_id": "imageId",
        "instance_type": "instanceType",
        "associate_public_ip_address": "associatePublicIpAddress",
        "ebs_block_device": "ebsBlockDevice",
        "ebs_optimized": "ebsOptimized",
        "enable_monitoring": "enableMonitoring",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "iam_instance_profile": "iamInstanceProfile",
        "key_name": "keyName",
        "name": "name",
        "name_prefix": "namePrefix",
        "placement_tenancy": "placementTenancy",
        "root_block_device": "rootBlockDevice",
        "security_groups": "securityGroups",
        "spot_price": "spotPrice",
        "user_data": "userData",
        "user_data_base64": "userDataBase64",
        "vpc_classic_link_id": "vpcClassicLinkId",
        "vpc_classic_link_security_groups": "vpcClassicLinkSecurityGroups",
    },
)
class LaunchConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        image_id: str,
        instance_type: str,
        associate_public_ip_address: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[
            typing.List["LaunchConfigurationEbsBlockDevice"]
        ] = None,
        ebs_optimized: typing.Optional[bool] = None,
        enable_monitoring: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["LaunchConfigurationEphemeralBlockDevice"]
        ] = None,
        iam_instance_profile: typing.Optional[str] = None,
        key_name: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        placement_tenancy: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["LaunchConfigurationRootBlockDevice"]
        ] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        spot_price: typing.Optional[str] = None,
        user_data: typing.Optional[str] = None,
        user_data_base64: typing.Optional[str] = None,
        vpc_classic_link_id: typing.Optional[str] = None,
        vpc_classic_link_security_groups: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param image_id: 
        :param instance_type: 
        :param associate_public_ip_address: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param enable_monitoring: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param iam_instance_profile: 
        :param key_name: 
        :param name: 
        :param name_prefix: 
        :param placement_tenancy: 
        :param root_block_device: root_block_device block.
        :param security_groups: 
        :param spot_price: 
        :param user_data: 
        :param user_data_base64: 
        :param vpc_classic_link_id: 
        :param vpc_classic_link_security_groups: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "image_id": image_id,
            "instance_type": instance_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if associate_public_ip_address is not None:
            self._values["associate_public_ip_address"] = associate_public_ip_address
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if enable_monitoring is not None:
            self._values["enable_monitoring"] = enable_monitoring
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if iam_instance_profile is not None:
            self._values["iam_instance_profile"] = iam_instance_profile
        if key_name is not None:
            self._values["key_name"] = key_name
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if placement_tenancy is not None:
            self._values["placement_tenancy"] = placement_tenancy
        if root_block_device is not None:
            self._values["root_block_device"] = root_block_device
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if spot_price is not None:
            self._values["spot_price"] = spot_price
        if user_data is not None:
            self._values["user_data"] = user_data
        if user_data_base64 is not None:
            self._values["user_data_base64"] = user_data_base64
        if vpc_classic_link_id is not None:
            self._values["vpc_classic_link_id"] = vpc_classic_link_id
        if vpc_classic_link_security_groups is not None:
            self._values[
                "vpc_classic_link_security_groups"
            ] = vpc_classic_link_security_groups

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def image_id(self) -> str:
        return self._values.get("image_id")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def associate_public_ip_address(self) -> typing.Optional[bool]:
        return self._values.get("associate_public_ip_address")

    @builtins.property
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["LaunchConfigurationEbsBlockDevice"]]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[bool]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def enable_monitoring(self) -> typing.Optional[bool]:
        return self._values.get("enable_monitoring")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["LaunchConfigurationEphemeralBlockDevice"]]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def iam_instance_profile(self) -> typing.Optional[str]:
        return self._values.get("iam_instance_profile")

    @builtins.property
    def key_name(self) -> typing.Optional[str]:
        return self._values.get("key_name")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def placement_tenancy(self) -> typing.Optional[str]:
        return self._values.get("placement_tenancy")

    @builtins.property
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["LaunchConfigurationRootBlockDevice"]]:
        """root_block_device block."""
        return self._values.get("root_block_device")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def spot_price(self) -> typing.Optional[str]:
        return self._values.get("spot_price")

    @builtins.property
    def user_data(self) -> typing.Optional[str]:
        return self._values.get("user_data")

    @builtins.property
    def user_data_base64(self) -> typing.Optional[str]:
        return self._values.get("user_data_base64")

    @builtins.property
    def vpc_classic_link_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_classic_link_id")

    @builtins.property
    def vpc_classic_link_security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_classic_link_security_groups")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchConfigurationEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "no_device": "noDevice",
        "snapshot_id": "snapshotId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class LaunchConfigurationEbsBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        no_device: typing.Optional[bool] = None,
        snapshot_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param no_device: 
        :param snapshot_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {
            "device_name": device_name,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if no_device is not None:
            self._values["no_device"] = no_device
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def no_device(self) -> typing.Optional[bool]:
        return self._values.get("no_device")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchConfigurationEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchConfigurationEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={"device_name": "deviceName", "virtual_name": "virtualName"},
)
class LaunchConfigurationEphemeralBlockDevice:
    def __init__(self, *, device_name: str, virtual_name: str) -> None:
        """
        :param device_name: 
        :param virtual_name: 
        """
        self._values = {
            "device_name": device_name,
            "virtual_name": virtual_name,
        }

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def virtual_name(self) -> str:
        return self._values.get("virtual_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchConfigurationEphemeralBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchConfigurationRootBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class LaunchConfigurationRootBlockDevice:
    def __init__(
        self,
        *,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {}
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchConfigurationRootBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LaunchTemplate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        block_device_mappings: typing.Optional[
            typing.List["LaunchTemplateBlockDeviceMappings"]
        ] = None,
        capacity_reservation_specification: typing.Optional[
            typing.List["LaunchTemplateCapacityReservationSpecification"]
        ] = None,
        cpu_options: typing.Optional[typing.List["LaunchTemplateCpuOptions"]] = None,
        credit_specification: typing.Optional[
            typing.List["LaunchTemplateCreditSpecification"]
        ] = None,
        default_version: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        disable_api_termination: typing.Optional[bool] = None,
        ebs_optimized: typing.Optional[str] = None,
        elastic_gpu_specifications: typing.Optional[
            typing.List["LaunchTemplateElasticGpuSpecifications"]
        ] = None,
        elastic_inference_accelerator: typing.Optional[
            typing.List["LaunchTemplateElasticInferenceAccelerator"]
        ] = None,
        hibernation_options: typing.Optional[
            typing.List["LaunchTemplateHibernationOptions"]
        ] = None,
        iam_instance_profile: typing.Optional[
            typing.List["LaunchTemplateIamInstanceProfile"]
        ] = None,
        image_id: typing.Optional[str] = None,
        instance_initiated_shutdown_behavior: typing.Optional[str] = None,
        instance_market_options: typing.Optional[
            typing.List["LaunchTemplateInstanceMarketOptions"]
        ] = None,
        instance_type: typing.Optional[str] = None,
        kernel_id: typing.Optional[str] = None,
        key_name: typing.Optional[str] = None,
        license_specification: typing.Optional[
            typing.List["LaunchTemplateLicenseSpecification"]
        ] = None,
        metadata_options: typing.Optional[
            typing.List["LaunchTemplateMetadataOptions"]
        ] = None,
        monitoring: typing.Optional[typing.List["LaunchTemplateMonitoring"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        network_interfaces: typing.Optional[
            typing.List["LaunchTemplateNetworkInterfaces"]
        ] = None,
        placement: typing.Optional[typing.List["LaunchTemplatePlacement"]] = None,
        ram_disk_id: typing.Optional[str] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tag_specifications: typing.Optional[
            typing.List["LaunchTemplateTagSpecifications"]
        ] = None,
        update_default_version: typing.Optional[bool] = None,
        user_data: typing.Optional[str] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param block_device_mappings: block_device_mappings block.
        :param capacity_reservation_specification: capacity_reservation_specification block.
        :param cpu_options: cpu_options block.
        :param credit_specification: credit_specification block.
        :param default_version: 
        :param description: 
        :param disable_api_termination: 
        :param ebs_optimized: 
        :param elastic_gpu_specifications: elastic_gpu_specifications block.
        :param elastic_inference_accelerator: elastic_inference_accelerator block.
        :param hibernation_options: hibernation_options block.
        :param iam_instance_profile: iam_instance_profile block.
        :param image_id: 
        :param instance_initiated_shutdown_behavior: 
        :param instance_market_options: instance_market_options block.
        :param instance_type: 
        :param kernel_id: 
        :param key_name: 
        :param license_specification: license_specification block.
        :param metadata_options: metadata_options block.
        :param monitoring: monitoring block.
        :param name: 
        :param name_prefix: 
        :param network_interfaces: network_interfaces block.
        :param placement: placement block.
        :param ram_disk_id: 
        :param security_group_names: 
        :param tags: 
        :param tag_specifications: tag_specifications block.
        :param update_default_version: 
        :param user_data: 
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LaunchTemplateConfig(
            block_device_mappings=block_device_mappings,
            capacity_reservation_specification=capacity_reservation_specification,
            cpu_options=cpu_options,
            credit_specification=credit_specification,
            default_version=default_version,
            description=description,
            disable_api_termination=disable_api_termination,
            ebs_optimized=ebs_optimized,
            elastic_gpu_specifications=elastic_gpu_specifications,
            elastic_inference_accelerator=elastic_inference_accelerator,
            hibernation_options=hibernation_options,
            iam_instance_profile=iam_instance_profile,
            image_id=image_id,
            instance_initiated_shutdown_behavior=instance_initiated_shutdown_behavior,
            instance_market_options=instance_market_options,
            instance_type=instance_type,
            kernel_id=kernel_id,
            key_name=key_name,
            license_specification=license_specification,
            metadata_options=metadata_options,
            monitoring=monitoring,
            name=name,
            name_prefix=name_prefix,
            network_interfaces=network_interfaces,
            placement=placement,
            ram_disk_id=ram_disk_id,
            security_group_names=security_group_names,
            tags=tags,
            tag_specifications=tag_specifications,
            update_default_version=update_default_version,
            user_data=user_data,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LaunchTemplate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="latestVersion")
    def latest_version(self) -> jsii.Number:
        return jsii.get(self, "latestVersion")

    @builtins.property
    @jsii.member(jsii_name="blockDeviceMappings")
    def block_device_mappings(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateBlockDeviceMappings"]]:
        return jsii.get(self, "blockDeviceMappings")

    @block_device_mappings.setter
    def block_device_mappings(
        self, value: typing.Optional[typing.List["LaunchTemplateBlockDeviceMappings"]]
    ) -> None:
        jsii.set(self, "blockDeviceMappings", value)

    @builtins.property
    @jsii.member(jsii_name="capacityReservationSpecification")
    def capacity_reservation_specification(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateCapacityReservationSpecification"]]:
        return jsii.get(self, "capacityReservationSpecification")

    @capacity_reservation_specification.setter
    def capacity_reservation_specification(
        self,
        value: typing.Optional[
            typing.List["LaunchTemplateCapacityReservationSpecification"]
        ],
    ) -> None:
        jsii.set(self, "capacityReservationSpecification", value)

    @builtins.property
    @jsii.member(jsii_name="cpuOptions")
    def cpu_options(self) -> typing.Optional[typing.List["LaunchTemplateCpuOptions"]]:
        return jsii.get(self, "cpuOptions")

    @cpu_options.setter
    def cpu_options(
        self, value: typing.Optional[typing.List["LaunchTemplateCpuOptions"]]
    ) -> None:
        jsii.set(self, "cpuOptions", value)

    @builtins.property
    @jsii.member(jsii_name="creditSpecification")
    def credit_specification(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateCreditSpecification"]]:
        return jsii.get(self, "creditSpecification")

    @credit_specification.setter
    def credit_specification(
        self, value: typing.Optional[typing.List["LaunchTemplateCreditSpecification"]]
    ) -> None:
        jsii.set(self, "creditSpecification", value)

    @builtins.property
    @jsii.member(jsii_name="defaultVersion")
    def default_version(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "defaultVersion")

    @default_version.setter
    def default_version(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "defaultVersion", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="disableApiTermination")
    def disable_api_termination(self) -> typing.Optional[bool]:
        return jsii.get(self, "disableApiTermination")

    @disable_api_termination.setter
    def disable_api_termination(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "disableApiTermination", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> typing.Optional[str]:
        return jsii.get(self, "ebsOptimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ebsOptimized", value)

    @builtins.property
    @jsii.member(jsii_name="elasticGpuSpecifications")
    def elastic_gpu_specifications(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateElasticGpuSpecifications"]]:
        return jsii.get(self, "elasticGpuSpecifications")

    @elastic_gpu_specifications.setter
    def elastic_gpu_specifications(
        self,
        value: typing.Optional[typing.List["LaunchTemplateElasticGpuSpecifications"]],
    ) -> None:
        jsii.set(self, "elasticGpuSpecifications", value)

    @builtins.property
    @jsii.member(jsii_name="elasticInferenceAccelerator")
    def elastic_inference_accelerator(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateElasticInferenceAccelerator"]]:
        return jsii.get(self, "elasticInferenceAccelerator")

    @elastic_inference_accelerator.setter
    def elastic_inference_accelerator(
        self,
        value: typing.Optional[
            typing.List["LaunchTemplateElasticInferenceAccelerator"]
        ],
    ) -> None:
        jsii.set(self, "elasticInferenceAccelerator", value)

    @builtins.property
    @jsii.member(jsii_name="hibernationOptions")
    def hibernation_options(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateHibernationOptions"]]:
        return jsii.get(self, "hibernationOptions")

    @hibernation_options.setter
    def hibernation_options(
        self, value: typing.Optional[typing.List["LaunchTemplateHibernationOptions"]]
    ) -> None:
        jsii.set(self, "hibernationOptions", value)

    @builtins.property
    @jsii.member(jsii_name="iamInstanceProfile")
    def iam_instance_profile(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateIamInstanceProfile"]]:
        return jsii.get(self, "iamInstanceProfile")

    @iam_instance_profile.setter
    def iam_instance_profile(
        self, value: typing.Optional[typing.List["LaunchTemplateIamInstanceProfile"]]
    ) -> None:
        jsii.set(self, "iamInstanceProfile", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="imageId")
    def image_id(self) -> typing.Optional[str]:
        return jsii.get(self, "imageId")

    @image_id.setter
    def image_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "imageId", value)

    @builtins.property
    @jsii.member(jsii_name="instanceInitiatedShutdownBehavior")
    def instance_initiated_shutdown_behavior(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceInitiatedShutdownBehavior")

    @instance_initiated_shutdown_behavior.setter
    def instance_initiated_shutdown_behavior(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceInitiatedShutdownBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="instanceMarketOptions")
    def instance_market_options(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateInstanceMarketOptions"]]:
        return jsii.get(self, "instanceMarketOptions")

    @instance_market_options.setter
    def instance_market_options(
        self, value: typing.Optional[typing.List["LaunchTemplateInstanceMarketOptions"]]
    ) -> None:
        jsii.set(self, "instanceMarketOptions", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="kernelId")
    def kernel_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kernelId")

    @kernel_id.setter
    def kernel_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kernelId", value)

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> typing.Optional[str]:
        return jsii.get(self, "keyName")

    @key_name.setter
    def key_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyName", value)

    @builtins.property
    @jsii.member(jsii_name="licenseSpecification")
    def license_specification(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateLicenseSpecification"]]:
        return jsii.get(self, "licenseSpecification")

    @license_specification.setter
    def license_specification(
        self, value: typing.Optional[typing.List["LaunchTemplateLicenseSpecification"]]
    ) -> None:
        jsii.set(self, "licenseSpecification", value)

    @builtins.property
    @jsii.member(jsii_name="metadataOptions")
    def metadata_options(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateMetadataOptions"]]:
        return jsii.get(self, "metadataOptions")

    @metadata_options.setter
    def metadata_options(
        self, value: typing.Optional[typing.List["LaunchTemplateMetadataOptions"]]
    ) -> None:
        jsii.set(self, "metadataOptions", value)

    @builtins.property
    @jsii.member(jsii_name="monitoring")
    def monitoring(self) -> typing.Optional[typing.List["LaunchTemplateMonitoring"]]:
        return jsii.get(self, "monitoring")

    @monitoring.setter
    def monitoring(
        self, value: typing.Optional[typing.List["LaunchTemplateMonitoring"]]
    ) -> None:
        jsii.set(self, "monitoring", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterfaces")
    def network_interfaces(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateNetworkInterfaces"]]:
        return jsii.get(self, "networkInterfaces")

    @network_interfaces.setter
    def network_interfaces(
        self, value: typing.Optional[typing.List["LaunchTemplateNetworkInterfaces"]]
    ) -> None:
        jsii.set(self, "networkInterfaces", value)

    @builtins.property
    @jsii.member(jsii_name="placement")
    def placement(self) -> typing.Optional[typing.List["LaunchTemplatePlacement"]]:
        return jsii.get(self, "placement")

    @placement.setter
    def placement(
        self, value: typing.Optional[typing.List["LaunchTemplatePlacement"]]
    ) -> None:
        jsii.set(self, "placement", value)

    @builtins.property
    @jsii.member(jsii_name="ramDiskId")
    def ram_disk_id(self) -> typing.Optional[str]:
        return jsii.get(self, "ramDiskId")

    @ram_disk_id.setter
    def ram_disk_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ramDiskId", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupNames")
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupNames")

    @security_group_names.setter
    def security_group_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupNames", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="tagSpecifications")
    def tag_specifications(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateTagSpecifications"]]:
        return jsii.get(self, "tagSpecifications")

    @tag_specifications.setter
    def tag_specifications(
        self, value: typing.Optional[typing.List["LaunchTemplateTagSpecifications"]]
    ) -> None:
        jsii.set(self, "tagSpecifications", value)

    @builtins.property
    @jsii.member(jsii_name="updateDefaultVersion")
    def update_default_version(self) -> typing.Optional[bool]:
        return jsii.get(self, "updateDefaultVersion")

    @update_default_version.setter
    def update_default_version(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "updateDefaultVersion", value)

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> typing.Optional[str]:
        return jsii.get(self, "userData")

    @user_data.setter
    def user_data(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userData", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateBlockDeviceMappings",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "ebs": "ebs",
        "no_device": "noDevice",
        "virtual_name": "virtualName",
    },
)
class LaunchTemplateBlockDeviceMappings:
    def __init__(
        self,
        *,
        device_name: typing.Optional[str] = None,
        ebs: typing.Optional[
            typing.List["LaunchTemplateBlockDeviceMappingsEbs"]
        ] = None,
        no_device: typing.Optional[str] = None,
        virtual_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param ebs: ebs block.
        :param no_device: 
        :param virtual_name: 
        """
        self._values = {}
        if device_name is not None:
            self._values["device_name"] = device_name
        if ebs is not None:
            self._values["ebs"] = ebs
        if no_device is not None:
            self._values["no_device"] = no_device
        if virtual_name is not None:
            self._values["virtual_name"] = virtual_name

    @builtins.property
    def device_name(self) -> typing.Optional[str]:
        return self._values.get("device_name")

    @builtins.property
    def ebs(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateBlockDeviceMappingsEbs"]]:
        """ebs block."""
        return self._values.get("ebs")

    @builtins.property
    def no_device(self) -> typing.Optional[str]:
        return self._values.get("no_device")

    @builtins.property
    def virtual_name(self) -> typing.Optional[str]:
        return self._values.get("virtual_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateBlockDeviceMappings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateBlockDeviceMappingsEbs",
    jsii_struct_bases=[],
    name_mapping={
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "snapshot_id": "snapshotId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class LaunchTemplateBlockDeviceMappingsEbs:
    def __init__(
        self,
        *,
        delete_on_termination: typing.Optional[str] = None,
        encrypted: typing.Optional[str] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        snapshot_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param snapshot_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {}
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[str]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[str]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateBlockDeviceMappingsEbs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateCapacityReservationSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "capacity_reservation_preference": "capacityReservationPreference",
        "capacity_reservation_target": "capacityReservationTarget",
    },
)
class LaunchTemplateCapacityReservationSpecification:
    def __init__(
        self,
        *,
        capacity_reservation_preference: typing.Optional[str] = None,
        capacity_reservation_target: typing.Optional[
            typing.List[
                "LaunchTemplateCapacityReservationSpecificationCapacityReservationTarget"
            ]
        ] = None,
    ) -> None:
        """
        :param capacity_reservation_preference: 
        :param capacity_reservation_target: capacity_reservation_target block.
        """
        self._values = {}
        if capacity_reservation_preference is not None:
            self._values[
                "capacity_reservation_preference"
            ] = capacity_reservation_preference
        if capacity_reservation_target is not None:
            self._values["capacity_reservation_target"] = capacity_reservation_target

    @builtins.property
    def capacity_reservation_preference(self) -> typing.Optional[str]:
        return self._values.get("capacity_reservation_preference")

    @builtins.property
    def capacity_reservation_target(
        self,
    ) -> typing.Optional[
        typing.List[
            "LaunchTemplateCapacityReservationSpecificationCapacityReservationTarget"
        ]
    ]:
        """capacity_reservation_target block."""
        return self._values.get("capacity_reservation_target")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateCapacityReservationSpecification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateCapacityReservationSpecificationCapacityReservationTarget",
    jsii_struct_bases=[],
    name_mapping={"capacity_reservation_id": "capacityReservationId"},
)
class LaunchTemplateCapacityReservationSpecificationCapacityReservationTarget:
    def __init__(self, *, capacity_reservation_id: typing.Optional[str] = None) -> None:
        """
        :param capacity_reservation_id: 
        """
        self._values = {}
        if capacity_reservation_id is not None:
            self._values["capacity_reservation_id"] = capacity_reservation_id

    @builtins.property
    def capacity_reservation_id(self) -> typing.Optional[str]:
        return self._values.get("capacity_reservation_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "LaunchTemplateCapacityReservationSpecificationCapacityReservationTarget(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "block_device_mappings": "blockDeviceMappings",
        "capacity_reservation_specification": "capacityReservationSpecification",
        "cpu_options": "cpuOptions",
        "credit_specification": "creditSpecification",
        "default_version": "defaultVersion",
        "description": "description",
        "disable_api_termination": "disableApiTermination",
        "ebs_optimized": "ebsOptimized",
        "elastic_gpu_specifications": "elasticGpuSpecifications",
        "elastic_inference_accelerator": "elasticInferenceAccelerator",
        "hibernation_options": "hibernationOptions",
        "iam_instance_profile": "iamInstanceProfile",
        "image_id": "imageId",
        "instance_initiated_shutdown_behavior": "instanceInitiatedShutdownBehavior",
        "instance_market_options": "instanceMarketOptions",
        "instance_type": "instanceType",
        "kernel_id": "kernelId",
        "key_name": "keyName",
        "license_specification": "licenseSpecification",
        "metadata_options": "metadataOptions",
        "monitoring": "monitoring",
        "name": "name",
        "name_prefix": "namePrefix",
        "network_interfaces": "networkInterfaces",
        "placement": "placement",
        "ram_disk_id": "ramDiskId",
        "security_group_names": "securityGroupNames",
        "tags": "tags",
        "tag_specifications": "tagSpecifications",
        "update_default_version": "updateDefaultVersion",
        "user_data": "userData",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class LaunchTemplateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        block_device_mappings: typing.Optional[
            typing.List["LaunchTemplateBlockDeviceMappings"]
        ] = None,
        capacity_reservation_specification: typing.Optional[
            typing.List["LaunchTemplateCapacityReservationSpecification"]
        ] = None,
        cpu_options: typing.Optional[typing.List["LaunchTemplateCpuOptions"]] = None,
        credit_specification: typing.Optional[
            typing.List["LaunchTemplateCreditSpecification"]
        ] = None,
        default_version: typing.Optional[jsii.Number] = None,
        description: typing.Optional[str] = None,
        disable_api_termination: typing.Optional[bool] = None,
        ebs_optimized: typing.Optional[str] = None,
        elastic_gpu_specifications: typing.Optional[
            typing.List["LaunchTemplateElasticGpuSpecifications"]
        ] = None,
        elastic_inference_accelerator: typing.Optional[
            typing.List["LaunchTemplateElasticInferenceAccelerator"]
        ] = None,
        hibernation_options: typing.Optional[
            typing.List["LaunchTemplateHibernationOptions"]
        ] = None,
        iam_instance_profile: typing.Optional[
            typing.List["LaunchTemplateIamInstanceProfile"]
        ] = None,
        image_id: typing.Optional[str] = None,
        instance_initiated_shutdown_behavior: typing.Optional[str] = None,
        instance_market_options: typing.Optional[
            typing.List["LaunchTemplateInstanceMarketOptions"]
        ] = None,
        instance_type: typing.Optional[str] = None,
        kernel_id: typing.Optional[str] = None,
        key_name: typing.Optional[str] = None,
        license_specification: typing.Optional[
            typing.List["LaunchTemplateLicenseSpecification"]
        ] = None,
        metadata_options: typing.Optional[
            typing.List["LaunchTemplateMetadataOptions"]
        ] = None,
        monitoring: typing.Optional[typing.List["LaunchTemplateMonitoring"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        network_interfaces: typing.Optional[
            typing.List["LaunchTemplateNetworkInterfaces"]
        ] = None,
        placement: typing.Optional[typing.List["LaunchTemplatePlacement"]] = None,
        ram_disk_id: typing.Optional[str] = None,
        security_group_names: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tag_specifications: typing.Optional[
            typing.List["LaunchTemplateTagSpecifications"]
        ] = None,
        update_default_version: typing.Optional[bool] = None,
        user_data: typing.Optional[str] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param block_device_mappings: block_device_mappings block.
        :param capacity_reservation_specification: capacity_reservation_specification block.
        :param cpu_options: cpu_options block.
        :param credit_specification: credit_specification block.
        :param default_version: 
        :param description: 
        :param disable_api_termination: 
        :param ebs_optimized: 
        :param elastic_gpu_specifications: elastic_gpu_specifications block.
        :param elastic_inference_accelerator: elastic_inference_accelerator block.
        :param hibernation_options: hibernation_options block.
        :param iam_instance_profile: iam_instance_profile block.
        :param image_id: 
        :param instance_initiated_shutdown_behavior: 
        :param instance_market_options: instance_market_options block.
        :param instance_type: 
        :param kernel_id: 
        :param key_name: 
        :param license_specification: license_specification block.
        :param metadata_options: metadata_options block.
        :param monitoring: monitoring block.
        :param name: 
        :param name_prefix: 
        :param network_interfaces: network_interfaces block.
        :param placement: placement block.
        :param ram_disk_id: 
        :param security_group_names: 
        :param tags: 
        :param tag_specifications: tag_specifications block.
        :param update_default_version: 
        :param user_data: 
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if block_device_mappings is not None:
            self._values["block_device_mappings"] = block_device_mappings
        if capacity_reservation_specification is not None:
            self._values[
                "capacity_reservation_specification"
            ] = capacity_reservation_specification
        if cpu_options is not None:
            self._values["cpu_options"] = cpu_options
        if credit_specification is not None:
            self._values["credit_specification"] = credit_specification
        if default_version is not None:
            self._values["default_version"] = default_version
        if description is not None:
            self._values["description"] = description
        if disable_api_termination is not None:
            self._values["disable_api_termination"] = disable_api_termination
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if elastic_gpu_specifications is not None:
            self._values["elastic_gpu_specifications"] = elastic_gpu_specifications
        if elastic_inference_accelerator is not None:
            self._values[
                "elastic_inference_accelerator"
            ] = elastic_inference_accelerator
        if hibernation_options is not None:
            self._values["hibernation_options"] = hibernation_options
        if iam_instance_profile is not None:
            self._values["iam_instance_profile"] = iam_instance_profile
        if image_id is not None:
            self._values["image_id"] = image_id
        if instance_initiated_shutdown_behavior is not None:
            self._values[
                "instance_initiated_shutdown_behavior"
            ] = instance_initiated_shutdown_behavior
        if instance_market_options is not None:
            self._values["instance_market_options"] = instance_market_options
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if kernel_id is not None:
            self._values["kernel_id"] = kernel_id
        if key_name is not None:
            self._values["key_name"] = key_name
        if license_specification is not None:
            self._values["license_specification"] = license_specification
        if metadata_options is not None:
            self._values["metadata_options"] = metadata_options
        if monitoring is not None:
            self._values["monitoring"] = monitoring
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if network_interfaces is not None:
            self._values["network_interfaces"] = network_interfaces
        if placement is not None:
            self._values["placement"] = placement
        if ram_disk_id is not None:
            self._values["ram_disk_id"] = ram_disk_id
        if security_group_names is not None:
            self._values["security_group_names"] = security_group_names
        if tags is not None:
            self._values["tags"] = tags
        if tag_specifications is not None:
            self._values["tag_specifications"] = tag_specifications
        if update_default_version is not None:
            self._values["update_default_version"] = update_default_version
        if user_data is not None:
            self._values["user_data"] = user_data
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def block_device_mappings(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateBlockDeviceMappings"]]:
        """block_device_mappings block."""
        return self._values.get("block_device_mappings")

    @builtins.property
    def capacity_reservation_specification(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateCapacityReservationSpecification"]]:
        """capacity_reservation_specification block."""
        return self._values.get("capacity_reservation_specification")

    @builtins.property
    def cpu_options(self) -> typing.Optional[typing.List["LaunchTemplateCpuOptions"]]:
        """cpu_options block."""
        return self._values.get("cpu_options")

    @builtins.property
    def credit_specification(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateCreditSpecification"]]:
        """credit_specification block."""
        return self._values.get("credit_specification")

    @builtins.property
    def default_version(self) -> typing.Optional[jsii.Number]:
        return self._values.get("default_version")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def disable_api_termination(self) -> typing.Optional[bool]:
        return self._values.get("disable_api_termination")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[str]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def elastic_gpu_specifications(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateElasticGpuSpecifications"]]:
        """elastic_gpu_specifications block."""
        return self._values.get("elastic_gpu_specifications")

    @builtins.property
    def elastic_inference_accelerator(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateElasticInferenceAccelerator"]]:
        """elastic_inference_accelerator block."""
        return self._values.get("elastic_inference_accelerator")

    @builtins.property
    def hibernation_options(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateHibernationOptions"]]:
        """hibernation_options block."""
        return self._values.get("hibernation_options")

    @builtins.property
    def iam_instance_profile(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateIamInstanceProfile"]]:
        """iam_instance_profile block."""
        return self._values.get("iam_instance_profile")

    @builtins.property
    def image_id(self) -> typing.Optional[str]:
        return self._values.get("image_id")

    @builtins.property
    def instance_initiated_shutdown_behavior(self) -> typing.Optional[str]:
        return self._values.get("instance_initiated_shutdown_behavior")

    @builtins.property
    def instance_market_options(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateInstanceMarketOptions"]]:
        """instance_market_options block."""
        return self._values.get("instance_market_options")

    @builtins.property
    def instance_type(self) -> typing.Optional[str]:
        return self._values.get("instance_type")

    @builtins.property
    def kernel_id(self) -> typing.Optional[str]:
        return self._values.get("kernel_id")

    @builtins.property
    def key_name(self) -> typing.Optional[str]:
        return self._values.get("key_name")

    @builtins.property
    def license_specification(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateLicenseSpecification"]]:
        """license_specification block."""
        return self._values.get("license_specification")

    @builtins.property
    def metadata_options(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateMetadataOptions"]]:
        """metadata_options block."""
        return self._values.get("metadata_options")

    @builtins.property
    def monitoring(self) -> typing.Optional[typing.List["LaunchTemplateMonitoring"]]:
        """monitoring block."""
        return self._values.get("monitoring")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def network_interfaces(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateNetworkInterfaces"]]:
        """network_interfaces block."""
        return self._values.get("network_interfaces")

    @builtins.property
    def placement(self) -> typing.Optional[typing.List["LaunchTemplatePlacement"]]:
        """placement block."""
        return self._values.get("placement")

    @builtins.property
    def ram_disk_id(self) -> typing.Optional[str]:
        return self._values.get("ram_disk_id")

    @builtins.property
    def security_group_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_names")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def tag_specifications(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateTagSpecifications"]]:
        """tag_specifications block."""
        return self._values.get("tag_specifications")

    @builtins.property
    def update_default_version(self) -> typing.Optional[bool]:
        return self._values.get("update_default_version")

    @builtins.property
    def user_data(self) -> typing.Optional[str]:
        return self._values.get("user_data")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateCpuOptions",
    jsii_struct_bases=[],
    name_mapping={"core_count": "coreCount", "threads_per_core": "threadsPerCore"},
)
class LaunchTemplateCpuOptions:
    def __init__(
        self,
        *,
        core_count: typing.Optional[jsii.Number] = None,
        threads_per_core: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param core_count: 
        :param threads_per_core: 
        """
        self._values = {}
        if core_count is not None:
            self._values["core_count"] = core_count
        if threads_per_core is not None:
            self._values["threads_per_core"] = threads_per_core

    @builtins.property
    def core_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("core_count")

    @builtins.property
    def threads_per_core(self) -> typing.Optional[jsii.Number]:
        return self._values.get("threads_per_core")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateCpuOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateCreditSpecification",
    jsii_struct_bases=[],
    name_mapping={"cpu_credits": "cpuCredits"},
)
class LaunchTemplateCreditSpecification:
    def __init__(self, *, cpu_credits: typing.Optional[str] = None) -> None:
        """
        :param cpu_credits: 
        """
        self._values = {}
        if cpu_credits is not None:
            self._values["cpu_credits"] = cpu_credits

    @builtins.property
    def cpu_credits(self) -> typing.Optional[str]:
        return self._values.get("cpu_credits")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateCreditSpecification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateElasticGpuSpecifications",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class LaunchTemplateElasticGpuSpecifications:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateElasticGpuSpecifications(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateElasticInferenceAccelerator",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class LaunchTemplateElasticInferenceAccelerator:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateElasticInferenceAccelerator(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateHibernationOptions",
    jsii_struct_bases=[],
    name_mapping={"configured": "configured"},
)
class LaunchTemplateHibernationOptions:
    def __init__(self, *, configured: bool) -> None:
        """
        :param configured: 
        """
        self._values = {
            "configured": configured,
        }

    @builtins.property
    def configured(self) -> bool:
        return self._values.get("configured")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateHibernationOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateIamInstanceProfile",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "name": "name"},
)
class LaunchTemplateIamInstanceProfile:
    def __init__(
        self, *, arn: typing.Optional[str] = None, name: typing.Optional[str] = None
    ) -> None:
        """
        :param arn: 
        :param name: 
        """
        self._values = {}
        if arn is not None:
            self._values["arn"] = arn
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def arn(self) -> typing.Optional[str]:
        return self._values.get("arn")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateIamInstanceProfile(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateInstanceMarketOptions",
    jsii_struct_bases=[],
    name_mapping={"market_type": "marketType", "spot_options": "spotOptions"},
)
class LaunchTemplateInstanceMarketOptions:
    def __init__(
        self,
        *,
        market_type: typing.Optional[str] = None,
        spot_options: typing.Optional[
            typing.List["LaunchTemplateInstanceMarketOptionsSpotOptions"]
        ] = None,
    ) -> None:
        """
        :param market_type: 
        :param spot_options: spot_options block.
        """
        self._values = {}
        if market_type is not None:
            self._values["market_type"] = market_type
        if spot_options is not None:
            self._values["spot_options"] = spot_options

    @builtins.property
    def market_type(self) -> typing.Optional[str]:
        return self._values.get("market_type")

    @builtins.property
    def spot_options(
        self,
    ) -> typing.Optional[typing.List["LaunchTemplateInstanceMarketOptionsSpotOptions"]]:
        """spot_options block."""
        return self._values.get("spot_options")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateInstanceMarketOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateInstanceMarketOptionsSpotOptions",
    jsii_struct_bases=[],
    name_mapping={
        "block_duration_minutes": "blockDurationMinutes",
        "instance_interruption_behavior": "instanceInterruptionBehavior",
        "max_price": "maxPrice",
        "spot_instance_type": "spotInstanceType",
        "valid_until": "validUntil",
    },
)
class LaunchTemplateInstanceMarketOptionsSpotOptions:
    def __init__(
        self,
        *,
        block_duration_minutes: typing.Optional[jsii.Number] = None,
        instance_interruption_behavior: typing.Optional[str] = None,
        max_price: typing.Optional[str] = None,
        spot_instance_type: typing.Optional[str] = None,
        valid_until: typing.Optional[str] = None,
    ) -> None:
        """
        :param block_duration_minutes: 
        :param instance_interruption_behavior: 
        :param max_price: 
        :param spot_instance_type: 
        :param valid_until: 
        """
        self._values = {}
        if block_duration_minutes is not None:
            self._values["block_duration_minutes"] = block_duration_minutes
        if instance_interruption_behavior is not None:
            self._values[
                "instance_interruption_behavior"
            ] = instance_interruption_behavior
        if max_price is not None:
            self._values["max_price"] = max_price
        if spot_instance_type is not None:
            self._values["spot_instance_type"] = spot_instance_type
        if valid_until is not None:
            self._values["valid_until"] = valid_until

    @builtins.property
    def block_duration_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("block_duration_minutes")

    @builtins.property
    def instance_interruption_behavior(self) -> typing.Optional[str]:
        return self._values.get("instance_interruption_behavior")

    @builtins.property
    def max_price(self) -> typing.Optional[str]:
        return self._values.get("max_price")

    @builtins.property
    def spot_instance_type(self) -> typing.Optional[str]:
        return self._values.get("spot_instance_type")

    @builtins.property
    def valid_until(self) -> typing.Optional[str]:
        return self._values.get("valid_until")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateInstanceMarketOptionsSpotOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateLicenseSpecification",
    jsii_struct_bases=[],
    name_mapping={"license_configuration_arn": "licenseConfigurationArn"},
)
class LaunchTemplateLicenseSpecification:
    def __init__(self, *, license_configuration_arn: str) -> None:
        """
        :param license_configuration_arn: 
        """
        self._values = {
            "license_configuration_arn": license_configuration_arn,
        }

    @builtins.property
    def license_configuration_arn(self) -> str:
        return self._values.get("license_configuration_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateLicenseSpecification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateMetadataOptions",
    jsii_struct_bases=[],
    name_mapping={
        "http_endpoint": "httpEndpoint",
        "http_put_response_hop_limit": "httpPutResponseHopLimit",
        "http_tokens": "httpTokens",
    },
)
class LaunchTemplateMetadataOptions:
    def __init__(
        self,
        *,
        http_endpoint: typing.Optional[str] = None,
        http_put_response_hop_limit: typing.Optional[jsii.Number] = None,
        http_tokens: typing.Optional[str] = None,
    ) -> None:
        """
        :param http_endpoint: 
        :param http_put_response_hop_limit: 
        :param http_tokens: 
        """
        self._values = {}
        if http_endpoint is not None:
            self._values["http_endpoint"] = http_endpoint
        if http_put_response_hop_limit is not None:
            self._values["http_put_response_hop_limit"] = http_put_response_hop_limit
        if http_tokens is not None:
            self._values["http_tokens"] = http_tokens

    @builtins.property
    def http_endpoint(self) -> typing.Optional[str]:
        return self._values.get("http_endpoint")

    @builtins.property
    def http_put_response_hop_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("http_put_response_hop_limit")

    @builtins.property
    def http_tokens(self) -> typing.Optional[str]:
        return self._values.get("http_tokens")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateMetadataOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateMonitoring",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class LaunchTemplateMonitoring:
    def __init__(self, *, enabled: typing.Optional[bool] = None) -> None:
        """
        :param enabled: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateMonitoring(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateNetworkInterfaces",
    jsii_struct_bases=[],
    name_mapping={
        "associate_public_ip_address": "associatePublicIpAddress",
        "delete_on_termination": "deleteOnTermination",
        "description": "description",
        "device_index": "deviceIndex",
        "ipv4_address_count": "ipv4AddressCount",
        "ipv4_addresses": "ipv4Addresses",
        "ipv6_address_count": "ipv6AddressCount",
        "ipv6_addresses": "ipv6Addresses",
        "network_interface_id": "networkInterfaceId",
        "private_ip_address": "privateIpAddress",
        "security_groups": "securityGroups",
        "subnet_id": "subnetId",
    },
)
class LaunchTemplateNetworkInterfaces:
    def __init__(
        self,
        *,
        associate_public_ip_address: typing.Optional[str] = None,
        delete_on_termination: typing.Optional[bool] = None,
        description: typing.Optional[str] = None,
        device_index: typing.Optional[jsii.Number] = None,
        ipv4_address_count: typing.Optional[jsii.Number] = None,
        ipv4_addresses: typing.Optional[typing.List[str]] = None,
        ipv6_address_count: typing.Optional[jsii.Number] = None,
        ipv6_addresses: typing.Optional[typing.List[str]] = None,
        network_interface_id: typing.Optional[str] = None,
        private_ip_address: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        subnet_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param associate_public_ip_address: 
        :param delete_on_termination: 
        :param description: 
        :param device_index: 
        :param ipv4_address_count: 
        :param ipv4_addresses: 
        :param ipv6_address_count: 
        :param ipv6_addresses: 
        :param network_interface_id: 
        :param private_ip_address: 
        :param security_groups: 
        :param subnet_id: 
        """
        self._values = {}
        if associate_public_ip_address is not None:
            self._values["associate_public_ip_address"] = associate_public_ip_address
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if description is not None:
            self._values["description"] = description
        if device_index is not None:
            self._values["device_index"] = device_index
        if ipv4_address_count is not None:
            self._values["ipv4_address_count"] = ipv4_address_count
        if ipv4_addresses is not None:
            self._values["ipv4_addresses"] = ipv4_addresses
        if ipv6_address_count is not None:
            self._values["ipv6_address_count"] = ipv6_address_count
        if ipv6_addresses is not None:
            self._values["ipv6_addresses"] = ipv6_addresses
        if network_interface_id is not None:
            self._values["network_interface_id"] = network_interface_id
        if private_ip_address is not None:
            self._values["private_ip_address"] = private_ip_address
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def associate_public_ip_address(self) -> typing.Optional[str]:
        return self._values.get("associate_public_ip_address")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def device_index(self) -> typing.Optional[jsii.Number]:
        return self._values.get("device_index")

    @builtins.property
    def ipv4_address_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("ipv4_address_count")

    @builtins.property
    def ipv4_addresses(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv4_addresses")

    @builtins.property
    def ipv6_address_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("ipv6_address_count")

    @builtins.property
    def ipv6_addresses(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_addresses")

    @builtins.property
    def network_interface_id(self) -> typing.Optional[str]:
        return self._values.get("network_interface_id")

    @builtins.property
    def private_ip_address(self) -> typing.Optional[str]:
        return self._values.get("private_ip_address")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateNetworkInterfaces(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplatePlacement",
    jsii_struct_bases=[],
    name_mapping={
        "affinity": "affinity",
        "availability_zone": "availabilityZone",
        "group_name": "groupName",
        "host_id": "hostId",
        "partition_number": "partitionNumber",
        "spread_domain": "spreadDomain",
        "tenancy": "tenancy",
    },
)
class LaunchTemplatePlacement:
    def __init__(
        self,
        *,
        affinity: typing.Optional[str] = None,
        availability_zone: typing.Optional[str] = None,
        group_name: typing.Optional[str] = None,
        host_id: typing.Optional[str] = None,
        partition_number: typing.Optional[jsii.Number] = None,
        spread_domain: typing.Optional[str] = None,
        tenancy: typing.Optional[str] = None,
    ) -> None:
        """
        :param affinity: 
        :param availability_zone: 
        :param group_name: 
        :param host_id: 
        :param partition_number: 
        :param spread_domain: 
        :param tenancy: 
        """
        self._values = {}
        if affinity is not None:
            self._values["affinity"] = affinity
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if group_name is not None:
            self._values["group_name"] = group_name
        if host_id is not None:
            self._values["host_id"] = host_id
        if partition_number is not None:
            self._values["partition_number"] = partition_number
        if spread_domain is not None:
            self._values["spread_domain"] = spread_domain
        if tenancy is not None:
            self._values["tenancy"] = tenancy

    @builtins.property
    def affinity(self) -> typing.Optional[str]:
        return self._values.get("affinity")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def group_name(self) -> typing.Optional[str]:
        return self._values.get("group_name")

    @builtins.property
    def host_id(self) -> typing.Optional[str]:
        return self._values.get("host_id")

    @builtins.property
    def partition_number(self) -> typing.Optional[jsii.Number]:
        return self._values.get("partition_number")

    @builtins.property
    def spread_domain(self) -> typing.Optional[str]:
        return self._values.get("spread_domain")

    @builtins.property
    def tenancy(self) -> typing.Optional[str]:
        return self._values.get("tenancy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplatePlacement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LaunchTemplateTagSpecifications",
    jsii_struct_bases=[],
    name_mapping={"resource_type": "resourceType", "tags": "tags"},
)
class LaunchTemplateTagSpecifications:
    def __init__(
        self,
        *,
        resource_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param resource_type: 
        :param tags: 
        """
        self._values = {}
        if resource_type is not None:
            self._values["resource_type"] = resource_type
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def resource_type(self) -> typing.Optional[str]:
        return self._values.get("resource_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LaunchTemplateTagSpecifications(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Lb(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Lb",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        access_logs: typing.Optional[typing.List["LbAccessLogs"]] = None,
        drop_invalid_header_fields: typing.Optional[bool] = None,
        enable_cross_zone_load_balancing: typing.Optional[bool] = None,
        enable_deletion_protection: typing.Optional[bool] = None,
        enable_http2: typing.Optional[bool] = None,
        idle_timeout: typing.Optional[jsii.Number] = None,
        internal: typing.Optional[bool] = None,
        ip_address_type: typing.Optional[str] = None,
        load_balancer_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        subnet_mapping: typing.Optional[typing.List["LbSubnetMapping"]] = None,
        subnets: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["LbTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param access_logs: access_logs block.
        :param drop_invalid_header_fields: 
        :param enable_cross_zone_load_balancing: 
        :param enable_deletion_protection: 
        :param enable_http2: 
        :param idle_timeout: 
        :param internal: 
        :param ip_address_type: 
        :param load_balancer_type: 
        :param name: 
        :param name_prefix: 
        :param security_groups: 
        :param subnet_mapping: subnet_mapping block.
        :param subnets: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbConfig(
            access_logs=access_logs,
            drop_invalid_header_fields=drop_invalid_header_fields,
            enable_cross_zone_load_balancing=enable_cross_zone_load_balancing,
            enable_deletion_protection=enable_deletion_protection,
            enable_http2=enable_http2,
            idle_timeout=idle_timeout,
            internal=internal,
            ip_address_type=ip_address_type,
            load_balancer_type=load_balancer_type,
            name=name,
            name_prefix=name_prefix,
            security_groups=security_groups,
            subnet_mapping=subnet_mapping,
            subnets=subnets,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Lb, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @builtins.property
    @jsii.member(jsii_name="accessLogs")
    def access_logs(self) -> typing.Optional[typing.List["LbAccessLogs"]]:
        return jsii.get(self, "accessLogs")

    @access_logs.setter
    def access_logs(self, value: typing.Optional[typing.List["LbAccessLogs"]]) -> None:
        jsii.set(self, "accessLogs", value)

    @builtins.property
    @jsii.member(jsii_name="dropInvalidHeaderFields")
    def drop_invalid_header_fields(self) -> typing.Optional[bool]:
        return jsii.get(self, "dropInvalidHeaderFields")

    @drop_invalid_header_fields.setter
    def drop_invalid_header_fields(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "dropInvalidHeaderFields", value)

    @builtins.property
    @jsii.member(jsii_name="enableCrossZoneLoadBalancing")
    def enable_cross_zone_load_balancing(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableCrossZoneLoadBalancing")

    @enable_cross_zone_load_balancing.setter
    def enable_cross_zone_load_balancing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableCrossZoneLoadBalancing", value)

    @builtins.property
    @jsii.member(jsii_name="enableDeletionProtection")
    def enable_deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableDeletionProtection")

    @enable_deletion_protection.setter
    def enable_deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableDeletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="enableHttp2")
    def enable_http2(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableHttp2")

    @enable_http2.setter
    def enable_http2(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableHttp2", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="idleTimeout")
    def idle_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "idleTimeout")

    @idle_timeout.setter
    def idle_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "idleTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="internal")
    def internal(self) -> typing.Optional[bool]:
        return jsii.get(self, "internal")

    @internal.setter
    def internal(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "internal", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddressType")
    def ip_address_type(self) -> typing.Optional[str]:
        return jsii.get(self, "ipAddressType")

    @ip_address_type.setter
    def ip_address_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipAddressType", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerType")
    def load_balancer_type(self) -> typing.Optional[str]:
        return jsii.get(self, "loadBalancerType")

    @load_balancer_type.setter
    def load_balancer_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "loadBalancerType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="subnetMapping")
    def subnet_mapping(self) -> typing.Optional[typing.List["LbSubnetMapping"]]:
        return jsii.get(self, "subnetMapping")

    @subnet_mapping.setter
    def subnet_mapping(
        self, value: typing.Optional[typing.List["LbSubnetMapping"]]
    ) -> None:
        jsii.set(self, "subnetMapping", value)

    @builtins.property
    @jsii.member(jsii_name="subnets")
    def subnets(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnets")

    @subnets.setter
    def subnets(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnets", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["LbTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbAccessLogs",
    jsii_struct_bases=[],
    name_mapping={"bucket": "bucket", "enabled": "enabled", "prefix": "prefix"},
)
class LbAccessLogs:
    def __init__(
        self,
        *,
        bucket: str,
        enabled: typing.Optional[bool] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket: 
        :param enabled: 
        :param prefix: 
        """
        self._values = {
            "bucket": bucket,
        }
        if enabled is not None:
            self._values["enabled"] = enabled
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbAccessLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "access_logs": "accessLogs",
        "drop_invalid_header_fields": "dropInvalidHeaderFields",
        "enable_cross_zone_load_balancing": "enableCrossZoneLoadBalancing",
        "enable_deletion_protection": "enableDeletionProtection",
        "enable_http2": "enableHttp2",
        "idle_timeout": "idleTimeout",
        "internal": "internal",
        "ip_address_type": "ipAddressType",
        "load_balancer_type": "loadBalancerType",
        "name": "name",
        "name_prefix": "namePrefix",
        "security_groups": "securityGroups",
        "subnet_mapping": "subnetMapping",
        "subnets": "subnets",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class LbConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        access_logs: typing.Optional[typing.List["LbAccessLogs"]] = None,
        drop_invalid_header_fields: typing.Optional[bool] = None,
        enable_cross_zone_load_balancing: typing.Optional[bool] = None,
        enable_deletion_protection: typing.Optional[bool] = None,
        enable_http2: typing.Optional[bool] = None,
        idle_timeout: typing.Optional[jsii.Number] = None,
        internal: typing.Optional[bool] = None,
        ip_address_type: typing.Optional[str] = None,
        load_balancer_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        subnet_mapping: typing.Optional[typing.List["LbSubnetMapping"]] = None,
        subnets: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["LbTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param access_logs: access_logs block.
        :param drop_invalid_header_fields: 
        :param enable_cross_zone_load_balancing: 
        :param enable_deletion_protection: 
        :param enable_http2: 
        :param idle_timeout: 
        :param internal: 
        :param ip_address_type: 
        :param load_balancer_type: 
        :param name: 
        :param name_prefix: 
        :param security_groups: 
        :param subnet_mapping: subnet_mapping block.
        :param subnets: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if access_logs is not None:
            self._values["access_logs"] = access_logs
        if drop_invalid_header_fields is not None:
            self._values["drop_invalid_header_fields"] = drop_invalid_header_fields
        if enable_cross_zone_load_balancing is not None:
            self._values[
                "enable_cross_zone_load_balancing"
            ] = enable_cross_zone_load_balancing
        if enable_deletion_protection is not None:
            self._values["enable_deletion_protection"] = enable_deletion_protection
        if enable_http2 is not None:
            self._values["enable_http2"] = enable_http2
        if idle_timeout is not None:
            self._values["idle_timeout"] = idle_timeout
        if internal is not None:
            self._values["internal"] = internal
        if ip_address_type is not None:
            self._values["ip_address_type"] = ip_address_type
        if load_balancer_type is not None:
            self._values["load_balancer_type"] = load_balancer_type
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if subnet_mapping is not None:
            self._values["subnet_mapping"] = subnet_mapping
        if subnets is not None:
            self._values["subnets"] = subnets
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def access_logs(self) -> typing.Optional[typing.List["LbAccessLogs"]]:
        """access_logs block."""
        return self._values.get("access_logs")

    @builtins.property
    def drop_invalid_header_fields(self) -> typing.Optional[bool]:
        return self._values.get("drop_invalid_header_fields")

    @builtins.property
    def enable_cross_zone_load_balancing(self) -> typing.Optional[bool]:
        return self._values.get("enable_cross_zone_load_balancing")

    @builtins.property
    def enable_deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("enable_deletion_protection")

    @builtins.property
    def enable_http2(self) -> typing.Optional[bool]:
        return self._values.get("enable_http2")

    @builtins.property
    def idle_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("idle_timeout")

    @builtins.property
    def internal(self) -> typing.Optional[bool]:
        return self._values.get("internal")

    @builtins.property
    def ip_address_type(self) -> typing.Optional[str]:
        return self._values.get("ip_address_type")

    @builtins.property
    def load_balancer_type(self) -> typing.Optional[str]:
        return self._values.get("load_balancer_type")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def subnet_mapping(self) -> typing.Optional[typing.List["LbSubnetMapping"]]:
        """subnet_mapping block."""
        return self._values.get("subnet_mapping")

    @builtins.property
    def subnets(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnets")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["LbTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbCookieStickinessPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LbCookieStickinessPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        lb_port: jsii.Number,
        load_balancer: str,
        name: str,
        cookie_expiration_period: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param lb_port: 
        :param load_balancer: 
        :param name: 
        :param cookie_expiration_period: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbCookieStickinessPolicyConfig(
            lb_port=lb_port,
            load_balancer=load_balancer,
            name=name,
            cookie_expiration_period=cookie_expiration_period,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbCookieStickinessPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="lbPort")
    def lb_port(self) -> jsii.Number:
        return jsii.get(self, "lbPort")

    @lb_port.setter
    def lb_port(self, value: jsii.Number) -> None:
        jsii.set(self, "lbPort", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancer")
    def load_balancer(self) -> str:
        return jsii.get(self, "loadBalancer")

    @load_balancer.setter
    def load_balancer(self, value: str) -> None:
        jsii.set(self, "loadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="cookieExpirationPeriod")
    def cookie_expiration_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cookieExpirationPeriod")

    @cookie_expiration_period.setter
    def cookie_expiration_period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cookieExpirationPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbCookieStickinessPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "lb_port": "lbPort",
        "load_balancer": "loadBalancer",
        "name": "name",
        "cookie_expiration_period": "cookieExpirationPeriod",
    },
)
class LbCookieStickinessPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        lb_port: jsii.Number,
        load_balancer: str,
        name: str,
        cookie_expiration_period: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param lb_port: 
        :param load_balancer: 
        :param name: 
        :param cookie_expiration_period: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "lb_port": lb_port,
            "load_balancer": load_balancer,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cookie_expiration_period is not None:
            self._values["cookie_expiration_period"] = cookie_expiration_period

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def lb_port(self) -> jsii.Number:
        return self._values.get("lb_port")

    @builtins.property
    def load_balancer(self) -> str:
        return self._values.get("load_balancer")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def cookie_expiration_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cookie_expiration_period")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbCookieStickinessPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbListener(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LbListener",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_action: typing.List["LbListenerDefaultAction"],
        load_balancer_arn: str,
        port: jsii.Number,
        certificate_arn: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        ssl_policy: typing.Optional[str] = None,
        timeouts: typing.Optional["LbListenerTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_action: default_action block.
        :param load_balancer_arn: 
        :param port: 
        :param certificate_arn: 
        :param protocol: 
        :param ssl_policy: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbListenerConfig(
            default_action=default_action,
            load_balancer_arn=load_balancer_arn,
            port=port,
            certificate_arn=certificate_arn,
            protocol=protocol,
            ssl_policy=ssl_policy,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbListener, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultAction")
    def default_action(self) -> typing.List["LbListenerDefaultAction"]:
        return jsii.get(self, "defaultAction")

    @default_action.setter
    def default_action(self, value: typing.List["LbListenerDefaultAction"]) -> None:
        jsii.set(self, "defaultAction", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerArn")
    def load_balancer_arn(self) -> str:
        return jsii.get(self, "loadBalancerArn")

    @load_balancer_arn.setter
    def load_balancer_arn(self, value: str) -> None:
        jsii.set(self, "loadBalancerArn", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: jsii.Number) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> typing.Optional[str]:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="sslPolicy")
    def ssl_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "sslPolicy")

    @ssl_policy.setter
    def ssl_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sslPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["LbListenerTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["LbListenerTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class LbListenerCertificate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerCertificate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate_arn: str,
        listener_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate_arn: 
        :param listener_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbListenerCertificateConfig(
            certificate_arn=certificate_arn,
            listener_arn=listener_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbListenerCertificate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="certificateArn")
    def certificate_arn(self) -> str:
        return jsii.get(self, "certificateArn")

    @certificate_arn.setter
    def certificate_arn(self, value: str) -> None:
        jsii.set(self, "certificateArn", value)

    @builtins.property
    @jsii.member(jsii_name="listenerArn")
    def listener_arn(self) -> str:
        return jsii.get(self, "listenerArn")

    @listener_arn.setter
    def listener_arn(self, value: str) -> None:
        jsii.set(self, "listenerArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerCertificateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate_arn": "certificateArn",
        "listener_arn": "listenerArn",
    },
)
class LbListenerCertificateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate_arn: str,
        listener_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate_arn: 
        :param listener_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "certificate_arn": certificate_arn,
            "listener_arn": listener_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate_arn(self) -> str:
        return self._values.get("certificate_arn")

    @builtins.property
    def listener_arn(self) -> str:
        return self._values.get("listener_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerCertificateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_action": "defaultAction",
        "load_balancer_arn": "loadBalancerArn",
        "port": "port",
        "certificate_arn": "certificateArn",
        "protocol": "protocol",
        "ssl_policy": "sslPolicy",
        "timeouts": "timeouts",
    },
)
class LbListenerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_action: typing.List["LbListenerDefaultAction"],
        load_balancer_arn: str,
        port: jsii.Number,
        certificate_arn: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        ssl_policy: typing.Optional[str] = None,
        timeouts: typing.Optional["LbListenerTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_action: default_action block.
        :param load_balancer_arn: 
        :param port: 
        :param certificate_arn: 
        :param protocol: 
        :param ssl_policy: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = LbListenerTimeouts(**timeouts)
        self._values = {
            "default_action": default_action,
            "load_balancer_arn": load_balancer_arn,
            "port": port,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if certificate_arn is not None:
            self._values["certificate_arn"] = certificate_arn
        if protocol is not None:
            self._values["protocol"] = protocol
        if ssl_policy is not None:
            self._values["ssl_policy"] = ssl_policy
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_action(self) -> typing.List["LbListenerDefaultAction"]:
        """default_action block."""
        return self._values.get("default_action")

    @builtins.property
    def load_balancer_arn(self) -> str:
        return self._values.get("load_balancer_arn")

    @builtins.property
    def port(self) -> jsii.Number:
        return self._values.get("port")

    @builtins.property
    def certificate_arn(self) -> typing.Optional[str]:
        return self._values.get("certificate_arn")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def ssl_policy(self) -> typing.Optional[str]:
        return self._values.get("ssl_policy")

    @builtins.property
    def timeouts(self) -> typing.Optional["LbListenerTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultAction",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "authenticate_cognito": "authenticateCognito",
        "authenticate_oidc": "authenticateOidc",
        "fixed_response": "fixedResponse",
        "forward": "forward",
        "order": "order",
        "redirect": "redirect",
        "target_group_arn": "targetGroupArn",
    },
)
class LbListenerDefaultAction:
    def __init__(
        self,
        *,
        type: str,
        authenticate_cognito: typing.Optional[
            typing.List["LbListenerDefaultActionAuthenticateCognito"]
        ] = None,
        authenticate_oidc: typing.Optional[
            typing.List["LbListenerDefaultActionAuthenticateOidc"]
        ] = None,
        fixed_response: typing.Optional[
            typing.List["LbListenerDefaultActionFixedResponse"]
        ] = None,
        forward: typing.Optional[typing.List["LbListenerDefaultActionForward"]] = None,
        order: typing.Optional[jsii.Number] = None,
        redirect: typing.Optional[
            typing.List["LbListenerDefaultActionRedirect"]
        ] = None,
        target_group_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param authenticate_cognito: authenticate_cognito block.
        :param authenticate_oidc: authenticate_oidc block.
        :param fixed_response: fixed_response block.
        :param forward: forward block.
        :param order: 
        :param redirect: redirect block.
        :param target_group_arn: 
        """
        self._values = {
            "type": type,
        }
        if authenticate_cognito is not None:
            self._values["authenticate_cognito"] = authenticate_cognito
        if authenticate_oidc is not None:
            self._values["authenticate_oidc"] = authenticate_oidc
        if fixed_response is not None:
            self._values["fixed_response"] = fixed_response
        if forward is not None:
            self._values["forward"] = forward
        if order is not None:
            self._values["order"] = order
        if redirect is not None:
            self._values["redirect"] = redirect
        if target_group_arn is not None:
            self._values["target_group_arn"] = target_group_arn

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def authenticate_cognito(
        self,
    ) -> typing.Optional[typing.List["LbListenerDefaultActionAuthenticateCognito"]]:
        """authenticate_cognito block."""
        return self._values.get("authenticate_cognito")

    @builtins.property
    def authenticate_oidc(
        self,
    ) -> typing.Optional[typing.List["LbListenerDefaultActionAuthenticateOidc"]]:
        """authenticate_oidc block."""
        return self._values.get("authenticate_oidc")

    @builtins.property
    def fixed_response(
        self,
    ) -> typing.Optional[typing.List["LbListenerDefaultActionFixedResponse"]]:
        """fixed_response block."""
        return self._values.get("fixed_response")

    @builtins.property
    def forward(self) -> typing.Optional[typing.List["LbListenerDefaultActionForward"]]:
        """forward block."""
        return self._values.get("forward")

    @builtins.property
    def order(self) -> typing.Optional[jsii.Number]:
        return self._values.get("order")

    @builtins.property
    def redirect(
        self,
    ) -> typing.Optional[typing.List["LbListenerDefaultActionRedirect"]]:
        """redirect block."""
        return self._values.get("redirect")

    @builtins.property
    def target_group_arn(self) -> typing.Optional[str]:
        return self._values.get("target_group_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultActionAuthenticateCognito",
    jsii_struct_bases=[],
    name_mapping={
        "user_pool_arn": "userPoolArn",
        "user_pool_client_id": "userPoolClientId",
        "user_pool_domain": "userPoolDomain",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class LbListenerDefaultActionAuthenticateCognito:
    def __init__(
        self,
        *,
        user_pool_arn: str,
        user_pool_client_id: str,
        user_pool_domain: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param user_pool_arn: 
        :param user_pool_client_id: 
        :param user_pool_domain: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "user_pool_arn": user_pool_arn,
            "user_pool_client_id": user_pool_client_id,
            "user_pool_domain": user_pool_domain,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def user_pool_arn(self) -> str:
        return self._values.get("user_pool_arn")

    @builtins.property
    def user_pool_client_id(self) -> str:
        return self._values.get("user_pool_client_id")

    @builtins.property
    def user_pool_domain(self) -> str:
        return self._values.get("user_pool_domain")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultActionAuthenticateCognito(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultActionAuthenticateOidc",
    jsii_struct_bases=[],
    name_mapping={
        "authorization_endpoint": "authorizationEndpoint",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "issuer": "issuer",
        "token_endpoint": "tokenEndpoint",
        "user_info_endpoint": "userInfoEndpoint",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class LbListenerDefaultActionAuthenticateOidc:
    def __init__(
        self,
        *,
        authorization_endpoint: str,
        client_id: str,
        client_secret: str,
        issuer: str,
        token_endpoint: str,
        user_info_endpoint: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param authorization_endpoint: 
        :param client_id: 
        :param client_secret: 
        :param issuer: 
        :param token_endpoint: 
        :param user_info_endpoint: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "authorization_endpoint": authorization_endpoint,
            "client_id": client_id,
            "client_secret": client_secret,
            "issuer": issuer,
            "token_endpoint": token_endpoint,
            "user_info_endpoint": user_info_endpoint,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def authorization_endpoint(self) -> str:
        return self._values.get("authorization_endpoint")

    @builtins.property
    def client_id(self) -> str:
        return self._values.get("client_id")

    @builtins.property
    def client_secret(self) -> str:
        return self._values.get("client_secret")

    @builtins.property
    def issuer(self) -> str:
        return self._values.get("issuer")

    @builtins.property
    def token_endpoint(self) -> str:
        return self._values.get("token_endpoint")

    @builtins.property
    def user_info_endpoint(self) -> str:
        return self._values.get("user_info_endpoint")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultActionAuthenticateOidc(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultActionFixedResponse",
    jsii_struct_bases=[],
    name_mapping={
        "content_type": "contentType",
        "message_body": "messageBody",
        "status_code": "statusCode",
    },
)
class LbListenerDefaultActionFixedResponse:
    def __init__(
        self,
        *,
        content_type: str,
        message_body: typing.Optional[str] = None,
        status_code: typing.Optional[str] = None,
    ) -> None:
        """
        :param content_type: 
        :param message_body: 
        :param status_code: 
        """
        self._values = {
            "content_type": content_type,
        }
        if message_body is not None:
            self._values["message_body"] = message_body
        if status_code is not None:
            self._values["status_code"] = status_code

    @builtins.property
    def content_type(self) -> str:
        return self._values.get("content_type")

    @builtins.property
    def message_body(self) -> typing.Optional[str]:
        return self._values.get("message_body")

    @builtins.property
    def status_code(self) -> typing.Optional[str]:
        return self._values.get("status_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultActionFixedResponse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultActionForward",
    jsii_struct_bases=[],
    name_mapping={"target_group": "targetGroup", "stickiness": "stickiness"},
)
class LbListenerDefaultActionForward:
    def __init__(
        self,
        *,
        target_group: typing.List["LbListenerDefaultActionForwardTargetGroup"],
        stickiness: typing.Optional[
            typing.List["LbListenerDefaultActionForwardStickiness"]
        ] = None,
    ) -> None:
        """
        :param target_group: target_group block.
        :param stickiness: stickiness block.
        """
        self._values = {
            "target_group": target_group,
        }
        if stickiness is not None:
            self._values["stickiness"] = stickiness

    @builtins.property
    def target_group(self) -> typing.List["LbListenerDefaultActionForwardTargetGroup"]:
        """target_group block."""
        return self._values.get("target_group")

    @builtins.property
    def stickiness(
        self,
    ) -> typing.Optional[typing.List["LbListenerDefaultActionForwardStickiness"]]:
        """stickiness block."""
        return self._values.get("stickiness")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultActionForward(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultActionForwardStickiness",
    jsii_struct_bases=[],
    name_mapping={"duration": "duration", "enabled": "enabled"},
)
class LbListenerDefaultActionForwardStickiness:
    def __init__(
        self, *, duration: jsii.Number, enabled: typing.Optional[bool] = None
    ) -> None:
        """
        :param duration: 
        :param enabled: 
        """
        self._values = {
            "duration": duration,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def duration(self) -> jsii.Number:
        return self._values.get("duration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultActionForwardStickiness(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultActionForwardTargetGroup",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "weight": "weight"},
)
class LbListenerDefaultActionForwardTargetGroup:
    def __init__(
        self, *, arn: str, weight: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param arn: 
        :param weight: 
        """
        self._values = {
            "arn": arn,
        }
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultActionForwardTargetGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerDefaultActionRedirect",
    jsii_struct_bases=[],
    name_mapping={
        "status_code": "statusCode",
        "host": "host",
        "path": "path",
        "port": "port",
        "protocol": "protocol",
        "query": "query",
    },
)
class LbListenerDefaultActionRedirect:
    def __init__(
        self,
        *,
        status_code: str,
        host: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        port: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        query: typing.Optional[str] = None,
    ) -> None:
        """
        :param status_code: 
        :param host: 
        :param path: 
        :param port: 
        :param protocol: 
        :param query: 
        """
        self._values = {
            "status_code": status_code,
        }
        if host is not None:
            self._values["host"] = host
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if query is not None:
            self._values["query"] = query

    @builtins.property
    def status_code(self) -> str:
        return self._values.get("status_code")

    @builtins.property
    def host(self) -> typing.Optional[str]:
        return self._values.get("host")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def port(self) -> typing.Optional[str]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def query(self) -> typing.Optional[str]:
        return self._values.get("query")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerDefaultActionRedirect(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbListenerRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        action: typing.List["LbListenerRuleAction"],
        condition: typing.List["LbListenerRuleCondition"],
        listener_arn: str,
        priority: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param action: action block.
        :param condition: condition block.
        :param listener_arn: 
        :param priority: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbListenerRuleConfig(
            action=action,
            condition=condition,
            listener_arn=listener_arn,
            priority=priority,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbListenerRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="action")
    def action(self) -> typing.List["LbListenerRuleAction"]:
        return jsii.get(self, "action")

    @action.setter
    def action(self, value: typing.List["LbListenerRuleAction"]) -> None:
        jsii.set(self, "action", value)

    @builtins.property
    @jsii.member(jsii_name="condition")
    def condition(self) -> typing.List["LbListenerRuleCondition"]:
        return jsii.get(self, "condition")

    @condition.setter
    def condition(self, value: typing.List["LbListenerRuleCondition"]) -> None:
        jsii.set(self, "condition", value)

    @builtins.property
    @jsii.member(jsii_name="listenerArn")
    def listener_arn(self) -> str:
        return jsii.get(self, "listenerArn")

    @listener_arn.setter
    def listener_arn(self, value: str) -> None:
        jsii.set(self, "listenerArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "priority")

    @priority.setter
    def priority(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "priority", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleAction",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "authenticate_cognito": "authenticateCognito",
        "authenticate_oidc": "authenticateOidc",
        "fixed_response": "fixedResponse",
        "forward": "forward",
        "order": "order",
        "redirect": "redirect",
        "target_group_arn": "targetGroupArn",
    },
)
class LbListenerRuleAction:
    def __init__(
        self,
        *,
        type: str,
        authenticate_cognito: typing.Optional[
            typing.List["LbListenerRuleActionAuthenticateCognito"]
        ] = None,
        authenticate_oidc: typing.Optional[
            typing.List["LbListenerRuleActionAuthenticateOidc"]
        ] = None,
        fixed_response: typing.Optional[
            typing.List["LbListenerRuleActionFixedResponse"]
        ] = None,
        forward: typing.Optional[typing.List["LbListenerRuleActionForward"]] = None,
        order: typing.Optional[jsii.Number] = None,
        redirect: typing.Optional[typing.List["LbListenerRuleActionRedirect"]] = None,
        target_group_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param authenticate_cognito: authenticate_cognito block.
        :param authenticate_oidc: authenticate_oidc block.
        :param fixed_response: fixed_response block.
        :param forward: forward block.
        :param order: 
        :param redirect: redirect block.
        :param target_group_arn: 
        """
        self._values = {
            "type": type,
        }
        if authenticate_cognito is not None:
            self._values["authenticate_cognito"] = authenticate_cognito
        if authenticate_oidc is not None:
            self._values["authenticate_oidc"] = authenticate_oidc
        if fixed_response is not None:
            self._values["fixed_response"] = fixed_response
        if forward is not None:
            self._values["forward"] = forward
        if order is not None:
            self._values["order"] = order
        if redirect is not None:
            self._values["redirect"] = redirect
        if target_group_arn is not None:
            self._values["target_group_arn"] = target_group_arn

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def authenticate_cognito(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleActionAuthenticateCognito"]]:
        """authenticate_cognito block."""
        return self._values.get("authenticate_cognito")

    @builtins.property
    def authenticate_oidc(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleActionAuthenticateOidc"]]:
        """authenticate_oidc block."""
        return self._values.get("authenticate_oidc")

    @builtins.property
    def fixed_response(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleActionFixedResponse"]]:
        """fixed_response block."""
        return self._values.get("fixed_response")

    @builtins.property
    def forward(self) -> typing.Optional[typing.List["LbListenerRuleActionForward"]]:
        """forward block."""
        return self._values.get("forward")

    @builtins.property
    def order(self) -> typing.Optional[jsii.Number]:
        return self._values.get("order")

    @builtins.property
    def redirect(self) -> typing.Optional[typing.List["LbListenerRuleActionRedirect"]]:
        """redirect block."""
        return self._values.get("redirect")

    @builtins.property
    def target_group_arn(self) -> typing.Optional[str]:
        return self._values.get("target_group_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleActionAuthenticateCognito",
    jsii_struct_bases=[],
    name_mapping={
        "user_pool_arn": "userPoolArn",
        "user_pool_client_id": "userPoolClientId",
        "user_pool_domain": "userPoolDomain",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class LbListenerRuleActionAuthenticateCognito:
    def __init__(
        self,
        *,
        user_pool_arn: str,
        user_pool_client_id: str,
        user_pool_domain: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param user_pool_arn: 
        :param user_pool_client_id: 
        :param user_pool_domain: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "user_pool_arn": user_pool_arn,
            "user_pool_client_id": user_pool_client_id,
            "user_pool_domain": user_pool_domain,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def user_pool_arn(self) -> str:
        return self._values.get("user_pool_arn")

    @builtins.property
    def user_pool_client_id(self) -> str:
        return self._values.get("user_pool_client_id")

    @builtins.property
    def user_pool_domain(self) -> str:
        return self._values.get("user_pool_domain")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleActionAuthenticateCognito(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleActionAuthenticateOidc",
    jsii_struct_bases=[],
    name_mapping={
        "authorization_endpoint": "authorizationEndpoint",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "issuer": "issuer",
        "token_endpoint": "tokenEndpoint",
        "user_info_endpoint": "userInfoEndpoint",
        "authentication_request_extra_params": "authenticationRequestExtraParams",
        "on_unauthenticated_request": "onUnauthenticatedRequest",
        "scope": "scope",
        "session_cookie_name": "sessionCookieName",
        "session_timeout": "sessionTimeout",
    },
)
class LbListenerRuleActionAuthenticateOidc:
    def __init__(
        self,
        *,
        authorization_endpoint: str,
        client_id: str,
        client_secret: str,
        issuer: str,
        token_endpoint: str,
        user_info_endpoint: str,
        authentication_request_extra_params: typing.Optional[
            typing.Mapping[str, str]
        ] = None,
        on_unauthenticated_request: typing.Optional[str] = None,
        scope: typing.Optional[str] = None,
        session_cookie_name: typing.Optional[str] = None,
        session_timeout: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param authorization_endpoint: 
        :param client_id: 
        :param client_secret: 
        :param issuer: 
        :param token_endpoint: 
        :param user_info_endpoint: 
        :param authentication_request_extra_params: 
        :param on_unauthenticated_request: 
        :param scope: 
        :param session_cookie_name: 
        :param session_timeout: 
        """
        self._values = {
            "authorization_endpoint": authorization_endpoint,
            "client_id": client_id,
            "client_secret": client_secret,
            "issuer": issuer,
            "token_endpoint": token_endpoint,
            "user_info_endpoint": user_info_endpoint,
        }
        if authentication_request_extra_params is not None:
            self._values[
                "authentication_request_extra_params"
            ] = authentication_request_extra_params
        if on_unauthenticated_request is not None:
            self._values["on_unauthenticated_request"] = on_unauthenticated_request
        if scope is not None:
            self._values["scope"] = scope
        if session_cookie_name is not None:
            self._values["session_cookie_name"] = session_cookie_name
        if session_timeout is not None:
            self._values["session_timeout"] = session_timeout

    @builtins.property
    def authorization_endpoint(self) -> str:
        return self._values.get("authorization_endpoint")

    @builtins.property
    def client_id(self) -> str:
        return self._values.get("client_id")

    @builtins.property
    def client_secret(self) -> str:
        return self._values.get("client_secret")

    @builtins.property
    def issuer(self) -> str:
        return self._values.get("issuer")

    @builtins.property
    def token_endpoint(self) -> str:
        return self._values.get("token_endpoint")

    @builtins.property
    def user_info_endpoint(self) -> str:
        return self._values.get("user_info_endpoint")

    @builtins.property
    def authentication_request_extra_params(
        self,
    ) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("authentication_request_extra_params")

    @builtins.property
    def on_unauthenticated_request(self) -> typing.Optional[str]:
        return self._values.get("on_unauthenticated_request")

    @builtins.property
    def scope(self) -> typing.Optional[str]:
        return self._values.get("scope")

    @builtins.property
    def session_cookie_name(self) -> typing.Optional[str]:
        return self._values.get("session_cookie_name")

    @builtins.property
    def session_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("session_timeout")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleActionAuthenticateOidc(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleActionFixedResponse",
    jsii_struct_bases=[],
    name_mapping={
        "content_type": "contentType",
        "message_body": "messageBody",
        "status_code": "statusCode",
    },
)
class LbListenerRuleActionFixedResponse:
    def __init__(
        self,
        *,
        content_type: str,
        message_body: typing.Optional[str] = None,
        status_code: typing.Optional[str] = None,
    ) -> None:
        """
        :param content_type: 
        :param message_body: 
        :param status_code: 
        """
        self._values = {
            "content_type": content_type,
        }
        if message_body is not None:
            self._values["message_body"] = message_body
        if status_code is not None:
            self._values["status_code"] = status_code

    @builtins.property
    def content_type(self) -> str:
        return self._values.get("content_type")

    @builtins.property
    def message_body(self) -> typing.Optional[str]:
        return self._values.get("message_body")

    @builtins.property
    def status_code(self) -> typing.Optional[str]:
        return self._values.get("status_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleActionFixedResponse(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleActionForward",
    jsii_struct_bases=[],
    name_mapping={"target_group": "targetGroup", "stickiness": "stickiness"},
)
class LbListenerRuleActionForward:
    def __init__(
        self,
        *,
        target_group: typing.List["LbListenerRuleActionForwardTargetGroup"],
        stickiness: typing.Optional[
            typing.List["LbListenerRuleActionForwardStickiness"]
        ] = None,
    ) -> None:
        """
        :param target_group: target_group block.
        :param stickiness: stickiness block.
        """
        self._values = {
            "target_group": target_group,
        }
        if stickiness is not None:
            self._values["stickiness"] = stickiness

    @builtins.property
    def target_group(self) -> typing.List["LbListenerRuleActionForwardTargetGroup"]:
        """target_group block."""
        return self._values.get("target_group")

    @builtins.property
    def stickiness(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleActionForwardStickiness"]]:
        """stickiness block."""
        return self._values.get("stickiness")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleActionForward(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleActionForwardStickiness",
    jsii_struct_bases=[],
    name_mapping={"duration": "duration", "enabled": "enabled"},
)
class LbListenerRuleActionForwardStickiness:
    def __init__(
        self, *, duration: jsii.Number, enabled: typing.Optional[bool] = None
    ) -> None:
        """
        :param duration: 
        :param enabled: 
        """
        self._values = {
            "duration": duration,
        }
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def duration(self) -> jsii.Number:
        return self._values.get("duration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleActionForwardStickiness(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleActionForwardTargetGroup",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "weight": "weight"},
)
class LbListenerRuleActionForwardTargetGroup:
    def __init__(
        self, *, arn: str, weight: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param arn: 
        :param weight: 
        """
        self._values = {
            "arn": arn,
        }
        if weight is not None:
            self._values["weight"] = weight

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleActionForwardTargetGroup(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleActionRedirect",
    jsii_struct_bases=[],
    name_mapping={
        "status_code": "statusCode",
        "host": "host",
        "path": "path",
        "port": "port",
        "protocol": "protocol",
        "query": "query",
    },
)
class LbListenerRuleActionRedirect:
    def __init__(
        self,
        *,
        status_code: str,
        host: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        port: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        query: typing.Optional[str] = None,
    ) -> None:
        """
        :param status_code: 
        :param host: 
        :param path: 
        :param port: 
        :param protocol: 
        :param query: 
        """
        self._values = {
            "status_code": status_code,
        }
        if host is not None:
            self._values["host"] = host
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if query is not None:
            self._values["query"] = query

    @builtins.property
    def status_code(self) -> str:
        return self._values.get("status_code")

    @builtins.property
    def host(self) -> typing.Optional[str]:
        return self._values.get("host")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def port(self) -> typing.Optional[str]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def query(self) -> typing.Optional[str]:
        return self._values.get("query")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleActionRedirect(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleCondition",
    jsii_struct_bases=[],
    name_mapping={
        "field": "field",
        "host_header": "hostHeader",
        "http_header": "httpHeader",
        "http_request_method": "httpRequestMethod",
        "path_pattern": "pathPattern",
        "query_string": "queryString",
        "source_ip": "sourceIp",
        "values": "values",
    },
)
class LbListenerRuleCondition:
    def __init__(
        self,
        *,
        field: typing.Optional[str] = None,
        host_header: typing.Optional[
            typing.List["LbListenerRuleConditionHostHeader"]
        ] = None,
        http_header: typing.Optional[
            typing.List["LbListenerRuleConditionHttpHeader"]
        ] = None,
        http_request_method: typing.Optional[
            typing.List["LbListenerRuleConditionHttpRequestMethod"]
        ] = None,
        path_pattern: typing.Optional[
            typing.List["LbListenerRuleConditionPathPattern"]
        ] = None,
        query_string: typing.Optional[
            typing.List["LbListenerRuleConditionQueryString"]
        ] = None,
        source_ip: typing.Optional[
            typing.List["LbListenerRuleConditionSourceIp"]
        ] = None,
        values: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param field: 
        :param host_header: host_header block.
        :param http_header: http_header block.
        :param http_request_method: http_request_method block.
        :param path_pattern: path_pattern block.
        :param query_string: query_string block.
        :param source_ip: source_ip block.
        :param values: 
        """
        self._values = {}
        if field is not None:
            self._values["field"] = field
        if host_header is not None:
            self._values["host_header"] = host_header
        if http_header is not None:
            self._values["http_header"] = http_header
        if http_request_method is not None:
            self._values["http_request_method"] = http_request_method
        if path_pattern is not None:
            self._values["path_pattern"] = path_pattern
        if query_string is not None:
            self._values["query_string"] = query_string
        if source_ip is not None:
            self._values["source_ip"] = source_ip
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def field(self) -> typing.Optional[str]:
        return self._values.get("field")

    @builtins.property
    def host_header(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleConditionHostHeader"]]:
        """host_header block."""
        return self._values.get("host_header")

    @builtins.property
    def http_header(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleConditionHttpHeader"]]:
        """http_header block."""
        return self._values.get("http_header")

    @builtins.property
    def http_request_method(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleConditionHttpRequestMethod"]]:
        """http_request_method block."""
        return self._values.get("http_request_method")

    @builtins.property
    def path_pattern(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleConditionPathPattern"]]:
        """path_pattern block."""
        return self._values.get("path_pattern")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleConditionQueryString"]]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def source_ip(
        self,
    ) -> typing.Optional[typing.List["LbListenerRuleConditionSourceIp"]]:
        """source_ip block."""
        return self._values.get("source_ip")

    @builtins.property
    def values(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleCondition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleConditionHostHeader",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class LbListenerRuleConditionHostHeader:
    def __init__(self, *, values: typing.Optional[typing.List[str]] = None) -> None:
        """
        :param values: 
        """
        self._values = {}
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def values(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleConditionHostHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleConditionHttpHeader",
    jsii_struct_bases=[],
    name_mapping={"http_header_name": "httpHeaderName", "values": "values"},
)
class LbListenerRuleConditionHttpHeader:
    def __init__(self, *, http_header_name: str, values: typing.List[str]) -> None:
        """
        :param http_header_name: 
        :param values: 
        """
        self._values = {
            "http_header_name": http_header_name,
            "values": values,
        }

    @builtins.property
    def http_header_name(self) -> str:
        return self._values.get("http_header_name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleConditionHttpHeader(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleConditionHttpRequestMethod",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class LbListenerRuleConditionHttpRequestMethod:
    def __init__(self, *, values: typing.List[str]) -> None:
        """
        :param values: 
        """
        self._values = {
            "values": values,
        }

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleConditionHttpRequestMethod(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleConditionPathPattern",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class LbListenerRuleConditionPathPattern:
    def __init__(self, *, values: typing.Optional[typing.List[str]] = None) -> None:
        """
        :param values: 
        """
        self._values = {}
        if values is not None:
            self._values["values"] = values

    @builtins.property
    def values(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleConditionPathPattern(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleConditionQueryString",
    jsii_struct_bases=[],
    name_mapping={"value": "value", "key": "key"},
)
class LbListenerRuleConditionQueryString:
    def __init__(self, *, value: str, key: typing.Optional[str] = None) -> None:
        """
        :param value: 
        :param key: 
        """
        self._values = {
            "value": value,
        }
        if key is not None:
            self._values["key"] = key

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def key(self) -> typing.Optional[str]:
        return self._values.get("key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleConditionQueryString(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleConditionSourceIp",
    jsii_struct_bases=[],
    name_mapping={"values": "values"},
)
class LbListenerRuleConditionSourceIp:
    def __init__(self, *, values: typing.List[str]) -> None:
        """
        :param values: 
        """
        self._values = {
            "values": values,
        }

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleConditionSourceIp(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "action": "action",
        "condition": "condition",
        "listener_arn": "listenerArn",
        "priority": "priority",
    },
)
class LbListenerRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        action: typing.List["LbListenerRuleAction"],
        condition: typing.List["LbListenerRuleCondition"],
        listener_arn: str,
        priority: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param action: action block.
        :param condition: condition block.
        :param listener_arn: 
        :param priority: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "action": action,
            "condition": condition,
            "listener_arn": listener_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if priority is not None:
            self._values["priority"] = priority

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def action(self) -> typing.List["LbListenerRuleAction"]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def condition(self) -> typing.List["LbListenerRuleCondition"]:
        """condition block."""
        return self._values.get("condition")

    @builtins.property
    def listener_arn(self) -> str:
        return self._values.get("listener_arn")

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        return self._values.get("priority")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbListenerTimeouts",
    jsii_struct_bases=[],
    name_mapping={"read": "read"},
)
class LbListenerTimeouts:
    def __init__(self, *, read: typing.Optional[str] = None) -> None:
        """
        :param read: 
        """
        self._values = {}
        if read is not None:
            self._values["read"] = read

    @builtins.property
    def read(self) -> typing.Optional[str]:
        return self._values.get("read")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbListenerTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbSslNegotiationPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LbSslNegotiationPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        lb_port: jsii.Number,
        load_balancer: str,
        name: str,
        attribute: typing.Optional[
            typing.List["LbSslNegotiationPolicyAttribute"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param lb_port: 
        :param load_balancer: 
        :param name: 
        :param attribute: attribute block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbSslNegotiationPolicyConfig(
            lb_port=lb_port,
            load_balancer=load_balancer,
            name=name,
            attribute=attribute,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbSslNegotiationPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="lbPort")
    def lb_port(self) -> jsii.Number:
        return jsii.get(self, "lbPort")

    @lb_port.setter
    def lb_port(self, value: jsii.Number) -> None:
        jsii.set(self, "lbPort", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancer")
    def load_balancer(self) -> str:
        return jsii.get(self, "loadBalancer")

    @load_balancer.setter
    def load_balancer(self, value: str) -> None:
        jsii.set(self, "loadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="attribute")
    def attribute(
        self,
    ) -> typing.Optional[typing.List["LbSslNegotiationPolicyAttribute"]]:
        return jsii.get(self, "attribute")

    @attribute.setter
    def attribute(
        self, value: typing.Optional[typing.List["LbSslNegotiationPolicyAttribute"]]
    ) -> None:
        jsii.set(self, "attribute", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbSslNegotiationPolicyAttribute",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class LbSslNegotiationPolicyAttribute:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbSslNegotiationPolicyAttribute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbSslNegotiationPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "lb_port": "lbPort",
        "load_balancer": "loadBalancer",
        "name": "name",
        "attribute": "attribute",
    },
)
class LbSslNegotiationPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        lb_port: jsii.Number,
        load_balancer: str,
        name: str,
        attribute: typing.Optional[
            typing.List["LbSslNegotiationPolicyAttribute"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param lb_port: 
        :param load_balancer: 
        :param name: 
        :param attribute: attribute block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "lb_port": lb_port,
            "load_balancer": load_balancer,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attribute is not None:
            self._values["attribute"] = attribute

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def lb_port(self) -> jsii.Number:
        return self._values.get("lb_port")

    @builtins.property
    def load_balancer(self) -> str:
        return self._values.get("load_balancer")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def attribute(
        self,
    ) -> typing.Optional[typing.List["LbSslNegotiationPolicyAttribute"]]:
        """attribute block."""
        return self._values.get("attribute")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbSslNegotiationPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbSubnetMapping",
    jsii_struct_bases=[],
    name_mapping={"subnet_id": "subnetId", "allocation_id": "allocationId"},
)
class LbSubnetMapping:
    def __init__(
        self, *, subnet_id: str, allocation_id: typing.Optional[str] = None
    ) -> None:
        """
        :param subnet_id: 
        :param allocation_id: 
        """
        self._values = {
            "subnet_id": subnet_id,
        }
        if allocation_id is not None:
            self._values["allocation_id"] = allocation_id

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    @builtins.property
    def allocation_id(self) -> typing.Optional[str]:
        return self._values.get("allocation_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbSubnetMapping(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LbTargetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LbTargetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        deregistration_delay: typing.Optional[jsii.Number] = None,
        health_check: typing.Optional[typing.List["LbTargetGroupHealthCheck"]] = None,
        lambda_multi_value_headers_enabled: typing.Optional[bool] = None,
        load_balancing_algorithm_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[str] = None,
        proxy_protocol_v2: typing.Optional[bool] = None,
        slow_start: typing.Optional[jsii.Number] = None,
        stickiness: typing.Optional[typing.List["LbTargetGroupStickiness"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_type: typing.Optional[str] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param deregistration_delay: 
        :param health_check: health_check block.
        :param lambda_multi_value_headers_enabled: 
        :param load_balancing_algorithm_type: 
        :param name: 
        :param name_prefix: 
        :param port: 
        :param protocol: 
        :param proxy_protocol_v2: 
        :param slow_start: 
        :param stickiness: stickiness block.
        :param tags: 
        :param target_type: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbTargetGroupConfig(
            deregistration_delay=deregistration_delay,
            health_check=health_check,
            lambda_multi_value_headers_enabled=lambda_multi_value_headers_enabled,
            load_balancing_algorithm_type=load_balancing_algorithm_type,
            name=name,
            name_prefix=name_prefix,
            port=port,
            protocol=protocol,
            proxy_protocol_v2=proxy_protocol_v2,
            slow_start=slow_start,
            stickiness=stickiness,
            tags=tags,
            target_type=target_type,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbTargetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="arnSuffix")
    def arn_suffix(self) -> str:
        return jsii.get(self, "arnSuffix")

    @builtins.property
    @jsii.member(jsii_name="deregistrationDelay")
    def deregistration_delay(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "deregistrationDelay")

    @deregistration_delay.setter
    def deregistration_delay(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "deregistrationDelay", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheck")
    def health_check(self) -> typing.Optional[typing.List["LbTargetGroupHealthCheck"]]:
        return jsii.get(self, "healthCheck")

    @health_check.setter
    def health_check(
        self, value: typing.Optional[typing.List["LbTargetGroupHealthCheck"]]
    ) -> None:
        jsii.set(self, "healthCheck", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaMultiValueHeadersEnabled")
    def lambda_multi_value_headers_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "lambdaMultiValueHeadersEnabled")

    @lambda_multi_value_headers_enabled.setter
    def lambda_multi_value_headers_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "lambdaMultiValueHeadersEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancingAlgorithmType")
    def load_balancing_algorithm_type(self) -> typing.Optional[str]:
        return jsii.get(self, "loadBalancingAlgorithmType")

    @load_balancing_algorithm_type.setter
    def load_balancing_algorithm_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "loadBalancingAlgorithmType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> typing.Optional[str]:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="proxyProtocolV2")
    def proxy_protocol_v2(self) -> typing.Optional[bool]:
        return jsii.get(self, "proxyProtocolV2")

    @proxy_protocol_v2.setter
    def proxy_protocol_v2(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "proxyProtocolV2", value)

    @builtins.property
    @jsii.member(jsii_name="slowStart")
    def slow_start(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "slowStart")

    @slow_start.setter
    def slow_start(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "slowStart", value)

    @builtins.property
    @jsii.member(jsii_name="stickiness")
    def stickiness(self) -> typing.Optional[typing.List["LbTargetGroupStickiness"]]:
        return jsii.get(self, "stickiness")

    @stickiness.setter
    def stickiness(
        self, value: typing.Optional[typing.List["LbTargetGroupStickiness"]]
    ) -> None:
        jsii.set(self, "stickiness", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="targetType")
    def target_type(self) -> typing.Optional[str]:
        return jsii.get(self, "targetType")

    @target_type.setter
    def target_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "targetType", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


class LbTargetGroupAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LbTargetGroupAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        target_group_arn: str,
        target_id: str,
        availability_zone: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param target_group_arn: 
        :param target_id: 
        :param availability_zone: 
        :param port: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LbTargetGroupAttachmentConfig(
            target_group_arn=target_group_arn,
            target_id=target_id,
            availability_zone=availability_zone,
            port=port,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LbTargetGroupAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="targetGroupArn")
    def target_group_arn(self) -> str:
        return jsii.get(self, "targetGroupArn")

    @target_group_arn.setter
    def target_group_arn(self, value: str) -> None:
        jsii.set(self, "targetGroupArn", value)

    @builtins.property
    @jsii.member(jsii_name="targetId")
    def target_id(self) -> str:
        return jsii.get(self, "targetId")

    @target_id.setter
    def target_id(self, value: str) -> None:
        jsii.set(self, "targetId", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbTargetGroupAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "target_group_arn": "targetGroupArn",
        "target_id": "targetId",
        "availability_zone": "availabilityZone",
        "port": "port",
    },
)
class LbTargetGroupAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        target_group_arn: str,
        target_id: str,
        availability_zone: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param target_group_arn: 
        :param target_id: 
        :param availability_zone: 
        :param port: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "target_group_arn": target_group_arn,
            "target_id": target_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def target_group_arn(self) -> str:
        return self._values.get("target_group_arn")

    @builtins.property
    def target_id(self) -> str:
        return self._values.get("target_id")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTargetGroupAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbTargetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "deregistration_delay": "deregistrationDelay",
        "health_check": "healthCheck",
        "lambda_multi_value_headers_enabled": "lambdaMultiValueHeadersEnabled",
        "load_balancing_algorithm_type": "loadBalancingAlgorithmType",
        "name": "name",
        "name_prefix": "namePrefix",
        "port": "port",
        "protocol": "protocol",
        "proxy_protocol_v2": "proxyProtocolV2",
        "slow_start": "slowStart",
        "stickiness": "stickiness",
        "tags": "tags",
        "target_type": "targetType",
        "vpc_id": "vpcId",
    },
)
class LbTargetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        deregistration_delay: typing.Optional[jsii.Number] = None,
        health_check: typing.Optional[typing.List["LbTargetGroupHealthCheck"]] = None,
        lambda_multi_value_headers_enabled: typing.Optional[bool] = None,
        load_balancing_algorithm_type: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        protocol: typing.Optional[str] = None,
        proxy_protocol_v2: typing.Optional[bool] = None,
        slow_start: typing.Optional[jsii.Number] = None,
        stickiness: typing.Optional[typing.List["LbTargetGroupStickiness"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_type: typing.Optional[str] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param deregistration_delay: 
        :param health_check: health_check block.
        :param lambda_multi_value_headers_enabled: 
        :param load_balancing_algorithm_type: 
        :param name: 
        :param name_prefix: 
        :param port: 
        :param protocol: 
        :param proxy_protocol_v2: 
        :param slow_start: 
        :param stickiness: stickiness block.
        :param tags: 
        :param target_type: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deregistration_delay is not None:
            self._values["deregistration_delay"] = deregistration_delay
        if health_check is not None:
            self._values["health_check"] = health_check
        if lambda_multi_value_headers_enabled is not None:
            self._values[
                "lambda_multi_value_headers_enabled"
            ] = lambda_multi_value_headers_enabled
        if load_balancing_algorithm_type is not None:
            self._values[
                "load_balancing_algorithm_type"
            ] = load_balancing_algorithm_type
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if proxy_protocol_v2 is not None:
            self._values["proxy_protocol_v2"] = proxy_protocol_v2
        if slow_start is not None:
            self._values["slow_start"] = slow_start
        if stickiness is not None:
            self._values["stickiness"] = stickiness
        if tags is not None:
            self._values["tags"] = tags
        if target_type is not None:
            self._values["target_type"] = target_type
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def deregistration_delay(self) -> typing.Optional[jsii.Number]:
        return self._values.get("deregistration_delay")

    @builtins.property
    def health_check(self) -> typing.Optional[typing.List["LbTargetGroupHealthCheck"]]:
        """health_check block."""
        return self._values.get("health_check")

    @builtins.property
    def lambda_multi_value_headers_enabled(self) -> typing.Optional[bool]:
        return self._values.get("lambda_multi_value_headers_enabled")

    @builtins.property
    def load_balancing_algorithm_type(self) -> typing.Optional[str]:
        return self._values.get("load_balancing_algorithm_type")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def proxy_protocol_v2(self) -> typing.Optional[bool]:
        return self._values.get("proxy_protocol_v2")

    @builtins.property
    def slow_start(self) -> typing.Optional[jsii.Number]:
        return self._values.get("slow_start")

    @builtins.property
    def stickiness(self) -> typing.Optional[typing.List["LbTargetGroupStickiness"]]:
        """stickiness block."""
        return self._values.get("stickiness")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target_type(self) -> typing.Optional[str]:
        return self._values.get("target_type")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTargetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbTargetGroupHealthCheck",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "healthy_threshold": "healthyThreshold",
        "interval": "interval",
        "matcher": "matcher",
        "path": "path",
        "port": "port",
        "protocol": "protocol",
        "timeout": "timeout",
        "unhealthy_threshold": "unhealthyThreshold",
    },
)
class LbTargetGroupHealthCheck:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        healthy_threshold: typing.Optional[jsii.Number] = None,
        interval: typing.Optional[jsii.Number] = None,
        matcher: typing.Optional[str] = None,
        path: typing.Optional[str] = None,
        port: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        timeout: typing.Optional[jsii.Number] = None,
        unhealthy_threshold: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param enabled: 
        :param healthy_threshold: 
        :param interval: 
        :param matcher: 
        :param path: 
        :param port: 
        :param protocol: 
        :param timeout: 
        :param unhealthy_threshold: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if healthy_threshold is not None:
            self._values["healthy_threshold"] = healthy_threshold
        if interval is not None:
            self._values["interval"] = interval
        if matcher is not None:
            self._values["matcher"] = matcher
        if path is not None:
            self._values["path"] = path
        if port is not None:
            self._values["port"] = port
        if protocol is not None:
            self._values["protocol"] = protocol
        if timeout is not None:
            self._values["timeout"] = timeout
        if unhealthy_threshold is not None:
            self._values["unhealthy_threshold"] = unhealthy_threshold

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def healthy_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("healthy_threshold")

    @builtins.property
    def interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("interval")

    @builtins.property
    def matcher(self) -> typing.Optional[str]:
        return self._values.get("matcher")

    @builtins.property
    def path(self) -> typing.Optional[str]:
        return self._values.get("path")

    @builtins.property
    def port(self) -> typing.Optional[str]:
        return self._values.get("port")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout")

    @builtins.property
    def unhealthy_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("unhealthy_threshold")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTargetGroupHealthCheck(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbTargetGroupStickiness",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "cookie_duration": "cookieDuration",
        "enabled": "enabled",
    },
)
class LbTargetGroupStickiness:
    def __init__(
        self,
        *,
        type: str,
        cookie_duration: typing.Optional[jsii.Number] = None,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param type: 
        :param cookie_duration: 
        :param enabled: 
        """
        self._values = {
            "type": type,
        }
        if cookie_duration is not None:
            self._values["cookie_duration"] = cookie_duration
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def cookie_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cookie_duration")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTargetGroupStickiness(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LbTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class LbTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LbTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LicensemanagerAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LicensemanagerAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        license_configuration_arn: str,
        resource_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param license_configuration_arn: 
        :param resource_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LicensemanagerAssociationConfig(
            license_configuration_arn=license_configuration_arn,
            resource_arn=resource_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LicensemanagerAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="licenseConfigurationArn")
    def license_configuration_arn(self) -> str:
        return jsii.get(self, "licenseConfigurationArn")

    @license_configuration_arn.setter
    def license_configuration_arn(self, value: str) -> None:
        jsii.set(self, "licenseConfigurationArn", value)

    @builtins.property
    @jsii.member(jsii_name="resourceArn")
    def resource_arn(self) -> str:
        return jsii.get(self, "resourceArn")

    @resource_arn.setter
    def resource_arn(self, value: str) -> None:
        jsii.set(self, "resourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LicensemanagerAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "license_configuration_arn": "licenseConfigurationArn",
        "resource_arn": "resourceArn",
    },
)
class LicensemanagerAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        license_configuration_arn: str,
        resource_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param license_configuration_arn: 
        :param resource_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "license_configuration_arn": license_configuration_arn,
            "resource_arn": resource_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def license_configuration_arn(self) -> str:
        return self._values.get("license_configuration_arn")

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LicensemanagerAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LicensemanagerLicenseConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LicensemanagerLicenseConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        license_counting_type: str,
        name: str,
        description: typing.Optional[str] = None,
        license_count: typing.Optional[jsii.Number] = None,
        license_count_hard_limit: typing.Optional[bool] = None,
        license_rules: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param license_counting_type: 
        :param name: 
        :param description: 
        :param license_count: 
        :param license_count_hard_limit: 
        :param license_rules: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LicensemanagerLicenseConfigurationConfig(
            license_counting_type=license_counting_type,
            name=name,
            description=description,
            license_count=license_count,
            license_count_hard_limit=license_count_hard_limit,
            license_rules=license_rules,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LicensemanagerLicenseConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="licenseCountingType")
    def license_counting_type(self) -> str:
        return jsii.get(self, "licenseCountingType")

    @license_counting_type.setter
    def license_counting_type(self, value: str) -> None:
        jsii.set(self, "licenseCountingType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="licenseCount")
    def license_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "licenseCount")

    @license_count.setter
    def license_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "licenseCount", value)

    @builtins.property
    @jsii.member(jsii_name="licenseCountHardLimit")
    def license_count_hard_limit(self) -> typing.Optional[bool]:
        return jsii.get(self, "licenseCountHardLimit")

    @license_count_hard_limit.setter
    def license_count_hard_limit(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "licenseCountHardLimit", value)

    @builtins.property
    @jsii.member(jsii_name="licenseRules")
    def license_rules(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "licenseRules")

    @license_rules.setter
    def license_rules(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "licenseRules", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LicensemanagerLicenseConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "license_counting_type": "licenseCountingType",
        "name": "name",
        "description": "description",
        "license_count": "licenseCount",
        "license_count_hard_limit": "licenseCountHardLimit",
        "license_rules": "licenseRules",
        "tags": "tags",
    },
)
class LicensemanagerLicenseConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        license_counting_type: str,
        name: str,
        description: typing.Optional[str] = None,
        license_count: typing.Optional[jsii.Number] = None,
        license_count_hard_limit: typing.Optional[bool] = None,
        license_rules: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param license_counting_type: 
        :param name: 
        :param description: 
        :param license_count: 
        :param license_count_hard_limit: 
        :param license_rules: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "license_counting_type": license_counting_type,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if license_count is not None:
            self._values["license_count"] = license_count
        if license_count_hard_limit is not None:
            self._values["license_count_hard_limit"] = license_count_hard_limit
        if license_rules is not None:
            self._values["license_rules"] = license_rules
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def license_counting_type(self) -> str:
        return self._values.get("license_counting_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def license_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("license_count")

    @builtins.property
    def license_count_hard_limit(self) -> typing.Optional[bool]:
        return self._values.get("license_count_hard_limit")

    @builtins.property
    def license_rules(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("license_rules")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LicensemanagerLicenseConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LightsailDomain(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailDomain",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LightsailDomainConfig(
            domain_name=domain_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LightsailDomain, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailDomainConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
    },
)
class LightsailDomainConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain_name": domain_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LightsailDomainConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LightsailInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        availability_zone: str,
        blueprint_id: str,
        bundle_id: str,
        name: str,
        key_pair_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        user_data: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param availability_zone: 
        :param blueprint_id: 
        :param bundle_id: 
        :param name: 
        :param key_pair_name: 
        :param tags: 
        :param user_data: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LightsailInstanceConfig(
            availability_zone=availability_zone,
            blueprint_id=blueprint_id,
            bundle_id=bundle_id,
            name=name,
            key_pair_name=key_pair_name,
            tags=tags,
            user_data=user_data,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LightsailInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="cpuCount")
    def cpu_count(self) -> jsii.Number:
        return jsii.get(self, "cpuCount")

    @builtins.property
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> str:
        return jsii.get(self, "createdAt")

    @builtins.property
    @jsii.member(jsii_name="ipv6Address")
    def ipv6_address(self) -> str:
        return jsii.get(self, "ipv6Address")

    @builtins.property
    @jsii.member(jsii_name="isStaticIp")
    def is_static_ip(self) -> bool:
        return jsii.get(self, "isStaticIp")

    @builtins.property
    @jsii.member(jsii_name="privateIpAddress")
    def private_ip_address(self) -> str:
        return jsii.get(self, "privateIpAddress")

    @builtins.property
    @jsii.member(jsii_name="publicIpAddress")
    def public_ip_address(self) -> str:
        return jsii.get(self, "publicIpAddress")

    @builtins.property
    @jsii.member(jsii_name="ramSize")
    def ram_size(self) -> jsii.Number:
        return jsii.get(self, "ramSize")

    @builtins.property
    @jsii.member(jsii_name="username")
    def username(self) -> str:
        return jsii.get(self, "username")

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> str:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: str) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="blueprintId")
    def blueprint_id(self) -> str:
        return jsii.get(self, "blueprintId")

    @blueprint_id.setter
    def blueprint_id(self, value: str) -> None:
        jsii.set(self, "blueprintId", value)

    @builtins.property
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> str:
        return jsii.get(self, "bundleId")

    @bundle_id.setter
    def bundle_id(self, value: str) -> None:
        jsii.set(self, "bundleId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="keyPairName")
    def key_pair_name(self) -> typing.Optional[str]:
        return jsii.get(self, "keyPairName")

    @key_pair_name.setter
    def key_pair_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyPairName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> typing.Optional[str]:
        return jsii.get(self, "userData")

    @user_data.setter
    def user_data(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userData", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "availability_zone": "availabilityZone",
        "blueprint_id": "blueprintId",
        "bundle_id": "bundleId",
        "name": "name",
        "key_pair_name": "keyPairName",
        "tags": "tags",
        "user_data": "userData",
    },
)
class LightsailInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        availability_zone: str,
        blueprint_id: str,
        bundle_id: str,
        name: str,
        key_pair_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        user_data: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param availability_zone: 
        :param blueprint_id: 
        :param bundle_id: 
        :param name: 
        :param key_pair_name: 
        :param tags: 
        :param user_data: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "availability_zone": availability_zone,
            "blueprint_id": blueprint_id,
            "bundle_id": bundle_id,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if key_pair_name is not None:
            self._values["key_pair_name"] = key_pair_name
        if tags is not None:
            self._values["tags"] = tags
        if user_data is not None:
            self._values["user_data"] = user_data

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def availability_zone(self) -> str:
        return self._values.get("availability_zone")

    @builtins.property
    def blueprint_id(self) -> str:
        return self._values.get("blueprint_id")

    @builtins.property
    def bundle_id(self) -> str:
        return self._values.get("bundle_id")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def key_pair_name(self) -> typing.Optional[str]:
        return self._values.get("key_pair_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def user_data(self) -> typing.Optional[str]:
        return self._values.get("user_data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LightsailInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LightsailKeyPair(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailKeyPair",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        pgp_key: typing.Optional[str] = None,
        public_key: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param name_prefix: 
        :param pgp_key: 
        :param public_key: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LightsailKeyPairConfig(
            name=name,
            name_prefix=name_prefix,
            pgp_key=pgp_key,
            public_key=public_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LightsailKeyPair, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="encryptedFingerprint")
    def encrypted_fingerprint(self) -> str:
        return jsii.get(self, "encryptedFingerprint")

    @builtins.property
    @jsii.member(jsii_name="encryptedPrivateKey")
    def encrypted_private_key(self) -> str:
        return jsii.get(self, "encryptedPrivateKey")

    @builtins.property
    @jsii.member(jsii_name="fingerprint")
    def fingerprint(self) -> str:
        return jsii.get(self, "fingerprint")

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> str:
        return jsii.get(self, "privateKey")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="pgpKey")
    def pgp_key(self) -> typing.Optional[str]:
        return jsii.get(self, "pgpKey")

    @pgp_key.setter
    def pgp_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "pgpKey", value)

    @builtins.property
    @jsii.member(jsii_name="publicKey")
    def public_key(self) -> typing.Optional[str]:
        return jsii.get(self, "publicKey")

    @public_key.setter
    def public_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "publicKey", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailKeyPairConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "name_prefix": "namePrefix",
        "pgp_key": "pgpKey",
        "public_key": "publicKey",
    },
)
class LightsailKeyPairConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        pgp_key: typing.Optional[str] = None,
        public_key: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param name_prefix: 
        :param pgp_key: 
        :param public_key: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if pgp_key is not None:
            self._values["pgp_key"] = pgp_key
        if public_key is not None:
            self._values["public_key"] = public_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def pgp_key(self) -> typing.Optional[str]:
        return self._values.get("pgp_key")

    @builtins.property
    def public_key(self) -> typing.Optional[str]:
        return self._values.get("public_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LightsailKeyPairConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LightsailStaticIp(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailStaticIp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LightsailStaticIpConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LightsailStaticIp, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")

    @builtins.property
    @jsii.member(jsii_name="supportCode")
    def support_code(self) -> str:
        return jsii.get(self, "supportCode")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class LightsailStaticIpAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailStaticIpAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        instance_name: str,
        static_ip_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param instance_name: 
        :param static_ip_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LightsailStaticIpAttachmentConfig(
            instance_name=instance_name,
            static_ip_name=static_ip_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LightsailStaticIpAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")

    @builtins.property
    @jsii.member(jsii_name="instanceName")
    def instance_name(self) -> str:
        return jsii.get(self, "instanceName")

    @instance_name.setter
    def instance_name(self, value: str) -> None:
        jsii.set(self, "instanceName", value)

    @builtins.property
    @jsii.member(jsii_name="staticIpName")
    def static_ip_name(self) -> str:
        return jsii.get(self, "staticIpName")

    @static_ip_name.setter
    def static_ip_name(self, value: str) -> None:
        jsii.set(self, "staticIpName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailStaticIpAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "instance_name": "instanceName",
        "static_ip_name": "staticIpName",
    },
)
class LightsailStaticIpAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        instance_name: str,
        static_ip_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param instance_name: 
        :param static_ip_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "instance_name": instance_name,
            "static_ip_name": static_ip_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def instance_name(self) -> str:
        return self._values.get("instance_name")

    @builtins.property
    def static_ip_name(self) -> str:
        return self._values.get("static_ip_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LightsailStaticIpAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LightsailStaticIpConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class LightsailStaticIpConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LightsailStaticIpConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LoadBalancerBackendServerPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LoadBalancerBackendServerPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        instance_port: jsii.Number,
        load_balancer_name: str,
        policy_names: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param instance_port: 
        :param load_balancer_name: 
        :param policy_names: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LoadBalancerBackendServerPolicyConfig(
            instance_port=instance_port,
            load_balancer_name=load_balancer_name,
            policy_names=policy_names,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LoadBalancerBackendServerPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="instancePort")
    def instance_port(self) -> jsii.Number:
        return jsii.get(self, "instancePort")

    @instance_port.setter
    def instance_port(self, value: jsii.Number) -> None:
        jsii.set(self, "instancePort", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerName")
    def load_balancer_name(self) -> str:
        return jsii.get(self, "loadBalancerName")

    @load_balancer_name.setter
    def load_balancer_name(self, value: str) -> None:
        jsii.set(self, "loadBalancerName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="policyNames")
    def policy_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "policyNames")

    @policy_names.setter
    def policy_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "policyNames", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LoadBalancerBackendServerPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "instance_port": "instancePort",
        "load_balancer_name": "loadBalancerName",
        "policy_names": "policyNames",
    },
)
class LoadBalancerBackendServerPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        instance_port: jsii.Number,
        load_balancer_name: str,
        policy_names: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param instance_port: 
        :param load_balancer_name: 
        :param policy_names: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "instance_port": instance_port,
            "load_balancer_name": load_balancer_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if policy_names is not None:
            self._values["policy_names"] = policy_names

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def instance_port(self) -> jsii.Number:
        return self._values.get("instance_port")

    @builtins.property
    def load_balancer_name(self) -> str:
        return self._values.get("load_balancer_name")

    @builtins.property
    def policy_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("policy_names")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LoadBalancerBackendServerPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LoadBalancerListenerPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LoadBalancerListenerPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        load_balancer_name: str,
        load_balancer_port: jsii.Number,
        policy_names: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param load_balancer_name: 
        :param load_balancer_port: 
        :param policy_names: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LoadBalancerListenerPolicyConfig(
            load_balancer_name=load_balancer_name,
            load_balancer_port=load_balancer_port,
            policy_names=policy_names,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LoadBalancerListenerPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="loadBalancerName")
    def load_balancer_name(self) -> str:
        return jsii.get(self, "loadBalancerName")

    @load_balancer_name.setter
    def load_balancer_name(self, value: str) -> None:
        jsii.set(self, "loadBalancerName", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancerPort")
    def load_balancer_port(self) -> jsii.Number:
        return jsii.get(self, "loadBalancerPort")

    @load_balancer_port.setter
    def load_balancer_port(self, value: jsii.Number) -> None:
        jsii.set(self, "loadBalancerPort", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="policyNames")
    def policy_names(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "policyNames")

    @policy_names.setter
    def policy_names(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "policyNames", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LoadBalancerListenerPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "load_balancer_name": "loadBalancerName",
        "load_balancer_port": "loadBalancerPort",
        "policy_names": "policyNames",
    },
)
class LoadBalancerListenerPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        load_balancer_name: str,
        load_balancer_port: jsii.Number,
        policy_names: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param load_balancer_name: 
        :param load_balancer_port: 
        :param policy_names: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "load_balancer_name": load_balancer_name,
            "load_balancer_port": load_balancer_port,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if policy_names is not None:
            self._values["policy_names"] = policy_names

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def load_balancer_name(self) -> str:
        return self._values.get("load_balancer_name")

    @builtins.property
    def load_balancer_port(self) -> jsii.Number:
        return self._values.get("load_balancer_port")

    @builtins.property
    def policy_names(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("policy_names")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LoadBalancerListenerPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class LoadBalancerPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.LoadBalancerPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        load_balancer_name: str,
        policy_name: str,
        policy_type_name: str,
        policy_attribute: typing.Optional[
            typing.List["LoadBalancerPolicyPolicyAttribute"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param load_balancer_name: 
        :param policy_name: 
        :param policy_type_name: 
        :param policy_attribute: policy_attribute block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = LoadBalancerPolicyConfig(
            load_balancer_name=load_balancer_name,
            policy_name=policy_name,
            policy_type_name=policy_type_name,
            policy_attribute=policy_attribute,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(LoadBalancerPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="loadBalancerName")
    def load_balancer_name(self) -> str:
        return jsii.get(self, "loadBalancerName")

    @load_balancer_name.setter
    def load_balancer_name(self, value: str) -> None:
        jsii.set(self, "loadBalancerName", value)

    @builtins.property
    @jsii.member(jsii_name="policyName")
    def policy_name(self) -> str:
        return jsii.get(self, "policyName")

    @policy_name.setter
    def policy_name(self, value: str) -> None:
        jsii.set(self, "policyName", value)

    @builtins.property
    @jsii.member(jsii_name="policyTypeName")
    def policy_type_name(self) -> str:
        return jsii.get(self, "policyTypeName")

    @policy_type_name.setter
    def policy_type_name(self, value: str) -> None:
        jsii.set(self, "policyTypeName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="policyAttribute")
    def policy_attribute(
        self,
    ) -> typing.Optional[typing.List["LoadBalancerPolicyPolicyAttribute"]]:
        return jsii.get(self, "policyAttribute")

    @policy_attribute.setter
    def policy_attribute(
        self, value: typing.Optional[typing.List["LoadBalancerPolicyPolicyAttribute"]]
    ) -> None:
        jsii.set(self, "policyAttribute", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LoadBalancerPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "load_balancer_name": "loadBalancerName",
        "policy_name": "policyName",
        "policy_type_name": "policyTypeName",
        "policy_attribute": "policyAttribute",
    },
)
class LoadBalancerPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        load_balancer_name: str,
        policy_name: str,
        policy_type_name: str,
        policy_attribute: typing.Optional[
            typing.List["LoadBalancerPolicyPolicyAttribute"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param load_balancer_name: 
        :param policy_name: 
        :param policy_type_name: 
        :param policy_attribute: policy_attribute block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "load_balancer_name": load_balancer_name,
            "policy_name": policy_name,
            "policy_type_name": policy_type_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if policy_attribute is not None:
            self._values["policy_attribute"] = policy_attribute

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def load_balancer_name(self) -> str:
        return self._values.get("load_balancer_name")

    @builtins.property
    def policy_name(self) -> str:
        return self._values.get("policy_name")

    @builtins.property
    def policy_type_name(self) -> str:
        return self._values.get("policy_type_name")

    @builtins.property
    def policy_attribute(
        self,
    ) -> typing.Optional[typing.List["LoadBalancerPolicyPolicyAttribute"]]:
        """policy_attribute block."""
        return self._values.get("policy_attribute")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LoadBalancerPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.LoadBalancerPolicyPolicyAttribute",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class LoadBalancerPolicyPolicyAttribute:
    def __init__(
        self, *, name: typing.Optional[str] = None, value: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {}
        if name is not None:
            self._values["name"] = name
        if value is not None:
            self._values["value"] = value

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def value(self) -> typing.Optional[str]:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "LoadBalancerPolicyPolicyAttribute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MacieMemberAccountAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MacieMemberAccountAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        member_account_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param member_account_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MacieMemberAccountAssociationConfig(
            member_account_id=member_account_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MacieMemberAccountAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="memberAccountId")
    def member_account_id(self) -> str:
        return jsii.get(self, "memberAccountId")

    @member_account_id.setter
    def member_account_id(self, value: str) -> None:
        jsii.set(self, "memberAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MacieMemberAccountAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "member_account_id": "memberAccountId",
    },
)
class MacieMemberAccountAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        member_account_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param member_account_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "member_account_id": member_account_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def member_account_id(self) -> str:
        return self._values.get("member_account_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MacieMemberAccountAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MacieS3BucketAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MacieS3BucketAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket_name: str,
        classification_type: typing.Optional[
            typing.List["MacieS3BucketAssociationClassificationType"]
        ] = None,
        member_account_id: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket_name: 
        :param classification_type: classification_type block.
        :param member_account_id: 
        :param prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MacieS3BucketAssociationConfig(
            bucket_name=bucket_name,
            classification_type=classification_type,
            member_account_id=member_account_id,
            prefix=prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MacieS3BucketAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucketName")
    def bucket_name(self) -> str:
        return jsii.get(self, "bucketName")

    @bucket_name.setter
    def bucket_name(self, value: str) -> None:
        jsii.set(self, "bucketName", value)

    @builtins.property
    @jsii.member(jsii_name="classificationType")
    def classification_type(
        self,
    ) -> typing.Optional[typing.List["MacieS3BucketAssociationClassificationType"]]:
        return jsii.get(self, "classificationType")

    @classification_type.setter
    def classification_type(
        self,
        value: typing.Optional[
            typing.List["MacieS3BucketAssociationClassificationType"]
        ],
    ) -> None:
        jsii.set(self, "classificationType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="memberAccountId")
    def member_account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "memberAccountId")

    @member_account_id.setter
    def member_account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "memberAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "prefix")

    @prefix.setter
    def prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "prefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MacieS3BucketAssociationClassificationType",
    jsii_struct_bases=[],
    name_mapping={"continuous": "continuous", "one_time": "oneTime"},
)
class MacieS3BucketAssociationClassificationType:
    def __init__(
        self,
        *,
        continuous: typing.Optional[str] = None,
        one_time: typing.Optional[str] = None,
    ) -> None:
        """
        :param continuous: 
        :param one_time: 
        """
        self._values = {}
        if continuous is not None:
            self._values["continuous"] = continuous
        if one_time is not None:
            self._values["one_time"] = one_time

    @builtins.property
    def continuous(self) -> typing.Optional[str]:
        return self._values.get("continuous")

    @builtins.property
    def one_time(self) -> typing.Optional[str]:
        return self._values.get("one_time")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MacieS3BucketAssociationClassificationType(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MacieS3BucketAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket_name": "bucketName",
        "classification_type": "classificationType",
        "member_account_id": "memberAccountId",
        "prefix": "prefix",
    },
)
class MacieS3BucketAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket_name: str,
        classification_type: typing.Optional[
            typing.List["MacieS3BucketAssociationClassificationType"]
        ] = None,
        member_account_id: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket_name: 
        :param classification_type: classification_type block.
        :param member_account_id: 
        :param prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket_name": bucket_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if classification_type is not None:
            self._values["classification_type"] = classification_type
        if member_account_id is not None:
            self._values["member_account_id"] = member_account_id
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket_name(self) -> str:
        return self._values.get("bucket_name")

    @builtins.property
    def classification_type(
        self,
    ) -> typing.Optional[typing.List["MacieS3BucketAssociationClassificationType"]]:
        """classification_type block."""
        return self._values.get("classification_type")

    @builtins.property
    def member_account_id(self) -> typing.Optional[str]:
        return self._values.get("member_account_id")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MacieS3BucketAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MainRouteTableAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MainRouteTableAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        route_table_id: str,
        vpc_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param route_table_id: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MainRouteTableAssociationConfig(
            route_table_id=route_table_id,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MainRouteTableAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="originalRouteTableId")
    def original_route_table_id(self) -> str:
        return jsii.get(self, "originalRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> str:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter
    def route_table_id(self, value: str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MainRouteTableAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "route_table_id": "routeTableId",
        "vpc_id": "vpcId",
    },
)
class MainRouteTableAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        route_table_id: str,
        vpc_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param route_table_id: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "route_table_id": route_table_id,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def route_table_id(self) -> str:
        return self._values.get("route_table_id")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MainRouteTableAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MediaConvertQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MediaConvertQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        pricing_plan: typing.Optional[str] = None,
        reservation_plan_settings: typing.Optional[
            typing.List["MediaConvertQueueReservationPlanSettings"]
        ] = None,
        status: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param pricing_plan: 
        :param reservation_plan_settings: reservation_plan_settings block.
        :param status: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MediaConvertQueueConfig(
            name=name,
            description=description,
            pricing_plan=pricing_plan,
            reservation_plan_settings=reservation_plan_settings,
            status=status,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MediaConvertQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="pricingPlan")
    def pricing_plan(self) -> typing.Optional[str]:
        return jsii.get(self, "pricingPlan")

    @pricing_plan.setter
    def pricing_plan(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "pricingPlan", value)

    @builtins.property
    @jsii.member(jsii_name="reservationPlanSettings")
    def reservation_plan_settings(
        self,
    ) -> typing.Optional[typing.List["MediaConvertQueueReservationPlanSettings"]]:
        return jsii.get(self, "reservationPlanSettings")

    @reservation_plan_settings.setter
    def reservation_plan_settings(
        self,
        value: typing.Optional[typing.List["MediaConvertQueueReservationPlanSettings"]],
    ) -> None:
        jsii.set(self, "reservationPlanSettings", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[str]:
        return jsii.get(self, "status")

    @status.setter
    def status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "status", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MediaConvertQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "pricing_plan": "pricingPlan",
        "reservation_plan_settings": "reservationPlanSettings",
        "status": "status",
        "tags": "tags",
    },
)
class MediaConvertQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        pricing_plan: typing.Optional[str] = None,
        reservation_plan_settings: typing.Optional[
            typing.List["MediaConvertQueueReservationPlanSettings"]
        ] = None,
        status: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param pricing_plan: 
        :param reservation_plan_settings: reservation_plan_settings block.
        :param status: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if pricing_plan is not None:
            self._values["pricing_plan"] = pricing_plan
        if reservation_plan_settings is not None:
            self._values["reservation_plan_settings"] = reservation_plan_settings
        if status is not None:
            self._values["status"] = status
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def pricing_plan(self) -> typing.Optional[str]:
        return self._values.get("pricing_plan")

    @builtins.property
    def reservation_plan_settings(
        self,
    ) -> typing.Optional[typing.List["MediaConvertQueueReservationPlanSettings"]]:
        """reservation_plan_settings block."""
        return self._values.get("reservation_plan_settings")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaConvertQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MediaConvertQueueReservationPlanSettings",
    jsii_struct_bases=[],
    name_mapping={
        "commitment": "commitment",
        "renewal_type": "renewalType",
        "reserved_slots": "reservedSlots",
    },
)
class MediaConvertQueueReservationPlanSettings:
    def __init__(
        self, *, commitment: str, renewal_type: str, reserved_slots: jsii.Number
    ) -> None:
        """
        :param commitment: 
        :param renewal_type: 
        :param reserved_slots: 
        """
        self._values = {
            "commitment": commitment,
            "renewal_type": renewal_type,
            "reserved_slots": reserved_slots,
        }

    @builtins.property
    def commitment(self) -> str:
        return self._values.get("commitment")

    @builtins.property
    def renewal_type(self) -> str:
        return self._values.get("renewal_type")

    @builtins.property
    def reserved_slots(self) -> jsii.Number:
        return self._values.get("reserved_slots")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaConvertQueueReservationPlanSettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MediaPackageChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MediaPackageChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        channel_id: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param channel_id: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MediaPackageChannelConfig(
            channel_id=channel_id,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MediaPackageChannel, self, [scope, id, config])

    @jsii.member(jsii_name="hlsIngest")
    def hls_ingest(self, index: str) -> "MediaPackageChannelHlsIngest":
        """
        :param index: -
        """
        return jsii.invoke(self, "hlsIngest", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="channelId")
    def channel_id(self) -> str:
        return jsii.get(self, "channelId")

    @channel_id.setter
    def channel_id(self, value: str) -> None:
        jsii.set(self, "channelId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MediaPackageChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "channel_id": "channelId",
        "description": "description",
        "tags": "tags",
    },
)
class MediaPackageChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        channel_id: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param channel_id: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "channel_id": channel_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def channel_id(self) -> str:
        return self._values.get("channel_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaPackageChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MediaPackageChannelHlsIngest(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MediaPackageChannelHlsIngest",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            MediaPackageChannelHlsIngest,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="ingestEndpoints")
    def ingest_endpoints(self) -> typing.Any:
        return jsii.get(self, "ingestEndpoints")


class MediaPackageChannelHlsIngestIngestEndpoints(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MediaPackageChannelHlsIngestIngestEndpoints",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            MediaPackageChannelHlsIngestIngestEndpoints,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="password")
    def password(self) -> str:
        return jsii.get(self, "password")

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> str:
        return jsii.get(self, "url")

    @builtins.property
    @jsii.member(jsii_name="username")
    def username(self) -> str:
        return jsii.get(self, "username")


class MediaStoreContainer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MediaStoreContainer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MediaStoreContainerConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MediaStoreContainer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MediaStoreContainerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class MediaStoreContainerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaStoreContainerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MediaStoreContainerPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MediaStoreContainerPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        container_name: str,
        policy: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param container_name: 
        :param policy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MediaStoreContainerPolicyConfig(
            container_name=container_name,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MediaStoreContainerPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="containerName")
    def container_name(self) -> str:
        return jsii.get(self, "containerName")

    @container_name.setter
    def container_name(self, value: str) -> None:
        jsii.set(self, "containerName", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MediaStoreContainerPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "container_name": "containerName",
        "policy": "policy",
    },
)
class MediaStoreContainerPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        container_name: str,
        policy: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param container_name: 
        :param policy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "container_name": container_name,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def container_name(self) -> str:
        return self._values.get("container_name")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MediaStoreContainerPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MqBroker(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MqBroker",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        broker_name: str,
        engine_type: str,
        engine_version: str,
        host_instance_type: str,
        security_groups: typing.List[str],
        user: typing.List["MqBrokerUser"],
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        configuration: typing.Optional[typing.List["MqBrokerConfiguration"]] = None,
        deployment_mode: typing.Optional[str] = None,
        encryption_options: typing.Optional[
            typing.List["MqBrokerEncryptionOptions"]
        ] = None,
        logs: typing.Optional[typing.List["MqBrokerLogs"]] = None,
        maintenance_window_start_time: typing.Optional[
            typing.List["MqBrokerMaintenanceWindowStartTime"]
        ] = None,
        publicly_accessible: typing.Optional[bool] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param broker_name: 
        :param engine_type: 
        :param engine_version: 
        :param host_instance_type: 
        :param security_groups: 
        :param user: user block.
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param configuration: configuration block.
        :param deployment_mode: 
        :param encryption_options: encryption_options block.
        :param logs: logs block.
        :param maintenance_window_start_time: maintenance_window_start_time block.
        :param publicly_accessible: 
        :param subnet_ids: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MqBrokerConfig(
            broker_name=broker_name,
            engine_type=engine_type,
            engine_version=engine_version,
            host_instance_type=host_instance_type,
            security_groups=security_groups,
            user=user,
            apply_immediately=apply_immediately,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
            configuration=configuration,
            deployment_mode=deployment_mode,
            encryption_options=encryption_options,
            logs=logs,
            maintenance_window_start_time=maintenance_window_start_time,
            publicly_accessible=publicly_accessible,
            subnet_ids=subnet_ids,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MqBroker, self, [scope, id, config])

    @jsii.member(jsii_name="instances")
    def instances(self, index: str) -> "MqBrokerInstances":
        """
        :param index: -
        """
        return jsii.invoke(self, "instances", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="brokerName")
    def broker_name(self) -> str:
        return jsii.get(self, "brokerName")

    @broker_name.setter
    def broker_name(self, value: str) -> None:
        jsii.set(self, "brokerName", value)

    @builtins.property
    @jsii.member(jsii_name="engineType")
    def engine_type(self) -> str:
        return jsii.get(self, "engineType")

    @engine_type.setter
    def engine_type(self, value: str) -> None:
        jsii.set(self, "engineType", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: str) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="hostInstanceType")
    def host_instance_type(self) -> str:
        return jsii.get(self, "hostInstanceType")

    @host_instance_type.setter
    def host_instance_type(self, value: str) -> None:
        jsii.set(self, "hostInstanceType", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.List[str]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.List[str]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="user")
    def user(self) -> typing.List["MqBrokerUser"]:
        return jsii.get(self, "user")

    @user.setter
    def user(self, value: typing.List["MqBrokerUser"]) -> None:
        jsii.set(self, "user", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoMinorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="configuration")
    def configuration(self) -> typing.Optional[typing.List["MqBrokerConfiguration"]]:
        return jsii.get(self, "configuration")

    @configuration.setter
    def configuration(
        self, value: typing.Optional[typing.List["MqBrokerConfiguration"]]
    ) -> None:
        jsii.set(self, "configuration", value)

    @builtins.property
    @jsii.member(jsii_name="deploymentMode")
    def deployment_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "deploymentMode")

    @deployment_mode.setter
    def deployment_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deploymentMode", value)

    @builtins.property
    @jsii.member(jsii_name="encryptionOptions")
    def encryption_options(
        self,
    ) -> typing.Optional[typing.List["MqBrokerEncryptionOptions"]]:
        return jsii.get(self, "encryptionOptions")

    @encryption_options.setter
    def encryption_options(
        self, value: typing.Optional[typing.List["MqBrokerEncryptionOptions"]]
    ) -> None:
        jsii.set(self, "encryptionOptions", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="logs")
    def logs(self) -> typing.Optional[typing.List["MqBrokerLogs"]]:
        return jsii.get(self, "logs")

    @logs.setter
    def logs(self, value: typing.Optional[typing.List["MqBrokerLogs"]]) -> None:
        jsii.set(self, "logs", value)

    @builtins.property
    @jsii.member(jsii_name="maintenanceWindowStartTime")
    def maintenance_window_start_time(
        self,
    ) -> typing.Optional[typing.List["MqBrokerMaintenanceWindowStartTime"]]:
        return jsii.get(self, "maintenanceWindowStartTime")

    @maintenance_window_start_time.setter
    def maintenance_window_start_time(
        self, value: typing.Optional[typing.List["MqBrokerMaintenanceWindowStartTime"]]
    ) -> None:
        jsii.set(self, "maintenanceWindowStartTime", value)

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> typing.Optional[bool]:
        return jsii.get(self, "publiclyAccessible")

    @publicly_accessible.setter
    def publicly_accessible(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "publiclyAccessible", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MqBrokerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "broker_name": "brokerName",
        "engine_type": "engineType",
        "engine_version": "engineVersion",
        "host_instance_type": "hostInstanceType",
        "security_groups": "securityGroups",
        "user": "user",
        "apply_immediately": "applyImmediately",
        "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
        "configuration": "configuration",
        "deployment_mode": "deploymentMode",
        "encryption_options": "encryptionOptions",
        "logs": "logs",
        "maintenance_window_start_time": "maintenanceWindowStartTime",
        "publicly_accessible": "publiclyAccessible",
        "subnet_ids": "subnetIds",
        "tags": "tags",
    },
)
class MqBrokerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        broker_name: str,
        engine_type: str,
        engine_version: str,
        host_instance_type: str,
        security_groups: typing.List[str],
        user: typing.List["MqBrokerUser"],
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        configuration: typing.Optional[typing.List["MqBrokerConfiguration"]] = None,
        deployment_mode: typing.Optional[str] = None,
        encryption_options: typing.Optional[
            typing.List["MqBrokerEncryptionOptions"]
        ] = None,
        logs: typing.Optional[typing.List["MqBrokerLogs"]] = None,
        maintenance_window_start_time: typing.Optional[
            typing.List["MqBrokerMaintenanceWindowStartTime"]
        ] = None,
        publicly_accessible: typing.Optional[bool] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param broker_name: 
        :param engine_type: 
        :param engine_version: 
        :param host_instance_type: 
        :param security_groups: 
        :param user: user block.
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param configuration: configuration block.
        :param deployment_mode: 
        :param encryption_options: encryption_options block.
        :param logs: logs block.
        :param maintenance_window_start_time: maintenance_window_start_time block.
        :param publicly_accessible: 
        :param subnet_ids: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "broker_name": broker_name,
            "engine_type": engine_type,
            "engine_version": engine_version,
            "host_instance_type": host_instance_type,
            "security_groups": security_groups,
            "user": user,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if auto_minor_version_upgrade is not None:
            self._values["auto_minor_version_upgrade"] = auto_minor_version_upgrade
        if configuration is not None:
            self._values["configuration"] = configuration
        if deployment_mode is not None:
            self._values["deployment_mode"] = deployment_mode
        if encryption_options is not None:
            self._values["encryption_options"] = encryption_options
        if logs is not None:
            self._values["logs"] = logs
        if maintenance_window_start_time is not None:
            self._values[
                "maintenance_window_start_time"
            ] = maintenance_window_start_time
        if publicly_accessible is not None:
            self._values["publicly_accessible"] = publicly_accessible
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def broker_name(self) -> str:
        return self._values.get("broker_name")

    @builtins.property
    def engine_type(self) -> str:
        return self._values.get("engine_type")

    @builtins.property
    def engine_version(self) -> str:
        return self._values.get("engine_version")

    @builtins.property
    def host_instance_type(self) -> str:
        return self._values.get("host_instance_type")

    @builtins.property
    def security_groups(self) -> typing.List[str]:
        return self._values.get("security_groups")

    @builtins.property
    def user(self) -> typing.List["MqBrokerUser"]:
        """user block."""
        return self._values.get("user")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("auto_minor_version_upgrade")

    @builtins.property
    def configuration(self) -> typing.Optional[typing.List["MqBrokerConfiguration"]]:
        """configuration block."""
        return self._values.get("configuration")

    @builtins.property
    def deployment_mode(self) -> typing.Optional[str]:
        return self._values.get("deployment_mode")

    @builtins.property
    def encryption_options(
        self,
    ) -> typing.Optional[typing.List["MqBrokerEncryptionOptions"]]:
        """encryption_options block."""
        return self._values.get("encryption_options")

    @builtins.property
    def logs(self) -> typing.Optional[typing.List["MqBrokerLogs"]]:
        """logs block."""
        return self._values.get("logs")

    @builtins.property
    def maintenance_window_start_time(
        self,
    ) -> typing.Optional[typing.List["MqBrokerMaintenanceWindowStartTime"]]:
        """maintenance_window_start_time block."""
        return self._values.get("maintenance_window_start_time")

    @builtins.property
    def publicly_accessible(self) -> typing.Optional[bool]:
        return self._values.get("publicly_accessible")

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MqBrokerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MqBrokerConfiguration",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "revision": "revision"},
)
class MqBrokerConfiguration:
    def __init__(
        self,
        *,
        id: typing.Optional[str] = None,
        revision: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param id: 
        :param revision: 
        """
        self._values = {}
        if id is not None:
            self._values["id"] = id
        if revision is not None:
            self._values["revision"] = revision

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def revision(self) -> typing.Optional[jsii.Number]:
        return self._values.get("revision")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MqBrokerConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MqBrokerEncryptionOptions",
    jsii_struct_bases=[],
    name_mapping={"kms_key_id": "kmsKeyId", "use_aws_owned_key": "useAwsOwnedKey"},
)
class MqBrokerEncryptionOptions:
    def __init__(
        self,
        *,
        kms_key_id: typing.Optional[str] = None,
        use_aws_owned_key: typing.Optional[bool] = None,
    ) -> None:
        """
        :param kms_key_id: 
        :param use_aws_owned_key: 
        """
        self._values = {}
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if use_aws_owned_key is not None:
            self._values["use_aws_owned_key"] = use_aws_owned_key

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def use_aws_owned_key(self) -> typing.Optional[bool]:
        return self._values.get("use_aws_owned_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MqBrokerEncryptionOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MqBrokerInstances(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MqBrokerInstances",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            MqBrokerInstances, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="consoleUrl")
    def console_url(self) -> str:
        return jsii.get(self, "consoleUrl")

    @builtins.property
    @jsii.member(jsii_name="endpoints")
    def endpoints(self) -> typing.List[str]:
        return jsii.get(self, "endpoints")

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MqBrokerLogs",
    jsii_struct_bases=[],
    name_mapping={"audit": "audit", "general": "general"},
)
class MqBrokerLogs:
    def __init__(
        self,
        *,
        audit: typing.Optional[bool] = None,
        general: typing.Optional[bool] = None,
    ) -> None:
        """
        :param audit: 
        :param general: 
        """
        self._values = {}
        if audit is not None:
            self._values["audit"] = audit
        if general is not None:
            self._values["general"] = general

    @builtins.property
    def audit(self) -> typing.Optional[bool]:
        return self._values.get("audit")

    @builtins.property
    def general(self) -> typing.Optional[bool]:
        return self._values.get("general")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MqBrokerLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MqBrokerMaintenanceWindowStartTime",
    jsii_struct_bases=[],
    name_mapping={
        "day_of_week": "dayOfWeek",
        "time_of_day": "timeOfDay",
        "time_zone": "timeZone",
    },
)
class MqBrokerMaintenanceWindowStartTime:
    def __init__(self, *, day_of_week: str, time_of_day: str, time_zone: str) -> None:
        """
        :param day_of_week: 
        :param time_of_day: 
        :param time_zone: 
        """
        self._values = {
            "day_of_week": day_of_week,
            "time_of_day": time_of_day,
            "time_zone": time_zone,
        }

    @builtins.property
    def day_of_week(self) -> str:
        return self._values.get("day_of_week")

    @builtins.property
    def time_of_day(self) -> str:
        return self._values.get("time_of_day")

    @builtins.property
    def time_zone(self) -> str:
        return self._values.get("time_zone")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MqBrokerMaintenanceWindowStartTime(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MqBrokerUser",
    jsii_struct_bases=[],
    name_mapping={
        "password": "password",
        "username": "username",
        "console_access": "consoleAccess",
        "groups": "groups",
    },
)
class MqBrokerUser:
    def __init__(
        self,
        *,
        password: str,
        username: str,
        console_access: typing.Optional[bool] = None,
        groups: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param password: 
        :param username: 
        :param console_access: 
        :param groups: 
        """
        self._values = {
            "password": password,
            "username": username,
        }
        if console_access is not None:
            self._values["console_access"] = console_access
        if groups is not None:
            self._values["groups"] = groups

    @builtins.property
    def password(self) -> str:
        return self._values.get("password")

    @builtins.property
    def username(self) -> str:
        return self._values.get("username")

    @builtins.property
    def console_access(self) -> typing.Optional[bool]:
        return self._values.get("console_access")

    @builtins.property
    def groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("groups")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MqBrokerUser(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MqConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MqConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        data: str,
        engine_type: str,
        engine_version: str,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param data: 
        :param engine_type: 
        :param engine_version: 
        :param name: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MqConfigurationConfig(
            data=data,
            engine_type=engine_type,
            engine_version=engine_version,
            name=name,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MqConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="latestRevision")
    def latest_revision(self) -> jsii.Number:
        return jsii.get(self, "latestRevision")

    @builtins.property
    @jsii.member(jsii_name="data")
    def data(self) -> str:
        return jsii.get(self, "data")

    @data.setter
    def data(self, value: str) -> None:
        jsii.set(self, "data", value)

    @builtins.property
    @jsii.member(jsii_name="engineType")
    def engine_type(self) -> str:
        return jsii.get(self, "engineType")

    @engine_type.setter
    def engine_type(self, value: str) -> None:
        jsii.set(self, "engineType", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: str) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MqConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "data": "data",
        "engine_type": "engineType",
        "engine_version": "engineVersion",
        "name": "name",
        "description": "description",
        "tags": "tags",
    },
)
class MqConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        data: str,
        engine_type: str,
        engine_version: str,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param data: 
        :param engine_type: 
        :param engine_version: 
        :param name: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "data": data,
            "engine_type": engine_type,
            "engine_version": engine_version,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def data(self) -> str:
        return self._values.get("data")

    @builtins.property
    def engine_type(self) -> str:
        return self._values.get("engine_type")

    @builtins.property
    def engine_version(self) -> str:
        return self._values.get("engine_version")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MqConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MskCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MskCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        broker_node_group_info: typing.List["MskClusterBrokerNodeGroupInfo"],
        cluster_name: str,
        kafka_version: str,
        number_of_broker_nodes: jsii.Number,
        client_authentication: typing.Optional[
            typing.List["MskClusterClientAuthentication"]
        ] = None,
        configuration_info: typing.Optional[
            typing.List["MskClusterConfigurationInfo"]
        ] = None,
        encryption_info: typing.Optional[
            typing.List["MskClusterEncryptionInfo"]
        ] = None,
        enhanced_monitoring: typing.Optional[str] = None,
        logging_info: typing.Optional[typing.List["MskClusterLoggingInfo"]] = None,
        open_monitoring: typing.Optional[
            typing.List["MskClusterOpenMonitoring"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param broker_node_group_info: broker_node_group_info block.
        :param cluster_name: 
        :param kafka_version: 
        :param number_of_broker_nodes: 
        :param client_authentication: client_authentication block.
        :param configuration_info: configuration_info block.
        :param encryption_info: encryption_info block.
        :param enhanced_monitoring: 
        :param logging_info: logging_info block.
        :param open_monitoring: open_monitoring block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MskClusterConfig(
            broker_node_group_info=broker_node_group_info,
            cluster_name=cluster_name,
            kafka_version=kafka_version,
            number_of_broker_nodes=number_of_broker_nodes,
            client_authentication=client_authentication,
            configuration_info=configuration_info,
            encryption_info=encryption_info,
            enhanced_monitoring=enhanced_monitoring,
            logging_info=logging_info,
            open_monitoring=open_monitoring,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MskCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="bootstrapBrokers")
    def bootstrap_brokers(self) -> str:
        return jsii.get(self, "bootstrapBrokers")

    @builtins.property
    @jsii.member(jsii_name="bootstrapBrokersTls")
    def bootstrap_brokers_tls(self) -> str:
        return jsii.get(self, "bootstrapBrokersTls")

    @builtins.property
    @jsii.member(jsii_name="currentVersion")
    def current_version(self) -> str:
        return jsii.get(self, "currentVersion")

    @builtins.property
    @jsii.member(jsii_name="zookeeperConnectString")
    def zookeeper_connect_string(self) -> str:
        return jsii.get(self, "zookeeperConnectString")

    @builtins.property
    @jsii.member(jsii_name="brokerNodeGroupInfo")
    def broker_node_group_info(self) -> typing.List["MskClusterBrokerNodeGroupInfo"]:
        return jsii.get(self, "brokerNodeGroupInfo")

    @broker_node_group_info.setter
    def broker_node_group_info(
        self, value: typing.List["MskClusterBrokerNodeGroupInfo"]
    ) -> None:
        jsii.set(self, "brokerNodeGroupInfo", value)

    @builtins.property
    @jsii.member(jsii_name="clusterName")
    def cluster_name(self) -> str:
        return jsii.get(self, "clusterName")

    @cluster_name.setter
    def cluster_name(self, value: str) -> None:
        jsii.set(self, "clusterName", value)

    @builtins.property
    @jsii.member(jsii_name="kafkaVersion")
    def kafka_version(self) -> str:
        return jsii.get(self, "kafkaVersion")

    @kafka_version.setter
    def kafka_version(self, value: str) -> None:
        jsii.set(self, "kafkaVersion", value)

    @builtins.property
    @jsii.member(jsii_name="numberOfBrokerNodes")
    def number_of_broker_nodes(self) -> jsii.Number:
        return jsii.get(self, "numberOfBrokerNodes")

    @number_of_broker_nodes.setter
    def number_of_broker_nodes(self, value: jsii.Number) -> None:
        jsii.set(self, "numberOfBrokerNodes", value)

    @builtins.property
    @jsii.member(jsii_name="clientAuthentication")
    def client_authentication(
        self,
    ) -> typing.Optional[typing.List["MskClusterClientAuthentication"]]:
        return jsii.get(self, "clientAuthentication")

    @client_authentication.setter
    def client_authentication(
        self, value: typing.Optional[typing.List["MskClusterClientAuthentication"]]
    ) -> None:
        jsii.set(self, "clientAuthentication", value)

    @builtins.property
    @jsii.member(jsii_name="configurationInfo")
    def configuration_info(
        self,
    ) -> typing.Optional[typing.List["MskClusterConfigurationInfo"]]:
        return jsii.get(self, "configurationInfo")

    @configuration_info.setter
    def configuration_info(
        self, value: typing.Optional[typing.List["MskClusterConfigurationInfo"]]
    ) -> None:
        jsii.set(self, "configurationInfo", value)

    @builtins.property
    @jsii.member(jsii_name="encryptionInfo")
    def encryption_info(
        self,
    ) -> typing.Optional[typing.List["MskClusterEncryptionInfo"]]:
        return jsii.get(self, "encryptionInfo")

    @encryption_info.setter
    def encryption_info(
        self, value: typing.Optional[typing.List["MskClusterEncryptionInfo"]]
    ) -> None:
        jsii.set(self, "encryptionInfo", value)

    @builtins.property
    @jsii.member(jsii_name="enhancedMonitoring")
    def enhanced_monitoring(self) -> typing.Optional[str]:
        return jsii.get(self, "enhancedMonitoring")

    @enhanced_monitoring.setter
    def enhanced_monitoring(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "enhancedMonitoring", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="loggingInfo")
    def logging_info(self) -> typing.Optional[typing.List["MskClusterLoggingInfo"]]:
        return jsii.get(self, "loggingInfo")

    @logging_info.setter
    def logging_info(
        self, value: typing.Optional[typing.List["MskClusterLoggingInfo"]]
    ) -> None:
        jsii.set(self, "loggingInfo", value)

    @builtins.property
    @jsii.member(jsii_name="openMonitoring")
    def open_monitoring(
        self,
    ) -> typing.Optional[typing.List["MskClusterOpenMonitoring"]]:
        return jsii.get(self, "openMonitoring")

    @open_monitoring.setter
    def open_monitoring(
        self, value: typing.Optional[typing.List["MskClusterOpenMonitoring"]]
    ) -> None:
        jsii.set(self, "openMonitoring", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterBrokerNodeGroupInfo",
    jsii_struct_bases=[],
    name_mapping={
        "client_subnets": "clientSubnets",
        "ebs_volume_size": "ebsVolumeSize",
        "instance_type": "instanceType",
        "security_groups": "securityGroups",
        "az_distribution": "azDistribution",
    },
)
class MskClusterBrokerNodeGroupInfo:
    def __init__(
        self,
        *,
        client_subnets: typing.List[str],
        ebs_volume_size: jsii.Number,
        instance_type: str,
        security_groups: typing.List[str],
        az_distribution: typing.Optional[str] = None,
    ) -> None:
        """
        :param client_subnets: 
        :param ebs_volume_size: 
        :param instance_type: 
        :param security_groups: 
        :param az_distribution: 
        """
        self._values = {
            "client_subnets": client_subnets,
            "ebs_volume_size": ebs_volume_size,
            "instance_type": instance_type,
            "security_groups": security_groups,
        }
        if az_distribution is not None:
            self._values["az_distribution"] = az_distribution

    @builtins.property
    def client_subnets(self) -> typing.List[str]:
        return self._values.get("client_subnets")

    @builtins.property
    def ebs_volume_size(self) -> jsii.Number:
        return self._values.get("ebs_volume_size")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def security_groups(self) -> typing.List[str]:
        return self._values.get("security_groups")

    @builtins.property
    def az_distribution(self) -> typing.Optional[str]:
        return self._values.get("az_distribution")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterBrokerNodeGroupInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterClientAuthentication",
    jsii_struct_bases=[],
    name_mapping={"tls": "tls"},
)
class MskClusterClientAuthentication:
    def __init__(
        self,
        *,
        tls: typing.Optional[typing.List["MskClusterClientAuthenticationTls"]] = None,
    ) -> None:
        """
        :param tls: tls block.
        """
        self._values = {}
        if tls is not None:
            self._values["tls"] = tls

    @builtins.property
    def tls(self) -> typing.Optional[typing.List["MskClusterClientAuthenticationTls"]]:
        """tls block."""
        return self._values.get("tls")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterClientAuthentication(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterClientAuthenticationTls",
    jsii_struct_bases=[],
    name_mapping={"certificate_authority_arns": "certificateAuthorityArns"},
)
class MskClusterClientAuthenticationTls:
    def __init__(
        self, *, certificate_authority_arns: typing.Optional[typing.List[str]] = None
    ) -> None:
        """
        :param certificate_authority_arns: 
        """
        self._values = {}
        if certificate_authority_arns is not None:
            self._values["certificate_authority_arns"] = certificate_authority_arns

    @builtins.property
    def certificate_authority_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("certificate_authority_arns")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterClientAuthenticationTls(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "broker_node_group_info": "brokerNodeGroupInfo",
        "cluster_name": "clusterName",
        "kafka_version": "kafkaVersion",
        "number_of_broker_nodes": "numberOfBrokerNodes",
        "client_authentication": "clientAuthentication",
        "configuration_info": "configurationInfo",
        "encryption_info": "encryptionInfo",
        "enhanced_monitoring": "enhancedMonitoring",
        "logging_info": "loggingInfo",
        "open_monitoring": "openMonitoring",
        "tags": "tags",
    },
)
class MskClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        broker_node_group_info: typing.List["MskClusterBrokerNodeGroupInfo"],
        cluster_name: str,
        kafka_version: str,
        number_of_broker_nodes: jsii.Number,
        client_authentication: typing.Optional[
            typing.List["MskClusterClientAuthentication"]
        ] = None,
        configuration_info: typing.Optional[
            typing.List["MskClusterConfigurationInfo"]
        ] = None,
        encryption_info: typing.Optional[
            typing.List["MskClusterEncryptionInfo"]
        ] = None,
        enhanced_monitoring: typing.Optional[str] = None,
        logging_info: typing.Optional[typing.List["MskClusterLoggingInfo"]] = None,
        open_monitoring: typing.Optional[
            typing.List["MskClusterOpenMonitoring"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param broker_node_group_info: broker_node_group_info block.
        :param cluster_name: 
        :param kafka_version: 
        :param number_of_broker_nodes: 
        :param client_authentication: client_authentication block.
        :param configuration_info: configuration_info block.
        :param encryption_info: encryption_info block.
        :param enhanced_monitoring: 
        :param logging_info: logging_info block.
        :param open_monitoring: open_monitoring block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "broker_node_group_info": broker_node_group_info,
            "cluster_name": cluster_name,
            "kafka_version": kafka_version,
            "number_of_broker_nodes": number_of_broker_nodes,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if client_authentication is not None:
            self._values["client_authentication"] = client_authentication
        if configuration_info is not None:
            self._values["configuration_info"] = configuration_info
        if encryption_info is not None:
            self._values["encryption_info"] = encryption_info
        if enhanced_monitoring is not None:
            self._values["enhanced_monitoring"] = enhanced_monitoring
        if logging_info is not None:
            self._values["logging_info"] = logging_info
        if open_monitoring is not None:
            self._values["open_monitoring"] = open_monitoring
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def broker_node_group_info(self) -> typing.List["MskClusterBrokerNodeGroupInfo"]:
        """broker_node_group_info block."""
        return self._values.get("broker_node_group_info")

    @builtins.property
    def cluster_name(self) -> str:
        return self._values.get("cluster_name")

    @builtins.property
    def kafka_version(self) -> str:
        return self._values.get("kafka_version")

    @builtins.property
    def number_of_broker_nodes(self) -> jsii.Number:
        return self._values.get("number_of_broker_nodes")

    @builtins.property
    def client_authentication(
        self,
    ) -> typing.Optional[typing.List["MskClusterClientAuthentication"]]:
        """client_authentication block."""
        return self._values.get("client_authentication")

    @builtins.property
    def configuration_info(
        self,
    ) -> typing.Optional[typing.List["MskClusterConfigurationInfo"]]:
        """configuration_info block."""
        return self._values.get("configuration_info")

    @builtins.property
    def encryption_info(
        self,
    ) -> typing.Optional[typing.List["MskClusterEncryptionInfo"]]:
        """encryption_info block."""
        return self._values.get("encryption_info")

    @builtins.property
    def enhanced_monitoring(self) -> typing.Optional[str]:
        return self._values.get("enhanced_monitoring")

    @builtins.property
    def logging_info(self) -> typing.Optional[typing.List["MskClusterLoggingInfo"]]:
        """logging_info block."""
        return self._values.get("logging_info")

    @builtins.property
    def open_monitoring(
        self,
    ) -> typing.Optional[typing.List["MskClusterOpenMonitoring"]]:
        """open_monitoring block."""
        return self._values.get("open_monitoring")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterConfigurationInfo",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "revision": "revision"},
)
class MskClusterConfigurationInfo:
    def __init__(self, *, arn: str, revision: jsii.Number) -> None:
        """
        :param arn: 
        :param revision: 
        """
        self._values = {
            "arn": arn,
            "revision": revision,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def revision(self) -> jsii.Number:
        return self._values.get("revision")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterConfigurationInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterEncryptionInfo",
    jsii_struct_bases=[],
    name_mapping={
        "encryption_at_rest_kms_key_arn": "encryptionAtRestKmsKeyArn",
        "encryption_in_transit": "encryptionInTransit",
    },
)
class MskClusterEncryptionInfo:
    def __init__(
        self,
        *,
        encryption_at_rest_kms_key_arn: typing.Optional[str] = None,
        encryption_in_transit: typing.Optional[
            typing.List["MskClusterEncryptionInfoEncryptionInTransit"]
        ] = None,
    ) -> None:
        """
        :param encryption_at_rest_kms_key_arn: 
        :param encryption_in_transit: encryption_in_transit block.
        """
        self._values = {}
        if encryption_at_rest_kms_key_arn is not None:
            self._values[
                "encryption_at_rest_kms_key_arn"
            ] = encryption_at_rest_kms_key_arn
        if encryption_in_transit is not None:
            self._values["encryption_in_transit"] = encryption_in_transit

    @builtins.property
    def encryption_at_rest_kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("encryption_at_rest_kms_key_arn")

    @builtins.property
    def encryption_in_transit(
        self,
    ) -> typing.Optional[typing.List["MskClusterEncryptionInfoEncryptionInTransit"]]:
        """encryption_in_transit block."""
        return self._values.get("encryption_in_transit")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterEncryptionInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterEncryptionInfoEncryptionInTransit",
    jsii_struct_bases=[],
    name_mapping={"client_broker": "clientBroker", "in_cluster": "inCluster"},
)
class MskClusterEncryptionInfoEncryptionInTransit:
    def __init__(
        self,
        *,
        client_broker: typing.Optional[str] = None,
        in_cluster: typing.Optional[bool] = None,
    ) -> None:
        """
        :param client_broker: 
        :param in_cluster: 
        """
        self._values = {}
        if client_broker is not None:
            self._values["client_broker"] = client_broker
        if in_cluster is not None:
            self._values["in_cluster"] = in_cluster

    @builtins.property
    def client_broker(self) -> typing.Optional[str]:
        return self._values.get("client_broker")

    @builtins.property
    def in_cluster(self) -> typing.Optional[bool]:
        return self._values.get("in_cluster")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterEncryptionInfoEncryptionInTransit(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterLoggingInfo",
    jsii_struct_bases=[],
    name_mapping={"broker_logs": "brokerLogs"},
)
class MskClusterLoggingInfo:
    def __init__(
        self, *, broker_logs: typing.List["MskClusterLoggingInfoBrokerLogs"]
    ) -> None:
        """
        :param broker_logs: broker_logs block.
        """
        self._values = {
            "broker_logs": broker_logs,
        }

    @builtins.property
    def broker_logs(self) -> typing.List["MskClusterLoggingInfoBrokerLogs"]:
        """broker_logs block."""
        return self._values.get("broker_logs")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterLoggingInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterLoggingInfoBrokerLogs",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_logs": "cloudwatchLogs",
        "firehose": "firehose",
        "s3": "s3",
    },
)
class MskClusterLoggingInfoBrokerLogs:
    def __init__(
        self,
        *,
        cloudwatch_logs: typing.Optional[
            typing.List["MskClusterLoggingInfoBrokerLogsCloudwatchLogs"]
        ] = None,
        firehose: typing.Optional[
            typing.List["MskClusterLoggingInfoBrokerLogsFirehose"]
        ] = None,
        s3: typing.Optional[typing.List["MskClusterLoggingInfoBrokerLogsS3"]] = None,
    ) -> None:
        """
        :param cloudwatch_logs: cloudwatch_logs block.
        :param firehose: firehose block.
        :param s3: s3 block.
        """
        self._values = {}
        if cloudwatch_logs is not None:
            self._values["cloudwatch_logs"] = cloudwatch_logs
        if firehose is not None:
            self._values["firehose"] = firehose
        if s3 is not None:
            self._values["s3"] = s3

    @builtins.property
    def cloudwatch_logs(
        self,
    ) -> typing.Optional[typing.List["MskClusterLoggingInfoBrokerLogsCloudwatchLogs"]]:
        """cloudwatch_logs block."""
        return self._values.get("cloudwatch_logs")

    @builtins.property
    def firehose(
        self,
    ) -> typing.Optional[typing.List["MskClusterLoggingInfoBrokerLogsFirehose"]]:
        """firehose block."""
        return self._values.get("firehose")

    @builtins.property
    def s3(self) -> typing.Optional[typing.List["MskClusterLoggingInfoBrokerLogsS3"]]:
        """s3 block."""
        return self._values.get("s3")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterLoggingInfoBrokerLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterLoggingInfoBrokerLogsCloudwatchLogs",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "log_group": "logGroup"},
)
class MskClusterLoggingInfoBrokerLogsCloudwatchLogs:
    def __init__(
        self, *, enabled: bool, log_group: typing.Optional[str] = None
    ) -> None:
        """
        :param enabled: 
        :param log_group: 
        """
        self._values = {
            "enabled": enabled,
        }
        if log_group is not None:
            self._values["log_group"] = log_group

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def log_group(self) -> typing.Optional[str]:
        return self._values.get("log_group")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterLoggingInfoBrokerLogsCloudwatchLogs(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterLoggingInfoBrokerLogsFirehose",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "delivery_stream": "deliveryStream"},
)
class MskClusterLoggingInfoBrokerLogsFirehose:
    def __init__(
        self, *, enabled: bool, delivery_stream: typing.Optional[str] = None
    ) -> None:
        """
        :param enabled: 
        :param delivery_stream: 
        """
        self._values = {
            "enabled": enabled,
        }
        if delivery_stream is not None:
            self._values["delivery_stream"] = delivery_stream

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def delivery_stream(self) -> typing.Optional[str]:
        return self._values.get("delivery_stream")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterLoggingInfoBrokerLogsFirehose(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterLoggingInfoBrokerLogsS3",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "bucket": "bucket", "prefix": "prefix"},
)
class MskClusterLoggingInfoBrokerLogsS3:
    def __init__(
        self,
        *,
        enabled: bool,
        bucket: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param enabled: 
        :param bucket: 
        :param prefix: 
        """
        self._values = {
            "enabled": enabled,
        }
        if bucket is not None:
            self._values["bucket"] = bucket
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def bucket(self) -> typing.Optional[str]:
        return self._values.get("bucket")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterLoggingInfoBrokerLogsS3(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterOpenMonitoring",
    jsii_struct_bases=[],
    name_mapping={"prometheus": "prometheus"},
)
class MskClusterOpenMonitoring:
    def __init__(
        self, *, prometheus: typing.List["MskClusterOpenMonitoringPrometheus"]
    ) -> None:
        """
        :param prometheus: prometheus block.
        """
        self._values = {
            "prometheus": prometheus,
        }

    @builtins.property
    def prometheus(self) -> typing.List["MskClusterOpenMonitoringPrometheus"]:
        """prometheus block."""
        return self._values.get("prometheus")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterOpenMonitoring(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterOpenMonitoringPrometheus",
    jsii_struct_bases=[],
    name_mapping={"jmx_exporter": "jmxExporter", "node_exporter": "nodeExporter"},
)
class MskClusterOpenMonitoringPrometheus:
    def __init__(
        self,
        *,
        jmx_exporter: typing.Optional[
            typing.List["MskClusterOpenMonitoringPrometheusJmxExporter"]
        ] = None,
        node_exporter: typing.Optional[
            typing.List["MskClusterOpenMonitoringPrometheusNodeExporter"]
        ] = None,
    ) -> None:
        """
        :param jmx_exporter: jmx_exporter block.
        :param node_exporter: node_exporter block.
        """
        self._values = {}
        if jmx_exporter is not None:
            self._values["jmx_exporter"] = jmx_exporter
        if node_exporter is not None:
            self._values["node_exporter"] = node_exporter

    @builtins.property
    def jmx_exporter(
        self,
    ) -> typing.Optional[typing.List["MskClusterOpenMonitoringPrometheusJmxExporter"]]:
        """jmx_exporter block."""
        return self._values.get("jmx_exporter")

    @builtins.property
    def node_exporter(
        self,
    ) -> typing.Optional[typing.List["MskClusterOpenMonitoringPrometheusNodeExporter"]]:
        """node_exporter block."""
        return self._values.get("node_exporter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterOpenMonitoringPrometheus(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterOpenMonitoringPrometheusJmxExporter",
    jsii_struct_bases=[],
    name_mapping={"enabled_in_broker": "enabledInBroker"},
)
class MskClusterOpenMonitoringPrometheusJmxExporter:
    def __init__(self, *, enabled_in_broker: bool) -> None:
        """
        :param enabled_in_broker: 
        """
        self._values = {
            "enabled_in_broker": enabled_in_broker,
        }

    @builtins.property
    def enabled_in_broker(self) -> bool:
        return self._values.get("enabled_in_broker")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterOpenMonitoringPrometheusJmxExporter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskClusterOpenMonitoringPrometheusNodeExporter",
    jsii_struct_bases=[],
    name_mapping={"enabled_in_broker": "enabledInBroker"},
)
class MskClusterOpenMonitoringPrometheusNodeExporter:
    def __init__(self, *, enabled_in_broker: bool) -> None:
        """
        :param enabled_in_broker: 
        """
        self._values = {
            "enabled_in_broker": enabled_in_broker,
        }

    @builtins.property
    def enabled_in_broker(self) -> bool:
        return self._values.get("enabled_in_broker")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskClusterOpenMonitoringPrometheusNodeExporter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class MskConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.MskConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        kafka_versions: typing.List[str],
        name: str,
        server_properties: str,
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param kafka_versions: 
        :param name: 
        :param server_properties: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = MskConfigurationConfig(
            kafka_versions=kafka_versions,
            name=name,
            server_properties=server_properties,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(MskConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="latestRevision")
    def latest_revision(self) -> jsii.Number:
        return jsii.get(self, "latestRevision")

    @builtins.property
    @jsii.member(jsii_name="kafkaVersions")
    def kafka_versions(self) -> typing.List[str]:
        return jsii.get(self, "kafkaVersions")

    @kafka_versions.setter
    def kafka_versions(self, value: typing.List[str]) -> None:
        jsii.set(self, "kafkaVersions", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="serverProperties")
    def server_properties(self) -> str:
        return jsii.get(self, "serverProperties")

    @server_properties.setter
    def server_properties(self, value: str) -> None:
        jsii.set(self, "serverProperties", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.MskConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "kafka_versions": "kafkaVersions",
        "name": "name",
        "server_properties": "serverProperties",
        "description": "description",
    },
)
class MskConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        kafka_versions: typing.List[str],
        name: str,
        server_properties: str,
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param kafka_versions: 
        :param name: 
        :param server_properties: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "kafka_versions": kafka_versions,
            "name": name,
            "server_properties": server_properties,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def kafka_versions(self) -> typing.List[str]:
        return self._values.get("kafka_versions")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def server_properties(self) -> str:
        return self._values.get("server_properties")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "MskConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NatGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NatGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        allocation_id: str,
        subnet_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param allocation_id: 
        :param subnet_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NatGatewayConfig(
            allocation_id=allocation_id,
            subnet_id=subnet_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NatGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> str:
        return jsii.get(self, "privateIp")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")

    @builtins.property
    @jsii.member(jsii_name="allocationId")
    def allocation_id(self) -> str:
        return jsii.get(self, "allocationId")

    @allocation_id.setter
    def allocation_id(self, value: str) -> None:
        jsii.set(self, "allocationId", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NatGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "allocation_id": "allocationId",
        "subnet_id": "subnetId",
        "tags": "tags",
    },
)
class NatGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        allocation_id: str,
        subnet_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param allocation_id: 
        :param subnet_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "allocation_id": allocation_id,
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def allocation_id(self) -> str:
        return self._values.get("allocation_id")

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NatGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NeptuneCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        apply_immediately: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        cluster_identifier: typing.Optional[str] = None,
        cluster_identifier_prefix: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        enable_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        iam_database_authentication_enabled: typing.Optional[bool] = None,
        iam_roles: typing.Optional[typing.List[str]] = None,
        kms_key_arn: typing.Optional[str] = None,
        neptune_cluster_parameter_group_name: typing.Optional[str] = None,
        neptune_subnet_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        replication_source_identifier: typing.Optional[str] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["NeptuneClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param apply_immediately: 
        :param availability_zones: 
        :param backup_retention_period: 
        :param cluster_identifier: 
        :param cluster_identifier_prefix: 
        :param deletion_protection: 
        :param enable_cloudwatch_logs_exports: 
        :param engine: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param iam_database_authentication_enabled: 
        :param iam_roles: 
        :param kms_key_arn: 
        :param neptune_cluster_parameter_group_name: 
        :param neptune_subnet_group_name: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param replication_source_identifier: 
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param storage_encrypted: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NeptuneClusterConfig(
            apply_immediately=apply_immediately,
            availability_zones=availability_zones,
            backup_retention_period=backup_retention_period,
            cluster_identifier=cluster_identifier,
            cluster_identifier_prefix=cluster_identifier_prefix,
            deletion_protection=deletion_protection,
            enable_cloudwatch_logs_exports=enable_cloudwatch_logs_exports,
            engine=engine,
            engine_version=engine_version,
            final_snapshot_identifier=final_snapshot_identifier,
            iam_database_authentication_enabled=iam_database_authentication_enabled,
            iam_roles=iam_roles,
            kms_key_arn=kms_key_arn,
            neptune_cluster_parameter_group_name=neptune_cluster_parameter_group_name,
            neptune_subnet_group_name=neptune_subnet_group_name,
            port=port,
            preferred_backup_window=preferred_backup_window,
            preferred_maintenance_window=preferred_maintenance_window,
            replication_source_identifier=replication_source_identifier,
            skip_final_snapshot=skip_final_snapshot,
            snapshot_identifier=snapshot_identifier,
            storage_encrypted=storage_encrypted,
            tags=tags,
            timeouts=timeouts,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NeptuneCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="clusterMembers")
    def cluster_members(self) -> typing.List[str]:
        return jsii.get(self, "clusterMembers")

    @builtins.property
    @jsii.member(jsii_name="clusterResourceId")
    def cluster_resource_id(self) -> str:
        return jsii.get(self, "clusterResourceId")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="readerEndpoint")
    def reader_endpoint(self) -> str:
        return jsii.get(self, "readerEndpoint")

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="backupRetentionPeriod")
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "backupRetentionPeriod")

    @backup_retention_period.setter
    def backup_retention_period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "backupRetentionPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifierPrefix")
    def cluster_identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterIdentifierPrefix")

    @cluster_identifier_prefix.setter
    def cluster_identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterIdentifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "deletionProtection")

    @deletion_protection.setter
    def deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="enableCloudwatchLogsExports")
    def enable_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "enableCloudwatchLogsExports")

    @enable_cloudwatch_logs_exports.setter
    def enable_cloudwatch_logs_exports(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "enableCloudwatchLogsExports", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="finalSnapshotIdentifier")
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "finalSnapshotIdentifier")

    @final_snapshot_identifier.setter
    def final_snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "finalSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="iamDatabaseAuthenticationEnabled")
    def iam_database_authentication_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "iamDatabaseAuthenticationEnabled")

    @iam_database_authentication_enabled.setter
    def iam_database_authentication_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "iamDatabaseAuthenticationEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="iamRoles")
    def iam_roles(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "iamRoles")

    @iam_roles.setter
    def iam_roles(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "iamRoles", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="neptuneClusterParameterGroupName")
    def neptune_cluster_parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "neptuneClusterParameterGroupName")

    @neptune_cluster_parameter_group_name.setter
    def neptune_cluster_parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "neptuneClusterParameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="neptuneSubnetGroupName")
    def neptune_subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "neptuneSubnetGroupName")

    @neptune_subnet_group_name.setter
    def neptune_subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "neptuneSubnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredBackupWindow")

    @preferred_backup_window.setter
    def preferred_backup_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredBackupWindow", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="replicationSourceIdentifier")
    def replication_source_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "replicationSourceIdentifier")

    @replication_source_identifier.setter
    def replication_source_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "replicationSourceIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="skipFinalSnapshot")
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipFinalSnapshot")

    @skip_final_snapshot.setter
    def skip_final_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipFinalSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotIdentifier")
    def snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotIdentifier")

    @snapshot_identifier.setter
    def snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "storageEncrypted")

    @storage_encrypted.setter
    def storage_encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "storageEncrypted", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NeptuneClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["NeptuneClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "apply_immediately": "applyImmediately",
        "availability_zones": "availabilityZones",
        "backup_retention_period": "backupRetentionPeriod",
        "cluster_identifier": "clusterIdentifier",
        "cluster_identifier_prefix": "clusterIdentifierPrefix",
        "deletion_protection": "deletionProtection",
        "enable_cloudwatch_logs_exports": "enableCloudwatchLogsExports",
        "engine": "engine",
        "engine_version": "engineVersion",
        "final_snapshot_identifier": "finalSnapshotIdentifier",
        "iam_database_authentication_enabled": "iamDatabaseAuthenticationEnabled",
        "iam_roles": "iamRoles",
        "kms_key_arn": "kmsKeyArn",
        "neptune_cluster_parameter_group_name": "neptuneClusterParameterGroupName",
        "neptune_subnet_group_name": "neptuneSubnetGroupName",
        "port": "port",
        "preferred_backup_window": "preferredBackupWindow",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "replication_source_identifier": "replicationSourceIdentifier",
        "skip_final_snapshot": "skipFinalSnapshot",
        "snapshot_identifier": "snapshotIdentifier",
        "storage_encrypted": "storageEncrypted",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class NeptuneClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        apply_immediately: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        cluster_identifier: typing.Optional[str] = None,
        cluster_identifier_prefix: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        enable_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        iam_database_authentication_enabled: typing.Optional[bool] = None,
        iam_roles: typing.Optional[typing.List[str]] = None,
        kms_key_arn: typing.Optional[str] = None,
        neptune_cluster_parameter_group_name: typing.Optional[str] = None,
        neptune_subnet_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        replication_source_identifier: typing.Optional[str] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["NeptuneClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param apply_immediately: 
        :param availability_zones: 
        :param backup_retention_period: 
        :param cluster_identifier: 
        :param cluster_identifier_prefix: 
        :param deletion_protection: 
        :param enable_cloudwatch_logs_exports: 
        :param engine: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param iam_database_authentication_enabled: 
        :param iam_roles: 
        :param kms_key_arn: 
        :param neptune_cluster_parameter_group_name: 
        :param neptune_subnet_group_name: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param replication_source_identifier: 
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param storage_encrypted: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NeptuneClusterTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if backup_retention_period is not None:
            self._values["backup_retention_period"] = backup_retention_period
        if cluster_identifier is not None:
            self._values["cluster_identifier"] = cluster_identifier
        if cluster_identifier_prefix is not None:
            self._values["cluster_identifier_prefix"] = cluster_identifier_prefix
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if enable_cloudwatch_logs_exports is not None:
            self._values[
                "enable_cloudwatch_logs_exports"
            ] = enable_cloudwatch_logs_exports
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if final_snapshot_identifier is not None:
            self._values["final_snapshot_identifier"] = final_snapshot_identifier
        if iam_database_authentication_enabled is not None:
            self._values[
                "iam_database_authentication_enabled"
            ] = iam_database_authentication_enabled
        if iam_roles is not None:
            self._values["iam_roles"] = iam_roles
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if neptune_cluster_parameter_group_name is not None:
            self._values[
                "neptune_cluster_parameter_group_name"
            ] = neptune_cluster_parameter_group_name
        if neptune_subnet_group_name is not None:
            self._values["neptune_subnet_group_name"] = neptune_subnet_group_name
        if port is not None:
            self._values["port"] = port
        if preferred_backup_window is not None:
            self._values["preferred_backup_window"] = preferred_backup_window
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if replication_source_identifier is not None:
            self._values[
                "replication_source_identifier"
            ] = replication_source_identifier
        if skip_final_snapshot is not None:
            self._values["skip_final_snapshot"] = skip_final_snapshot
        if snapshot_identifier is not None:
            self._values["snapshot_identifier"] = snapshot_identifier
        if storage_encrypted is not None:
            self._values["storage_encrypted"] = storage_encrypted
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("backup_retention_period")

    @builtins.property
    def cluster_identifier(self) -> typing.Optional[str]:
        return self._values.get("cluster_identifier")

    @builtins.property
    def cluster_identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("cluster_identifier_prefix")

    @builtins.property
    def deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("deletion_protection")

    @builtins.property
    def enable_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("enable_cloudwatch_logs_exports")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("final_snapshot_identifier")

    @builtins.property
    def iam_database_authentication_enabled(self) -> typing.Optional[bool]:
        return self._values.get("iam_database_authentication_enabled")

    @builtins.property
    def iam_roles(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("iam_roles")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def neptune_cluster_parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("neptune_cluster_parameter_group_name")

    @builtins.property
    def neptune_subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("neptune_subnet_group_name")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def preferred_backup_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_backup_window")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def replication_source_identifier(self) -> typing.Optional[str]:
        return self._values.get("replication_source_identifier")

    @builtins.property
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("skip_final_snapshot")

    @builtins.property
    def snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("snapshot_identifier")

    @builtins.property
    def storage_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("storage_encrypted")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["NeptuneClusterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NeptuneClusterInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_identifier: str,
        instance_class: str,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        neptune_parameter_group_name: typing.Optional[str] = None,
        neptune_subnet_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        promotion_tier: typing.Optional[jsii.Number] = None,
        publicly_accessible: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["NeptuneClusterInstanceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_identifier: 
        :param instance_class: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param engine: 
        :param engine_version: 
        :param identifier: 
        :param identifier_prefix: 
        :param neptune_parameter_group_name: 
        :param neptune_subnet_group_name: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param promotion_tier: 
        :param publicly_accessible: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NeptuneClusterInstanceConfig(
            cluster_identifier=cluster_identifier,
            instance_class=instance_class,
            apply_immediately=apply_immediately,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
            availability_zone=availability_zone,
            engine=engine,
            engine_version=engine_version,
            identifier=identifier,
            identifier_prefix=identifier_prefix,
            neptune_parameter_group_name=neptune_parameter_group_name,
            neptune_subnet_group_name=neptune_subnet_group_name,
            port=port,
            preferred_backup_window=preferred_backup_window,
            preferred_maintenance_window=preferred_maintenance_window,
            promotion_tier=promotion_tier,
            publicly_accessible=publicly_accessible,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NeptuneClusterInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="address")
    def address(self) -> str:
        return jsii.get(self, "address")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dbiResourceId")
    def dbi_resource_id(self) -> str:
        return jsii.get(self, "dbiResourceId")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> str:
        return jsii.get(self, "kmsKeyArn")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="writer")
    def writer(self) -> bool:
        return jsii.get(self, "writer")

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="instanceClass")
    def instance_class(self) -> str:
        return jsii.get(self, "instanceClass")

    @instance_class.setter
    def instance_class(self, value: str) -> None:
        jsii.set(self, "instanceClass", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoMinorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property
    @jsii.member(jsii_name="identifierPrefix")
    def identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "identifierPrefix")

    @identifier_prefix.setter
    def identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="neptuneParameterGroupName")
    def neptune_parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "neptuneParameterGroupName")

    @neptune_parameter_group_name.setter
    def neptune_parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "neptuneParameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="neptuneSubnetGroupName")
    def neptune_subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "neptuneSubnetGroupName")

    @neptune_subnet_group_name.setter
    def neptune_subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "neptuneSubnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredBackupWindow")

    @preferred_backup_window.setter
    def preferred_backup_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredBackupWindow", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="promotionTier")
    def promotion_tier(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "promotionTier")

    @promotion_tier.setter
    def promotion_tier(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "promotionTier", value)

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> typing.Optional[bool]:
        return jsii.get(self, "publiclyAccessible")

    @publicly_accessible.setter
    def publicly_accessible(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "publiclyAccessible", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NeptuneClusterInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["NeptuneClusterInstanceTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_identifier": "clusterIdentifier",
        "instance_class": "instanceClass",
        "apply_immediately": "applyImmediately",
        "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
        "availability_zone": "availabilityZone",
        "engine": "engine",
        "engine_version": "engineVersion",
        "identifier": "identifier",
        "identifier_prefix": "identifierPrefix",
        "neptune_parameter_group_name": "neptuneParameterGroupName",
        "neptune_subnet_group_name": "neptuneSubnetGroupName",
        "port": "port",
        "preferred_backup_window": "preferredBackupWindow",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "promotion_tier": "promotionTier",
        "publicly_accessible": "publiclyAccessible",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NeptuneClusterInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_identifier: str,
        instance_class: str,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        neptune_parameter_group_name: typing.Optional[str] = None,
        neptune_subnet_group_name: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        promotion_tier: typing.Optional[jsii.Number] = None,
        publicly_accessible: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["NeptuneClusterInstanceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_identifier: 
        :param instance_class: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param engine: 
        :param engine_version: 
        :param identifier: 
        :param identifier_prefix: 
        :param neptune_parameter_group_name: 
        :param neptune_subnet_group_name: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param promotion_tier: 
        :param publicly_accessible: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NeptuneClusterInstanceTimeouts(**timeouts)
        self._values = {
            "cluster_identifier": cluster_identifier,
            "instance_class": instance_class,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if auto_minor_version_upgrade is not None:
            self._values["auto_minor_version_upgrade"] = auto_minor_version_upgrade
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if identifier is not None:
            self._values["identifier"] = identifier
        if identifier_prefix is not None:
            self._values["identifier_prefix"] = identifier_prefix
        if neptune_parameter_group_name is not None:
            self._values["neptune_parameter_group_name"] = neptune_parameter_group_name
        if neptune_subnet_group_name is not None:
            self._values["neptune_subnet_group_name"] = neptune_subnet_group_name
        if port is not None:
            self._values["port"] = port
        if preferred_backup_window is not None:
            self._values["preferred_backup_window"] = preferred_backup_window
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if promotion_tier is not None:
            self._values["promotion_tier"] = promotion_tier
        if publicly_accessible is not None:
            self._values["publicly_accessible"] = publicly_accessible
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def instance_class(self) -> str:
        return self._values.get("instance_class")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("auto_minor_version_upgrade")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def identifier(self) -> typing.Optional[str]:
        return self._values.get("identifier")

    @builtins.property
    def identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("identifier_prefix")

    @builtins.property
    def neptune_parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("neptune_parameter_group_name")

    @builtins.property
    def neptune_subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("neptune_subnet_group_name")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def preferred_backup_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_backup_window")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def promotion_tier(self) -> typing.Optional[jsii.Number]:
        return self._values.get("promotion_tier")

    @builtins.property
    def publicly_accessible(self) -> typing.Optional[bool]:
        return self._values.get("publicly_accessible")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["NeptuneClusterInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class NeptuneClusterInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NeptuneClusterParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["NeptuneClusterParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NeptuneClusterParameterGroupConfig(
            family=family,
            description=description,
            name=name,
            name_prefix=name_prefix,
            parameter=parameter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NeptuneClusterParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="parameter")
    def parameter(
        self,
    ) -> typing.Optional[typing.List["NeptuneClusterParameterGroupParameter"]]:
        return jsii.get(self, "parameter")

    @parameter.setter
    def parameter(
        self,
        value: typing.Optional[typing.List["NeptuneClusterParameterGroupParameter"]],
    ) -> None:
        jsii.set(self, "parameter", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "parameter": "parameter",
        "tags": "tags",
    },
)
class NeptuneClusterParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["NeptuneClusterParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "family": family,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if parameter is not None:
            self._values["parameter"] = parameter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[typing.List["NeptuneClusterParameterGroupParameter"]]:
        """parameter block."""
        return self._values.get("parameter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterParameterGroupParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value", "apply_method": "applyMethod"},
)
class NeptuneClusterParameterGroupParameter:
    def __init__(
        self, *, name: str, value: str, apply_method: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        :param apply_method: 
        """
        self._values = {
            "name": name,
            "value": value,
        }
        if apply_method is not None:
            self._values["apply_method"] = apply_method

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def apply_method(self) -> typing.Optional[str]:
        return self._values.get("apply_method")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterParameterGroupParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NeptuneClusterSnapshot(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterSnapshot",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_cluster_identifier: str,
        db_cluster_snapshot_identifier: str,
        timeouts: typing.Optional["NeptuneClusterSnapshotTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NeptuneClusterSnapshotConfig(
            db_cluster_identifier=db_cluster_identifier,
            db_cluster_snapshot_identifier=db_cluster_snapshot_identifier,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NeptuneClusterSnapshot, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="allocatedStorage")
    def allocated_storage(self) -> jsii.Number:
        return jsii.get(self, "allocatedStorage")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotArn")
    def db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "dbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> str:
        return jsii.get(self, "engine")

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> str:
        return jsii.get(self, "engineVersion")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="licenseModel")
    def license_model(self) -> str:
        return jsii.get(self, "licenseModel")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="snapshotType")
    def snapshot_type(self) -> str:
        return jsii.get(self, "snapshotType")

    @builtins.property
    @jsii.member(jsii_name="sourceDbClusterSnapshotArn")
    def source_db_cluster_snapshot_arn(self) -> str:
        return jsii.get(self, "sourceDbClusterSnapshotArn")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="dbClusterIdentifier")
    def db_cluster_identifier(self) -> str:
        return jsii.get(self, "dbClusterIdentifier")

    @db_cluster_identifier.setter
    def db_cluster_identifier(self, value: str) -> None:
        jsii.set(self, "dbClusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="dbClusterSnapshotIdentifier")
    def db_cluster_snapshot_identifier(self) -> str:
        return jsii.get(self, "dbClusterSnapshotIdentifier")

    @db_cluster_snapshot_identifier.setter
    def db_cluster_snapshot_identifier(self, value: str) -> None:
        jsii.set(self, "dbClusterSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NeptuneClusterSnapshotTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["NeptuneClusterSnapshotTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterSnapshotConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_cluster_identifier": "dbClusterIdentifier",
        "db_cluster_snapshot_identifier": "dbClusterSnapshotIdentifier",
        "timeouts": "timeouts",
    },
)
class NeptuneClusterSnapshotConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_cluster_identifier: str,
        db_cluster_snapshot_identifier: str,
        timeouts: typing.Optional["NeptuneClusterSnapshotTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_cluster_identifier: 
        :param db_cluster_snapshot_identifier: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NeptuneClusterSnapshotTimeouts(**timeouts)
        self._values = {
            "db_cluster_identifier": db_cluster_identifier,
            "db_cluster_snapshot_identifier": db_cluster_snapshot_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_cluster_identifier(self) -> str:
        return self._values.get("db_cluster_identifier")

    @builtins.property
    def db_cluster_snapshot_identifier(self) -> str:
        return self._values.get("db_cluster_snapshot_identifier")

    @builtins.property
    def timeouts(self) -> typing.Optional["NeptuneClusterSnapshotTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterSnapshotConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterSnapshotTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class NeptuneClusterSnapshotTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterSnapshotTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class NeptuneClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NeptuneEventSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneEventSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        sns_topic_arn: str,
        enabled: typing.Optional[bool] = None,
        event_categories: typing.Optional[typing.List[str]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["NeptuneEventSubscriptionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param sns_topic_arn: 
        :param enabled: 
        :param event_categories: 
        :param name: 
        :param name_prefix: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NeptuneEventSubscriptionConfig(
            sns_topic_arn=sns_topic_arn,
            enabled=enabled,
            event_categories=event_categories,
            name=name,
            name_prefix=name_prefix,
            source_ids=source_ids,
            source_type=source_type,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NeptuneEventSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="customerAwsId")
    def customer_aws_id(self) -> str:
        return jsii.get(self, "customerAwsId")

    @builtins.property
    @jsii.member(jsii_name="snsTopicArn")
    def sns_topic_arn(self) -> str:
        return jsii.get(self, "snsTopicArn")

    @sns_topic_arn.setter
    def sns_topic_arn(self, value: str) -> None:
        jsii.set(self, "snsTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="eventCategories")
    def event_categories(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "eventCategories")

    @event_categories.setter
    def event_categories(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "eventCategories", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="sourceIds")
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "sourceIds")

    @source_ids.setter
    def source_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "sourceIds", value)

    @builtins.property
    @jsii.member(jsii_name="sourceType")
    def source_type(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceType")

    @source_type.setter
    def source_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["NeptuneEventSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["NeptuneEventSubscriptionTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneEventSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "sns_topic_arn": "snsTopicArn",
        "enabled": "enabled",
        "event_categories": "eventCategories",
        "name": "name",
        "name_prefix": "namePrefix",
        "source_ids": "sourceIds",
        "source_type": "sourceType",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class NeptuneEventSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        sns_topic_arn: str,
        enabled: typing.Optional[bool] = None,
        event_categories: typing.Optional[typing.List[str]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["NeptuneEventSubscriptionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param sns_topic_arn: 
        :param enabled: 
        :param event_categories: 
        :param name: 
        :param name_prefix: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = NeptuneEventSubscriptionTimeouts(**timeouts)
        self._values = {
            "sns_topic_arn": sns_topic_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if event_categories is not None:
            self._values["event_categories"] = event_categories
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if source_ids is not None:
            self._values["source_ids"] = source_ids
        if source_type is not None:
            self._values["source_type"] = source_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def sns_topic_arn(self) -> str:
        return self._values.get("sns_topic_arn")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def event_categories(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("event_categories")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("source_ids")

    @builtins.property
    def source_type(self) -> typing.Optional[str]:
        return self._values.get("source_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["NeptuneEventSubscriptionTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneEventSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneEventSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class NeptuneEventSubscriptionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneEventSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NeptuneParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        family: str,
        name: str,
        description: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["NeptuneParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param family: 
        :param name: 
        :param description: 
        :param parameter: parameter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NeptuneParameterGroupConfig(
            family=family,
            name=name,
            description=description,
            parameter=parameter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NeptuneParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parameter")
    def parameter(
        self,
    ) -> typing.Optional[typing.List["NeptuneParameterGroupParameter"]]:
        return jsii.get(self, "parameter")

    @parameter.setter
    def parameter(
        self, value: typing.Optional[typing.List["NeptuneParameterGroupParameter"]]
    ) -> None:
        jsii.set(self, "parameter", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "name": "name",
        "description": "description",
        "parameter": "parameter",
        "tags": "tags",
    },
)
class NeptuneParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: str,
        name: str,
        description: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["NeptuneParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: 
        :param name: 
        :param description: 
        :param parameter: parameter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "family": family,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if parameter is not None:
            self._values["parameter"] = parameter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[typing.List["NeptuneParameterGroupParameter"]]:
        """parameter block."""
        return self._values.get("parameter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneParameterGroupParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value", "apply_method": "applyMethod"},
)
class NeptuneParameterGroupParameter:
    def __init__(
        self, *, name: str, value: str, apply_method: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        :param apply_method: 
        """
        self._values = {
            "name": name,
            "value": value,
        }
        if apply_method is not None:
            self._values["apply_method"] = apply_method

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def apply_method(self) -> typing.Optional[str]:
        return self._values.get("apply_method")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneParameterGroupParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NeptuneSubnetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneSubnetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param subnet_ids: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NeptuneSubnetGroupConfig(
            subnet_ids=subnet_ids,
            description=description,
            name=name,
            name_prefix=name_prefix,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NeptuneSubnetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NeptuneSubnetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "subnet_ids": "subnetIds",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "tags": "tags",
    },
)
class NeptuneSubnetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param subnet_ids: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NeptuneSubnetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkAcl(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkAcl",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_id: str,
        egress: typing.Optional[typing.List["NetworkAclEgress"]] = None,
        ingress: typing.Optional[typing.List["NetworkAclIngress"]] = None,
        subnet_id: typing.Optional[str] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_id: 
        :param egress: 
        :param ingress: 
        :param subnet_id: 
        :param subnet_ids: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkAclConfig(
            vpc_id=vpc_id,
            egress=egress,
            ingress=ingress,
            subnet_id=subnet_id,
            subnet_ids=subnet_ids,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkAcl, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="egress")
    def egress(self) -> typing.Optional[typing.List["NetworkAclEgress"]]:
        return jsii.get(self, "egress")

    @egress.setter
    def egress(self, value: typing.Optional[typing.List["NetworkAclEgress"]]) -> None:
        jsii.set(self, "egress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> typing.Optional[typing.List["NetworkAclIngress"]]:
        return jsii.get(self, "ingress")

    @ingress.setter
    def ingress(self, value: typing.Optional[typing.List["NetworkAclIngress"]]) -> None:
        jsii.set(self, "ingress", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_id": "vpcId",
        "egress": "egress",
        "ingress": "ingress",
        "subnet_id": "subnetId",
        "subnet_ids": "subnetIds",
        "tags": "tags",
    },
)
class NetworkAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_id: str,
        egress: typing.Optional[typing.List["NetworkAclEgress"]] = None,
        ingress: typing.Optional[typing.List["NetworkAclIngress"]] = None,
        subnet_id: typing.Optional[str] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_id: 
        :param egress: 
        :param ingress: 
        :param subnet_id: 
        :param subnet_ids: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if egress is not None:
            self._values["egress"] = egress
        if ingress is not None:
            self._values["ingress"] = ingress
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def egress(self) -> typing.Optional[typing.List["NetworkAclEgress"]]:
        return self._values.get("egress")

    @builtins.property
    def ingress(self) -> typing.Optional[typing.List["NetworkAclIngress"]]:
        return self._values.get("ingress")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkAclEgress",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "cidr_block": "cidrBlock",
        "from_port": "fromPort",
        "icmp_code": "icmpCode",
        "icmp_type": "icmpType",
        "ipv6_cidr_block": "ipv6CidrBlock",
        "protocol": "protocol",
        "rule_no": "ruleNo",
        "to_port": "toPort",
    },
)
class NetworkAclEgress:
    def __init__(
        self,
        *,
        action: typing.Optional[str] = None,
        cidr_block: typing.Optional[str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        icmp_code: typing.Optional[jsii.Number] = None,
        icmp_type: typing.Optional[jsii.Number] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        rule_no: typing.Optional[jsii.Number] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param action: 
        :param cidr_block: 
        :param from_port: 
        :param icmp_code: 
        :param icmp_type: 
        :param ipv6_cidr_block: 
        :param protocol: 
        :param rule_no: 
        :param to_port: 
        """
        self._values = {}
        if action is not None:
            self._values["action"] = action
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if from_port is not None:
            self._values["from_port"] = from_port
        if icmp_code is not None:
            self._values["icmp_code"] = icmp_code
        if icmp_type is not None:
            self._values["icmp_type"] = icmp_type
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block
        if protocol is not None:
            self._values["protocol"] = protocol
        if rule_no is not None:
            self._values["rule_no"] = rule_no
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def action(self) -> typing.Optional[str]:
        return self._values.get("action")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def icmp_code(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_code")

    @builtins.property
    def icmp_type(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_type")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def rule_no(self) -> typing.Optional[jsii.Number]:
        return self._values.get("rule_no")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkAclEgress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkAclIngress",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "cidr_block": "cidrBlock",
        "from_port": "fromPort",
        "icmp_code": "icmpCode",
        "icmp_type": "icmpType",
        "ipv6_cidr_block": "ipv6CidrBlock",
        "protocol": "protocol",
        "rule_no": "ruleNo",
        "to_port": "toPort",
    },
)
class NetworkAclIngress:
    def __init__(
        self,
        *,
        action: typing.Optional[str] = None,
        cidr_block: typing.Optional[str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        icmp_code: typing.Optional[jsii.Number] = None,
        icmp_type: typing.Optional[jsii.Number] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        protocol: typing.Optional[str] = None,
        rule_no: typing.Optional[jsii.Number] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param action: 
        :param cidr_block: 
        :param from_port: 
        :param icmp_code: 
        :param icmp_type: 
        :param ipv6_cidr_block: 
        :param protocol: 
        :param rule_no: 
        :param to_port: 
        """
        self._values = {}
        if action is not None:
            self._values["action"] = action
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if from_port is not None:
            self._values["from_port"] = from_port
        if icmp_code is not None:
            self._values["icmp_code"] = icmp_code
        if icmp_type is not None:
            self._values["icmp_type"] = icmp_type
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block
        if protocol is not None:
            self._values["protocol"] = protocol
        if rule_no is not None:
            self._values["rule_no"] = rule_no
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def action(self) -> typing.Optional[str]:
        return self._values.get("action")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def icmp_code(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_code")

    @builtins.property
    def icmp_type(self) -> typing.Optional[jsii.Number]:
        return self._values.get("icmp_type")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def rule_no(self) -> typing.Optional[jsii.Number]:
        return self._values.get("rule_no")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkAclIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkAclRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkAclRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        network_acl_id: str,
        protocol: str,
        rule_action: str,
        rule_number: jsii.Number,
        cidr_block: typing.Optional[str] = None,
        egress: typing.Optional[bool] = None,
        from_port: typing.Optional[jsii.Number] = None,
        icmp_code: typing.Optional[str] = None,
        icmp_type: typing.Optional[str] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        to_port: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param network_acl_id: 
        :param protocol: 
        :param rule_action: 
        :param rule_number: 
        :param cidr_block: 
        :param egress: 
        :param from_port: 
        :param icmp_code: 
        :param icmp_type: 
        :param ipv6_cidr_block: 
        :param to_port: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkAclRuleConfig(
            network_acl_id=network_acl_id,
            protocol=protocol,
            rule_action=rule_action,
            rule_number=rule_number,
            cidr_block=cidr_block,
            egress=egress,
            from_port=from_port,
            icmp_code=icmp_code,
            icmp_type=icmp_type,
            ipv6_cidr_block=ipv6_cidr_block,
            to_port=to_port,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkAclRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="networkAclId")
    def network_acl_id(self) -> str:
        return jsii.get(self, "networkAclId")

    @network_acl_id.setter
    def network_acl_id(self, value: str) -> None:
        jsii.set(self, "networkAclId", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="ruleAction")
    def rule_action(self) -> str:
        return jsii.get(self, "ruleAction")

    @rule_action.setter
    def rule_action(self, value: str) -> None:
        jsii.set(self, "ruleAction", value)

    @builtins.property
    @jsii.member(jsii_name="ruleNumber")
    def rule_number(self) -> jsii.Number:
        return jsii.get(self, "ruleNumber")

    @rule_number.setter
    def rule_number(self, value: jsii.Number) -> None:
        jsii.set(self, "ruleNumber", value)

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "cidrBlock")

    @cidr_block.setter
    def cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="egress")
    def egress(self) -> typing.Optional[bool]:
        return jsii.get(self, "egress")

    @egress.setter
    def egress(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "egress", value)

    @builtins.property
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "fromPort")

    @from_port.setter
    def from_port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "fromPort", value)

    @builtins.property
    @jsii.member(jsii_name="icmpCode")
    def icmp_code(self) -> typing.Optional[str]:
        return jsii.get(self, "icmpCode")

    @icmp_code.setter
    def icmp_code(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "icmpCode", value)

    @builtins.property
    @jsii.member(jsii_name="icmpType")
    def icmp_type(self) -> typing.Optional[str]:
        return jsii.get(self, "icmpType")

    @icmp_type.setter
    def icmp_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "icmpType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "ipv6CidrBlock")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipv6CidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "toPort")

    @to_port.setter
    def to_port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "toPort", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkAclRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_acl_id": "networkAclId",
        "protocol": "protocol",
        "rule_action": "ruleAction",
        "rule_number": "ruleNumber",
        "cidr_block": "cidrBlock",
        "egress": "egress",
        "from_port": "fromPort",
        "icmp_code": "icmpCode",
        "icmp_type": "icmpType",
        "ipv6_cidr_block": "ipv6CidrBlock",
        "to_port": "toPort",
    },
)
class NetworkAclRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_acl_id: str,
        protocol: str,
        rule_action: str,
        rule_number: jsii.Number,
        cidr_block: typing.Optional[str] = None,
        egress: typing.Optional[bool] = None,
        from_port: typing.Optional[jsii.Number] = None,
        icmp_code: typing.Optional[str] = None,
        icmp_type: typing.Optional[str] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_acl_id: 
        :param protocol: 
        :param rule_action: 
        :param rule_number: 
        :param cidr_block: 
        :param egress: 
        :param from_port: 
        :param icmp_code: 
        :param icmp_type: 
        :param ipv6_cidr_block: 
        :param to_port: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "network_acl_id": network_acl_id,
            "protocol": protocol,
            "rule_action": rule_action,
            "rule_number": rule_number,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if egress is not None:
            self._values["egress"] = egress
        if from_port is not None:
            self._values["from_port"] = from_port
        if icmp_code is not None:
            self._values["icmp_code"] = icmp_code
        if icmp_type is not None:
            self._values["icmp_type"] = icmp_type
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def network_acl_id(self) -> str:
        return self._values.get("network_acl_id")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def rule_action(self) -> str:
        return self._values.get("rule_action")

    @builtins.property
    def rule_number(self) -> jsii.Number:
        return self._values.get("rule_number")

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def egress(self) -> typing.Optional[bool]:
        return self._values.get("egress")

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def icmp_code(self) -> typing.Optional[str]:
        return self._values.get("icmp_code")

    @builtins.property
    def icmp_type(self) -> typing.Optional[str]:
        return self._values.get("icmp_type")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkAclRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterface(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkInterface",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        subnet_id: str,
        attachment: typing.Optional[typing.List["NetworkInterfaceAttachment"]] = None,
        description: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        private_ips: typing.Optional[typing.List[str]] = None,
        private_ips_count: typing.Optional[jsii.Number] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_dest_check: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param subnet_id: 
        :param attachment: attachment block.
        :param description: 
        :param private_ip: 
        :param private_ips: 
        :param private_ips_count: 
        :param security_groups: 
        :param source_dest_check: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceConfig(
            subnet_id=subnet_id,
            attachment=attachment,
            description=description,
            private_ip=private_ip,
            private_ips=private_ips,
            private_ips_count=private_ips_count,
            security_groups=security_groups,
            source_dest_check=source_dest_check,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterface, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="macAddress")
    def mac_address(self) -> str:
        return jsii.get(self, "macAddress")

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="privateDnsName")
    def private_dns_name(self) -> str:
        return jsii.get(self, "privateDnsName")

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="attachment")
    def attachment(self) -> typing.Optional[typing.List["NetworkInterfaceAttachment"]]:
        return jsii.get(self, "attachment")

    @attachment.setter
    def attachment(
        self, value: typing.Optional[typing.List["NetworkInterfaceAttachment"]]
    ) -> None:
        jsii.set(self, "attachment", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "privateIp")

    @private_ip.setter
    def private_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateIp", value)

    @builtins.property
    @jsii.member(jsii_name="privateIps")
    def private_ips(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "privateIps")

    @private_ips.setter
    def private_ips(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "privateIps", value)

    @builtins.property
    @jsii.member(jsii_name="privateIpsCount")
    def private_ips_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "privateIpsCount")

    @private_ips_count.setter
    def private_ips_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "privateIpsCount", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="sourceDestCheck")
    def source_dest_check(self) -> typing.Optional[bool]:
        return jsii.get(self, "sourceDestCheck")

    @source_dest_check.setter
    def source_dest_check(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "sourceDestCheck", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkInterfaceAttachment",
    jsii_struct_bases=[],
    name_mapping={"device_index": "deviceIndex", "instance": "instance"},
)
class NetworkInterfaceAttachment:
    def __init__(self, *, device_index: jsii.Number, instance: str) -> None:
        """
        :param device_index: 
        :param instance: 
        """
        self._values = {
            "device_index": device_index,
            "instance": instance,
        }

    @builtins.property
    def device_index(self) -> jsii.Number:
        return self._values.get("device_index")

    @builtins.property
    def instance(self) -> str:
        return self._values.get("instance")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceAttachment(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterfaceAttachmentA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkInterfaceAttachmentA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        device_index: jsii.Number,
        instance_id: str,
        network_interface_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param device_index: 
        :param instance_id: 
        :param network_interface_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceAttachmentAConfig(
            device_index=device_index,
            instance_id=instance_id,
            network_interface_id=network_interface_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterfaceAttachmentA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="attachmentId")
    def attachment_id(self) -> str:
        return jsii.get(self, "attachmentId")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="deviceIndex")
    def device_index(self) -> jsii.Number:
        return jsii.get(self, "deviceIndex")

    @device_index.setter
    def device_index(self, value: jsii.Number) -> None:
        jsii.set(self, "deviceIndex", value)

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> str:
        return jsii.get(self, "instanceId")

    @instance_id.setter
    def instance_id(self, value: str) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkInterfaceAttachmentAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "device_index": "deviceIndex",
        "instance_id": "instanceId",
        "network_interface_id": "networkInterfaceId",
    },
)
class NetworkInterfaceAttachmentAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        device_index: jsii.Number,
        instance_id: str,
        network_interface_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param device_index: 
        :param instance_id: 
        :param network_interface_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "device_index": device_index,
            "instance_id": instance_id,
            "network_interface_id": network_interface_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def device_index(self) -> jsii.Number:
        return self._values.get("device_index")

    @builtins.property
    def instance_id(self) -> str:
        return self._values.get("instance_id")

    @builtins.property
    def network_interface_id(self) -> str:
        return self._values.get("network_interface_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceAttachmentAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkInterfaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "subnet_id": "subnetId",
        "attachment": "attachment",
        "description": "description",
        "private_ip": "privateIp",
        "private_ips": "privateIps",
        "private_ips_count": "privateIpsCount",
        "security_groups": "securityGroups",
        "source_dest_check": "sourceDestCheck",
        "tags": "tags",
    },
)
class NetworkInterfaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        subnet_id: str,
        attachment: typing.Optional[typing.List["NetworkInterfaceAttachment"]] = None,
        description: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        private_ips: typing.Optional[typing.List[str]] = None,
        private_ips_count: typing.Optional[jsii.Number] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_dest_check: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param subnet_id: 
        :param attachment: attachment block.
        :param description: 
        :param private_ip: 
        :param private_ips: 
        :param private_ips_count: 
        :param security_groups: 
        :param source_dest_check: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "subnet_id": subnet_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attachment is not None:
            self._values["attachment"] = attachment
        if description is not None:
            self._values["description"] = description
        if private_ip is not None:
            self._values["private_ip"] = private_ip
        if private_ips is not None:
            self._values["private_ips"] = private_ips
        if private_ips_count is not None:
            self._values["private_ips_count"] = private_ips_count
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if source_dest_check is not None:
            self._values["source_dest_check"] = source_dest_check
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    @builtins.property
    def attachment(self) -> typing.Optional[typing.List["NetworkInterfaceAttachment"]]:
        """attachment block."""
        return self._values.get("attachment")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def private_ip(self) -> typing.Optional[str]:
        return self._values.get("private_ip")

    @builtins.property
    def private_ips(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("private_ips")

    @builtins.property
    def private_ips_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("private_ips_count")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def source_dest_check(self) -> typing.Optional[bool]:
        return self._values.get("source_dest_check")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class NetworkInterfaceSgAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkInterfaceSgAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        network_interface_id: str,
        security_group_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param network_interface_id: 
        :param security_group_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = NetworkInterfaceSgAttachmentConfig(
            network_interface_id=network_interface_id,
            security_group_id=security_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(NetworkInterfaceSgAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> str:
        return jsii.get(self, "securityGroupId")

    @security_group_id.setter
    def security_group_id(self, value: str) -> None:
        jsii.set(self, "securityGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.NetworkInterfaceSgAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "network_interface_id": "networkInterfaceId",
        "security_group_id": "securityGroupId",
    },
)
class NetworkInterfaceSgAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        network_interface_id: str,
        security_group_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param network_interface_id: 
        :param security_group_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "network_interface_id": network_interface_id,
            "security_group_id": security_group_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def network_interface_id(self) -> str:
        return self._values.get("network_interface_id")

    @builtins.property
    def security_group_id(self) -> str:
        return self._values.get("security_group_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "NetworkInterfaceSgAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksApplication(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksApplication",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        stack_id: str,
        type: str,
        app_source: typing.Optional[typing.List["OpsworksApplicationAppSource"]] = None,
        auto_bundle_on_deploy: typing.Optional[str] = None,
        aws_flow_ruby_settings: typing.Optional[str] = None,
        data_source_arn: typing.Optional[str] = None,
        data_source_database_name: typing.Optional[str] = None,
        data_source_type: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        document_root: typing.Optional[str] = None,
        domains: typing.Optional[typing.List[str]] = None,
        enable_ssl: typing.Optional[bool] = None,
        environment: typing.Optional[
            typing.List["OpsworksApplicationEnvironment"]
        ] = None,
        rails_env: typing.Optional[str] = None,
        short_name: typing.Optional[str] = None,
        ssl_configuration: typing.Optional[
            typing.List["OpsworksApplicationSslConfiguration"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param stack_id: 
        :param type: 
        :param app_source: app_source block.
        :param auto_bundle_on_deploy: 
        :param aws_flow_ruby_settings: 
        :param data_source_arn: 
        :param data_source_database_name: 
        :param data_source_type: 
        :param description: 
        :param document_root: 
        :param domains: 
        :param enable_ssl: 
        :param environment: environment block.
        :param rails_env: 
        :param short_name: 
        :param ssl_configuration: ssl_configuration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksApplicationConfig(
            name=name,
            stack_id=stack_id,
            type=type,
            app_source=app_source,
            auto_bundle_on_deploy=auto_bundle_on_deploy,
            aws_flow_ruby_settings=aws_flow_ruby_settings,
            data_source_arn=data_source_arn,
            data_source_database_name=data_source_database_name,
            data_source_type=data_source_type,
            description=description,
            document_root=document_root,
            domains=domains,
            enable_ssl=enable_ssl,
            environment=environment,
            rails_env=rails_env,
            short_name=short_name,
            ssl_configuration=ssl_configuration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksApplication, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="appSource")
    def app_source(
        self,
    ) -> typing.Optional[typing.List["OpsworksApplicationAppSource"]]:
        return jsii.get(self, "appSource")

    @app_source.setter
    def app_source(
        self, value: typing.Optional[typing.List["OpsworksApplicationAppSource"]]
    ) -> None:
        jsii.set(self, "appSource", value)

    @builtins.property
    @jsii.member(jsii_name="autoBundleOnDeploy")
    def auto_bundle_on_deploy(self) -> typing.Optional[str]:
        return jsii.get(self, "autoBundleOnDeploy")

    @auto_bundle_on_deploy.setter
    def auto_bundle_on_deploy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "autoBundleOnDeploy", value)

    @builtins.property
    @jsii.member(jsii_name="awsFlowRubySettings")
    def aws_flow_ruby_settings(self) -> typing.Optional[str]:
        return jsii.get(self, "awsFlowRubySettings")

    @aws_flow_ruby_settings.setter
    def aws_flow_ruby_settings(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "awsFlowRubySettings", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceArn")
    def data_source_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "dataSourceArn")

    @data_source_arn.setter
    def data_source_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dataSourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceDatabaseName")
    def data_source_database_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dataSourceDatabaseName")

    @data_source_database_name.setter
    def data_source_database_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dataSourceDatabaseName", value)

    @builtins.property
    @jsii.member(jsii_name="dataSourceType")
    def data_source_type(self) -> typing.Optional[str]:
        return jsii.get(self, "dataSourceType")

    @data_source_type.setter
    def data_source_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dataSourceType", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="documentRoot")
    def document_root(self) -> typing.Optional[str]:
        return jsii.get(self, "documentRoot")

    @document_root.setter
    def document_root(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "documentRoot", value)

    @builtins.property
    @jsii.member(jsii_name="domains")
    def domains(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "domains")

    @domains.setter
    def domains(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "domains", value)

    @builtins.property
    @jsii.member(jsii_name="enableSsl")
    def enable_ssl(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableSsl")

    @enable_ssl.setter
    def enable_ssl(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableSsl", value)

    @builtins.property
    @jsii.member(jsii_name="environment")
    def environment(
        self,
    ) -> typing.Optional[typing.List["OpsworksApplicationEnvironment"]]:
        return jsii.get(self, "environment")

    @environment.setter
    def environment(
        self, value: typing.Optional[typing.List["OpsworksApplicationEnvironment"]]
    ) -> None:
        jsii.set(self, "environment", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="railsEnv")
    def rails_env(self) -> typing.Optional[str]:
        return jsii.get(self, "railsEnv")

    @rails_env.setter
    def rails_env(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "railsEnv", value)

    @builtins.property
    @jsii.member(jsii_name="shortName")
    def short_name(self) -> typing.Optional[str]:
        return jsii.get(self, "shortName")

    @short_name.setter
    def short_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "shortName", value)

    @builtins.property
    @jsii.member(jsii_name="sslConfiguration")
    def ssl_configuration(
        self,
    ) -> typing.Optional[typing.List["OpsworksApplicationSslConfiguration"]]:
        return jsii.get(self, "sslConfiguration")

    @ssl_configuration.setter
    def ssl_configuration(
        self, value: typing.Optional[typing.List["OpsworksApplicationSslConfiguration"]]
    ) -> None:
        jsii.set(self, "sslConfiguration", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksApplicationAppSource",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "password": "password",
        "revision": "revision",
        "ssh_key": "sshKey",
        "url": "url",
        "username": "username",
    },
)
class OpsworksApplicationAppSource:
    def __init__(
        self,
        *,
        type: str,
        password: typing.Optional[str] = None,
        revision: typing.Optional[str] = None,
        ssh_key: typing.Optional[str] = None,
        url: typing.Optional[str] = None,
        username: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param password: 
        :param revision: 
        :param ssh_key: 
        :param url: 
        :param username: 
        """
        self._values = {
            "type": type,
        }
        if password is not None:
            self._values["password"] = password
        if revision is not None:
            self._values["revision"] = revision
        if ssh_key is not None:
            self._values["ssh_key"] = ssh_key
        if url is not None:
            self._values["url"] = url
        if username is not None:
            self._values["username"] = username

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def password(self) -> typing.Optional[str]:
        return self._values.get("password")

    @builtins.property
    def revision(self) -> typing.Optional[str]:
        return self._values.get("revision")

    @builtins.property
    def ssh_key(self) -> typing.Optional[str]:
        return self._values.get("ssh_key")

    @builtins.property
    def url(self) -> typing.Optional[str]:
        return self._values.get("url")

    @builtins.property
    def username(self) -> typing.Optional[str]:
        return self._values.get("username")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksApplicationAppSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksApplicationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "stack_id": "stackId",
        "type": "type",
        "app_source": "appSource",
        "auto_bundle_on_deploy": "autoBundleOnDeploy",
        "aws_flow_ruby_settings": "awsFlowRubySettings",
        "data_source_arn": "dataSourceArn",
        "data_source_database_name": "dataSourceDatabaseName",
        "data_source_type": "dataSourceType",
        "description": "description",
        "document_root": "documentRoot",
        "domains": "domains",
        "enable_ssl": "enableSsl",
        "environment": "environment",
        "rails_env": "railsEnv",
        "short_name": "shortName",
        "ssl_configuration": "sslConfiguration",
    },
)
class OpsworksApplicationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        stack_id: str,
        type: str,
        app_source: typing.Optional[typing.List["OpsworksApplicationAppSource"]] = None,
        auto_bundle_on_deploy: typing.Optional[str] = None,
        aws_flow_ruby_settings: typing.Optional[str] = None,
        data_source_arn: typing.Optional[str] = None,
        data_source_database_name: typing.Optional[str] = None,
        data_source_type: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        document_root: typing.Optional[str] = None,
        domains: typing.Optional[typing.List[str]] = None,
        enable_ssl: typing.Optional[bool] = None,
        environment: typing.Optional[
            typing.List["OpsworksApplicationEnvironment"]
        ] = None,
        rails_env: typing.Optional[str] = None,
        short_name: typing.Optional[str] = None,
        ssl_configuration: typing.Optional[
            typing.List["OpsworksApplicationSslConfiguration"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param stack_id: 
        :param type: 
        :param app_source: app_source block.
        :param auto_bundle_on_deploy: 
        :param aws_flow_ruby_settings: 
        :param data_source_arn: 
        :param data_source_database_name: 
        :param data_source_type: 
        :param description: 
        :param document_root: 
        :param domains: 
        :param enable_ssl: 
        :param environment: environment block.
        :param rails_env: 
        :param short_name: 
        :param ssl_configuration: ssl_configuration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "stack_id": stack_id,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if app_source is not None:
            self._values["app_source"] = app_source
        if auto_bundle_on_deploy is not None:
            self._values["auto_bundle_on_deploy"] = auto_bundle_on_deploy
        if aws_flow_ruby_settings is not None:
            self._values["aws_flow_ruby_settings"] = aws_flow_ruby_settings
        if data_source_arn is not None:
            self._values["data_source_arn"] = data_source_arn
        if data_source_database_name is not None:
            self._values["data_source_database_name"] = data_source_database_name
        if data_source_type is not None:
            self._values["data_source_type"] = data_source_type
        if description is not None:
            self._values["description"] = description
        if document_root is not None:
            self._values["document_root"] = document_root
        if domains is not None:
            self._values["domains"] = domains
        if enable_ssl is not None:
            self._values["enable_ssl"] = enable_ssl
        if environment is not None:
            self._values["environment"] = environment
        if rails_env is not None:
            self._values["rails_env"] = rails_env
        if short_name is not None:
            self._values["short_name"] = short_name
        if ssl_configuration is not None:
            self._values["ssl_configuration"] = ssl_configuration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def app_source(
        self,
    ) -> typing.Optional[typing.List["OpsworksApplicationAppSource"]]:
        """app_source block."""
        return self._values.get("app_source")

    @builtins.property
    def auto_bundle_on_deploy(self) -> typing.Optional[str]:
        return self._values.get("auto_bundle_on_deploy")

    @builtins.property
    def aws_flow_ruby_settings(self) -> typing.Optional[str]:
        return self._values.get("aws_flow_ruby_settings")

    @builtins.property
    def data_source_arn(self) -> typing.Optional[str]:
        return self._values.get("data_source_arn")

    @builtins.property
    def data_source_database_name(self) -> typing.Optional[str]:
        return self._values.get("data_source_database_name")

    @builtins.property
    def data_source_type(self) -> typing.Optional[str]:
        return self._values.get("data_source_type")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def document_root(self) -> typing.Optional[str]:
        return self._values.get("document_root")

    @builtins.property
    def domains(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("domains")

    @builtins.property
    def enable_ssl(self) -> typing.Optional[bool]:
        return self._values.get("enable_ssl")

    @builtins.property
    def environment(
        self,
    ) -> typing.Optional[typing.List["OpsworksApplicationEnvironment"]]:
        """environment block."""
        return self._values.get("environment")

    @builtins.property
    def rails_env(self) -> typing.Optional[str]:
        return self._values.get("rails_env")

    @builtins.property
    def short_name(self) -> typing.Optional[str]:
        return self._values.get("short_name")

    @builtins.property
    def ssl_configuration(
        self,
    ) -> typing.Optional[typing.List["OpsworksApplicationSslConfiguration"]]:
        """ssl_configuration block."""
        return self._values.get("ssl_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksApplicationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksApplicationEnvironment",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "value": "value", "secure": "secure"},
)
class OpsworksApplicationEnvironment:
    def __init__(
        self, *, key: str, value: str, secure: typing.Optional[bool] = None
    ) -> None:
        """
        :param key: 
        :param value: 
        :param secure: 
        """
        self._values = {
            "key": key,
            "value": value,
        }
        if secure is not None:
            self._values["secure"] = secure

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def secure(self) -> typing.Optional[bool]:
        return self._values.get("secure")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksApplicationEnvironment(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksApplicationSslConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "certificate": "certificate",
        "private_key": "privateKey",
        "chain": "chain",
    },
)
class OpsworksApplicationSslConfiguration:
    def __init__(
        self, *, certificate: str, private_key: str, chain: typing.Optional[str] = None
    ) -> None:
        """
        :param certificate: 
        :param private_key: 
        :param chain: 
        """
        self._values = {
            "certificate": certificate,
            "private_key": private_key,
        }
        if chain is not None:
            self._values["chain"] = chain

    @builtins.property
    def certificate(self) -> str:
        return self._values.get("certificate")

    @builtins.property
    def private_key(self) -> str:
        return self._values.get("private_key")

    @builtins.property
    def chain(self) -> typing.Optional[str]:
        return self._values.get("chain")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksApplicationSslConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksCustomLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksCustomLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        short_name: str,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[typing.List["OpsworksCustomLayerEbsVolume"]] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param short_name: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksCustomLayerConfig(
            name=name,
            short_name=short_name,
            stack_id=stack_id,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksCustomLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="shortName")
    def short_name(self) -> str:
        return jsii.get(self, "shortName")

    @short_name.setter
    def short_name(self, value: str) -> None:
        jsii.set(self, "shortName", value)

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksCustomLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksCustomLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksCustomLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "short_name": "shortName",
        "stack_id": "stackId",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksCustomLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        short_name: str,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[typing.List["OpsworksCustomLayerEbsVolume"]] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param short_name: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "short_name": short_name,
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def short_name(self) -> str:
        return self._values.get("short_name")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksCustomLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksCustomLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksCustomLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksCustomLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksCustomLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksGangliaLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksGangliaLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        password: str,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksGangliaLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        url: typing.Optional[str] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        username: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param password: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param url: 
        :param use_ebs_optimized_instances: 
        :param username: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksGangliaLayerConfig(
            password=password,
            stack_id=stack_id,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            name=name,
            system_packages=system_packages,
            tags=tags,
            url=url,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            username=username,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksGangliaLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="password")
    def password(self) -> str:
        return jsii.get(self, "password")

    @password.setter
    def password(self, value: str) -> None:
        jsii.set(self, "password", value)

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksGangliaLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksGangliaLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> typing.Optional[str]:
        return jsii.get(self, "url")

    @url.setter
    def url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "url", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)

    @builtins.property
    @jsii.member(jsii_name="username")
    def username(self) -> typing.Optional[str]:
        return jsii.get(self, "username")

    @username.setter
    def username(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "username", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksGangliaLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "password": "password",
        "stack_id": "stackId",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "name": "name",
        "system_packages": "systemPackages",
        "tags": "tags",
        "url": "url",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
        "username": "username",
    },
)
class OpsworksGangliaLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        password: str,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksGangliaLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        url: typing.Optional[str] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        username: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param password: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param url: 
        :param use_ebs_optimized_instances: 
        :param username: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "password": password,
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if name is not None:
            self._values["name"] = name
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if url is not None:
            self._values["url"] = url
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances
        if username is not None:
            self._values["username"] = username

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def password(self) -> str:
        return self._values.get("password")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksGangliaLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def url(self) -> typing.Optional[str]:
        return self._values.get("url")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    @builtins.property
    def username(self) -> typing.Optional[str]:
        return self._values.get("username")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksGangliaLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksGangliaLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksGangliaLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksGangliaLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksHaproxyLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksHaproxyLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        stats_password: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksHaproxyLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        healthcheck_method: typing.Optional[str] = None,
        healthcheck_url: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        stats_enabled: typing.Optional[bool] = None,
        stats_url: typing.Optional[str] = None,
        stats_user: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param stats_password: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param healthcheck_method: 
        :param healthcheck_url: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param stats_enabled: 
        :param stats_url: 
        :param stats_user: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksHaproxyLayerConfig(
            stack_id=stack_id,
            stats_password=stats_password,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            healthcheck_method=healthcheck_method,
            healthcheck_url=healthcheck_url,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            name=name,
            stats_enabled=stats_enabled,
            stats_url=stats_url,
            stats_user=stats_user,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksHaproxyLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="statsPassword")
    def stats_password(self) -> str:
        return jsii.get(self, "statsPassword")

    @stats_password.setter
    def stats_password(self, value: str) -> None:
        jsii.set(self, "statsPassword", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksHaproxyLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksHaproxyLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="healthcheckMethod")
    def healthcheck_method(self) -> typing.Optional[str]:
        return jsii.get(self, "healthcheckMethod")

    @healthcheck_method.setter
    def healthcheck_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "healthcheckMethod", value)

    @builtins.property
    @jsii.member(jsii_name="healthcheckUrl")
    def healthcheck_url(self) -> typing.Optional[str]:
        return jsii.get(self, "healthcheckUrl")

    @healthcheck_url.setter
    def healthcheck_url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "healthcheckUrl", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="statsEnabled")
    def stats_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "statsEnabled")

    @stats_enabled.setter
    def stats_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "statsEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="statsUrl")
    def stats_url(self) -> typing.Optional[str]:
        return jsii.get(self, "statsUrl")

    @stats_url.setter
    def stats_url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "statsUrl", value)

    @builtins.property
    @jsii.member(jsii_name="statsUser")
    def stats_user(self) -> typing.Optional[str]:
        return jsii.get(self, "statsUser")

    @stats_user.setter
    def stats_user(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "statsUser", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksHaproxyLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "stats_password": "statsPassword",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "healthcheck_method": "healthcheckMethod",
        "healthcheck_url": "healthcheckUrl",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "name": "name",
        "stats_enabled": "statsEnabled",
        "stats_url": "statsUrl",
        "stats_user": "statsUser",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksHaproxyLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        stats_password: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksHaproxyLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        healthcheck_method: typing.Optional[str] = None,
        healthcheck_url: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        stats_enabled: typing.Optional[bool] = None,
        stats_url: typing.Optional[str] = None,
        stats_user: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param stats_password: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param healthcheck_method: 
        :param healthcheck_url: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param stats_enabled: 
        :param stats_url: 
        :param stats_user: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
            "stats_password": stats_password,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if healthcheck_method is not None:
            self._values["healthcheck_method"] = healthcheck_method
        if healthcheck_url is not None:
            self._values["healthcheck_url"] = healthcheck_url
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if name is not None:
            self._values["name"] = name
        if stats_enabled is not None:
            self._values["stats_enabled"] = stats_enabled
        if stats_url is not None:
            self._values["stats_url"] = stats_url
        if stats_user is not None:
            self._values["stats_user"] = stats_user
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def stats_password(self) -> str:
        return self._values.get("stats_password")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksHaproxyLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def healthcheck_method(self) -> typing.Optional[str]:
        return self._values.get("healthcheck_method")

    @builtins.property
    def healthcheck_url(self) -> typing.Optional[str]:
        return self._values.get("healthcheck_url")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def stats_enabled(self) -> typing.Optional[bool]:
        return self._values.get("stats_enabled")

    @builtins.property
    def stats_url(self) -> typing.Optional[str]:
        return self._values.get("stats_url")

    @builtins.property
    def stats_user(self) -> typing.Optional[str]:
        return self._values.get("stats_user")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksHaproxyLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksHaproxyLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksHaproxyLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksHaproxyLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        layer_ids: typing.List[str],
        stack_id: str,
        agent_version: typing.Optional[str] = None,
        ami_id: typing.Optional[str] = None,
        architecture: typing.Optional[str] = None,
        auto_scaling_type: typing.Optional[str] = None,
        availability_zone: typing.Optional[str] = None,
        created_at: typing.Optional[str] = None,
        delete_ebs: typing.Optional[bool] = None,
        delete_eip: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[
            typing.List["OpsworksInstanceEbsBlockDevice"]
        ] = None,
        ebs_optimized: typing.Optional[bool] = None,
        ecs_cluster_arn: typing.Optional[str] = None,
        elastic_ip: typing.Optional[str] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["OpsworksInstanceEphemeralBlockDevice"]
        ] = None,
        hostname: typing.Optional[str] = None,
        infrastructure_class: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_profile_arn: typing.Optional[str] = None,
        instance_type: typing.Optional[str] = None,
        last_service_error_id: typing.Optional[str] = None,
        os: typing.Optional[str] = None,
        platform: typing.Optional[str] = None,
        private_dns: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        public_dns: typing.Optional[str] = None,
        public_ip: typing.Optional[str] = None,
        registered_by: typing.Optional[str] = None,
        reported_agent_version: typing.Optional[str] = None,
        reported_os_family: typing.Optional[str] = None,
        reported_os_name: typing.Optional[str] = None,
        reported_os_version: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["OpsworksInstanceRootBlockDevice"]
        ] = None,
        root_device_type: typing.Optional[str] = None,
        root_device_volume_id: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        ssh_host_dsa_key_fingerprint: typing.Optional[str] = None,
        ssh_host_rsa_key_fingerprint: typing.Optional[str] = None,
        ssh_key_name: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tenancy: typing.Optional[str] = None,
        timeouts: typing.Optional["OpsworksInstanceTimeouts"] = None,
        virtualization_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param layer_ids: 
        :param stack_id: 
        :param agent_version: 
        :param ami_id: 
        :param architecture: 
        :param auto_scaling_type: 
        :param availability_zone: 
        :param created_at: 
        :param delete_ebs: 
        :param delete_eip: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param ecs_cluster_arn: 
        :param elastic_ip: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param hostname: 
        :param infrastructure_class: 
        :param install_updates_on_boot: 
        :param instance_profile_arn: 
        :param instance_type: 
        :param last_service_error_id: 
        :param os: 
        :param platform: 
        :param private_dns: 
        :param private_ip: 
        :param public_dns: 
        :param public_ip: 
        :param registered_by: 
        :param reported_agent_version: 
        :param reported_os_family: 
        :param reported_os_name: 
        :param reported_os_version: 
        :param root_block_device: root_block_device block.
        :param root_device_type: 
        :param root_device_volume_id: 
        :param security_group_ids: 
        :param ssh_host_dsa_key_fingerprint: 
        :param ssh_host_rsa_key_fingerprint: 
        :param ssh_key_name: 
        :param state: 
        :param status: 
        :param subnet_id: 
        :param tenancy: 
        :param timeouts: timeouts block.
        :param virtualization_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksInstanceConfig(
            layer_ids=layer_ids,
            stack_id=stack_id,
            agent_version=agent_version,
            ami_id=ami_id,
            architecture=architecture,
            auto_scaling_type=auto_scaling_type,
            availability_zone=availability_zone,
            created_at=created_at,
            delete_ebs=delete_ebs,
            delete_eip=delete_eip,
            ebs_block_device=ebs_block_device,
            ebs_optimized=ebs_optimized,
            ecs_cluster_arn=ecs_cluster_arn,
            elastic_ip=elastic_ip,
            ephemeral_block_device=ephemeral_block_device,
            hostname=hostname,
            infrastructure_class=infrastructure_class,
            install_updates_on_boot=install_updates_on_boot,
            instance_profile_arn=instance_profile_arn,
            instance_type=instance_type,
            last_service_error_id=last_service_error_id,
            os=os,
            platform=platform,
            private_dns=private_dns,
            private_ip=private_ip,
            public_dns=public_dns,
            public_ip=public_ip,
            registered_by=registered_by,
            reported_agent_version=reported_agent_version,
            reported_os_family=reported_os_family,
            reported_os_name=reported_os_name,
            reported_os_version=reported_os_version,
            root_block_device=root_block_device,
            root_device_type=root_device_type,
            root_device_volume_id=root_device_volume_id,
            security_group_ids=security_group_ids,
            ssh_host_dsa_key_fingerprint=ssh_host_dsa_key_fingerprint,
            ssh_host_rsa_key_fingerprint=ssh_host_rsa_key_fingerprint,
            ssh_key_name=ssh_key_name,
            state=state,
            status=status,
            subnet_id=subnet_id,
            tenancy=tenancy,
            timeouts=timeouts,
            virtualization_type=virtualization_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ec2InstanceId")
    def ec2_instance_id(self) -> str:
        return jsii.get(self, "ec2InstanceId")

    @builtins.property
    @jsii.member(jsii_name="layerIds")
    def layer_ids(self) -> typing.List[str]:
        return jsii.get(self, "layerIds")

    @layer_ids.setter
    def layer_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "layerIds", value)

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="agentVersion")
    def agent_version(self) -> typing.Optional[str]:
        return jsii.get(self, "agentVersion")

    @agent_version.setter
    def agent_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "agentVersion", value)

    @builtins.property
    @jsii.member(jsii_name="amiId")
    def ami_id(self) -> typing.Optional[str]:
        return jsii.get(self, "amiId")

    @ami_id.setter
    def ami_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amiId", value)

    @builtins.property
    @jsii.member(jsii_name="architecture")
    def architecture(self) -> typing.Optional[str]:
        return jsii.get(self, "architecture")

    @architecture.setter
    def architecture(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "architecture", value)

    @builtins.property
    @jsii.member(jsii_name="autoScalingType")
    def auto_scaling_type(self) -> typing.Optional[str]:
        return jsii.get(self, "autoScalingType")

    @auto_scaling_type.setter
    def auto_scaling_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "autoScalingType", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="createdAt")
    def created_at(self) -> typing.Optional[str]:
        return jsii.get(self, "createdAt")

    @created_at.setter
    def created_at(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "createdAt", value)

    @builtins.property
    @jsii.member(jsii_name="deleteEbs")
    def delete_ebs(self) -> typing.Optional[bool]:
        return jsii.get(self, "deleteEbs")

    @delete_ebs.setter
    def delete_ebs(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deleteEbs", value)

    @builtins.property
    @jsii.member(jsii_name="deleteEip")
    def delete_eip(self) -> typing.Optional[bool]:
        return jsii.get(self, "deleteEip")

    @delete_eip.setter
    def delete_eip(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deleteEip", value)

    @builtins.property
    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["OpsworksInstanceEbsBlockDevice"]]:
        return jsii.get(self, "ebsBlockDevice")

    @ebs_block_device.setter
    def ebs_block_device(
        self, value: typing.Optional[typing.List["OpsworksInstanceEbsBlockDevice"]]
    ) -> None:
        jsii.set(self, "ebsBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> typing.Optional[bool]:
        return jsii.get(self, "ebsOptimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ebsOptimized", value)

    @builtins.property
    @jsii.member(jsii_name="ecsClusterArn")
    def ecs_cluster_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "ecsClusterArn")

    @ecs_cluster_arn.setter
    def ecs_cluster_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ecsClusterArn", value)

    @builtins.property
    @jsii.member(jsii_name="elasticIp")
    def elastic_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticIp")

    @elastic_ip.setter
    def elastic_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticIp", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["OpsworksInstanceEphemeralBlockDevice"]]:
        return jsii.get(self, "ephemeralBlockDevice")

    @ephemeral_block_device.setter
    def ephemeral_block_device(
        self,
        value: typing.Optional[typing.List["OpsworksInstanceEphemeralBlockDevice"]],
    ) -> None:
        jsii.set(self, "ephemeralBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="hostname")
    def hostname(self) -> typing.Optional[str]:
        return jsii.get(self, "hostname")

    @hostname.setter
    def hostname(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "hostname", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="infrastructureClass")
    def infrastructure_class(self) -> typing.Optional[str]:
        return jsii.get(self, "infrastructureClass")

    @infrastructure_class.setter
    def infrastructure_class(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "infrastructureClass", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceProfileArn")
    def instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceProfileArn")

    @instance_profile_arn.setter
    def instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="lastServiceErrorId")
    def last_service_error_id(self) -> typing.Optional[str]:
        return jsii.get(self, "lastServiceErrorId")

    @last_service_error_id.setter
    def last_service_error_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "lastServiceErrorId", value)

    @builtins.property
    @jsii.member(jsii_name="os")
    def os(self) -> typing.Optional[str]:
        return jsii.get(self, "os")

    @os.setter
    def os(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "os", value)

    @builtins.property
    @jsii.member(jsii_name="platform")
    def platform(self) -> typing.Optional[str]:
        return jsii.get(self, "platform")

    @platform.setter
    def platform(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "platform", value)

    @builtins.property
    @jsii.member(jsii_name="privateDns")
    def private_dns(self) -> typing.Optional[str]:
        return jsii.get(self, "privateDns")

    @private_dns.setter
    def private_dns(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateDns", value)

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "privateIp")

    @private_ip.setter
    def private_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateIp", value)

    @builtins.property
    @jsii.member(jsii_name="publicDns")
    def public_dns(self) -> typing.Optional[str]:
        return jsii.get(self, "publicDns")

    @public_dns.setter
    def public_dns(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "publicDns", value)

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "publicIp")

    @public_ip.setter
    def public_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "publicIp", value)

    @builtins.property
    @jsii.member(jsii_name="registeredBy")
    def registered_by(self) -> typing.Optional[str]:
        return jsii.get(self, "registeredBy")

    @registered_by.setter
    def registered_by(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "registeredBy", value)

    @builtins.property
    @jsii.member(jsii_name="reportedAgentVersion")
    def reported_agent_version(self) -> typing.Optional[str]:
        return jsii.get(self, "reportedAgentVersion")

    @reported_agent_version.setter
    def reported_agent_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "reportedAgentVersion", value)

    @builtins.property
    @jsii.member(jsii_name="reportedOsFamily")
    def reported_os_family(self) -> typing.Optional[str]:
        return jsii.get(self, "reportedOsFamily")

    @reported_os_family.setter
    def reported_os_family(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "reportedOsFamily", value)

    @builtins.property
    @jsii.member(jsii_name="reportedOsName")
    def reported_os_name(self) -> typing.Optional[str]:
        return jsii.get(self, "reportedOsName")

    @reported_os_name.setter
    def reported_os_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "reportedOsName", value)

    @builtins.property
    @jsii.member(jsii_name="reportedOsVersion")
    def reported_os_version(self) -> typing.Optional[str]:
        return jsii.get(self, "reportedOsVersion")

    @reported_os_version.setter
    def reported_os_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "reportedOsVersion", value)

    @builtins.property
    @jsii.member(jsii_name="rootBlockDevice")
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["OpsworksInstanceRootBlockDevice"]]:
        return jsii.get(self, "rootBlockDevice")

    @root_block_device.setter
    def root_block_device(
        self, value: typing.Optional[typing.List["OpsworksInstanceRootBlockDevice"]]
    ) -> None:
        jsii.set(self, "rootBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="rootDeviceType")
    def root_device_type(self) -> typing.Optional[str]:
        return jsii.get(self, "rootDeviceType")

    @root_device_type.setter
    def root_device_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rootDeviceType", value)

    @builtins.property
    @jsii.member(jsii_name="rootDeviceVolumeId")
    def root_device_volume_id(self) -> typing.Optional[str]:
        return jsii.get(self, "rootDeviceVolumeId")

    @root_device_volume_id.setter
    def root_device_volume_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rootDeviceVolumeId", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="sshHostDsaKeyFingerprint")
    def ssh_host_dsa_key_fingerprint(self) -> typing.Optional[str]:
        return jsii.get(self, "sshHostDsaKeyFingerprint")

    @ssh_host_dsa_key_fingerprint.setter
    def ssh_host_dsa_key_fingerprint(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sshHostDsaKeyFingerprint", value)

    @builtins.property
    @jsii.member(jsii_name="sshHostRsaKeyFingerprint")
    def ssh_host_rsa_key_fingerprint(self) -> typing.Optional[str]:
        return jsii.get(self, "sshHostRsaKeyFingerprint")

    @ssh_host_rsa_key_fingerprint.setter
    def ssh_host_rsa_key_fingerprint(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sshHostRsaKeyFingerprint", value)

    @builtins.property
    @jsii.member(jsii_name="sshKeyName")
    def ssh_key_name(self) -> typing.Optional[str]:
        return jsii.get(self, "sshKeyName")

    @ssh_key_name.setter
    def ssh_key_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sshKeyName", value)

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> typing.Optional[str]:
        return jsii.get(self, "state")

    @state.setter
    def state(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "state", value)

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> typing.Optional[str]:
        return jsii.get(self, "status")

    @status.setter
    def status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "status", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tenancy")
    def tenancy(self) -> typing.Optional[str]:
        return jsii.get(self, "tenancy")

    @tenancy.setter
    def tenancy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tenancy", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["OpsworksInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["OpsworksInstanceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="virtualizationType")
    def virtualization_type(self) -> typing.Optional[str]:
        return jsii.get(self, "virtualizationType")

    @virtualization_type.setter
    def virtualization_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "virtualizationType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "layer_ids": "layerIds",
        "stack_id": "stackId",
        "agent_version": "agentVersion",
        "ami_id": "amiId",
        "architecture": "architecture",
        "auto_scaling_type": "autoScalingType",
        "availability_zone": "availabilityZone",
        "created_at": "createdAt",
        "delete_ebs": "deleteEbs",
        "delete_eip": "deleteEip",
        "ebs_block_device": "ebsBlockDevice",
        "ebs_optimized": "ebsOptimized",
        "ecs_cluster_arn": "ecsClusterArn",
        "elastic_ip": "elasticIp",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "hostname": "hostname",
        "infrastructure_class": "infrastructureClass",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_profile_arn": "instanceProfileArn",
        "instance_type": "instanceType",
        "last_service_error_id": "lastServiceErrorId",
        "os": "os",
        "platform": "platform",
        "private_dns": "privateDns",
        "private_ip": "privateIp",
        "public_dns": "publicDns",
        "public_ip": "publicIp",
        "registered_by": "registeredBy",
        "reported_agent_version": "reportedAgentVersion",
        "reported_os_family": "reportedOsFamily",
        "reported_os_name": "reportedOsName",
        "reported_os_version": "reportedOsVersion",
        "root_block_device": "rootBlockDevice",
        "root_device_type": "rootDeviceType",
        "root_device_volume_id": "rootDeviceVolumeId",
        "security_group_ids": "securityGroupIds",
        "ssh_host_dsa_key_fingerprint": "sshHostDsaKeyFingerprint",
        "ssh_host_rsa_key_fingerprint": "sshHostRsaKeyFingerprint",
        "ssh_key_name": "sshKeyName",
        "state": "state",
        "status": "status",
        "subnet_id": "subnetId",
        "tenancy": "tenancy",
        "timeouts": "timeouts",
        "virtualization_type": "virtualizationType",
    },
)
class OpsworksInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        layer_ids: typing.List[str],
        stack_id: str,
        agent_version: typing.Optional[str] = None,
        ami_id: typing.Optional[str] = None,
        architecture: typing.Optional[str] = None,
        auto_scaling_type: typing.Optional[str] = None,
        availability_zone: typing.Optional[str] = None,
        created_at: typing.Optional[str] = None,
        delete_ebs: typing.Optional[bool] = None,
        delete_eip: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[
            typing.List["OpsworksInstanceEbsBlockDevice"]
        ] = None,
        ebs_optimized: typing.Optional[bool] = None,
        ecs_cluster_arn: typing.Optional[str] = None,
        elastic_ip: typing.Optional[str] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["OpsworksInstanceEphemeralBlockDevice"]
        ] = None,
        hostname: typing.Optional[str] = None,
        infrastructure_class: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_profile_arn: typing.Optional[str] = None,
        instance_type: typing.Optional[str] = None,
        last_service_error_id: typing.Optional[str] = None,
        os: typing.Optional[str] = None,
        platform: typing.Optional[str] = None,
        private_dns: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        public_dns: typing.Optional[str] = None,
        public_ip: typing.Optional[str] = None,
        registered_by: typing.Optional[str] = None,
        reported_agent_version: typing.Optional[str] = None,
        reported_os_family: typing.Optional[str] = None,
        reported_os_name: typing.Optional[str] = None,
        reported_os_version: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["OpsworksInstanceRootBlockDevice"]
        ] = None,
        root_device_type: typing.Optional[str] = None,
        root_device_volume_id: typing.Optional[str] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        ssh_host_dsa_key_fingerprint: typing.Optional[str] = None,
        ssh_host_rsa_key_fingerprint: typing.Optional[str] = None,
        ssh_key_name: typing.Optional[str] = None,
        state: typing.Optional[str] = None,
        status: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tenancy: typing.Optional[str] = None,
        timeouts: typing.Optional["OpsworksInstanceTimeouts"] = None,
        virtualization_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param layer_ids: 
        :param stack_id: 
        :param agent_version: 
        :param ami_id: 
        :param architecture: 
        :param auto_scaling_type: 
        :param availability_zone: 
        :param created_at: 
        :param delete_ebs: 
        :param delete_eip: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param ecs_cluster_arn: 
        :param elastic_ip: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param hostname: 
        :param infrastructure_class: 
        :param install_updates_on_boot: 
        :param instance_profile_arn: 
        :param instance_type: 
        :param last_service_error_id: 
        :param os: 
        :param platform: 
        :param private_dns: 
        :param private_ip: 
        :param public_dns: 
        :param public_ip: 
        :param registered_by: 
        :param reported_agent_version: 
        :param reported_os_family: 
        :param reported_os_name: 
        :param reported_os_version: 
        :param root_block_device: root_block_device block.
        :param root_device_type: 
        :param root_device_volume_id: 
        :param security_group_ids: 
        :param ssh_host_dsa_key_fingerprint: 
        :param ssh_host_rsa_key_fingerprint: 
        :param ssh_key_name: 
        :param state: 
        :param status: 
        :param subnet_id: 
        :param tenancy: 
        :param timeouts: timeouts block.
        :param virtualization_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = OpsworksInstanceTimeouts(**timeouts)
        self._values = {
            "layer_ids": layer_ids,
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if agent_version is not None:
            self._values["agent_version"] = agent_version
        if ami_id is not None:
            self._values["ami_id"] = ami_id
        if architecture is not None:
            self._values["architecture"] = architecture
        if auto_scaling_type is not None:
            self._values["auto_scaling_type"] = auto_scaling_type
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if created_at is not None:
            self._values["created_at"] = created_at
        if delete_ebs is not None:
            self._values["delete_ebs"] = delete_ebs
        if delete_eip is not None:
            self._values["delete_eip"] = delete_eip
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if ecs_cluster_arn is not None:
            self._values["ecs_cluster_arn"] = ecs_cluster_arn
        if elastic_ip is not None:
            self._values["elastic_ip"] = elastic_ip
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if hostname is not None:
            self._values["hostname"] = hostname
        if infrastructure_class is not None:
            self._values["infrastructure_class"] = infrastructure_class
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_profile_arn is not None:
            self._values["instance_profile_arn"] = instance_profile_arn
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if last_service_error_id is not None:
            self._values["last_service_error_id"] = last_service_error_id
        if os is not None:
            self._values["os"] = os
        if platform is not None:
            self._values["platform"] = platform
        if private_dns is not None:
            self._values["private_dns"] = private_dns
        if private_ip is not None:
            self._values["private_ip"] = private_ip
        if public_dns is not None:
            self._values["public_dns"] = public_dns
        if public_ip is not None:
            self._values["public_ip"] = public_ip
        if registered_by is not None:
            self._values["registered_by"] = registered_by
        if reported_agent_version is not None:
            self._values["reported_agent_version"] = reported_agent_version
        if reported_os_family is not None:
            self._values["reported_os_family"] = reported_os_family
        if reported_os_name is not None:
            self._values["reported_os_name"] = reported_os_name
        if reported_os_version is not None:
            self._values["reported_os_version"] = reported_os_version
        if root_block_device is not None:
            self._values["root_block_device"] = root_block_device
        if root_device_type is not None:
            self._values["root_device_type"] = root_device_type
        if root_device_volume_id is not None:
            self._values["root_device_volume_id"] = root_device_volume_id
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if ssh_host_dsa_key_fingerprint is not None:
            self._values["ssh_host_dsa_key_fingerprint"] = ssh_host_dsa_key_fingerprint
        if ssh_host_rsa_key_fingerprint is not None:
            self._values["ssh_host_rsa_key_fingerprint"] = ssh_host_rsa_key_fingerprint
        if ssh_key_name is not None:
            self._values["ssh_key_name"] = ssh_key_name
        if state is not None:
            self._values["state"] = state
        if status is not None:
            self._values["status"] = status
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tenancy is not None:
            self._values["tenancy"] = tenancy
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if virtualization_type is not None:
            self._values["virtualization_type"] = virtualization_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def layer_ids(self) -> typing.List[str]:
        return self._values.get("layer_ids")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def agent_version(self) -> typing.Optional[str]:
        return self._values.get("agent_version")

    @builtins.property
    def ami_id(self) -> typing.Optional[str]:
        return self._values.get("ami_id")

    @builtins.property
    def architecture(self) -> typing.Optional[str]:
        return self._values.get("architecture")

    @builtins.property
    def auto_scaling_type(self) -> typing.Optional[str]:
        return self._values.get("auto_scaling_type")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def created_at(self) -> typing.Optional[str]:
        return self._values.get("created_at")

    @builtins.property
    def delete_ebs(self) -> typing.Optional[bool]:
        return self._values.get("delete_ebs")

    @builtins.property
    def delete_eip(self) -> typing.Optional[bool]:
        return self._values.get("delete_eip")

    @builtins.property
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["OpsworksInstanceEbsBlockDevice"]]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[bool]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def ecs_cluster_arn(self) -> typing.Optional[str]:
        return self._values.get("ecs_cluster_arn")

    @builtins.property
    def elastic_ip(self) -> typing.Optional[str]:
        return self._values.get("elastic_ip")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["OpsworksInstanceEphemeralBlockDevice"]]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def hostname(self) -> typing.Optional[str]:
        return self._values.get("hostname")

    @builtins.property
    def infrastructure_class(self) -> typing.Optional[str]:
        return self._values.get("infrastructure_class")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("instance_profile_arn")

    @builtins.property
    def instance_type(self) -> typing.Optional[str]:
        return self._values.get("instance_type")

    @builtins.property
    def last_service_error_id(self) -> typing.Optional[str]:
        return self._values.get("last_service_error_id")

    @builtins.property
    def os(self) -> typing.Optional[str]:
        return self._values.get("os")

    @builtins.property
    def platform(self) -> typing.Optional[str]:
        return self._values.get("platform")

    @builtins.property
    def private_dns(self) -> typing.Optional[str]:
        return self._values.get("private_dns")

    @builtins.property
    def private_ip(self) -> typing.Optional[str]:
        return self._values.get("private_ip")

    @builtins.property
    def public_dns(self) -> typing.Optional[str]:
        return self._values.get("public_dns")

    @builtins.property
    def public_ip(self) -> typing.Optional[str]:
        return self._values.get("public_ip")

    @builtins.property
    def registered_by(self) -> typing.Optional[str]:
        return self._values.get("registered_by")

    @builtins.property
    def reported_agent_version(self) -> typing.Optional[str]:
        return self._values.get("reported_agent_version")

    @builtins.property
    def reported_os_family(self) -> typing.Optional[str]:
        return self._values.get("reported_os_family")

    @builtins.property
    def reported_os_name(self) -> typing.Optional[str]:
        return self._values.get("reported_os_name")

    @builtins.property
    def reported_os_version(self) -> typing.Optional[str]:
        return self._values.get("reported_os_version")

    @builtins.property
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["OpsworksInstanceRootBlockDevice"]]:
        """root_block_device block."""
        return self._values.get("root_block_device")

    @builtins.property
    def root_device_type(self) -> typing.Optional[str]:
        return self._values.get("root_device_type")

    @builtins.property
    def root_device_volume_id(self) -> typing.Optional[str]:
        return self._values.get("root_device_volume_id")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def ssh_host_dsa_key_fingerprint(self) -> typing.Optional[str]:
        return self._values.get("ssh_host_dsa_key_fingerprint")

    @builtins.property
    def ssh_host_rsa_key_fingerprint(self) -> typing.Optional[str]:
        return self._values.get("ssh_host_rsa_key_fingerprint")

    @builtins.property
    def ssh_key_name(self) -> typing.Optional[str]:
        return self._values.get("ssh_key_name")

    @builtins.property
    def state(self) -> typing.Optional[str]:
        return self._values.get("state")

    @builtins.property
    def status(self) -> typing.Optional[str]:
        return self._values.get("status")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tenancy(self) -> typing.Optional[str]:
        return self._values.get("tenancy")

    @builtins.property
    def timeouts(self) -> typing.Optional["OpsworksInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def virtualization_type(self) -> typing.Optional[str]:
        return self._values.get("virtualization_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksInstanceEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "delete_on_termination": "deleteOnTermination",
        "iops": "iops",
        "snapshot_id": "snapshotId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class OpsworksInstanceEbsBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        delete_on_termination: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        snapshot_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param delete_on_termination: 
        :param iops: 
        :param snapshot_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {
            "device_name": device_name,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if iops is not None:
            self._values["iops"] = iops
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksInstanceEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksInstanceEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={"device_name": "deviceName", "virtual_name": "virtualName"},
)
class OpsworksInstanceEphemeralBlockDevice:
    def __init__(self, *, device_name: str, virtual_name: str) -> None:
        """
        :param device_name: 
        :param virtual_name: 
        """
        self._values = {
            "device_name": device_name,
            "virtual_name": virtual_name,
        }

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def virtual_name(self) -> str:
        return self._values.get("virtual_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksInstanceEphemeralBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksInstanceRootBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "delete_on_termination": "deleteOnTermination",
        "iops": "iops",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class OpsworksInstanceRootBlockDevice:
    def __init__(
        self,
        *,
        delete_on_termination: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete_on_termination: 
        :param iops: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {}
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if iops is not None:
            self._values["iops"] = iops
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksInstanceRootBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class OpsworksInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksJavaAppLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksJavaAppLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        app_server: typing.Optional[str] = None,
        app_server_version: typing.Optional[str] = None,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksJavaAppLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        jvm_options: typing.Optional[str] = None,
        jvm_type: typing.Optional[str] = None,
        jvm_version: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param app_server: 
        :param app_server_version: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param jvm_options: 
        :param jvm_type: 
        :param jvm_version: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksJavaAppLayerConfig(
            stack_id=stack_id,
            app_server=app_server,
            app_server_version=app_server_version,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            jvm_options=jvm_options,
            jvm_type=jvm_type,
            jvm_version=jvm_version,
            name=name,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksJavaAppLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="appServer")
    def app_server(self) -> typing.Optional[str]:
        return jsii.get(self, "appServer")

    @app_server.setter
    def app_server(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "appServer", value)

    @builtins.property
    @jsii.member(jsii_name="appServerVersion")
    def app_server_version(self) -> typing.Optional[str]:
        return jsii.get(self, "appServerVersion")

    @app_server_version.setter
    def app_server_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "appServerVersion", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksJavaAppLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksJavaAppLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="jvmOptions")
    def jvm_options(self) -> typing.Optional[str]:
        return jsii.get(self, "jvmOptions")

    @jvm_options.setter
    def jvm_options(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "jvmOptions", value)

    @builtins.property
    @jsii.member(jsii_name="jvmType")
    def jvm_type(self) -> typing.Optional[str]:
        return jsii.get(self, "jvmType")

    @jvm_type.setter
    def jvm_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "jvmType", value)

    @builtins.property
    @jsii.member(jsii_name="jvmVersion")
    def jvm_version(self) -> typing.Optional[str]:
        return jsii.get(self, "jvmVersion")

    @jvm_version.setter
    def jvm_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "jvmVersion", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksJavaAppLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "app_server": "appServer",
        "app_server_version": "appServerVersion",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "jvm_options": "jvmOptions",
        "jvm_type": "jvmType",
        "jvm_version": "jvmVersion",
        "name": "name",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksJavaAppLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        app_server: typing.Optional[str] = None,
        app_server_version: typing.Optional[str] = None,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksJavaAppLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        jvm_options: typing.Optional[str] = None,
        jvm_type: typing.Optional[str] = None,
        jvm_version: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param app_server: 
        :param app_server_version: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param jvm_options: 
        :param jvm_type: 
        :param jvm_version: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if app_server is not None:
            self._values["app_server"] = app_server
        if app_server_version is not None:
            self._values["app_server_version"] = app_server_version
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if jvm_options is not None:
            self._values["jvm_options"] = jvm_options
        if jvm_type is not None:
            self._values["jvm_type"] = jvm_type
        if jvm_version is not None:
            self._values["jvm_version"] = jvm_version
        if name is not None:
            self._values["name"] = name
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def app_server(self) -> typing.Optional[str]:
        return self._values.get("app_server")

    @builtins.property
    def app_server_version(self) -> typing.Optional[str]:
        return self._values.get("app_server_version")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksJavaAppLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def jvm_options(self) -> typing.Optional[str]:
        return self._values.get("jvm_options")

    @builtins.property
    def jvm_type(self) -> typing.Optional[str]:
        return self._values.get("jvm_type")

    @builtins.property
    def jvm_version(self) -> typing.Optional[str]:
        return self._values.get("jvm_version")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksJavaAppLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksJavaAppLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksJavaAppLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksJavaAppLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksMemcachedLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksMemcachedLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        allocated_memory: typing.Optional[jsii.Number] = None,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksMemcachedLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param allocated_memory: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksMemcachedLayerConfig(
            stack_id=stack_id,
            allocated_memory=allocated_memory,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            name=name,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksMemcachedLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="allocatedMemory")
    def allocated_memory(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "allocatedMemory")

    @allocated_memory.setter
    def allocated_memory(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "allocatedMemory", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksMemcachedLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksMemcachedLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksMemcachedLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "allocated_memory": "allocatedMemory",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "name": "name",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksMemcachedLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        allocated_memory: typing.Optional[jsii.Number] = None,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksMemcachedLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param allocated_memory: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocated_memory is not None:
            self._values["allocated_memory"] = allocated_memory
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if name is not None:
            self._values["name"] = name
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def allocated_memory(self) -> typing.Optional[jsii.Number]:
        return self._values.get("allocated_memory")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksMemcachedLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksMemcachedLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksMemcachedLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksMemcachedLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksMemcachedLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksMysqlLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksMysqlLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[typing.List["OpsworksMysqlLayerEbsVolume"]] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        root_password: typing.Optional[str] = None,
        root_password_on_all_instances: typing.Optional[bool] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param root_password: 
        :param root_password_on_all_instances: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksMysqlLayerConfig(
            stack_id=stack_id,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            name=name,
            root_password=root_password,
            root_password_on_all_instances=root_password_on_all_instances,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksMysqlLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(self) -> typing.Optional[typing.List["OpsworksMysqlLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksMysqlLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="rootPassword")
    def root_password(self) -> typing.Optional[str]:
        return jsii.get(self, "rootPassword")

    @root_password.setter
    def root_password(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rootPassword", value)

    @builtins.property
    @jsii.member(jsii_name="rootPasswordOnAllInstances")
    def root_password_on_all_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "rootPasswordOnAllInstances")

    @root_password_on_all_instances.setter
    def root_password_on_all_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "rootPasswordOnAllInstances", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksMysqlLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "name": "name",
        "root_password": "rootPassword",
        "root_password_on_all_instances": "rootPasswordOnAllInstances",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksMysqlLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[typing.List["OpsworksMysqlLayerEbsVolume"]] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        root_password: typing.Optional[str] = None,
        root_password_on_all_instances: typing.Optional[bool] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param root_password: 
        :param root_password_on_all_instances: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if name is not None:
            self._values["name"] = name
        if root_password is not None:
            self._values["root_password"] = root_password
        if root_password_on_all_instances is not None:
            self._values[
                "root_password_on_all_instances"
            ] = root_password_on_all_instances
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(self) -> typing.Optional[typing.List["OpsworksMysqlLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def root_password(self) -> typing.Optional[str]:
        return self._values.get("root_password")

    @builtins.property
    def root_password_on_all_instances(self) -> typing.Optional[bool]:
        return self._values.get("root_password_on_all_instances")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksMysqlLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksMysqlLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksMysqlLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksMysqlLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksNodejsAppLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksNodejsAppLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksNodejsAppLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        nodejs_version: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param nodejs_version: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksNodejsAppLayerConfig(
            stack_id=stack_id,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            name=name,
            nodejs_version=nodejs_version,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksNodejsAppLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksNodejsAppLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksNodejsAppLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="nodejsVersion")
    def nodejs_version(self) -> typing.Optional[str]:
        return jsii.get(self, "nodejsVersion")

    @nodejs_version.setter
    def nodejs_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "nodejsVersion", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksNodejsAppLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "name": "name",
        "nodejs_version": "nodejsVersion",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksNodejsAppLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksNodejsAppLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        nodejs_version: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param nodejs_version: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if name is not None:
            self._values["name"] = name
        if nodejs_version is not None:
            self._values["nodejs_version"] = nodejs_version
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksNodejsAppLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def nodejs_version(self) -> typing.Optional[str]:
        return self._values.get("nodejs_version")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksNodejsAppLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksNodejsAppLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksNodejsAppLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksNodejsAppLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksPermission(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksPermission",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        user_arn: str,
        allow_ssh: typing.Optional[bool] = None,
        allow_sudo: typing.Optional[bool] = None,
        level: typing.Optional[str] = None,
        stack_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param user_arn: 
        :param allow_ssh: 
        :param allow_sudo: 
        :param level: 
        :param stack_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksPermissionConfig(
            user_arn=user_arn,
            allow_ssh=allow_ssh,
            allow_sudo=allow_sudo,
            level=level,
            stack_id=stack_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksPermission, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="userArn")
    def user_arn(self) -> str:
        return jsii.get(self, "userArn")

    @user_arn.setter
    def user_arn(self, value: str) -> None:
        jsii.set(self, "userArn", value)

    @builtins.property
    @jsii.member(jsii_name="allowSsh")
    def allow_ssh(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowSsh")

    @allow_ssh.setter
    def allow_ssh(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowSsh", value)

    @builtins.property
    @jsii.member(jsii_name="allowSudo")
    def allow_sudo(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowSudo")

    @allow_sudo.setter
    def allow_sudo(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowSudo", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="level")
    def level(self) -> typing.Optional[str]:
        return jsii.get(self, "level")

    @level.setter
    def level(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "level", value)

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> typing.Optional[str]:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "stackId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksPermissionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "user_arn": "userArn",
        "allow_ssh": "allowSsh",
        "allow_sudo": "allowSudo",
        "level": "level",
        "stack_id": "stackId",
    },
)
class OpsworksPermissionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        user_arn: str,
        allow_ssh: typing.Optional[bool] = None,
        allow_sudo: typing.Optional[bool] = None,
        level: typing.Optional[str] = None,
        stack_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param user_arn: 
        :param allow_ssh: 
        :param allow_sudo: 
        :param level: 
        :param stack_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "user_arn": user_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_ssh is not None:
            self._values["allow_ssh"] = allow_ssh
        if allow_sudo is not None:
            self._values["allow_sudo"] = allow_sudo
        if level is not None:
            self._values["level"] = level
        if stack_id is not None:
            self._values["stack_id"] = stack_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def user_arn(self) -> str:
        return self._values.get("user_arn")

    @builtins.property
    def allow_ssh(self) -> typing.Optional[bool]:
        return self._values.get("allow_ssh")

    @builtins.property
    def allow_sudo(self) -> typing.Optional[bool]:
        return self._values.get("allow_sudo")

    @builtins.property
    def level(self) -> typing.Optional[str]:
        return self._values.get("level")

    @builtins.property
    def stack_id(self) -> typing.Optional[str]:
        return self._values.get("stack_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksPermissionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksPhpAppLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksPhpAppLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[typing.List["OpsworksPhpAppLayerEbsVolume"]] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksPhpAppLayerConfig(
            stack_id=stack_id,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            name=name,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksPhpAppLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksPhpAppLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksPhpAppLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksPhpAppLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "name": "name",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksPhpAppLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[typing.List["OpsworksPhpAppLayerEbsVolume"]] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if name is not None:
            self._values["name"] = name
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksPhpAppLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksPhpAppLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksPhpAppLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksPhpAppLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksPhpAppLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksRailsAppLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksRailsAppLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        app_server: typing.Optional[str] = None,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        bundler_version: typing.Optional[str] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksRailsAppLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        manage_bundler: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        passenger_version: typing.Optional[str] = None,
        rubygems_version: typing.Optional[str] = None,
        ruby_version: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param app_server: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param bundler_version: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param manage_bundler: 
        :param name: 
        :param passenger_version: 
        :param rubygems_version: 
        :param ruby_version: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksRailsAppLayerConfig(
            stack_id=stack_id,
            app_server=app_server,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            bundler_version=bundler_version,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            manage_bundler=manage_bundler,
            name=name,
            passenger_version=passenger_version,
            rubygems_version=rubygems_version,
            ruby_version=ruby_version,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksRailsAppLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="appServer")
    def app_server(self) -> typing.Optional[str]:
        return jsii.get(self, "appServer")

    @app_server.setter
    def app_server(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "appServer", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="bundlerVersion")
    def bundler_version(self) -> typing.Optional[str]:
        return jsii.get(self, "bundlerVersion")

    @bundler_version.setter
    def bundler_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bundlerVersion", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksRailsAppLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksRailsAppLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="manageBundler")
    def manage_bundler(self) -> typing.Optional[bool]:
        return jsii.get(self, "manageBundler")

    @manage_bundler.setter
    def manage_bundler(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "manageBundler", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="passengerVersion")
    def passenger_version(self) -> typing.Optional[str]:
        return jsii.get(self, "passengerVersion")

    @passenger_version.setter
    def passenger_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "passengerVersion", value)

    @builtins.property
    @jsii.member(jsii_name="rubygemsVersion")
    def rubygems_version(self) -> typing.Optional[str]:
        return jsii.get(self, "rubygemsVersion")

    @rubygems_version.setter
    def rubygems_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rubygemsVersion", value)

    @builtins.property
    @jsii.member(jsii_name="rubyVersion")
    def ruby_version(self) -> typing.Optional[str]:
        return jsii.get(self, "rubyVersion")

    @ruby_version.setter
    def ruby_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rubyVersion", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksRailsAppLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "app_server": "appServer",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "bundler_version": "bundlerVersion",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "manage_bundler": "manageBundler",
        "name": "name",
        "passenger_version": "passengerVersion",
        "rubygems_version": "rubygemsVersion",
        "ruby_version": "rubyVersion",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksRailsAppLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        app_server: typing.Optional[str] = None,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        bundler_version: typing.Optional[str] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksRailsAppLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        manage_bundler: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        passenger_version: typing.Optional[str] = None,
        rubygems_version: typing.Optional[str] = None,
        ruby_version: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param app_server: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param bundler_version: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param manage_bundler: 
        :param name: 
        :param passenger_version: 
        :param rubygems_version: 
        :param ruby_version: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if app_server is not None:
            self._values["app_server"] = app_server
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if bundler_version is not None:
            self._values["bundler_version"] = bundler_version
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if manage_bundler is not None:
            self._values["manage_bundler"] = manage_bundler
        if name is not None:
            self._values["name"] = name
        if passenger_version is not None:
            self._values["passenger_version"] = passenger_version
        if rubygems_version is not None:
            self._values["rubygems_version"] = rubygems_version
        if ruby_version is not None:
            self._values["ruby_version"] = ruby_version
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def app_server(self) -> typing.Optional[str]:
        return self._values.get("app_server")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def bundler_version(self) -> typing.Optional[str]:
        return self._values.get("bundler_version")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksRailsAppLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def manage_bundler(self) -> typing.Optional[bool]:
        return self._values.get("manage_bundler")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def passenger_version(self) -> typing.Optional[str]:
        return self._values.get("passenger_version")

    @builtins.property
    def rubygems_version(self) -> typing.Optional[str]:
        return self._values.get("rubygems_version")

    @builtins.property
    def ruby_version(self) -> typing.Optional[str]:
        return self._values.get("ruby_version")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksRailsAppLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksRailsAppLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksRailsAppLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksRailsAppLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksRdsDbInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksRdsDbInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        db_password: str,
        db_user: str,
        rds_db_instance_arn: str,
        stack_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param db_password: 
        :param db_user: 
        :param rds_db_instance_arn: 
        :param stack_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksRdsDbInstanceConfig(
            db_password=db_password,
            db_user=db_user,
            rds_db_instance_arn=rds_db_instance_arn,
            stack_id=stack_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksRdsDbInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dbPassword")
    def db_password(self) -> str:
        return jsii.get(self, "dbPassword")

    @db_password.setter
    def db_password(self, value: str) -> None:
        jsii.set(self, "dbPassword", value)

    @builtins.property
    @jsii.member(jsii_name="dbUser")
    def db_user(self) -> str:
        return jsii.get(self, "dbUser")

    @db_user.setter
    def db_user(self, value: str) -> None:
        jsii.set(self, "dbUser", value)

    @builtins.property
    @jsii.member(jsii_name="rdsDbInstanceArn")
    def rds_db_instance_arn(self) -> str:
        return jsii.get(self, "rdsDbInstanceArn")

    @rds_db_instance_arn.setter
    def rds_db_instance_arn(self, value: str) -> None:
        jsii.set(self, "rdsDbInstanceArn", value)

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksRdsDbInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "db_password": "dbPassword",
        "db_user": "dbUser",
        "rds_db_instance_arn": "rdsDbInstanceArn",
        "stack_id": "stackId",
    },
)
class OpsworksRdsDbInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        db_password: str,
        db_user: str,
        rds_db_instance_arn: str,
        stack_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param db_password: 
        :param db_user: 
        :param rds_db_instance_arn: 
        :param stack_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "db_password": db_password,
            "db_user": db_user,
            "rds_db_instance_arn": rds_db_instance_arn,
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def db_password(self) -> str:
        return self._values.get("db_password")

    @builtins.property
    def db_user(self) -> str:
        return self._values.get("db_user")

    @builtins.property
    def rds_db_instance_arn(self) -> str:
        return self._values.get("rds_db_instance_arn")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksRdsDbInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksStack(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksStack",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_instance_profile_arn: str,
        name: str,
        region: str,
        service_role_arn: str,
        agent_version: typing.Optional[str] = None,
        berkshelf_version: typing.Optional[str] = None,
        color: typing.Optional[str] = None,
        configuration_manager_name: typing.Optional[str] = None,
        configuration_manager_version: typing.Optional[str] = None,
        custom_cookbooks_source: typing.Optional[
            typing.List["OpsworksStackCustomCookbooksSource"]
        ] = None,
        custom_json: typing.Optional[str] = None,
        default_availability_zone: typing.Optional[str] = None,
        default_os: typing.Optional[str] = None,
        default_root_device_type: typing.Optional[str] = None,
        default_ssh_key_name: typing.Optional[str] = None,
        default_subnet_id: typing.Optional[str] = None,
        hostname_theme: typing.Optional[str] = None,
        manage_berkshelf: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_custom_cookbooks: typing.Optional[bool] = None,
        use_opsworks_security_groups: typing.Optional[bool] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_instance_profile_arn: 
        :param name: 
        :param region: 
        :param service_role_arn: 
        :param agent_version: 
        :param berkshelf_version: 
        :param color: 
        :param configuration_manager_name: 
        :param configuration_manager_version: 
        :param custom_cookbooks_source: custom_cookbooks_source block.
        :param custom_json: 
        :param default_availability_zone: 
        :param default_os: 
        :param default_root_device_type: 
        :param default_ssh_key_name: 
        :param default_subnet_id: 
        :param hostname_theme: 
        :param manage_berkshelf: 
        :param tags: 
        :param use_custom_cookbooks: 
        :param use_opsworks_security_groups: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksStackConfig(
            default_instance_profile_arn=default_instance_profile_arn,
            name=name,
            region=region,
            service_role_arn=service_role_arn,
            agent_version=agent_version,
            berkshelf_version=berkshelf_version,
            color=color,
            configuration_manager_name=configuration_manager_name,
            configuration_manager_version=configuration_manager_version,
            custom_cookbooks_source=custom_cookbooks_source,
            custom_json=custom_json,
            default_availability_zone=default_availability_zone,
            default_os=default_os,
            default_root_device_type=default_root_device_type,
            default_ssh_key_name=default_ssh_key_name,
            default_subnet_id=default_subnet_id,
            hostname_theme=hostname_theme,
            manage_berkshelf=manage_berkshelf,
            tags=tags,
            use_custom_cookbooks=use_custom_cookbooks,
            use_opsworks_security_groups=use_opsworks_security_groups,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksStack, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackEndpoint")
    def stack_endpoint(self) -> str:
        return jsii.get(self, "stackEndpoint")

    @builtins.property
    @jsii.member(jsii_name="defaultInstanceProfileArn")
    def default_instance_profile_arn(self) -> str:
        return jsii.get(self, "defaultInstanceProfileArn")

    @default_instance_profile_arn.setter
    def default_instance_profile_arn(self, value: str) -> None:
        jsii.set(self, "defaultInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> str:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: str) -> None:
        jsii.set(self, "region", value)

    @builtins.property
    @jsii.member(jsii_name="serviceRoleArn")
    def service_role_arn(self) -> str:
        return jsii.get(self, "serviceRoleArn")

    @service_role_arn.setter
    def service_role_arn(self, value: str) -> None:
        jsii.set(self, "serviceRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="agentVersion")
    def agent_version(self) -> typing.Optional[str]:
        return jsii.get(self, "agentVersion")

    @agent_version.setter
    def agent_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "agentVersion", value)

    @builtins.property
    @jsii.member(jsii_name="berkshelfVersion")
    def berkshelf_version(self) -> typing.Optional[str]:
        return jsii.get(self, "berkshelfVersion")

    @berkshelf_version.setter
    def berkshelf_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "berkshelfVersion", value)

    @builtins.property
    @jsii.member(jsii_name="color")
    def color(self) -> typing.Optional[str]:
        return jsii.get(self, "color")

    @color.setter
    def color(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "color", value)

    @builtins.property
    @jsii.member(jsii_name="configurationManagerName")
    def configuration_manager_name(self) -> typing.Optional[str]:
        return jsii.get(self, "configurationManagerName")

    @configuration_manager_name.setter
    def configuration_manager_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "configurationManagerName", value)

    @builtins.property
    @jsii.member(jsii_name="configurationManagerVersion")
    def configuration_manager_version(self) -> typing.Optional[str]:
        return jsii.get(self, "configurationManagerVersion")

    @configuration_manager_version.setter
    def configuration_manager_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "configurationManagerVersion", value)

    @builtins.property
    @jsii.member(jsii_name="customCookbooksSource")
    def custom_cookbooks_source(
        self,
    ) -> typing.Optional[typing.List["OpsworksStackCustomCookbooksSource"]]:
        return jsii.get(self, "customCookbooksSource")

    @custom_cookbooks_source.setter
    def custom_cookbooks_source(
        self, value: typing.Optional[typing.List["OpsworksStackCustomCookbooksSource"]]
    ) -> None:
        jsii.set(self, "customCookbooksSource", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="defaultAvailabilityZone")
    def default_availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultAvailabilityZone")

    @default_availability_zone.setter
    def default_availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultAvailabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="defaultOs")
    def default_os(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultOs")

    @default_os.setter
    def default_os(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultOs", value)

    @builtins.property
    @jsii.member(jsii_name="defaultRootDeviceType")
    def default_root_device_type(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultRootDeviceType")

    @default_root_device_type.setter
    def default_root_device_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultRootDeviceType", value)

    @builtins.property
    @jsii.member(jsii_name="defaultSshKeyName")
    def default_ssh_key_name(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultSshKeyName")

    @default_ssh_key_name.setter
    def default_ssh_key_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultSshKeyName", value)

    @builtins.property
    @jsii.member(jsii_name="defaultSubnetId")
    def default_subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultSubnetId")

    @default_subnet_id.setter
    def default_subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultSubnetId", value)

    @builtins.property
    @jsii.member(jsii_name="hostnameTheme")
    def hostname_theme(self) -> typing.Optional[str]:
        return jsii.get(self, "hostnameTheme")

    @hostname_theme.setter
    def hostname_theme(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "hostnameTheme", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="manageBerkshelf")
    def manage_berkshelf(self) -> typing.Optional[bool]:
        return jsii.get(self, "manageBerkshelf")

    @manage_berkshelf.setter
    def manage_berkshelf(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "manageBerkshelf", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useCustomCookbooks")
    def use_custom_cookbooks(self) -> typing.Optional[bool]:
        return jsii.get(self, "useCustomCookbooks")

    @use_custom_cookbooks.setter
    def use_custom_cookbooks(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useCustomCookbooks", value)

    @builtins.property
    @jsii.member(jsii_name="useOpsworksSecurityGroups")
    def use_opsworks_security_groups(self) -> typing.Optional[bool]:
        return jsii.get(self, "useOpsworksSecurityGroups")

    @use_opsworks_security_groups.setter
    def use_opsworks_security_groups(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useOpsworksSecurityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksStackConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_instance_profile_arn": "defaultInstanceProfileArn",
        "name": "name",
        "region": "region",
        "service_role_arn": "serviceRoleArn",
        "agent_version": "agentVersion",
        "berkshelf_version": "berkshelfVersion",
        "color": "color",
        "configuration_manager_name": "configurationManagerName",
        "configuration_manager_version": "configurationManagerVersion",
        "custom_cookbooks_source": "customCookbooksSource",
        "custom_json": "customJson",
        "default_availability_zone": "defaultAvailabilityZone",
        "default_os": "defaultOs",
        "default_root_device_type": "defaultRootDeviceType",
        "default_ssh_key_name": "defaultSshKeyName",
        "default_subnet_id": "defaultSubnetId",
        "hostname_theme": "hostnameTheme",
        "manage_berkshelf": "manageBerkshelf",
        "tags": "tags",
        "use_custom_cookbooks": "useCustomCookbooks",
        "use_opsworks_security_groups": "useOpsworksSecurityGroups",
        "vpc_id": "vpcId",
    },
)
class OpsworksStackConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_instance_profile_arn: str,
        name: str,
        region: str,
        service_role_arn: str,
        agent_version: typing.Optional[str] = None,
        berkshelf_version: typing.Optional[str] = None,
        color: typing.Optional[str] = None,
        configuration_manager_name: typing.Optional[str] = None,
        configuration_manager_version: typing.Optional[str] = None,
        custom_cookbooks_source: typing.Optional[
            typing.List["OpsworksStackCustomCookbooksSource"]
        ] = None,
        custom_json: typing.Optional[str] = None,
        default_availability_zone: typing.Optional[str] = None,
        default_os: typing.Optional[str] = None,
        default_root_device_type: typing.Optional[str] = None,
        default_ssh_key_name: typing.Optional[str] = None,
        default_subnet_id: typing.Optional[str] = None,
        hostname_theme: typing.Optional[str] = None,
        manage_berkshelf: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_custom_cookbooks: typing.Optional[bool] = None,
        use_opsworks_security_groups: typing.Optional[bool] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_instance_profile_arn: 
        :param name: 
        :param region: 
        :param service_role_arn: 
        :param agent_version: 
        :param berkshelf_version: 
        :param color: 
        :param configuration_manager_name: 
        :param configuration_manager_version: 
        :param custom_cookbooks_source: custom_cookbooks_source block.
        :param custom_json: 
        :param default_availability_zone: 
        :param default_os: 
        :param default_root_device_type: 
        :param default_ssh_key_name: 
        :param default_subnet_id: 
        :param hostname_theme: 
        :param manage_berkshelf: 
        :param tags: 
        :param use_custom_cookbooks: 
        :param use_opsworks_security_groups: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "default_instance_profile_arn": default_instance_profile_arn,
            "name": name,
            "region": region,
            "service_role_arn": service_role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if agent_version is not None:
            self._values["agent_version"] = agent_version
        if berkshelf_version is not None:
            self._values["berkshelf_version"] = berkshelf_version
        if color is not None:
            self._values["color"] = color
        if configuration_manager_name is not None:
            self._values["configuration_manager_name"] = configuration_manager_name
        if configuration_manager_version is not None:
            self._values[
                "configuration_manager_version"
            ] = configuration_manager_version
        if custom_cookbooks_source is not None:
            self._values["custom_cookbooks_source"] = custom_cookbooks_source
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if default_availability_zone is not None:
            self._values["default_availability_zone"] = default_availability_zone
        if default_os is not None:
            self._values["default_os"] = default_os
        if default_root_device_type is not None:
            self._values["default_root_device_type"] = default_root_device_type
        if default_ssh_key_name is not None:
            self._values["default_ssh_key_name"] = default_ssh_key_name
        if default_subnet_id is not None:
            self._values["default_subnet_id"] = default_subnet_id
        if hostname_theme is not None:
            self._values["hostname_theme"] = hostname_theme
        if manage_berkshelf is not None:
            self._values["manage_berkshelf"] = manage_berkshelf
        if tags is not None:
            self._values["tags"] = tags
        if use_custom_cookbooks is not None:
            self._values["use_custom_cookbooks"] = use_custom_cookbooks
        if use_opsworks_security_groups is not None:
            self._values["use_opsworks_security_groups"] = use_opsworks_security_groups
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_instance_profile_arn(self) -> str:
        return self._values.get("default_instance_profile_arn")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def region(self) -> str:
        return self._values.get("region")

    @builtins.property
    def service_role_arn(self) -> str:
        return self._values.get("service_role_arn")

    @builtins.property
    def agent_version(self) -> typing.Optional[str]:
        return self._values.get("agent_version")

    @builtins.property
    def berkshelf_version(self) -> typing.Optional[str]:
        return self._values.get("berkshelf_version")

    @builtins.property
    def color(self) -> typing.Optional[str]:
        return self._values.get("color")

    @builtins.property
    def configuration_manager_name(self) -> typing.Optional[str]:
        return self._values.get("configuration_manager_name")

    @builtins.property
    def configuration_manager_version(self) -> typing.Optional[str]:
        return self._values.get("configuration_manager_version")

    @builtins.property
    def custom_cookbooks_source(
        self,
    ) -> typing.Optional[typing.List["OpsworksStackCustomCookbooksSource"]]:
        """custom_cookbooks_source block."""
        return self._values.get("custom_cookbooks_source")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def default_availability_zone(self) -> typing.Optional[str]:
        return self._values.get("default_availability_zone")

    @builtins.property
    def default_os(self) -> typing.Optional[str]:
        return self._values.get("default_os")

    @builtins.property
    def default_root_device_type(self) -> typing.Optional[str]:
        return self._values.get("default_root_device_type")

    @builtins.property
    def default_ssh_key_name(self) -> typing.Optional[str]:
        return self._values.get("default_ssh_key_name")

    @builtins.property
    def default_subnet_id(self) -> typing.Optional[str]:
        return self._values.get("default_subnet_id")

    @builtins.property
    def hostname_theme(self) -> typing.Optional[str]:
        return self._values.get("hostname_theme")

    @builtins.property
    def manage_berkshelf(self) -> typing.Optional[bool]:
        return self._values.get("manage_berkshelf")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_custom_cookbooks(self) -> typing.Optional[bool]:
        return self._values.get("use_custom_cookbooks")

    @builtins.property
    def use_opsworks_security_groups(self) -> typing.Optional[bool]:
        return self._values.get("use_opsworks_security_groups")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksStackConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksStackCustomCookbooksSource",
    jsii_struct_bases=[],
    name_mapping={
        "type": "type",
        "url": "url",
        "password": "password",
        "revision": "revision",
        "ssh_key": "sshKey",
        "username": "username",
    },
)
class OpsworksStackCustomCookbooksSource:
    def __init__(
        self,
        *,
        type: str,
        url: str,
        password: typing.Optional[str] = None,
        revision: typing.Optional[str] = None,
        ssh_key: typing.Optional[str] = None,
        username: typing.Optional[str] = None,
    ) -> None:
        """
        :param type: 
        :param url: 
        :param password: 
        :param revision: 
        :param ssh_key: 
        :param username: 
        """
        self._values = {
            "type": type,
            "url": url,
        }
        if password is not None:
            self._values["password"] = password
        if revision is not None:
            self._values["revision"] = revision
        if ssh_key is not None:
            self._values["ssh_key"] = ssh_key
        if username is not None:
            self._values["username"] = username

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def url(self) -> str:
        return self._values.get("url")

    @builtins.property
    def password(self) -> typing.Optional[str]:
        return self._values.get("password")

    @builtins.property
    def revision(self) -> typing.Optional[str]:
        return self._values.get("revision")

    @builtins.property
    def ssh_key(self) -> typing.Optional[str]:
        return self._values.get("ssh_key")

    @builtins.property
    def username(self) -> typing.Optional[str]:
        return self._values.get("username")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksStackCustomCookbooksSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksStaticWebLayer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksStaticWebLayer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksStaticWebLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksStaticWebLayerConfig(
            stack_id=stack_id,
            auto_assign_elastic_ips=auto_assign_elastic_ips,
            auto_assign_public_ips=auto_assign_public_ips,
            auto_healing=auto_healing,
            custom_configure_recipes=custom_configure_recipes,
            custom_deploy_recipes=custom_deploy_recipes,
            custom_instance_profile_arn=custom_instance_profile_arn,
            custom_json=custom_json,
            custom_security_group_ids=custom_security_group_ids,
            custom_setup_recipes=custom_setup_recipes,
            custom_shutdown_recipes=custom_shutdown_recipes,
            custom_undeploy_recipes=custom_undeploy_recipes,
            drain_elb_on_shutdown=drain_elb_on_shutdown,
            ebs_volume=ebs_volume,
            elastic_load_balancer=elastic_load_balancer,
            install_updates_on_boot=install_updates_on_boot,
            instance_shutdown_timeout=instance_shutdown_timeout,
            name=name,
            system_packages=system_packages,
            tags=tags,
            use_ebs_optimized_instances=use_ebs_optimized_instances,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksStaticWebLayer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="stackId")
    def stack_id(self) -> str:
        return jsii.get(self, "stackId")

    @stack_id.setter
    def stack_id(self, value: str) -> None:
        jsii.set(self, "stackId", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignElasticIps")
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignElasticIps")

    @auto_assign_elastic_ips.setter
    def auto_assign_elastic_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignElasticIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoAssignPublicIps")
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAssignPublicIps")

    @auto_assign_public_ips.setter
    def auto_assign_public_ips(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAssignPublicIps", value)

    @builtins.property
    @jsii.member(jsii_name="autoHealing")
    def auto_healing(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoHealing")

    @auto_healing.setter
    def auto_healing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoHealing", value)

    @builtins.property
    @jsii.member(jsii_name="customConfigureRecipes")
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customConfigureRecipes")

    @custom_configure_recipes.setter
    def custom_configure_recipes(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customConfigureRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customDeployRecipes")
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customDeployRecipes")

    @custom_deploy_recipes.setter
    def custom_deploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customDeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customInstanceProfileArn")
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "customInstanceProfileArn")

    @custom_instance_profile_arn.setter
    def custom_instance_profile_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customInstanceProfileArn", value)

    @builtins.property
    @jsii.member(jsii_name="customJson")
    def custom_json(self) -> typing.Optional[str]:
        return jsii.get(self, "customJson")

    @custom_json.setter
    def custom_json(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "customJson", value)

    @builtins.property
    @jsii.member(jsii_name="customSecurityGroupIds")
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSecurityGroupIds")

    @custom_security_group_ids.setter
    def custom_security_group_ids(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "customSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="customSetupRecipes")
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customSetupRecipes")

    @custom_setup_recipes.setter
    def custom_setup_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customSetupRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customShutdownRecipes")
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customShutdownRecipes")

    @custom_shutdown_recipes.setter
    def custom_shutdown_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customShutdownRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="customUndeployRecipes")
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "customUndeployRecipes")

    @custom_undeploy_recipes.setter
    def custom_undeploy_recipes(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "customUndeployRecipes", value)

    @builtins.property
    @jsii.member(jsii_name="drainElbOnShutdown")
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return jsii.get(self, "drainElbOnShutdown")

    @drain_elb_on_shutdown.setter
    def drain_elb_on_shutdown(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "drainElbOnShutdown", value)

    @builtins.property
    @jsii.member(jsii_name="ebsVolume")
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksStaticWebLayerEbsVolume"]]:
        return jsii.get(self, "ebsVolume")

    @ebs_volume.setter
    def ebs_volume(
        self, value: typing.Optional[typing.List["OpsworksStaticWebLayerEbsVolume"]]
    ) -> None:
        jsii.set(self, "ebsVolume", value)

    @builtins.property
    @jsii.member(jsii_name="elasticLoadBalancer")
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticLoadBalancer")

    @elastic_load_balancer.setter
    def elastic_load_balancer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticLoadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="installUpdatesOnBoot")
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return jsii.get(self, "installUpdatesOnBoot")

    @install_updates_on_boot.setter
    def install_updates_on_boot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "installUpdatesOnBoot", value)

    @builtins.property
    @jsii.member(jsii_name="instanceShutdownTimeout")
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instanceShutdownTimeout")

    @instance_shutdown_timeout.setter
    def instance_shutdown_timeout(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instanceShutdownTimeout", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="systemPackages")
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "systemPackages")

    @system_packages.setter
    def system_packages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "systemPackages", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="useEbsOptimizedInstances")
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "useEbsOptimizedInstances")

    @use_ebs_optimized_instances.setter
    def use_ebs_optimized_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "useEbsOptimizedInstances", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksStaticWebLayerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "stack_id": "stackId",
        "auto_assign_elastic_ips": "autoAssignElasticIps",
        "auto_assign_public_ips": "autoAssignPublicIps",
        "auto_healing": "autoHealing",
        "custom_configure_recipes": "customConfigureRecipes",
        "custom_deploy_recipes": "customDeployRecipes",
        "custom_instance_profile_arn": "customInstanceProfileArn",
        "custom_json": "customJson",
        "custom_security_group_ids": "customSecurityGroupIds",
        "custom_setup_recipes": "customSetupRecipes",
        "custom_shutdown_recipes": "customShutdownRecipes",
        "custom_undeploy_recipes": "customUndeployRecipes",
        "drain_elb_on_shutdown": "drainElbOnShutdown",
        "ebs_volume": "ebsVolume",
        "elastic_load_balancer": "elasticLoadBalancer",
        "install_updates_on_boot": "installUpdatesOnBoot",
        "instance_shutdown_timeout": "instanceShutdownTimeout",
        "name": "name",
        "system_packages": "systemPackages",
        "tags": "tags",
        "use_ebs_optimized_instances": "useEbsOptimizedInstances",
    },
)
class OpsworksStaticWebLayerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        stack_id: str,
        auto_assign_elastic_ips: typing.Optional[bool] = None,
        auto_assign_public_ips: typing.Optional[bool] = None,
        auto_healing: typing.Optional[bool] = None,
        custom_configure_recipes: typing.Optional[typing.List[str]] = None,
        custom_deploy_recipes: typing.Optional[typing.List[str]] = None,
        custom_instance_profile_arn: typing.Optional[str] = None,
        custom_json: typing.Optional[str] = None,
        custom_security_group_ids: typing.Optional[typing.List[str]] = None,
        custom_setup_recipes: typing.Optional[typing.List[str]] = None,
        custom_shutdown_recipes: typing.Optional[typing.List[str]] = None,
        custom_undeploy_recipes: typing.Optional[typing.List[str]] = None,
        drain_elb_on_shutdown: typing.Optional[bool] = None,
        ebs_volume: typing.Optional[
            typing.List["OpsworksStaticWebLayerEbsVolume"]
        ] = None,
        elastic_load_balancer: typing.Optional[str] = None,
        install_updates_on_boot: typing.Optional[bool] = None,
        instance_shutdown_timeout: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        system_packages: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        use_ebs_optimized_instances: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param stack_id: 
        :param auto_assign_elastic_ips: 
        :param auto_assign_public_ips: 
        :param auto_healing: 
        :param custom_configure_recipes: 
        :param custom_deploy_recipes: 
        :param custom_instance_profile_arn: 
        :param custom_json: 
        :param custom_security_group_ids: 
        :param custom_setup_recipes: 
        :param custom_shutdown_recipes: 
        :param custom_undeploy_recipes: 
        :param drain_elb_on_shutdown: 
        :param ebs_volume: ebs_volume block.
        :param elastic_load_balancer: 
        :param install_updates_on_boot: 
        :param instance_shutdown_timeout: 
        :param name: 
        :param system_packages: 
        :param tags: 
        :param use_ebs_optimized_instances: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "stack_id": stack_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_assign_elastic_ips is not None:
            self._values["auto_assign_elastic_ips"] = auto_assign_elastic_ips
        if auto_assign_public_ips is not None:
            self._values["auto_assign_public_ips"] = auto_assign_public_ips
        if auto_healing is not None:
            self._values["auto_healing"] = auto_healing
        if custom_configure_recipes is not None:
            self._values["custom_configure_recipes"] = custom_configure_recipes
        if custom_deploy_recipes is not None:
            self._values["custom_deploy_recipes"] = custom_deploy_recipes
        if custom_instance_profile_arn is not None:
            self._values["custom_instance_profile_arn"] = custom_instance_profile_arn
        if custom_json is not None:
            self._values["custom_json"] = custom_json
        if custom_security_group_ids is not None:
            self._values["custom_security_group_ids"] = custom_security_group_ids
        if custom_setup_recipes is not None:
            self._values["custom_setup_recipes"] = custom_setup_recipes
        if custom_shutdown_recipes is not None:
            self._values["custom_shutdown_recipes"] = custom_shutdown_recipes
        if custom_undeploy_recipes is not None:
            self._values["custom_undeploy_recipes"] = custom_undeploy_recipes
        if drain_elb_on_shutdown is not None:
            self._values["drain_elb_on_shutdown"] = drain_elb_on_shutdown
        if ebs_volume is not None:
            self._values["ebs_volume"] = ebs_volume
        if elastic_load_balancer is not None:
            self._values["elastic_load_balancer"] = elastic_load_balancer
        if install_updates_on_boot is not None:
            self._values["install_updates_on_boot"] = install_updates_on_boot
        if instance_shutdown_timeout is not None:
            self._values["instance_shutdown_timeout"] = instance_shutdown_timeout
        if name is not None:
            self._values["name"] = name
        if system_packages is not None:
            self._values["system_packages"] = system_packages
        if tags is not None:
            self._values["tags"] = tags
        if use_ebs_optimized_instances is not None:
            self._values["use_ebs_optimized_instances"] = use_ebs_optimized_instances

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def stack_id(self) -> str:
        return self._values.get("stack_id")

    @builtins.property
    def auto_assign_elastic_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_elastic_ips")

    @builtins.property
    def auto_assign_public_ips(self) -> typing.Optional[bool]:
        return self._values.get("auto_assign_public_ips")

    @builtins.property
    def auto_healing(self) -> typing.Optional[bool]:
        return self._values.get("auto_healing")

    @builtins.property
    def custom_configure_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_configure_recipes")

    @builtins.property
    def custom_deploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_deploy_recipes")

    @builtins.property
    def custom_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("custom_instance_profile_arn")

    @builtins.property
    def custom_json(self) -> typing.Optional[str]:
        return self._values.get("custom_json")

    @builtins.property
    def custom_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_security_group_ids")

    @builtins.property
    def custom_setup_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_setup_recipes")

    @builtins.property
    def custom_shutdown_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_shutdown_recipes")

    @builtins.property
    def custom_undeploy_recipes(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("custom_undeploy_recipes")

    @builtins.property
    def drain_elb_on_shutdown(self) -> typing.Optional[bool]:
        return self._values.get("drain_elb_on_shutdown")

    @builtins.property
    def ebs_volume(
        self,
    ) -> typing.Optional[typing.List["OpsworksStaticWebLayerEbsVolume"]]:
        """ebs_volume block."""
        return self._values.get("ebs_volume")

    @builtins.property
    def elastic_load_balancer(self) -> typing.Optional[str]:
        return self._values.get("elastic_load_balancer")

    @builtins.property
    def install_updates_on_boot(self) -> typing.Optional[bool]:
        return self._values.get("install_updates_on_boot")

    @builtins.property
    def instance_shutdown_timeout(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_shutdown_timeout")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def system_packages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("system_packages")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def use_ebs_optimized_instances(self) -> typing.Optional[bool]:
        return self._values.get("use_ebs_optimized_instances")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksStaticWebLayerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksStaticWebLayerEbsVolume",
    jsii_struct_bases=[],
    name_mapping={
        "mount_point": "mountPoint",
        "number_of_disks": "numberOfDisks",
        "size": "size",
        "encrypted": "encrypted",
        "iops": "iops",
        "raid_level": "raidLevel",
        "type": "type",
    },
)
class OpsworksStaticWebLayerEbsVolume:
    def __init__(
        self,
        *,
        mount_point: str,
        number_of_disks: jsii.Number,
        size: jsii.Number,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        raid_level: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param mount_point: 
        :param number_of_disks: 
        :param size: 
        :param encrypted: 
        :param iops: 
        :param raid_level: 
        :param type: 
        """
        self._values = {
            "mount_point": mount_point,
            "number_of_disks": number_of_disks,
            "size": size,
        }
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if raid_level is not None:
            self._values["raid_level"] = raid_level
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def mount_point(self) -> str:
        return self._values.get("mount_point")

    @builtins.property
    def number_of_disks(self) -> jsii.Number:
        return self._values.get("number_of_disks")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def raid_level(self) -> typing.Optional[str]:
        return self._values.get("raid_level")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksStaticWebLayerEbsVolume(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OpsworksUserProfile(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksUserProfile",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        ssh_username: str,
        user_arn: str,
        allow_self_management: typing.Optional[bool] = None,
        ssh_public_key: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ssh_username: 
        :param user_arn: 
        :param allow_self_management: 
        :param ssh_public_key: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OpsworksUserProfileConfig(
            ssh_username=ssh_username,
            user_arn=user_arn,
            allow_self_management=allow_self_management,
            ssh_public_key=ssh_public_key,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OpsworksUserProfile, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="sshUsername")
    def ssh_username(self) -> str:
        return jsii.get(self, "sshUsername")

    @ssh_username.setter
    def ssh_username(self, value: str) -> None:
        jsii.set(self, "sshUsername", value)

    @builtins.property
    @jsii.member(jsii_name="userArn")
    def user_arn(self) -> str:
        return jsii.get(self, "userArn")

    @user_arn.setter
    def user_arn(self, value: str) -> None:
        jsii.set(self, "userArn", value)

    @builtins.property
    @jsii.member(jsii_name="allowSelfManagement")
    def allow_self_management(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowSelfManagement")

    @allow_self_management.setter
    def allow_self_management(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowSelfManagement", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sshPublicKey")
    def ssh_public_key(self) -> typing.Optional[str]:
        return jsii.get(self, "sshPublicKey")

    @ssh_public_key.setter
    def ssh_public_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sshPublicKey", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OpsworksUserProfileConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ssh_username": "sshUsername",
        "user_arn": "userArn",
        "allow_self_management": "allowSelfManagement",
        "ssh_public_key": "sshPublicKey",
    },
)
class OpsworksUserProfileConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ssh_username: str,
        user_arn: str,
        allow_self_management: typing.Optional[bool] = None,
        ssh_public_key: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ssh_username: 
        :param user_arn: 
        :param allow_self_management: 
        :param ssh_public_key: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "ssh_username": ssh_username,
            "user_arn": user_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_self_management is not None:
            self._values["allow_self_management"] = allow_self_management
        if ssh_public_key is not None:
            self._values["ssh_public_key"] = ssh_public_key

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def ssh_username(self) -> str:
        return self._values.get("ssh_username")

    @builtins.property
    def user_arn(self) -> str:
        return self._values.get("user_arn")

    @builtins.property
    def allow_self_management(self) -> typing.Optional[bool]:
        return self._values.get("allow_self_management")

    @builtins.property
    def ssh_public_key(self) -> typing.Optional[str]:
        return self._values.get("ssh_public_key")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OpsworksUserProfileConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationsAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        email: str,
        name: str,
        iam_user_access_to_billing: typing.Optional[str] = None,
        parent_id: typing.Optional[str] = None,
        role_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param email: 
        :param name: 
        :param iam_user_access_to_billing: 
        :param parent_id: 
        :param role_name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OrganizationsAccountConfig(
            email=email,
            name=name,
            iam_user_access_to_billing=iam_user_access_to_billing,
            parent_id=parent_id,
            role_name=role_name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OrganizationsAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="joinedMethod")
    def joined_method(self) -> str:
        return jsii.get(self, "joinedMethod")

    @builtins.property
    @jsii.member(jsii_name="joinedTimestamp")
    def joined_timestamp(self) -> str:
        return jsii.get(self, "joinedTimestamp")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @email.setter
    def email(self, value: str) -> None:
        jsii.set(self, "email", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="iamUserAccessToBilling")
    def iam_user_access_to_billing(self) -> typing.Optional[str]:
        return jsii.get(self, "iamUserAccessToBilling")

    @iam_user_access_to_billing.setter
    def iam_user_access_to_billing(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamUserAccessToBilling", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parentId")
    def parent_id(self) -> typing.Optional[str]:
        return jsii.get(self, "parentId")

    @parent_id.setter
    def parent_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "parentId", value)

    @builtins.property
    @jsii.member(jsii_name="roleName")
    def role_name(self) -> typing.Optional[str]:
        return jsii.get(self, "roleName")

    @role_name.setter
    def role_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "roleName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "email": "email",
        "name": "name",
        "iam_user_access_to_billing": "iamUserAccessToBilling",
        "parent_id": "parentId",
        "role_name": "roleName",
        "tags": "tags",
    },
)
class OrganizationsAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        email: str,
        name: str,
        iam_user_access_to_billing: typing.Optional[str] = None,
        parent_id: typing.Optional[str] = None,
        role_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param email: 
        :param name: 
        :param iam_user_access_to_billing: 
        :param parent_id: 
        :param role_name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "email": email,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if iam_user_access_to_billing is not None:
            self._values["iam_user_access_to_billing"] = iam_user_access_to_billing
        if parent_id is not None:
            self._values["parent_id"] = parent_id
        if role_name is not None:
            self._values["role_name"] = role_name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def email(self) -> str:
        return self._values.get("email")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def iam_user_access_to_billing(self) -> typing.Optional[str]:
        return self._values.get("iam_user_access_to_billing")

    @builtins.property
    def parent_id(self) -> typing.Optional[str]:
        return self._values.get("parent_id")

    @builtins.property
    def role_name(self) -> typing.Optional[str]:
        return self._values.get("role_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationsAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationsOrganization(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganization",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        aws_service_access_principals: typing.Optional[typing.List[str]] = None,
        enabled_policy_types: typing.Optional[typing.List[str]] = None,
        feature_set: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param aws_service_access_principals: 
        :param enabled_policy_types: 
        :param feature_set: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OrganizationsOrganizationConfig(
            aws_service_access_principals=aws_service_access_principals,
            enabled_policy_types=enabled_policy_types,
            feature_set=feature_set,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OrganizationsOrganization, self, [scope, id, config])

    @jsii.member(jsii_name="accounts")
    def accounts(self, index: str) -> "OrganizationsOrganizationAccounts":
        """
        :param index: -
        """
        return jsii.invoke(self, "accounts", [index])

    @jsii.member(jsii_name="nonMasterAccounts")
    def non_master_accounts(
        self, index: str
    ) -> "OrganizationsOrganizationNonMasterAccounts":
        """
        :param index: -
        """
        return jsii.invoke(self, "nonMasterAccounts", [index])

    @jsii.member(jsii_name="roots")
    def roots(self, index: str) -> "OrganizationsOrganizationRoots":
        """
        :param index: -
        """
        return jsii.invoke(self, "roots", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="masterAccountArn")
    def master_account_arn(self) -> str:
        return jsii.get(self, "masterAccountArn")

    @builtins.property
    @jsii.member(jsii_name="masterAccountEmail")
    def master_account_email(self) -> str:
        return jsii.get(self, "masterAccountEmail")

    @builtins.property
    @jsii.member(jsii_name="masterAccountId")
    def master_account_id(self) -> str:
        return jsii.get(self, "masterAccountId")

    @builtins.property
    @jsii.member(jsii_name="awsServiceAccessPrincipals")
    def aws_service_access_principals(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "awsServiceAccessPrincipals")

    @aws_service_access_principals.setter
    def aws_service_access_principals(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "awsServiceAccessPrincipals", value)

    @builtins.property
    @jsii.member(jsii_name="enabledPolicyTypes")
    def enabled_policy_types(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "enabledPolicyTypes")

    @enabled_policy_types.setter
    def enabled_policy_types(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "enabledPolicyTypes", value)

    @builtins.property
    @jsii.member(jsii_name="featureSet")
    def feature_set(self) -> typing.Optional[str]:
        return jsii.get(self, "featureSet")

    @feature_set.setter
    def feature_set(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "featureSet", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class OrganizationsOrganizationAccounts(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationAccounts",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            OrganizationsOrganizationAccounts,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "aws_service_access_principals": "awsServiceAccessPrincipals",
        "enabled_policy_types": "enabledPolicyTypes",
        "feature_set": "featureSet",
    },
)
class OrganizationsOrganizationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        aws_service_access_principals: typing.Optional[typing.List[str]] = None,
        enabled_policy_types: typing.Optional[typing.List[str]] = None,
        feature_set: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param aws_service_access_principals: 
        :param enabled_policy_types: 
        :param feature_set: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if aws_service_access_principals is not None:
            self._values[
                "aws_service_access_principals"
            ] = aws_service_access_principals
        if enabled_policy_types is not None:
            self._values["enabled_policy_types"] = enabled_policy_types
        if feature_set is not None:
            self._values["feature_set"] = feature_set

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def aws_service_access_principals(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("aws_service_access_principals")

    @builtins.property
    def enabled_policy_types(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("enabled_policy_types")

    @builtins.property
    def feature_set(self) -> typing.Optional[str]:
        return self._values.get("feature_set")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationsOrganizationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationsOrganizationNonMasterAccounts(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationNonMasterAccounts",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            OrganizationsOrganizationNonMasterAccounts,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")


class OrganizationsOrganizationRoots(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationRoots",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            OrganizationsOrganizationRoots,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="policyTypes")
    def policy_types(self) -> typing.Any:
        return jsii.get(self, "policyTypes")


class OrganizationsOrganizationRootsPolicyTypes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationRootsPolicyTypes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            OrganizationsOrganizationRootsPolicyTypes,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


class OrganizationsOrganizationalUnit(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationalUnit",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        parent_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param parent_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OrganizationsOrganizationalUnitConfig(
            name=name,
            parent_id=parent_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OrganizationsOrganizationalUnit, self, [scope, id, config])

    @jsii.member(jsii_name="accounts")
    def accounts(self, index: str) -> "OrganizationsOrganizationalUnitAccounts":
        """
        :param index: -
        """
        return jsii.invoke(self, "accounts", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="parentId")
    def parent_id(self) -> str:
        return jsii.get(self, "parentId")

    @parent_id.setter
    def parent_id(self, value: str) -> None:
        jsii.set(self, "parentId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


class OrganizationsOrganizationalUnitAccounts(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationalUnitAccounts",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            OrganizationsOrganizationalUnitAccounts,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> str:
        return jsii.get(self, "id")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsOrganizationalUnitConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "parent_id": "parentId",
    },
)
class OrganizationsOrganizationalUnitConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        parent_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param parent_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "parent_id": parent_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def parent_id(self) -> str:
        return self._values.get("parent_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationsOrganizationalUnitConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class OrganizationsPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        content: str,
        name: str,
        description: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param content: 
        :param name: 
        :param description: 
        :param type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OrganizationsPolicyConfig(
            content=content,
            name=name,
            description=description,
            type=type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OrganizationsPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="content")
    def content(self) -> str:
        return jsii.get(self, "content")

    @content.setter
    def content(self, value: str) -> None:
        jsii.set(self, "content", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> typing.Optional[str]:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "type", value)


class OrganizationsPolicyAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsPolicyAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy_id: str,
        target_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy_id: 
        :param target_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = OrganizationsPolicyAttachmentConfig(
            policy_id=policy_id,
            target_id=target_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(OrganizationsPolicyAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policyId")
    def policy_id(self) -> str:
        return jsii.get(self, "policyId")

    @policy_id.setter
    def policy_id(self, value: str) -> None:
        jsii.set(self, "policyId", value)

    @builtins.property
    @jsii.member(jsii_name="targetId")
    def target_id(self) -> str:
        return jsii.get(self, "targetId")

    @target_id.setter
    def target_id(self, value: str) -> None:
        jsii.set(self, "targetId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsPolicyAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy_id": "policyId",
        "target_id": "targetId",
    },
)
class OrganizationsPolicyAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy_id: str,
        target_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy_id: 
        :param target_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy_id": policy_id,
            "target_id": target_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy_id(self) -> str:
        return self._values.get("policy_id")

    @builtins.property
    def target_id(self) -> str:
        return self._values.get("target_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationsPolicyAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.OrganizationsPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "content": "content",
        "name": "name",
        "description": "description",
        "type": "type",
    },
)
class OrganizationsPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        content: str,
        name: str,
        description: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param content: 
        :param name: 
        :param description: 
        :param type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "content": content,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def content(self) -> str:
        return self._values.get("content")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "OrganizationsPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointAdmChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointAdmChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        client_id: str,
        client_secret: str,
        enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param client_id: 
        :param client_secret: 
        :param enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointAdmChannelConfig(
            application_id=application_id,
            client_id=client_id,
            client_secret=client_secret,
            enabled=enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointAdmChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="clientId")
    def client_id(self) -> str:
        return jsii.get(self, "clientId")

    @client_id.setter
    def client_id(self, value: str) -> None:
        jsii.set(self, "clientId", value)

    @builtins.property
    @jsii.member(jsii_name="clientSecret")
    def client_secret(self) -> str:
        return jsii.get(self, "clientSecret")

    @client_secret.setter
    def client_secret(self, value: str) -> None:
        jsii.set(self, "clientSecret", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointAdmChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "client_id": "clientId",
        "client_secret": "clientSecret",
        "enabled": "enabled",
    },
)
class PinpointAdmChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        client_id: str,
        client_secret: str,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param client_id: 
        :param client_secret: 
        :param enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
            "client_id": client_id,
            "client_secret": client_secret,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def client_id(self) -> str:
        return self._values.get("client_id")

    @builtins.property
    def client_secret(self) -> str:
        return self._values.get("client_secret")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointAdmChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointApnsChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointApnsChannelConfig(
            application_id=application_id,
            bundle_id=bundle_id,
            certificate=certificate,
            default_authentication_method=default_authentication_method,
            enabled=enabled,
            private_key=private_key,
            team_id=team_id,
            token_key=token_key,
            token_key_id=token_key_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointApnsChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> typing.Optional[str]:
        return jsii.get(self, "bundleId")

    @bundle_id.setter
    def bundle_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bundleId", value)

    @builtins.property
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> typing.Optional[str]:
        return jsii.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property
    @jsii.member(jsii_name="defaultAuthenticationMethod")
    def default_authentication_method(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultAuthenticationMethod")

    @default_authentication_method.setter
    def default_authentication_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultAuthenticationMethod", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> typing.Optional[str]:
        return jsii.get(self, "privateKey")

    @private_key.setter
    def private_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateKey", value)

    @builtins.property
    @jsii.member(jsii_name="teamId")
    def team_id(self) -> typing.Optional[str]:
        return jsii.get(self, "teamId")

    @team_id.setter
    def team_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "teamId", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKey")
    def token_key(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKey")

    @token_key.setter
    def token_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKey", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKeyId")
    def token_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKeyId")

    @token_key_id.setter
    def token_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKeyId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "bundle_id": "bundleId",
        "certificate": "certificate",
        "default_authentication_method": "defaultAuthenticationMethod",
        "enabled": "enabled",
        "private_key": "privateKey",
        "team_id": "teamId",
        "token_key": "tokenKey",
        "token_key_id": "tokenKeyId",
    },
)
class PinpointApnsChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bundle_id is not None:
            self._values["bundle_id"] = bundle_id
        if certificate is not None:
            self._values["certificate"] = certificate
        if default_authentication_method is not None:
            self._values[
                "default_authentication_method"
            ] = default_authentication_method
        if enabled is not None:
            self._values["enabled"] = enabled
        if private_key is not None:
            self._values["private_key"] = private_key
        if team_id is not None:
            self._values["team_id"] = team_id
        if token_key is not None:
            self._values["token_key"] = token_key
        if token_key_id is not None:
            self._values["token_key_id"] = token_key_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def bundle_id(self) -> typing.Optional[str]:
        return self._values.get("bundle_id")

    @builtins.property
    def certificate(self) -> typing.Optional[str]:
        return self._values.get("certificate")

    @builtins.property
    def default_authentication_method(self) -> typing.Optional[str]:
        return self._values.get("default_authentication_method")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def private_key(self) -> typing.Optional[str]:
        return self._values.get("private_key")

    @builtins.property
    def team_id(self) -> typing.Optional[str]:
        return self._values.get("team_id")

    @builtins.property
    def token_key(self) -> typing.Optional[str]:
        return self._values.get("token_key")

    @builtins.property
    def token_key_id(self) -> typing.Optional[str]:
        return self._values.get("token_key_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointApnsChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointApnsSandboxChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsSandboxChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointApnsSandboxChannelConfig(
            application_id=application_id,
            bundle_id=bundle_id,
            certificate=certificate,
            default_authentication_method=default_authentication_method,
            enabled=enabled,
            private_key=private_key,
            team_id=team_id,
            token_key=token_key,
            token_key_id=token_key_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointApnsSandboxChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> typing.Optional[str]:
        return jsii.get(self, "bundleId")

    @bundle_id.setter
    def bundle_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bundleId", value)

    @builtins.property
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> typing.Optional[str]:
        return jsii.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property
    @jsii.member(jsii_name="defaultAuthenticationMethod")
    def default_authentication_method(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultAuthenticationMethod")

    @default_authentication_method.setter
    def default_authentication_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultAuthenticationMethod", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> typing.Optional[str]:
        return jsii.get(self, "privateKey")

    @private_key.setter
    def private_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateKey", value)

    @builtins.property
    @jsii.member(jsii_name="teamId")
    def team_id(self) -> typing.Optional[str]:
        return jsii.get(self, "teamId")

    @team_id.setter
    def team_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "teamId", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKey")
    def token_key(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKey")

    @token_key.setter
    def token_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKey", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKeyId")
    def token_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKeyId")

    @token_key_id.setter
    def token_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKeyId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsSandboxChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "bundle_id": "bundleId",
        "certificate": "certificate",
        "default_authentication_method": "defaultAuthenticationMethod",
        "enabled": "enabled",
        "private_key": "privateKey",
        "team_id": "teamId",
        "token_key": "tokenKey",
        "token_key_id": "tokenKeyId",
    },
)
class PinpointApnsSandboxChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bundle_id is not None:
            self._values["bundle_id"] = bundle_id
        if certificate is not None:
            self._values["certificate"] = certificate
        if default_authentication_method is not None:
            self._values[
                "default_authentication_method"
            ] = default_authentication_method
        if enabled is not None:
            self._values["enabled"] = enabled
        if private_key is not None:
            self._values["private_key"] = private_key
        if team_id is not None:
            self._values["team_id"] = team_id
        if token_key is not None:
            self._values["token_key"] = token_key
        if token_key_id is not None:
            self._values["token_key_id"] = token_key_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def bundle_id(self) -> typing.Optional[str]:
        return self._values.get("bundle_id")

    @builtins.property
    def certificate(self) -> typing.Optional[str]:
        return self._values.get("certificate")

    @builtins.property
    def default_authentication_method(self) -> typing.Optional[str]:
        return self._values.get("default_authentication_method")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def private_key(self) -> typing.Optional[str]:
        return self._values.get("private_key")

    @builtins.property
    def team_id(self) -> typing.Optional[str]:
        return self._values.get("team_id")

    @builtins.property
    def token_key(self) -> typing.Optional[str]:
        return self._values.get("token_key")

    @builtins.property
    def token_key_id(self) -> typing.Optional[str]:
        return self._values.get("token_key_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointApnsSandboxChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointApnsVoipChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsVoipChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointApnsVoipChannelConfig(
            application_id=application_id,
            bundle_id=bundle_id,
            certificate=certificate,
            default_authentication_method=default_authentication_method,
            enabled=enabled,
            private_key=private_key,
            team_id=team_id,
            token_key=token_key,
            token_key_id=token_key_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointApnsVoipChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> typing.Optional[str]:
        return jsii.get(self, "bundleId")

    @bundle_id.setter
    def bundle_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bundleId", value)

    @builtins.property
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> typing.Optional[str]:
        return jsii.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property
    @jsii.member(jsii_name="defaultAuthenticationMethod")
    def default_authentication_method(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultAuthenticationMethod")

    @default_authentication_method.setter
    def default_authentication_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultAuthenticationMethod", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> typing.Optional[str]:
        return jsii.get(self, "privateKey")

    @private_key.setter
    def private_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateKey", value)

    @builtins.property
    @jsii.member(jsii_name="teamId")
    def team_id(self) -> typing.Optional[str]:
        return jsii.get(self, "teamId")

    @team_id.setter
    def team_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "teamId", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKey")
    def token_key(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKey")

    @token_key.setter
    def token_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKey", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKeyId")
    def token_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKeyId")

    @token_key_id.setter
    def token_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKeyId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsVoipChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "bundle_id": "bundleId",
        "certificate": "certificate",
        "default_authentication_method": "defaultAuthenticationMethod",
        "enabled": "enabled",
        "private_key": "privateKey",
        "team_id": "teamId",
        "token_key": "tokenKey",
        "token_key_id": "tokenKeyId",
    },
)
class PinpointApnsVoipChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bundle_id is not None:
            self._values["bundle_id"] = bundle_id
        if certificate is not None:
            self._values["certificate"] = certificate
        if default_authentication_method is not None:
            self._values[
                "default_authentication_method"
            ] = default_authentication_method
        if enabled is not None:
            self._values["enabled"] = enabled
        if private_key is not None:
            self._values["private_key"] = private_key
        if team_id is not None:
            self._values["team_id"] = team_id
        if token_key is not None:
            self._values["token_key"] = token_key
        if token_key_id is not None:
            self._values["token_key_id"] = token_key_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def bundle_id(self) -> typing.Optional[str]:
        return self._values.get("bundle_id")

    @builtins.property
    def certificate(self) -> typing.Optional[str]:
        return self._values.get("certificate")

    @builtins.property
    def default_authentication_method(self) -> typing.Optional[str]:
        return self._values.get("default_authentication_method")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def private_key(self) -> typing.Optional[str]:
        return self._values.get("private_key")

    @builtins.property
    def team_id(self) -> typing.Optional[str]:
        return self._values.get("team_id")

    @builtins.property
    def token_key(self) -> typing.Optional[str]:
        return self._values.get("token_key")

    @builtins.property
    def token_key_id(self) -> typing.Optional[str]:
        return self._values.get("token_key_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointApnsVoipChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointApnsVoipSandboxChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsVoipSandboxChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointApnsVoipSandboxChannelConfig(
            application_id=application_id,
            bundle_id=bundle_id,
            certificate=certificate,
            default_authentication_method=default_authentication_method,
            enabled=enabled,
            private_key=private_key,
            team_id=team_id,
            token_key=token_key,
            token_key_id=token_key_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointApnsVoipSandboxChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> typing.Optional[str]:
        return jsii.get(self, "bundleId")

    @bundle_id.setter
    def bundle_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bundleId", value)

    @builtins.property
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> typing.Optional[str]:
        return jsii.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property
    @jsii.member(jsii_name="defaultAuthenticationMethod")
    def default_authentication_method(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultAuthenticationMethod")

    @default_authentication_method.setter
    def default_authentication_method(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultAuthenticationMethod", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="privateKey")
    def private_key(self) -> typing.Optional[str]:
        return jsii.get(self, "privateKey")

    @private_key.setter
    def private_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateKey", value)

    @builtins.property
    @jsii.member(jsii_name="teamId")
    def team_id(self) -> typing.Optional[str]:
        return jsii.get(self, "teamId")

    @team_id.setter
    def team_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "teamId", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKey")
    def token_key(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKey")

    @token_key.setter
    def token_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKey", value)

    @builtins.property
    @jsii.member(jsii_name="tokenKeyId")
    def token_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "tokenKeyId")

    @token_key_id.setter
    def token_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tokenKeyId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApnsVoipSandboxChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "bundle_id": "bundleId",
        "certificate": "certificate",
        "default_authentication_method": "defaultAuthenticationMethod",
        "enabled": "enabled",
        "private_key": "privateKey",
        "team_id": "teamId",
        "token_key": "tokenKey",
        "token_key_id": "tokenKeyId",
    },
)
class PinpointApnsVoipSandboxChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        bundle_id: typing.Optional[str] = None,
        certificate: typing.Optional[str] = None,
        default_authentication_method: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        private_key: typing.Optional[str] = None,
        team_id: typing.Optional[str] = None,
        token_key: typing.Optional[str] = None,
        token_key_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param bundle_id: 
        :param certificate: 
        :param default_authentication_method: 
        :param enabled: 
        :param private_key: 
        :param team_id: 
        :param token_key: 
        :param token_key_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if bundle_id is not None:
            self._values["bundle_id"] = bundle_id
        if certificate is not None:
            self._values["certificate"] = certificate
        if default_authentication_method is not None:
            self._values[
                "default_authentication_method"
            ] = default_authentication_method
        if enabled is not None:
            self._values["enabled"] = enabled
        if private_key is not None:
            self._values["private_key"] = private_key
        if team_id is not None:
            self._values["team_id"] = team_id
        if token_key is not None:
            self._values["token_key"] = token_key
        if token_key_id is not None:
            self._values["token_key_id"] = token_key_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def bundle_id(self) -> typing.Optional[str]:
        return self._values.get("bundle_id")

    @builtins.property
    def certificate(self) -> typing.Optional[str]:
        return self._values.get("certificate")

    @builtins.property
    def default_authentication_method(self) -> typing.Optional[str]:
        return self._values.get("default_authentication_method")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def private_key(self) -> typing.Optional[str]:
        return self._values.get("private_key")

    @builtins.property
    def team_id(self) -> typing.Optional[str]:
        return self._values.get("team_id")

    @builtins.property
    def token_key(self) -> typing.Optional[str]:
        return self._values.get("token_key")

    @builtins.property
    def token_key_id(self) -> typing.Optional[str]:
        return self._values.get("token_key_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointApnsVoipSandboxChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointApp(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointApp",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        campaign_hook: typing.Optional[typing.List["PinpointAppCampaignHook"]] = None,
        limits: typing.Optional[typing.List["PinpointAppLimits"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        quiet_time: typing.Optional[typing.List["PinpointAppQuietTime"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param campaign_hook: campaign_hook block.
        :param limits: limits block.
        :param name: 
        :param name_prefix: 
        :param quiet_time: quiet_time block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointAppConfig(
            campaign_hook=campaign_hook,
            limits=limits,
            name=name,
            name_prefix=name_prefix,
            quiet_time=quiet_time,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointApp, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="campaignHook")
    def campaign_hook(self) -> typing.Optional[typing.List["PinpointAppCampaignHook"]]:
        return jsii.get(self, "campaignHook")

    @campaign_hook.setter
    def campaign_hook(
        self, value: typing.Optional[typing.List["PinpointAppCampaignHook"]]
    ) -> None:
        jsii.set(self, "campaignHook", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="limits")
    def limits(self) -> typing.Optional[typing.List["PinpointAppLimits"]]:
        return jsii.get(self, "limits")

    @limits.setter
    def limits(self, value: typing.Optional[typing.List["PinpointAppLimits"]]) -> None:
        jsii.set(self, "limits", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="quietTime")
    def quiet_time(self) -> typing.Optional[typing.List["PinpointAppQuietTime"]]:
        return jsii.get(self, "quietTime")

    @quiet_time.setter
    def quiet_time(
        self, value: typing.Optional[typing.List["PinpointAppQuietTime"]]
    ) -> None:
        jsii.set(self, "quietTime", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointAppCampaignHook",
    jsii_struct_bases=[],
    name_mapping={
        "lambda_function_name": "lambdaFunctionName",
        "mode": "mode",
        "web_url": "webUrl",
    },
)
class PinpointAppCampaignHook:
    def __init__(
        self,
        *,
        lambda_function_name: typing.Optional[str] = None,
        mode: typing.Optional[str] = None,
        web_url: typing.Optional[str] = None,
    ) -> None:
        """
        :param lambda_function_name: 
        :param mode: 
        :param web_url: 
        """
        self._values = {}
        if lambda_function_name is not None:
            self._values["lambda_function_name"] = lambda_function_name
        if mode is not None:
            self._values["mode"] = mode
        if web_url is not None:
            self._values["web_url"] = web_url

    @builtins.property
    def lambda_function_name(self) -> typing.Optional[str]:
        return self._values.get("lambda_function_name")

    @builtins.property
    def mode(self) -> typing.Optional[str]:
        return self._values.get("mode")

    @builtins.property
    def web_url(self) -> typing.Optional[str]:
        return self._values.get("web_url")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointAppCampaignHook(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointAppConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "campaign_hook": "campaignHook",
        "limits": "limits",
        "name": "name",
        "name_prefix": "namePrefix",
        "quiet_time": "quietTime",
        "tags": "tags",
    },
)
class PinpointAppConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        campaign_hook: typing.Optional[typing.List["PinpointAppCampaignHook"]] = None,
        limits: typing.Optional[typing.List["PinpointAppLimits"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        quiet_time: typing.Optional[typing.List["PinpointAppQuietTime"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param campaign_hook: campaign_hook block.
        :param limits: limits block.
        :param name: 
        :param name_prefix: 
        :param quiet_time: quiet_time block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if campaign_hook is not None:
            self._values["campaign_hook"] = campaign_hook
        if limits is not None:
            self._values["limits"] = limits
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if quiet_time is not None:
            self._values["quiet_time"] = quiet_time
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def campaign_hook(self) -> typing.Optional[typing.List["PinpointAppCampaignHook"]]:
        """campaign_hook block."""
        return self._values.get("campaign_hook")

    @builtins.property
    def limits(self) -> typing.Optional[typing.List["PinpointAppLimits"]]:
        """limits block."""
        return self._values.get("limits")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def quiet_time(self) -> typing.Optional[typing.List["PinpointAppQuietTime"]]:
        """quiet_time block."""
        return self._values.get("quiet_time")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointAppConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointAppLimits",
    jsii_struct_bases=[],
    name_mapping={
        "daily": "daily",
        "maximum_duration": "maximumDuration",
        "messages_per_second": "messagesPerSecond",
        "total": "total",
    },
)
class PinpointAppLimits:
    def __init__(
        self,
        *,
        daily: typing.Optional[jsii.Number] = None,
        maximum_duration: typing.Optional[jsii.Number] = None,
        messages_per_second: typing.Optional[jsii.Number] = None,
        total: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param daily: 
        :param maximum_duration: 
        :param messages_per_second: 
        :param total: 
        """
        self._values = {}
        if daily is not None:
            self._values["daily"] = daily
        if maximum_duration is not None:
            self._values["maximum_duration"] = maximum_duration
        if messages_per_second is not None:
            self._values["messages_per_second"] = messages_per_second
        if total is not None:
            self._values["total"] = total

    @builtins.property
    def daily(self) -> typing.Optional[jsii.Number]:
        return self._values.get("daily")

    @builtins.property
    def maximum_duration(self) -> typing.Optional[jsii.Number]:
        return self._values.get("maximum_duration")

    @builtins.property
    def messages_per_second(self) -> typing.Optional[jsii.Number]:
        return self._values.get("messages_per_second")

    @builtins.property
    def total(self) -> typing.Optional[jsii.Number]:
        return self._values.get("total")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointAppLimits(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointAppQuietTime",
    jsii_struct_bases=[],
    name_mapping={"end": "end", "start": "start"},
)
class PinpointAppQuietTime:
    def __init__(
        self, *, end: typing.Optional[str] = None, start: typing.Optional[str] = None
    ) -> None:
        """
        :param end: 
        :param start: 
        """
        self._values = {}
        if end is not None:
            self._values["end"] = end
        if start is not None:
            self._values["start"] = start

    @builtins.property
    def end(self) -> typing.Optional[str]:
        return self._values.get("end")

    @builtins.property
    def start(self) -> typing.Optional[str]:
        return self._values.get("start")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointAppQuietTime(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointBaiduChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointBaiduChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_key: str,
        application_id: str,
        secret_key: str,
        enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_key: 
        :param application_id: 
        :param secret_key: 
        :param enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointBaiduChannelConfig(
            api_key=api_key,
            application_id=application_id,
            secret_key=secret_key,
            enabled=enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointBaiduChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiKey")
    def api_key(self) -> str:
        return jsii.get(self, "apiKey")

    @api_key.setter
    def api_key(self, value: str) -> None:
        jsii.set(self, "apiKey", value)

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="secretKey")
    def secret_key(self) -> str:
        return jsii.get(self, "secretKey")

    @secret_key.setter
    def secret_key(self, value: str) -> None:
        jsii.set(self, "secretKey", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointBaiduChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_key": "apiKey",
        "application_id": "applicationId",
        "secret_key": "secretKey",
        "enabled": "enabled",
    },
)
class PinpointBaiduChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_key: str,
        application_id: str,
        secret_key: str,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_key: 
        :param application_id: 
        :param secret_key: 
        :param enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_key": api_key,
            "application_id": application_id,
            "secret_key": secret_key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_key(self) -> str:
        return self._values.get("api_key")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def secret_key(self) -> str:
        return self._values.get("secret_key")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointBaiduChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointEmailChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointEmailChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        from_address: str,
        identity: str,
        role_arn: str,
        enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param from_address: 
        :param identity: 
        :param role_arn: 
        :param enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointEmailChannelConfig(
            application_id=application_id,
            from_address=from_address,
            identity=identity,
            role_arn=role_arn,
            enabled=enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointEmailChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="messagesPerSecond")
    def messages_per_second(self) -> jsii.Number:
        return jsii.get(self, "messagesPerSecond")

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="fromAddress")
    def from_address(self) -> str:
        return jsii.get(self, "fromAddress")

    @from_address.setter
    def from_address(self, value: str) -> None:
        jsii.set(self, "fromAddress", value)

    @builtins.property
    @jsii.member(jsii_name="identity")
    def identity(self) -> str:
        return jsii.get(self, "identity")

    @identity.setter
    def identity(self, value: str) -> None:
        jsii.set(self, "identity", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointEmailChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "from_address": "fromAddress",
        "identity": "identity",
        "role_arn": "roleArn",
        "enabled": "enabled",
    },
)
class PinpointEmailChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        from_address: str,
        identity: str,
        role_arn: str,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param from_address: 
        :param identity: 
        :param role_arn: 
        :param enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
            "from_address": from_address,
            "identity": identity,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def from_address(self) -> str:
        return self._values.get("from_address")

    @builtins.property
    def identity(self) -> str:
        return self._values.get("identity")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointEmailChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointEventStream(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointEventStream",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        destination_stream_arn: str,
        role_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param destination_stream_arn: 
        :param role_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointEventStreamConfig(
            application_id=application_id,
            destination_stream_arn=destination_stream_arn,
            role_arn=role_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointEventStream, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="destinationStreamArn")
    def destination_stream_arn(self) -> str:
        return jsii.get(self, "destinationStreamArn")

    @destination_stream_arn.setter
    def destination_stream_arn(self, value: str) -> None:
        jsii.set(self, "destinationStreamArn", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointEventStreamConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "destination_stream_arn": "destinationStreamArn",
        "role_arn": "roleArn",
    },
)
class PinpointEventStreamConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        destination_stream_arn: str,
        role_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param destination_stream_arn: 
        :param role_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
            "destination_stream_arn": destination_stream_arn,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def destination_stream_arn(self) -> str:
        return self._values.get("destination_stream_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointEventStreamConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointGcmChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointGcmChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        api_key: str,
        application_id: str,
        enabled: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param api_key: 
        :param application_id: 
        :param enabled: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointGcmChannelConfig(
            api_key=api_key,
            application_id=application_id,
            enabled=enabled,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointGcmChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="apiKey")
    def api_key(self) -> str:
        return jsii.get(self, "apiKey")

    @api_key.setter
    def api_key(self, value: str) -> None:
        jsii.set(self, "apiKey", value)

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointGcmChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "api_key": "apiKey",
        "application_id": "applicationId",
        "enabled": "enabled",
    },
)
class PinpointGcmChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        api_key: str,
        application_id: str,
        enabled: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param api_key: 
        :param application_id: 
        :param enabled: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "api_key": api_key,
            "application_id": application_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def api_key(self) -> str:
        return self._values.get("api_key")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointGcmChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PinpointSmsChannel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointSmsChannel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_id: str,
        enabled: typing.Optional[bool] = None,
        sender_id: typing.Optional[str] = None,
        short_code: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_id: 
        :param enabled: 
        :param sender_id: 
        :param short_code: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PinpointSmsChannelConfig(
            application_id=application_id,
            enabled=enabled,
            sender_id=sender_id,
            short_code=short_code,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PinpointSmsChannel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="promotionalMessagesPerSecond")
    def promotional_messages_per_second(self) -> jsii.Number:
        return jsii.get(self, "promotionalMessagesPerSecond")

    @builtins.property
    @jsii.member(jsii_name="transactionalMessagesPerSecond")
    def transactional_messages_per_second(self) -> jsii.Number:
        return jsii.get(self, "transactionalMessagesPerSecond")

    @builtins.property
    @jsii.member(jsii_name="applicationId")
    def application_id(self) -> str:
        return jsii.get(self, "applicationId")

    @application_id.setter
    def application_id(self, value: str) -> None:
        jsii.set(self, "applicationId", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="senderId")
    def sender_id(self) -> typing.Optional[str]:
        return jsii.get(self, "senderId")

    @sender_id.setter
    def sender_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "senderId", value)

    @builtins.property
    @jsii.member(jsii_name="shortCode")
    def short_code(self) -> typing.Optional[str]:
        return jsii.get(self, "shortCode")

    @short_code.setter
    def short_code(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "shortCode", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PinpointSmsChannelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_id": "applicationId",
        "enabled": "enabled",
        "sender_id": "senderId",
        "short_code": "shortCode",
    },
)
class PinpointSmsChannelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_id: str,
        enabled: typing.Optional[bool] = None,
        sender_id: typing.Optional[str] = None,
        short_code: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_id: 
        :param enabled: 
        :param sender_id: 
        :param short_code: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "application_id": application_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if sender_id is not None:
            self._values["sender_id"] = sender_id
        if short_code is not None:
            self._values["short_code"] = short_code

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_id(self) -> str:
        return self._values.get("application_id")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def sender_id(self) -> typing.Optional[str]:
        return self._values.get("sender_id")

    @builtins.property
    def short_code(self) -> typing.Optional[str]:
        return self._values.get("short_code")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PinpointSmsChannelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class PlacementGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.PlacementGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        strategy: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param strategy: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = PlacementGroupConfig(
            name=name,
            strategy=strategy,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(PlacementGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="placementGroupId")
    def placement_group_id(self) -> str:
        return jsii.get(self, "placementGroupId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="strategy")
    def strategy(self) -> str:
        return jsii.get(self, "strategy")

    @strategy.setter
    def strategy(self, value: str) -> None:
        jsii.set(self, "strategy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.PlacementGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "strategy": "strategy",
        "tags": "tags",
    },
)
class PlacementGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        strategy: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param strategy: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "strategy": strategy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def strategy(self) -> str:
        return self._values.get("strategy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "PlacementGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ProxyProtocolPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ProxyProtocolPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        instance_ports: typing.List[str],
        load_balancer: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param instance_ports: 
        :param load_balancer: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ProxyProtocolPolicyConfig(
            instance_ports=instance_ports,
            load_balancer=load_balancer,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ProxyProtocolPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="instancePorts")
    def instance_ports(self) -> typing.List[str]:
        return jsii.get(self, "instancePorts")

    @instance_ports.setter
    def instance_ports(self, value: typing.List[str]) -> None:
        jsii.set(self, "instancePorts", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancer")
    def load_balancer(self) -> str:
        return jsii.get(self, "loadBalancer")

    @load_balancer.setter
    def load_balancer(self, value: str) -> None:
        jsii.set(self, "loadBalancer", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ProxyProtocolPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "instance_ports": "instancePorts",
        "load_balancer": "loadBalancer",
    },
)
class ProxyProtocolPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        instance_ports: typing.List[str],
        load_balancer: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param instance_ports: 
        :param load_balancer: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "instance_ports": instance_ports,
            "load_balancer": load_balancer,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def instance_ports(self) -> typing.List[str]:
        return self._values.get("instance_ports")

    @builtins.property
    def load_balancer(self) -> str:
        return self._values.get("load_balancer")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ProxyProtocolPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class QldbLedger(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.QldbLedger",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        deletion_protection: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param deletion_protection: 
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = QldbLedgerConfig(
            deletion_protection=deletion_protection,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(QldbLedger, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "deletionProtection")

    @deletion_protection.setter
    def deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.QldbLedgerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "deletion_protection": "deletionProtection",
        "name": "name",
        "tags": "tags",
    },
)
class QldbLedgerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        deletion_protection: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param deletion_protection: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("deletion_protection")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "QldbLedgerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class QuicksightGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.QuicksightGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        group_name: str,
        aws_account_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        namespace: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param group_name: 
        :param aws_account_id: 
        :param description: 
        :param namespace: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = QuicksightGroupConfig(
            group_name=group_name,
            aws_account_id=aws_account_id,
            description=description,
            namespace=namespace,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(QuicksightGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="groupName")
    def group_name(self) -> str:
        return jsii.get(self, "groupName")

    @group_name.setter
    def group_name(self, value: str) -> None:
        jsii.set(self, "groupName", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "awsAccountId")

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="namespace")
    def namespace(self) -> typing.Optional[str]:
        return jsii.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namespace", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.QuicksightGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "group_name": "groupName",
        "aws_account_id": "awsAccountId",
        "description": "description",
        "namespace": "namespace",
    },
)
class QuicksightGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        group_name: str,
        aws_account_id: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        namespace: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param group_name: 
        :param aws_account_id: 
        :param description: 
        :param namespace: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "group_name": group_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if description is not None:
            self._values["description"] = description
        if namespace is not None:
            self._values["namespace"] = namespace

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def group_name(self) -> str:
        return self._values.get("group_name")

    @builtins.property
    def aws_account_id(self) -> typing.Optional[str]:
        return self._values.get("aws_account_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def namespace(self) -> typing.Optional[str]:
        return self._values.get("namespace")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "QuicksightGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class QuicksightUser(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.QuicksightUser",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        email: str,
        identity_type: str,
        user_role: str,
        aws_account_id: typing.Optional[str] = None,
        iam_arn: typing.Optional[str] = None,
        namespace: typing.Optional[str] = None,
        session_name: typing.Optional[str] = None,
        user_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param email: 
        :param identity_type: 
        :param user_role: 
        :param aws_account_id: 
        :param iam_arn: 
        :param namespace: 
        :param session_name: 
        :param user_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = QuicksightUserConfig(
            email=email,
            identity_type=identity_type,
            user_role=user_role,
            aws_account_id=aws_account_id,
            iam_arn=iam_arn,
            namespace=namespace,
            session_name=session_name,
            user_name=user_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(QuicksightUser, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @email.setter
    def email(self, value: str) -> None:
        jsii.set(self, "email", value)

    @builtins.property
    @jsii.member(jsii_name="identityType")
    def identity_type(self) -> str:
        return jsii.get(self, "identityType")

    @identity_type.setter
    def identity_type(self, value: str) -> None:
        jsii.set(self, "identityType", value)

    @builtins.property
    @jsii.member(jsii_name="userRole")
    def user_role(self) -> str:
        return jsii.get(self, "userRole")

    @user_role.setter
    def user_role(self, value: str) -> None:
        jsii.set(self, "userRole", value)

    @builtins.property
    @jsii.member(jsii_name="awsAccountId")
    def aws_account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "awsAccountId")

    @aws_account_id.setter
    def aws_account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "awsAccountId", value)

    @builtins.property
    @jsii.member(jsii_name="iamArn")
    def iam_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "iamArn")

    @iam_arn.setter
    def iam_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="namespace")
    def namespace(self) -> typing.Optional[str]:
        return jsii.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namespace", value)

    @builtins.property
    @jsii.member(jsii_name="sessionName")
    def session_name(self) -> typing.Optional[str]:
        return jsii.get(self, "sessionName")

    @session_name.setter
    def session_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sessionName", value)

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> typing.Optional[str]:
        return jsii.get(self, "userName")

    @user_name.setter
    def user_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.QuicksightUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "email": "email",
        "identity_type": "identityType",
        "user_role": "userRole",
        "aws_account_id": "awsAccountId",
        "iam_arn": "iamArn",
        "namespace": "namespace",
        "session_name": "sessionName",
        "user_name": "userName",
    },
)
class QuicksightUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        email: str,
        identity_type: str,
        user_role: str,
        aws_account_id: typing.Optional[str] = None,
        iam_arn: typing.Optional[str] = None,
        namespace: typing.Optional[str] = None,
        session_name: typing.Optional[str] = None,
        user_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param email: 
        :param identity_type: 
        :param user_role: 
        :param aws_account_id: 
        :param iam_arn: 
        :param namespace: 
        :param session_name: 
        :param user_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "email": email,
            "identity_type": identity_type,
            "user_role": user_role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if aws_account_id is not None:
            self._values["aws_account_id"] = aws_account_id
        if iam_arn is not None:
            self._values["iam_arn"] = iam_arn
        if namespace is not None:
            self._values["namespace"] = namespace
        if session_name is not None:
            self._values["session_name"] = session_name
        if user_name is not None:
            self._values["user_name"] = user_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def email(self) -> str:
        return self._values.get("email")

    @builtins.property
    def identity_type(self) -> str:
        return self._values.get("identity_type")

    @builtins.property
    def user_role(self) -> str:
        return self._values.get("user_role")

    @builtins.property
    def aws_account_id(self) -> typing.Optional[str]:
        return self._values.get("aws_account_id")

    @builtins.property
    def iam_arn(self) -> typing.Optional[str]:
        return self._values.get("iam_arn")

    @builtins.property
    def namespace(self) -> typing.Optional[str]:
        return self._values.get("namespace")

    @builtins.property
    def session_name(self) -> typing.Optional[str]:
        return self._values.get("session_name")

    @builtins.property
    def user_name(self) -> typing.Optional[str]:
        return self._values.get("user_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "QuicksightUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RamPrincipalAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RamPrincipalAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        principal: str,
        resource_share_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param principal: 
        :param resource_share_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RamPrincipalAssociationConfig(
            principal=principal,
            resource_share_arn=resource_share_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RamPrincipalAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="principal")
    def principal(self) -> str:
        return jsii.get(self, "principal")

    @principal.setter
    def principal(self, value: str) -> None:
        jsii.set(self, "principal", value)

    @builtins.property
    @jsii.member(jsii_name="resourceShareArn")
    def resource_share_arn(self) -> str:
        return jsii.get(self, "resourceShareArn")

    @resource_share_arn.setter
    def resource_share_arn(self, value: str) -> None:
        jsii.set(self, "resourceShareArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RamPrincipalAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "principal": "principal",
        "resource_share_arn": "resourceShareArn",
    },
)
class RamPrincipalAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        principal: str,
        resource_share_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param principal: 
        :param resource_share_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "principal": principal,
            "resource_share_arn": resource_share_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def principal(self) -> str:
        return self._values.get("principal")

    @builtins.property
    def resource_share_arn(self) -> str:
        return self._values.get("resource_share_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RamPrincipalAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RamResourceAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        resource_arn: str,
        resource_share_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_arn: 
        :param resource_share_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RamResourceAssociationConfig(
            resource_arn=resource_arn,
            resource_share_arn=resource_share_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RamResourceAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resourceArn")
    def resource_arn(self) -> str:
        return jsii.get(self, "resourceArn")

    @resource_arn.setter
    def resource_arn(self, value: str) -> None:
        jsii.set(self, "resourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="resourceShareArn")
    def resource_share_arn(self) -> str:
        return jsii.get(self, "resourceShareArn")

    @resource_share_arn.setter
    def resource_share_arn(self, value: str) -> None:
        jsii.set(self, "resourceShareArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_arn": "resourceArn",
        "resource_share_arn": "resourceShareArn",
    },
)
class RamResourceAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_arn: str,
        resource_share_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_arn: 
        :param resource_share_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "resource_arn": resource_arn,
            "resource_share_arn": resource_share_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def resource_share_arn(self) -> str:
        return self._values.get("resource_share_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RamResourceAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RamResourceShare(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceShare",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        allow_external_principals: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RamResourceShareTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param allow_external_principals: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RamResourceShareConfig(
            name=name,
            allow_external_principals=allow_external_principals,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RamResourceShare, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="allowExternalPrincipals")
    def allow_external_principals(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowExternalPrincipals")

    @allow_external_principals.setter
    def allow_external_principals(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowExternalPrincipals", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RamResourceShareTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["RamResourceShareTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class RamResourceShareAccepter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceShareAccepter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        share_arn: str,
        timeouts: typing.Optional["RamResourceShareAccepterTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param share_arn: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RamResourceShareAccepterConfig(
            share_arn=share_arn,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RamResourceShareAccepter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="invitationArn")
    def invitation_arn(self) -> str:
        return jsii.get(self, "invitationArn")

    @builtins.property
    @jsii.member(jsii_name="receiverAccountId")
    def receiver_account_id(self) -> str:
        return jsii.get(self, "receiverAccountId")

    @builtins.property
    @jsii.member(jsii_name="resources")
    def resources(self) -> typing.List[str]:
        return jsii.get(self, "resources")

    @builtins.property
    @jsii.member(jsii_name="senderAccountId")
    def sender_account_id(self) -> str:
        return jsii.get(self, "senderAccountId")

    @builtins.property
    @jsii.member(jsii_name="shareId")
    def share_id(self) -> str:
        return jsii.get(self, "shareId")

    @builtins.property
    @jsii.member(jsii_name="shareName")
    def share_name(self) -> str:
        return jsii.get(self, "shareName")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="shareArn")
    def share_arn(self) -> str:
        return jsii.get(self, "shareArn")

    @share_arn.setter
    def share_arn(self, value: str) -> None:
        jsii.set(self, "shareArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RamResourceShareAccepterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["RamResourceShareAccepterTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceShareAccepterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "share_arn": "shareArn",
        "timeouts": "timeouts",
    },
)
class RamResourceShareAccepterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        share_arn: str,
        timeouts: typing.Optional["RamResourceShareAccepterTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param share_arn: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RamResourceShareAccepterTimeouts(**timeouts)
        self._values = {
            "share_arn": share_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def share_arn(self) -> str:
        return self._values.get("share_arn")

    @builtins.property
    def timeouts(self) -> typing.Optional["RamResourceShareAccepterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RamResourceShareAccepterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceShareAccepterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class RamResourceShareAccepterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RamResourceShareAccepterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceShareConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "allow_external_principals": "allowExternalPrincipals",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class RamResourceShareConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        allow_external_principals: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RamResourceShareTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param allow_external_principals: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RamResourceShareTimeouts(**timeouts)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_external_principals is not None:
            self._values["allow_external_principals"] = allow_external_principals
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def allow_external_principals(self) -> typing.Optional[bool]:
        return self._values.get("allow_external_principals")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["RamResourceShareTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RamResourceShareConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RamResourceShareTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class RamResourceShareTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RamResourceShareTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RdsCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RdsCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        apply_immediately: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        backtrack_window: typing.Optional[jsii.Number] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        cluster_identifier: typing.Optional[str] = None,
        cluster_identifier_prefix: typing.Optional[str] = None,
        cluster_members: typing.Optional[typing.List[str]] = None,
        copy_tags_to_snapshot: typing.Optional[bool] = None,
        database_name: typing.Optional[str] = None,
        db_cluster_parameter_group_name: typing.Optional[str] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        enabled_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        enable_http_endpoint: typing.Optional[bool] = None,
        engine: typing.Optional[str] = None,
        engine_mode: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        global_cluster_identifier: typing.Optional[str] = None,
        iam_database_authentication_enabled: typing.Optional[bool] = None,
        iam_roles: typing.Optional[typing.List[str]] = None,
        kms_key_id: typing.Optional[str] = None,
        master_password: typing.Optional[str] = None,
        master_username: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        replication_source_identifier: typing.Optional[str] = None,
        s3_import: typing.Optional[typing.List["RdsClusterS3Import"]] = None,
        scaling_configuration: typing.Optional[
            typing.List["RdsClusterScalingConfiguration"]
        ] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        source_region: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RdsClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param apply_immediately: 
        :param availability_zones: 
        :param backtrack_window: 
        :param backup_retention_period: 
        :param cluster_identifier: 
        :param cluster_identifier_prefix: 
        :param cluster_members: 
        :param copy_tags_to_snapshot: 
        :param database_name: 
        :param db_cluster_parameter_group_name: 
        :param db_subnet_group_name: 
        :param deletion_protection: 
        :param enabled_cloudwatch_logs_exports: 
        :param enable_http_endpoint: 
        :param engine: 
        :param engine_mode: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param global_cluster_identifier: 
        :param iam_database_authentication_enabled: 
        :param iam_roles: 
        :param kms_key_id: 
        :param master_password: 
        :param master_username: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param replication_source_identifier: 
        :param s3_import: s3_import block.
        :param scaling_configuration: scaling_configuration block.
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param source_region: 
        :param storage_encrypted: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RdsClusterConfig(
            apply_immediately=apply_immediately,
            availability_zones=availability_zones,
            backtrack_window=backtrack_window,
            backup_retention_period=backup_retention_period,
            cluster_identifier=cluster_identifier,
            cluster_identifier_prefix=cluster_identifier_prefix,
            cluster_members=cluster_members,
            copy_tags_to_snapshot=copy_tags_to_snapshot,
            database_name=database_name,
            db_cluster_parameter_group_name=db_cluster_parameter_group_name,
            db_subnet_group_name=db_subnet_group_name,
            deletion_protection=deletion_protection,
            enabled_cloudwatch_logs_exports=enabled_cloudwatch_logs_exports,
            enable_http_endpoint=enable_http_endpoint,
            engine=engine,
            engine_mode=engine_mode,
            engine_version=engine_version,
            final_snapshot_identifier=final_snapshot_identifier,
            global_cluster_identifier=global_cluster_identifier,
            iam_database_authentication_enabled=iam_database_authentication_enabled,
            iam_roles=iam_roles,
            kms_key_id=kms_key_id,
            master_password=master_password,
            master_username=master_username,
            port=port,
            preferred_backup_window=preferred_backup_window,
            preferred_maintenance_window=preferred_maintenance_window,
            replication_source_identifier=replication_source_identifier,
            s3_import=s3_import,
            scaling_configuration=scaling_configuration,
            skip_final_snapshot=skip_final_snapshot,
            snapshot_identifier=snapshot_identifier,
            source_region=source_region,
            storage_encrypted=storage_encrypted,
            tags=tags,
            timeouts=timeouts,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RdsCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="clusterResourceId")
    def cluster_resource_id(self) -> str:
        return jsii.get(self, "clusterResourceId")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")

    @builtins.property
    @jsii.member(jsii_name="readerEndpoint")
    def reader_endpoint(self) -> str:
        return jsii.get(self, "readerEndpoint")

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "availabilityZones")

    @availability_zones.setter
    def availability_zones(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "availabilityZones", value)

    @builtins.property
    @jsii.member(jsii_name="backtrackWindow")
    def backtrack_window(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "backtrackWindow")

    @backtrack_window.setter
    def backtrack_window(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "backtrackWindow", value)

    @builtins.property
    @jsii.member(jsii_name="backupRetentionPeriod")
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "backupRetentionPeriod")

    @backup_retention_period.setter
    def backup_retention_period(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "backupRetentionPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifierPrefix")
    def cluster_identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterIdentifierPrefix")

    @cluster_identifier_prefix.setter
    def cluster_identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterIdentifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="clusterMembers")
    def cluster_members(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "clusterMembers")

    @cluster_members.setter
    def cluster_members(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "clusterMembers", value)

    @builtins.property
    @jsii.member(jsii_name="copyTagsToSnapshot")
    def copy_tags_to_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "copyTagsToSnapshot")

    @copy_tags_to_snapshot.setter
    def copy_tags_to_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "copyTagsToSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> typing.Optional[str]:
        return jsii.get(self, "databaseName")

    @database_name.setter
    def database_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property
    @jsii.member(jsii_name="dbClusterParameterGroupName")
    def db_cluster_parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dbClusterParameterGroupName")

    @db_cluster_parameter_group_name.setter
    def db_cluster_parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbClusterParameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="dbSubnetGroupName")
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dbSubnetGroupName")

    @db_subnet_group_name.setter
    def db_subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbSubnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "deletionProtection")

    @deletion_protection.setter
    def deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="enabledCloudwatchLogsExports")
    def enabled_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "enabledCloudwatchLogsExports")

    @enabled_cloudwatch_logs_exports.setter
    def enabled_cloudwatch_logs_exports(
        self, value: typing.Optional[typing.List[str]]
    ) -> None:
        jsii.set(self, "enabledCloudwatchLogsExports", value)

    @builtins.property
    @jsii.member(jsii_name="enableHttpEndpoint")
    def enable_http_endpoint(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableHttpEndpoint")

    @enable_http_endpoint.setter
    def enable_http_endpoint(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableHttpEndpoint", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineMode")
    def engine_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "engineMode")

    @engine_mode.setter
    def engine_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineMode", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="finalSnapshotIdentifier")
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "finalSnapshotIdentifier")

    @final_snapshot_identifier.setter
    def final_snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "finalSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="globalClusterIdentifier")
    def global_cluster_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "globalClusterIdentifier")

    @global_cluster_identifier.setter
    def global_cluster_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "globalClusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="iamDatabaseAuthenticationEnabled")
    def iam_database_authentication_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "iamDatabaseAuthenticationEnabled")

    @iam_database_authentication_enabled.setter
    def iam_database_authentication_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "iamDatabaseAuthenticationEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="iamRoles")
    def iam_roles(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "iamRoles")

    @iam_roles.setter
    def iam_roles(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "iamRoles", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="masterPassword")
    def master_password(self) -> typing.Optional[str]:
        return jsii.get(self, "masterPassword")

    @master_password.setter
    def master_password(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "masterPassword", value)

    @builtins.property
    @jsii.member(jsii_name="masterUsername")
    def master_username(self) -> typing.Optional[str]:
        return jsii.get(self, "masterUsername")

    @master_username.setter
    def master_username(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "masterUsername", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredBackupWindow")

    @preferred_backup_window.setter
    def preferred_backup_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredBackupWindow", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="replicationSourceIdentifier")
    def replication_source_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "replicationSourceIdentifier")

    @replication_source_identifier.setter
    def replication_source_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "replicationSourceIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="s3Import")
    def s3_import(self) -> typing.Optional[typing.List["RdsClusterS3Import"]]:
        return jsii.get(self, "s3Import")

    @s3_import.setter
    def s3_import(
        self, value: typing.Optional[typing.List["RdsClusterS3Import"]]
    ) -> None:
        jsii.set(self, "s3Import", value)

    @builtins.property
    @jsii.member(jsii_name="scalingConfiguration")
    def scaling_configuration(
        self,
    ) -> typing.Optional[typing.List["RdsClusterScalingConfiguration"]]:
        return jsii.get(self, "scalingConfiguration")

    @scaling_configuration.setter
    def scaling_configuration(
        self, value: typing.Optional[typing.List["RdsClusterScalingConfiguration"]]
    ) -> None:
        jsii.set(self, "scalingConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="skipFinalSnapshot")
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipFinalSnapshot")

    @skip_final_snapshot.setter
    def skip_final_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipFinalSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotIdentifier")
    def snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotIdentifier")

    @snapshot_identifier.setter
    def snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="sourceRegion")
    def source_region(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceRegion")

    @source_region.setter
    def source_region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceRegion", value)

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "storageEncrypted")

    @storage_encrypted.setter
    def storage_encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "storageEncrypted", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RdsClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["RdsClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "apply_immediately": "applyImmediately",
        "availability_zones": "availabilityZones",
        "backtrack_window": "backtrackWindow",
        "backup_retention_period": "backupRetentionPeriod",
        "cluster_identifier": "clusterIdentifier",
        "cluster_identifier_prefix": "clusterIdentifierPrefix",
        "cluster_members": "clusterMembers",
        "copy_tags_to_snapshot": "copyTagsToSnapshot",
        "database_name": "databaseName",
        "db_cluster_parameter_group_name": "dbClusterParameterGroupName",
        "db_subnet_group_name": "dbSubnetGroupName",
        "deletion_protection": "deletionProtection",
        "enabled_cloudwatch_logs_exports": "enabledCloudwatchLogsExports",
        "enable_http_endpoint": "enableHttpEndpoint",
        "engine": "engine",
        "engine_mode": "engineMode",
        "engine_version": "engineVersion",
        "final_snapshot_identifier": "finalSnapshotIdentifier",
        "global_cluster_identifier": "globalClusterIdentifier",
        "iam_database_authentication_enabled": "iamDatabaseAuthenticationEnabled",
        "iam_roles": "iamRoles",
        "kms_key_id": "kmsKeyId",
        "master_password": "masterPassword",
        "master_username": "masterUsername",
        "port": "port",
        "preferred_backup_window": "preferredBackupWindow",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "replication_source_identifier": "replicationSourceIdentifier",
        "s3_import": "s3Import",
        "scaling_configuration": "scalingConfiguration",
        "skip_final_snapshot": "skipFinalSnapshot",
        "snapshot_identifier": "snapshotIdentifier",
        "source_region": "sourceRegion",
        "storage_encrypted": "storageEncrypted",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class RdsClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        apply_immediately: typing.Optional[bool] = None,
        availability_zones: typing.Optional[typing.List[str]] = None,
        backtrack_window: typing.Optional[jsii.Number] = None,
        backup_retention_period: typing.Optional[jsii.Number] = None,
        cluster_identifier: typing.Optional[str] = None,
        cluster_identifier_prefix: typing.Optional[str] = None,
        cluster_members: typing.Optional[typing.List[str]] = None,
        copy_tags_to_snapshot: typing.Optional[bool] = None,
        database_name: typing.Optional[str] = None,
        db_cluster_parameter_group_name: typing.Optional[str] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        enabled_cloudwatch_logs_exports: typing.Optional[typing.List[str]] = None,
        enable_http_endpoint: typing.Optional[bool] = None,
        engine: typing.Optional[str] = None,
        engine_mode: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        global_cluster_identifier: typing.Optional[str] = None,
        iam_database_authentication_enabled: typing.Optional[bool] = None,
        iam_roles: typing.Optional[typing.List[str]] = None,
        kms_key_id: typing.Optional[str] = None,
        master_password: typing.Optional[str] = None,
        master_username: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        replication_source_identifier: typing.Optional[str] = None,
        s3_import: typing.Optional[typing.List["RdsClusterS3Import"]] = None,
        scaling_configuration: typing.Optional[
            typing.List["RdsClusterScalingConfiguration"]
        ] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_identifier: typing.Optional[str] = None,
        source_region: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RdsClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param apply_immediately: 
        :param availability_zones: 
        :param backtrack_window: 
        :param backup_retention_period: 
        :param cluster_identifier: 
        :param cluster_identifier_prefix: 
        :param cluster_members: 
        :param copy_tags_to_snapshot: 
        :param database_name: 
        :param db_cluster_parameter_group_name: 
        :param db_subnet_group_name: 
        :param deletion_protection: 
        :param enabled_cloudwatch_logs_exports: 
        :param enable_http_endpoint: 
        :param engine: 
        :param engine_mode: 
        :param engine_version: 
        :param final_snapshot_identifier: 
        :param global_cluster_identifier: 
        :param iam_database_authentication_enabled: 
        :param iam_roles: 
        :param kms_key_id: 
        :param master_password: 
        :param master_username: 
        :param port: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param replication_source_identifier: 
        :param s3_import: s3_import block.
        :param scaling_configuration: scaling_configuration block.
        :param skip_final_snapshot: 
        :param snapshot_identifier: 
        :param source_region: 
        :param storage_encrypted: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RdsClusterTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if availability_zones is not None:
            self._values["availability_zones"] = availability_zones
        if backtrack_window is not None:
            self._values["backtrack_window"] = backtrack_window
        if backup_retention_period is not None:
            self._values["backup_retention_period"] = backup_retention_period
        if cluster_identifier is not None:
            self._values["cluster_identifier"] = cluster_identifier
        if cluster_identifier_prefix is not None:
            self._values["cluster_identifier_prefix"] = cluster_identifier_prefix
        if cluster_members is not None:
            self._values["cluster_members"] = cluster_members
        if copy_tags_to_snapshot is not None:
            self._values["copy_tags_to_snapshot"] = copy_tags_to_snapshot
        if database_name is not None:
            self._values["database_name"] = database_name
        if db_cluster_parameter_group_name is not None:
            self._values[
                "db_cluster_parameter_group_name"
            ] = db_cluster_parameter_group_name
        if db_subnet_group_name is not None:
            self._values["db_subnet_group_name"] = db_subnet_group_name
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if enabled_cloudwatch_logs_exports is not None:
            self._values[
                "enabled_cloudwatch_logs_exports"
            ] = enabled_cloudwatch_logs_exports
        if enable_http_endpoint is not None:
            self._values["enable_http_endpoint"] = enable_http_endpoint
        if engine is not None:
            self._values["engine"] = engine
        if engine_mode is not None:
            self._values["engine_mode"] = engine_mode
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if final_snapshot_identifier is not None:
            self._values["final_snapshot_identifier"] = final_snapshot_identifier
        if global_cluster_identifier is not None:
            self._values["global_cluster_identifier"] = global_cluster_identifier
        if iam_database_authentication_enabled is not None:
            self._values[
                "iam_database_authentication_enabled"
            ] = iam_database_authentication_enabled
        if iam_roles is not None:
            self._values["iam_roles"] = iam_roles
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if master_password is not None:
            self._values["master_password"] = master_password
        if master_username is not None:
            self._values["master_username"] = master_username
        if port is not None:
            self._values["port"] = port
        if preferred_backup_window is not None:
            self._values["preferred_backup_window"] = preferred_backup_window
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if replication_source_identifier is not None:
            self._values[
                "replication_source_identifier"
            ] = replication_source_identifier
        if s3_import is not None:
            self._values["s3_import"] = s3_import
        if scaling_configuration is not None:
            self._values["scaling_configuration"] = scaling_configuration
        if skip_final_snapshot is not None:
            self._values["skip_final_snapshot"] = skip_final_snapshot
        if snapshot_identifier is not None:
            self._values["snapshot_identifier"] = snapshot_identifier
        if source_region is not None:
            self._values["source_region"] = source_region
        if storage_encrypted is not None:
            self._values["storage_encrypted"] = storage_encrypted
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def availability_zones(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("availability_zones")

    @builtins.property
    def backtrack_window(self) -> typing.Optional[jsii.Number]:
        return self._values.get("backtrack_window")

    @builtins.property
    def backup_retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("backup_retention_period")

    @builtins.property
    def cluster_identifier(self) -> typing.Optional[str]:
        return self._values.get("cluster_identifier")

    @builtins.property
    def cluster_identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("cluster_identifier_prefix")

    @builtins.property
    def cluster_members(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cluster_members")

    @builtins.property
    def copy_tags_to_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("copy_tags_to_snapshot")

    @builtins.property
    def database_name(self) -> typing.Optional[str]:
        return self._values.get("database_name")

    @builtins.property
    def db_cluster_parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("db_cluster_parameter_group_name")

    @builtins.property
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("db_subnet_group_name")

    @builtins.property
    def deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("deletion_protection")

    @builtins.property
    def enabled_cloudwatch_logs_exports(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("enabled_cloudwatch_logs_exports")

    @builtins.property
    def enable_http_endpoint(self) -> typing.Optional[bool]:
        return self._values.get("enable_http_endpoint")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_mode(self) -> typing.Optional[str]:
        return self._values.get("engine_mode")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("final_snapshot_identifier")

    @builtins.property
    def global_cluster_identifier(self) -> typing.Optional[str]:
        return self._values.get("global_cluster_identifier")

    @builtins.property
    def iam_database_authentication_enabled(self) -> typing.Optional[bool]:
        return self._values.get("iam_database_authentication_enabled")

    @builtins.property
    def iam_roles(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("iam_roles")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def master_password(self) -> typing.Optional[str]:
        return self._values.get("master_password")

    @builtins.property
    def master_username(self) -> typing.Optional[str]:
        return self._values.get("master_username")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def preferred_backup_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_backup_window")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def replication_source_identifier(self) -> typing.Optional[str]:
        return self._values.get("replication_source_identifier")

    @builtins.property
    def s3_import(self) -> typing.Optional[typing.List["RdsClusterS3Import"]]:
        """s3_import block."""
        return self._values.get("s3_import")

    @builtins.property
    def scaling_configuration(
        self,
    ) -> typing.Optional[typing.List["RdsClusterScalingConfiguration"]]:
        """scaling_configuration block."""
        return self._values.get("scaling_configuration")

    @builtins.property
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("skip_final_snapshot")

    @builtins.property
    def snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("snapshot_identifier")

    @builtins.property
    def source_region(self) -> typing.Optional[str]:
        return self._values.get("source_region")

    @builtins.property
    def storage_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("storage_encrypted")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["RdsClusterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RdsClusterEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_endpoint_identifier: str,
        cluster_identifier: str,
        custom_endpoint_type: str,
        excluded_members: typing.Optional[typing.List[str]] = None,
        static_members: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_endpoint_identifier: 
        :param cluster_identifier: 
        :param custom_endpoint_type: 
        :param excluded_members: 
        :param static_members: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RdsClusterEndpointConfig(
            cluster_endpoint_identifier=cluster_endpoint_identifier,
            cluster_identifier=cluster_identifier,
            custom_endpoint_type=custom_endpoint_type,
            excluded_members=excluded_members,
            static_members=static_members,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RdsClusterEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="clusterEndpointIdentifier")
    def cluster_endpoint_identifier(self) -> str:
        return jsii.get(self, "clusterEndpointIdentifier")

    @cluster_endpoint_identifier.setter
    def cluster_endpoint_identifier(self, value: str) -> None:
        jsii.set(self, "clusterEndpointIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="customEndpointType")
    def custom_endpoint_type(self) -> str:
        return jsii.get(self, "customEndpointType")

    @custom_endpoint_type.setter
    def custom_endpoint_type(self, value: str) -> None:
        jsii.set(self, "customEndpointType", value)

    @builtins.property
    @jsii.member(jsii_name="excludedMembers")
    def excluded_members(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "excludedMembers")

    @excluded_members.setter
    def excluded_members(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "excludedMembers", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="staticMembers")
    def static_members(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "staticMembers")

    @static_members.setter
    def static_members(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "staticMembers", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_endpoint_identifier": "clusterEndpointIdentifier",
        "cluster_identifier": "clusterIdentifier",
        "custom_endpoint_type": "customEndpointType",
        "excluded_members": "excludedMembers",
        "static_members": "staticMembers",
        "tags": "tags",
    },
)
class RdsClusterEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_endpoint_identifier: str,
        cluster_identifier: str,
        custom_endpoint_type: str,
        excluded_members: typing.Optional[typing.List[str]] = None,
        static_members: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_endpoint_identifier: 
        :param cluster_identifier: 
        :param custom_endpoint_type: 
        :param excluded_members: 
        :param static_members: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_endpoint_identifier": cluster_endpoint_identifier,
            "cluster_identifier": cluster_identifier,
            "custom_endpoint_type": custom_endpoint_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if excluded_members is not None:
            self._values["excluded_members"] = excluded_members
        if static_members is not None:
            self._values["static_members"] = static_members
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_endpoint_identifier(self) -> str:
        return self._values.get("cluster_endpoint_identifier")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def custom_endpoint_type(self) -> str:
        return self._values.get("custom_endpoint_type")

    @builtins.property
    def excluded_members(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("excluded_members")

    @builtins.property
    def static_members(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("static_members")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RdsClusterInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_identifier: str,
        instance_class: str,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        ca_cert_identifier: typing.Optional[str] = None,
        copy_tags_to_snapshot: typing.Optional[bool] = None,
        db_parameter_group_name: typing.Optional[str] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        monitoring_interval: typing.Optional[jsii.Number] = None,
        monitoring_role_arn: typing.Optional[str] = None,
        performance_insights_enabled: typing.Optional[bool] = None,
        performance_insights_kms_key_id: typing.Optional[str] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        promotion_tier: typing.Optional[jsii.Number] = None,
        publicly_accessible: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RdsClusterInstanceTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_identifier: 
        :param instance_class: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param ca_cert_identifier: 
        :param copy_tags_to_snapshot: 
        :param db_parameter_group_name: 
        :param db_subnet_group_name: 
        :param engine: 
        :param engine_version: 
        :param identifier: 
        :param identifier_prefix: 
        :param monitoring_interval: 
        :param monitoring_role_arn: 
        :param performance_insights_enabled: 
        :param performance_insights_kms_key_id: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param promotion_tier: 
        :param publicly_accessible: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RdsClusterInstanceConfig(
            cluster_identifier=cluster_identifier,
            instance_class=instance_class,
            apply_immediately=apply_immediately,
            auto_minor_version_upgrade=auto_minor_version_upgrade,
            availability_zone=availability_zone,
            ca_cert_identifier=ca_cert_identifier,
            copy_tags_to_snapshot=copy_tags_to_snapshot,
            db_parameter_group_name=db_parameter_group_name,
            db_subnet_group_name=db_subnet_group_name,
            engine=engine,
            engine_version=engine_version,
            identifier=identifier,
            identifier_prefix=identifier_prefix,
            monitoring_interval=monitoring_interval,
            monitoring_role_arn=monitoring_role_arn,
            performance_insights_enabled=performance_insights_enabled,
            performance_insights_kms_key_id=performance_insights_kms_key_id,
            preferred_backup_window=preferred_backup_window,
            preferred_maintenance_window=preferred_maintenance_window,
            promotion_tier=promotion_tier,
            publicly_accessible=publicly_accessible,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RdsClusterInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dbiResourceId")
    def dbi_resource_id(self) -> str:
        return jsii.get(self, "dbiResourceId")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> str:
        return jsii.get(self, "kmsKeyId")

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> jsii.Number:
        return jsii.get(self, "port")

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> bool:
        return jsii.get(self, "storageEncrypted")

    @builtins.property
    @jsii.member(jsii_name="writer")
    def writer(self) -> bool:
        return jsii.get(self, "writer")

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="instanceClass")
    def instance_class(self) -> str:
        return jsii.get(self, "instanceClass")

    @instance_class.setter
    def instance_class(self, value: str) -> None:
        jsii.set(self, "instanceClass", value)

    @builtins.property
    @jsii.member(jsii_name="applyImmediately")
    def apply_immediately(self) -> typing.Optional[bool]:
        return jsii.get(self, "applyImmediately")

    @apply_immediately.setter
    def apply_immediately(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "applyImmediately", value)

    @builtins.property
    @jsii.member(jsii_name="autoMinorVersionUpgrade")
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoMinorVersionUpgrade")

    @auto_minor_version_upgrade.setter
    def auto_minor_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoMinorVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="caCertIdentifier")
    def ca_cert_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "caCertIdentifier")

    @ca_cert_identifier.setter
    def ca_cert_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "caCertIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="copyTagsToSnapshot")
    def copy_tags_to_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "copyTagsToSnapshot")

    @copy_tags_to_snapshot.setter
    def copy_tags_to_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "copyTagsToSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="dbParameterGroupName")
    def db_parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dbParameterGroupName")

    @db_parameter_group_name.setter
    def db_parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbParameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="dbSubnetGroupName")
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "dbSubnetGroupName")

    @db_subnet_group_name.setter
    def db_subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "dbSubnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property
    @jsii.member(jsii_name="identifierPrefix")
    def identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "identifierPrefix")

    @identifier_prefix.setter
    def identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="monitoringInterval")
    def monitoring_interval(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "monitoringInterval")

    @monitoring_interval.setter
    def monitoring_interval(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "monitoringInterval", value)

    @builtins.property
    @jsii.member(jsii_name="monitoringRoleArn")
    def monitoring_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "monitoringRoleArn")

    @monitoring_role_arn.setter
    def monitoring_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "monitoringRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="performanceInsightsEnabled")
    def performance_insights_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "performanceInsightsEnabled")

    @performance_insights_enabled.setter
    def performance_insights_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "performanceInsightsEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="performanceInsightsKmsKeyId")
    def performance_insights_kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "performanceInsightsKmsKeyId")

    @performance_insights_kms_key_id.setter
    def performance_insights_kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "performanceInsightsKmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="preferredBackupWindow")
    def preferred_backup_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredBackupWindow")

    @preferred_backup_window.setter
    def preferred_backup_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredBackupWindow", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="promotionTier")
    def promotion_tier(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "promotionTier")

    @promotion_tier.setter
    def promotion_tier(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "promotionTier", value)

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> typing.Optional[bool]:
        return jsii.get(self, "publiclyAccessible")

    @publicly_accessible.setter
    def publicly_accessible(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "publiclyAccessible", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RdsClusterInstanceTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["RdsClusterInstanceTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_identifier": "clusterIdentifier",
        "instance_class": "instanceClass",
        "apply_immediately": "applyImmediately",
        "auto_minor_version_upgrade": "autoMinorVersionUpgrade",
        "availability_zone": "availabilityZone",
        "ca_cert_identifier": "caCertIdentifier",
        "copy_tags_to_snapshot": "copyTagsToSnapshot",
        "db_parameter_group_name": "dbParameterGroupName",
        "db_subnet_group_name": "dbSubnetGroupName",
        "engine": "engine",
        "engine_version": "engineVersion",
        "identifier": "identifier",
        "identifier_prefix": "identifierPrefix",
        "monitoring_interval": "monitoringInterval",
        "monitoring_role_arn": "monitoringRoleArn",
        "performance_insights_enabled": "performanceInsightsEnabled",
        "performance_insights_kms_key_id": "performanceInsightsKmsKeyId",
        "preferred_backup_window": "preferredBackupWindow",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "promotion_tier": "promotionTier",
        "publicly_accessible": "publiclyAccessible",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class RdsClusterInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_identifier: str,
        instance_class: str,
        apply_immediately: typing.Optional[bool] = None,
        auto_minor_version_upgrade: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        ca_cert_identifier: typing.Optional[str] = None,
        copy_tags_to_snapshot: typing.Optional[bool] = None,
        db_parameter_group_name: typing.Optional[str] = None,
        db_subnet_group_name: typing.Optional[str] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        monitoring_interval: typing.Optional[jsii.Number] = None,
        monitoring_role_arn: typing.Optional[str] = None,
        performance_insights_enabled: typing.Optional[bool] = None,
        performance_insights_kms_key_id: typing.Optional[str] = None,
        preferred_backup_window: typing.Optional[str] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        promotion_tier: typing.Optional[jsii.Number] = None,
        publicly_accessible: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RdsClusterInstanceTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_identifier: 
        :param instance_class: 
        :param apply_immediately: 
        :param auto_minor_version_upgrade: 
        :param availability_zone: 
        :param ca_cert_identifier: 
        :param copy_tags_to_snapshot: 
        :param db_parameter_group_name: 
        :param db_subnet_group_name: 
        :param engine: 
        :param engine_version: 
        :param identifier: 
        :param identifier_prefix: 
        :param monitoring_interval: 
        :param monitoring_role_arn: 
        :param performance_insights_enabled: 
        :param performance_insights_kms_key_id: 
        :param preferred_backup_window: 
        :param preferred_maintenance_window: 
        :param promotion_tier: 
        :param publicly_accessible: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RdsClusterInstanceTimeouts(**timeouts)
        self._values = {
            "cluster_identifier": cluster_identifier,
            "instance_class": instance_class,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if apply_immediately is not None:
            self._values["apply_immediately"] = apply_immediately
        if auto_minor_version_upgrade is not None:
            self._values["auto_minor_version_upgrade"] = auto_minor_version_upgrade
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if ca_cert_identifier is not None:
            self._values["ca_cert_identifier"] = ca_cert_identifier
        if copy_tags_to_snapshot is not None:
            self._values["copy_tags_to_snapshot"] = copy_tags_to_snapshot
        if db_parameter_group_name is not None:
            self._values["db_parameter_group_name"] = db_parameter_group_name
        if db_subnet_group_name is not None:
            self._values["db_subnet_group_name"] = db_subnet_group_name
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if identifier is not None:
            self._values["identifier"] = identifier
        if identifier_prefix is not None:
            self._values["identifier_prefix"] = identifier_prefix
        if monitoring_interval is not None:
            self._values["monitoring_interval"] = monitoring_interval
        if monitoring_role_arn is not None:
            self._values["monitoring_role_arn"] = monitoring_role_arn
        if performance_insights_enabled is not None:
            self._values["performance_insights_enabled"] = performance_insights_enabled
        if performance_insights_kms_key_id is not None:
            self._values[
                "performance_insights_kms_key_id"
            ] = performance_insights_kms_key_id
        if preferred_backup_window is not None:
            self._values["preferred_backup_window"] = preferred_backup_window
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if promotion_tier is not None:
            self._values["promotion_tier"] = promotion_tier
        if publicly_accessible is not None:
            self._values["publicly_accessible"] = publicly_accessible
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def instance_class(self) -> str:
        return self._values.get("instance_class")

    @builtins.property
    def apply_immediately(self) -> typing.Optional[bool]:
        return self._values.get("apply_immediately")

    @builtins.property
    def auto_minor_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("auto_minor_version_upgrade")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def ca_cert_identifier(self) -> typing.Optional[str]:
        return self._values.get("ca_cert_identifier")

    @builtins.property
    def copy_tags_to_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("copy_tags_to_snapshot")

    @builtins.property
    def db_parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("db_parameter_group_name")

    @builtins.property
    def db_subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("db_subnet_group_name")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def identifier(self) -> typing.Optional[str]:
        return self._values.get("identifier")

    @builtins.property
    def identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("identifier_prefix")

    @builtins.property
    def monitoring_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("monitoring_interval")

    @builtins.property
    def monitoring_role_arn(self) -> typing.Optional[str]:
        return self._values.get("monitoring_role_arn")

    @builtins.property
    def performance_insights_enabled(self) -> typing.Optional[bool]:
        return self._values.get("performance_insights_enabled")

    @builtins.property
    def performance_insights_kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("performance_insights_kms_key_id")

    @builtins.property
    def preferred_backup_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_backup_window")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def promotion_tier(self) -> typing.Optional[jsii.Number]:
        return self._values.get("promotion_tier")

    @builtins.property
    def publicly_accessible(self) -> typing.Optional[bool]:
        return self._values.get("publicly_accessible")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["RdsClusterInstanceTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterInstanceTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class RdsClusterInstanceTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterInstanceTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RdsClusterParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["RdsClusterParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RdsClusterParameterGroupConfig(
            family=family,
            description=description,
            name=name,
            name_prefix=name_prefix,
            parameter=parameter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RdsClusterParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="parameter")
    def parameter(
        self,
    ) -> typing.Optional[typing.List["RdsClusterParameterGroupParameter"]]:
        return jsii.get(self, "parameter")

    @parameter.setter
    def parameter(
        self, value: typing.Optional[typing.List["RdsClusterParameterGroupParameter"]]
    ) -> None:
        jsii.set(self, "parameter", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "parameter": "parameter",
        "tags": "tags",
    },
)
class RdsClusterParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["RdsClusterParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param parameter: parameter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "family": family,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if parameter is not None:
            self._values["parameter"] = parameter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[typing.List["RdsClusterParameterGroupParameter"]]:
        """parameter block."""
        return self._values.get("parameter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterParameterGroupParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value", "apply_method": "applyMethod"},
)
class RdsClusterParameterGroupParameter:
    def __init__(
        self, *, name: str, value: str, apply_method: typing.Optional[str] = None
    ) -> None:
        """
        :param name: 
        :param value: 
        :param apply_method: 
        """
        self._values = {
            "name": name,
            "value": value,
        }
        if apply_method is not None:
            self._values["apply_method"] = apply_method

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def apply_method(self) -> typing.Optional[str]:
        return self._values.get("apply_method")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterParameterGroupParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterS3Import",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_name": "bucketName",
        "ingestion_role": "ingestionRole",
        "source_engine": "sourceEngine",
        "source_engine_version": "sourceEngineVersion",
        "bucket_prefix": "bucketPrefix",
    },
)
class RdsClusterS3Import:
    def __init__(
        self,
        *,
        bucket_name: str,
        ingestion_role: str,
        source_engine: str,
        source_engine_version: str,
        bucket_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_name: 
        :param ingestion_role: 
        :param source_engine: 
        :param source_engine_version: 
        :param bucket_prefix: 
        """
        self._values = {
            "bucket_name": bucket_name,
            "ingestion_role": ingestion_role,
            "source_engine": source_engine,
            "source_engine_version": source_engine_version,
        }
        if bucket_prefix is not None:
            self._values["bucket_prefix"] = bucket_prefix

    @builtins.property
    def bucket_name(self) -> str:
        return self._values.get("bucket_name")

    @builtins.property
    def ingestion_role(self) -> str:
        return self._values.get("ingestion_role")

    @builtins.property
    def source_engine(self) -> str:
        return self._values.get("source_engine")

    @builtins.property
    def source_engine_version(self) -> str:
        return self._values.get("source_engine_version")

    @builtins.property
    def bucket_prefix(self) -> typing.Optional[str]:
        return self._values.get("bucket_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterS3Import(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterScalingConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "auto_pause": "autoPause",
        "max_capacity": "maxCapacity",
        "min_capacity": "minCapacity",
        "seconds_until_auto_pause": "secondsUntilAutoPause",
        "timeout_action": "timeoutAction",
    },
)
class RdsClusterScalingConfiguration:
    def __init__(
        self,
        *,
        auto_pause: typing.Optional[bool] = None,
        max_capacity: typing.Optional[jsii.Number] = None,
        min_capacity: typing.Optional[jsii.Number] = None,
        seconds_until_auto_pause: typing.Optional[jsii.Number] = None,
        timeout_action: typing.Optional[str] = None,
    ) -> None:
        """
        :param auto_pause: 
        :param max_capacity: 
        :param min_capacity: 
        :param seconds_until_auto_pause: 
        :param timeout_action: 
        """
        self._values = {}
        if auto_pause is not None:
            self._values["auto_pause"] = auto_pause
        if max_capacity is not None:
            self._values["max_capacity"] = max_capacity
        if min_capacity is not None:
            self._values["min_capacity"] = min_capacity
        if seconds_until_auto_pause is not None:
            self._values["seconds_until_auto_pause"] = seconds_until_auto_pause
        if timeout_action is not None:
            self._values["timeout_action"] = timeout_action

    @builtins.property
    def auto_pause(self) -> typing.Optional[bool]:
        return self._values.get("auto_pause")

    @builtins.property
    def max_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_capacity")

    @builtins.property
    def min_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("min_capacity")

    @builtins.property
    def seconds_until_auto_pause(self) -> typing.Optional[jsii.Number]:
        return self._values.get("seconds_until_auto_pause")

    @builtins.property
    def timeout_action(self) -> typing.Optional[str]:
        return self._values.get("timeout_action")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterScalingConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class RdsClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RdsGlobalCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RdsGlobalCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        global_cluster_identifier: str,
        database_name: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param global_cluster_identifier: 
        :param database_name: 
        :param deletion_protection: 
        :param engine: 
        :param engine_version: 
        :param storage_encrypted: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RdsGlobalClusterConfig(
            global_cluster_identifier=global_cluster_identifier,
            database_name=database_name,
            deletion_protection=deletion_protection,
            engine=engine,
            engine_version=engine_version,
            storage_encrypted=storage_encrypted,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RdsGlobalCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="globalClusterResourceId")
    def global_cluster_resource_id(self) -> str:
        return jsii.get(self, "globalClusterResourceId")

    @builtins.property
    @jsii.member(jsii_name="globalClusterIdentifier")
    def global_cluster_identifier(self) -> str:
        return jsii.get(self, "globalClusterIdentifier")

    @global_cluster_identifier.setter
    def global_cluster_identifier(self, value: str) -> None:
        jsii.set(self, "globalClusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> typing.Optional[str]:
        return jsii.get(self, "databaseName")

    @database_name.setter
    def database_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property
    @jsii.member(jsii_name="deletionProtection")
    def deletion_protection(self) -> typing.Optional[bool]:
        return jsii.get(self, "deletionProtection")

    @deletion_protection.setter
    def deletion_protection(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "deletionProtection", value)

    @builtins.property
    @jsii.member(jsii_name="engine")
    def engine(self) -> typing.Optional[str]:
        return jsii.get(self, "engine")

    @engine.setter
    def engine(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engine", value)

    @builtins.property
    @jsii.member(jsii_name="engineVersion")
    def engine_version(self) -> typing.Optional[str]:
        return jsii.get(self, "engineVersion")

    @engine_version.setter
    def engine_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "engineVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="storageEncrypted")
    def storage_encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "storageEncrypted")

    @storage_encrypted.setter
    def storage_encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "storageEncrypted", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RdsGlobalClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "global_cluster_identifier": "globalClusterIdentifier",
        "database_name": "databaseName",
        "deletion_protection": "deletionProtection",
        "engine": "engine",
        "engine_version": "engineVersion",
        "storage_encrypted": "storageEncrypted",
    },
)
class RdsGlobalClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        global_cluster_identifier: str,
        database_name: typing.Optional[str] = None,
        deletion_protection: typing.Optional[bool] = None,
        engine: typing.Optional[str] = None,
        engine_version: typing.Optional[str] = None,
        storage_encrypted: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param global_cluster_identifier: 
        :param database_name: 
        :param deletion_protection: 
        :param engine: 
        :param engine_version: 
        :param storage_encrypted: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "global_cluster_identifier": global_cluster_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if database_name is not None:
            self._values["database_name"] = database_name
        if deletion_protection is not None:
            self._values["deletion_protection"] = deletion_protection
        if engine is not None:
            self._values["engine"] = engine
        if engine_version is not None:
            self._values["engine_version"] = engine_version
        if storage_encrypted is not None:
            self._values["storage_encrypted"] = storage_encrypted

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def global_cluster_identifier(self) -> str:
        return self._values.get("global_cluster_identifier")

    @builtins.property
    def database_name(self) -> typing.Optional[str]:
        return self._values.get("database_name")

    @builtins.property
    def deletion_protection(self) -> typing.Optional[bool]:
        return self._values.get("deletion_protection")

    @builtins.property
    def engine(self) -> typing.Optional[str]:
        return self._values.get("engine")

    @builtins.property
    def engine_version(self) -> typing.Optional[str]:
        return self._values.get("engine_version")

    @builtins.property
    def storage_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("storage_encrypted")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RdsGlobalClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftCluster(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftCluster",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_identifier: str,
        node_type: str,
        allow_version_upgrade: typing.Optional[bool] = None,
        automated_snapshot_retention_period: typing.Optional[jsii.Number] = None,
        availability_zone: typing.Optional[str] = None,
        bucket_name: typing.Optional[str] = None,
        cluster_parameter_group_name: typing.Optional[str] = None,
        cluster_public_key: typing.Optional[str] = None,
        cluster_revision_number: typing.Optional[str] = None,
        cluster_security_groups: typing.Optional[typing.List[str]] = None,
        cluster_subnet_group_name: typing.Optional[str] = None,
        cluster_type: typing.Optional[str] = None,
        cluster_version: typing.Optional[str] = None,
        database_name: typing.Optional[str] = None,
        elastic_ip: typing.Optional[str] = None,
        enable_logging: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        endpoint: typing.Optional[str] = None,
        enhanced_vpc_routing: typing.Optional[bool] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        iam_roles: typing.Optional[typing.List[str]] = None,
        kms_key_id: typing.Optional[str] = None,
        logging: typing.Optional[typing.List["RedshiftClusterLogging"]] = None,
        master_password: typing.Optional[str] = None,
        master_username: typing.Optional[str] = None,
        number_of_nodes: typing.Optional[jsii.Number] = None,
        owner_account: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        publicly_accessible: typing.Optional[bool] = None,
        s3_key_prefix: typing.Optional[str] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_cluster_identifier: typing.Optional[str] = None,
        snapshot_copy: typing.Optional[
            typing.List["RedshiftClusterSnapshotCopy"]
        ] = None,
        snapshot_identifier: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RedshiftClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_identifier: 
        :param node_type: 
        :param allow_version_upgrade: 
        :param automated_snapshot_retention_period: 
        :param availability_zone: 
        :param bucket_name: 
        :param cluster_parameter_group_name: 
        :param cluster_public_key: 
        :param cluster_revision_number: 
        :param cluster_security_groups: 
        :param cluster_subnet_group_name: 
        :param cluster_type: 
        :param cluster_version: 
        :param database_name: 
        :param elastic_ip: 
        :param enable_logging: 
        :param encrypted: 
        :param endpoint: 
        :param enhanced_vpc_routing: 
        :param final_snapshot_identifier: 
        :param iam_roles: 
        :param kms_key_id: 
        :param logging: logging block.
        :param master_password: 
        :param master_username: 
        :param number_of_nodes: 
        :param owner_account: 
        :param port: 
        :param preferred_maintenance_window: 
        :param publicly_accessible: 
        :param s3_key_prefix: 
        :param skip_final_snapshot: 
        :param snapshot_cluster_identifier: 
        :param snapshot_copy: snapshot_copy block.
        :param snapshot_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftClusterConfig(
            cluster_identifier=cluster_identifier,
            node_type=node_type,
            allow_version_upgrade=allow_version_upgrade,
            automated_snapshot_retention_period=automated_snapshot_retention_period,
            availability_zone=availability_zone,
            bucket_name=bucket_name,
            cluster_parameter_group_name=cluster_parameter_group_name,
            cluster_public_key=cluster_public_key,
            cluster_revision_number=cluster_revision_number,
            cluster_security_groups=cluster_security_groups,
            cluster_subnet_group_name=cluster_subnet_group_name,
            cluster_type=cluster_type,
            cluster_version=cluster_version,
            database_name=database_name,
            elastic_ip=elastic_ip,
            enable_logging=enable_logging,
            encrypted=encrypted,
            endpoint=endpoint,
            enhanced_vpc_routing=enhanced_vpc_routing,
            final_snapshot_identifier=final_snapshot_identifier,
            iam_roles=iam_roles,
            kms_key_id=kms_key_id,
            logging=logging,
            master_password=master_password,
            master_username=master_username,
            number_of_nodes=number_of_nodes,
            owner_account=owner_account,
            port=port,
            preferred_maintenance_window=preferred_maintenance_window,
            publicly_accessible=publicly_accessible,
            s3_key_prefix=s3_key_prefix,
            skip_final_snapshot=skip_final_snapshot,
            snapshot_cluster_identifier=snapshot_cluster_identifier,
            snapshot_copy=snapshot_copy,
            snapshot_identifier=snapshot_identifier,
            tags=tags,
            timeouts=timeouts,
            vpc_security_group_ids=vpc_security_group_ids,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftCluster, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="nodeType")
    def node_type(self) -> str:
        return jsii.get(self, "nodeType")

    @node_type.setter
    def node_type(self, value: str) -> None:
        jsii.set(self, "nodeType", value)

    @builtins.property
    @jsii.member(jsii_name="allowVersionUpgrade")
    def allow_version_upgrade(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowVersionUpgrade")

    @allow_version_upgrade.setter
    def allow_version_upgrade(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowVersionUpgrade", value)

    @builtins.property
    @jsii.member(jsii_name="automatedSnapshotRetentionPeriod")
    def automated_snapshot_retention_period(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "automatedSnapshotRetentionPeriod")

    @automated_snapshot_retention_period.setter
    def automated_snapshot_retention_period(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "automatedSnapshotRetentionPeriod", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="bucketName")
    def bucket_name(self) -> typing.Optional[str]:
        return jsii.get(self, "bucketName")

    @bucket_name.setter
    def bucket_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bucketName", value)

    @builtins.property
    @jsii.member(jsii_name="clusterParameterGroupName")
    def cluster_parameter_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterParameterGroupName")

    @cluster_parameter_group_name.setter
    def cluster_parameter_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterParameterGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="clusterPublicKey")
    def cluster_public_key(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterPublicKey")

    @cluster_public_key.setter
    def cluster_public_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterPublicKey", value)

    @builtins.property
    @jsii.member(jsii_name="clusterRevisionNumber")
    def cluster_revision_number(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterRevisionNumber")

    @cluster_revision_number.setter
    def cluster_revision_number(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterRevisionNumber", value)

    @builtins.property
    @jsii.member(jsii_name="clusterSecurityGroups")
    def cluster_security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "clusterSecurityGroups")

    @cluster_security_groups.setter
    def cluster_security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "clusterSecurityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="clusterSubnetGroupName")
    def cluster_subnet_group_name(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterSubnetGroupName")

    @cluster_subnet_group_name.setter
    def cluster_subnet_group_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterSubnetGroupName", value)

    @builtins.property
    @jsii.member(jsii_name="clusterType")
    def cluster_type(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterType")

    @cluster_type.setter
    def cluster_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterType", value)

    @builtins.property
    @jsii.member(jsii_name="clusterVersion")
    def cluster_version(self) -> typing.Optional[str]:
        return jsii.get(self, "clusterVersion")

    @cluster_version.setter
    def cluster_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "clusterVersion", value)

    @builtins.property
    @jsii.member(jsii_name="databaseName")
    def database_name(self) -> typing.Optional[str]:
        return jsii.get(self, "databaseName")

    @database_name.setter
    def database_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "databaseName", value)

    @builtins.property
    @jsii.member(jsii_name="elasticIp")
    def elastic_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "elasticIp")

    @elastic_ip.setter
    def elastic_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "elasticIp", value)

    @builtins.property
    @jsii.member(jsii_name="enableLogging")
    def enable_logging(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableLogging")

    @enable_logging.setter
    def enable_logging(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableLogging", value)

    @builtins.property
    @jsii.member(jsii_name="encrypted")
    def encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "encrypted")

    @encrypted.setter
    def encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "encrypted", value)

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> typing.Optional[str]:
        return jsii.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property
    @jsii.member(jsii_name="enhancedVpcRouting")
    def enhanced_vpc_routing(self) -> typing.Optional[bool]:
        return jsii.get(self, "enhancedVpcRouting")

    @enhanced_vpc_routing.setter
    def enhanced_vpc_routing(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enhancedVpcRouting", value)

    @builtins.property
    @jsii.member(jsii_name="finalSnapshotIdentifier")
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "finalSnapshotIdentifier")

    @final_snapshot_identifier.setter
    def final_snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "finalSnapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="iamRoles")
    def iam_roles(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "iamRoles")

    @iam_roles.setter
    def iam_roles(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "iamRoles", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="logging")
    def logging(self) -> typing.Optional[typing.List["RedshiftClusterLogging"]]:
        return jsii.get(self, "logging")

    @logging.setter
    def logging(
        self, value: typing.Optional[typing.List["RedshiftClusterLogging"]]
    ) -> None:
        jsii.set(self, "logging", value)

    @builtins.property
    @jsii.member(jsii_name="masterPassword")
    def master_password(self) -> typing.Optional[str]:
        return jsii.get(self, "masterPassword")

    @master_password.setter
    def master_password(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "masterPassword", value)

    @builtins.property
    @jsii.member(jsii_name="masterUsername")
    def master_username(self) -> typing.Optional[str]:
        return jsii.get(self, "masterUsername")

    @master_username.setter
    def master_username(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "masterUsername", value)

    @builtins.property
    @jsii.member(jsii_name="numberOfNodes")
    def number_of_nodes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "numberOfNodes")

    @number_of_nodes.setter
    def number_of_nodes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "numberOfNodes", value)

    @builtins.property
    @jsii.member(jsii_name="ownerAccount")
    def owner_account(self) -> typing.Optional[str]:
        return jsii.get(self, "ownerAccount")

    @owner_account.setter
    def owner_account(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ownerAccount", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="preferredMaintenanceWindow")
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return jsii.get(self, "preferredMaintenanceWindow")

    @preferred_maintenance_window.setter
    def preferred_maintenance_window(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "preferredMaintenanceWindow", value)

    @builtins.property
    @jsii.member(jsii_name="publiclyAccessible")
    def publicly_accessible(self) -> typing.Optional[bool]:
        return jsii.get(self, "publiclyAccessible")

    @publicly_accessible.setter
    def publicly_accessible(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "publiclyAccessible", value)

    @builtins.property
    @jsii.member(jsii_name="s3KeyPrefix")
    def s3_key_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "s3KeyPrefix")

    @s3_key_prefix.setter
    def s3_key_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "s3KeyPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="skipFinalSnapshot")
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipFinalSnapshot")

    @skip_final_snapshot.setter
    def skip_final_snapshot(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipFinalSnapshot", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotClusterIdentifier")
    def snapshot_cluster_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotClusterIdentifier")

    @snapshot_cluster_identifier.setter
    def snapshot_cluster_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotClusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotCopy")
    def snapshot_copy(
        self,
    ) -> typing.Optional[typing.List["RedshiftClusterSnapshotCopy"]]:
        return jsii.get(self, "snapshotCopy")

    @snapshot_copy.setter
    def snapshot_copy(
        self, value: typing.Optional[typing.List["RedshiftClusterSnapshotCopy"]]
    ) -> None:
        jsii.set(self, "snapshotCopy", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotIdentifier")
    def snapshot_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotIdentifier")

    @snapshot_identifier.setter
    def snapshot_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RedshiftClusterTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["RedshiftClusterTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftClusterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_identifier": "clusterIdentifier",
        "node_type": "nodeType",
        "allow_version_upgrade": "allowVersionUpgrade",
        "automated_snapshot_retention_period": "automatedSnapshotRetentionPeriod",
        "availability_zone": "availabilityZone",
        "bucket_name": "bucketName",
        "cluster_parameter_group_name": "clusterParameterGroupName",
        "cluster_public_key": "clusterPublicKey",
        "cluster_revision_number": "clusterRevisionNumber",
        "cluster_security_groups": "clusterSecurityGroups",
        "cluster_subnet_group_name": "clusterSubnetGroupName",
        "cluster_type": "clusterType",
        "cluster_version": "clusterVersion",
        "database_name": "databaseName",
        "elastic_ip": "elasticIp",
        "enable_logging": "enableLogging",
        "encrypted": "encrypted",
        "endpoint": "endpoint",
        "enhanced_vpc_routing": "enhancedVpcRouting",
        "final_snapshot_identifier": "finalSnapshotIdentifier",
        "iam_roles": "iamRoles",
        "kms_key_id": "kmsKeyId",
        "logging": "logging",
        "master_password": "masterPassword",
        "master_username": "masterUsername",
        "number_of_nodes": "numberOfNodes",
        "owner_account": "ownerAccount",
        "port": "port",
        "preferred_maintenance_window": "preferredMaintenanceWindow",
        "publicly_accessible": "publiclyAccessible",
        "s3_key_prefix": "s3KeyPrefix",
        "skip_final_snapshot": "skipFinalSnapshot",
        "snapshot_cluster_identifier": "snapshotClusterIdentifier",
        "snapshot_copy": "snapshotCopy",
        "snapshot_identifier": "snapshotIdentifier",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
    },
)
class RedshiftClusterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_identifier: str,
        node_type: str,
        allow_version_upgrade: typing.Optional[bool] = None,
        automated_snapshot_retention_period: typing.Optional[jsii.Number] = None,
        availability_zone: typing.Optional[str] = None,
        bucket_name: typing.Optional[str] = None,
        cluster_parameter_group_name: typing.Optional[str] = None,
        cluster_public_key: typing.Optional[str] = None,
        cluster_revision_number: typing.Optional[str] = None,
        cluster_security_groups: typing.Optional[typing.List[str]] = None,
        cluster_subnet_group_name: typing.Optional[str] = None,
        cluster_type: typing.Optional[str] = None,
        cluster_version: typing.Optional[str] = None,
        database_name: typing.Optional[str] = None,
        elastic_ip: typing.Optional[str] = None,
        enable_logging: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        endpoint: typing.Optional[str] = None,
        enhanced_vpc_routing: typing.Optional[bool] = None,
        final_snapshot_identifier: typing.Optional[str] = None,
        iam_roles: typing.Optional[typing.List[str]] = None,
        kms_key_id: typing.Optional[str] = None,
        logging: typing.Optional[typing.List["RedshiftClusterLogging"]] = None,
        master_password: typing.Optional[str] = None,
        master_username: typing.Optional[str] = None,
        number_of_nodes: typing.Optional[jsii.Number] = None,
        owner_account: typing.Optional[str] = None,
        port: typing.Optional[jsii.Number] = None,
        preferred_maintenance_window: typing.Optional[str] = None,
        publicly_accessible: typing.Optional[bool] = None,
        s3_key_prefix: typing.Optional[str] = None,
        skip_final_snapshot: typing.Optional[bool] = None,
        snapshot_cluster_identifier: typing.Optional[str] = None,
        snapshot_copy: typing.Optional[
            typing.List["RedshiftClusterSnapshotCopy"]
        ] = None,
        snapshot_identifier: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RedshiftClusterTimeouts"] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_identifier: 
        :param node_type: 
        :param allow_version_upgrade: 
        :param automated_snapshot_retention_period: 
        :param availability_zone: 
        :param bucket_name: 
        :param cluster_parameter_group_name: 
        :param cluster_public_key: 
        :param cluster_revision_number: 
        :param cluster_security_groups: 
        :param cluster_subnet_group_name: 
        :param cluster_type: 
        :param cluster_version: 
        :param database_name: 
        :param elastic_ip: 
        :param enable_logging: 
        :param encrypted: 
        :param endpoint: 
        :param enhanced_vpc_routing: 
        :param final_snapshot_identifier: 
        :param iam_roles: 
        :param kms_key_id: 
        :param logging: logging block.
        :param master_password: 
        :param master_username: 
        :param number_of_nodes: 
        :param owner_account: 
        :param port: 
        :param preferred_maintenance_window: 
        :param publicly_accessible: 
        :param s3_key_prefix: 
        :param skip_final_snapshot: 
        :param snapshot_cluster_identifier: 
        :param snapshot_copy: snapshot_copy block.
        :param snapshot_identifier: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_security_group_ids: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RedshiftClusterTimeouts(**timeouts)
        self._values = {
            "cluster_identifier": cluster_identifier,
            "node_type": node_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_version_upgrade is not None:
            self._values["allow_version_upgrade"] = allow_version_upgrade
        if automated_snapshot_retention_period is not None:
            self._values[
                "automated_snapshot_retention_period"
            ] = automated_snapshot_retention_period
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if bucket_name is not None:
            self._values["bucket_name"] = bucket_name
        if cluster_parameter_group_name is not None:
            self._values["cluster_parameter_group_name"] = cluster_parameter_group_name
        if cluster_public_key is not None:
            self._values["cluster_public_key"] = cluster_public_key
        if cluster_revision_number is not None:
            self._values["cluster_revision_number"] = cluster_revision_number
        if cluster_security_groups is not None:
            self._values["cluster_security_groups"] = cluster_security_groups
        if cluster_subnet_group_name is not None:
            self._values["cluster_subnet_group_name"] = cluster_subnet_group_name
        if cluster_type is not None:
            self._values["cluster_type"] = cluster_type
        if cluster_version is not None:
            self._values["cluster_version"] = cluster_version
        if database_name is not None:
            self._values["database_name"] = database_name
        if elastic_ip is not None:
            self._values["elastic_ip"] = elastic_ip
        if enable_logging is not None:
            self._values["enable_logging"] = enable_logging
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if endpoint is not None:
            self._values["endpoint"] = endpoint
        if enhanced_vpc_routing is not None:
            self._values["enhanced_vpc_routing"] = enhanced_vpc_routing
        if final_snapshot_identifier is not None:
            self._values["final_snapshot_identifier"] = final_snapshot_identifier
        if iam_roles is not None:
            self._values["iam_roles"] = iam_roles
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if logging is not None:
            self._values["logging"] = logging
        if master_password is not None:
            self._values["master_password"] = master_password
        if master_username is not None:
            self._values["master_username"] = master_username
        if number_of_nodes is not None:
            self._values["number_of_nodes"] = number_of_nodes
        if owner_account is not None:
            self._values["owner_account"] = owner_account
        if port is not None:
            self._values["port"] = port
        if preferred_maintenance_window is not None:
            self._values["preferred_maintenance_window"] = preferred_maintenance_window
        if publicly_accessible is not None:
            self._values["publicly_accessible"] = publicly_accessible
        if s3_key_prefix is not None:
            self._values["s3_key_prefix"] = s3_key_prefix
        if skip_final_snapshot is not None:
            self._values["skip_final_snapshot"] = skip_final_snapshot
        if snapshot_cluster_identifier is not None:
            self._values["snapshot_cluster_identifier"] = snapshot_cluster_identifier
        if snapshot_copy is not None:
            self._values["snapshot_copy"] = snapshot_copy
        if snapshot_identifier is not None:
            self._values["snapshot_identifier"] = snapshot_identifier
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def node_type(self) -> str:
        return self._values.get("node_type")

    @builtins.property
    def allow_version_upgrade(self) -> typing.Optional[bool]:
        return self._values.get("allow_version_upgrade")

    @builtins.property
    def automated_snapshot_retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("automated_snapshot_retention_period")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def bucket_name(self) -> typing.Optional[str]:
        return self._values.get("bucket_name")

    @builtins.property
    def cluster_parameter_group_name(self) -> typing.Optional[str]:
        return self._values.get("cluster_parameter_group_name")

    @builtins.property
    def cluster_public_key(self) -> typing.Optional[str]:
        return self._values.get("cluster_public_key")

    @builtins.property
    def cluster_revision_number(self) -> typing.Optional[str]:
        return self._values.get("cluster_revision_number")

    @builtins.property
    def cluster_security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cluster_security_groups")

    @builtins.property
    def cluster_subnet_group_name(self) -> typing.Optional[str]:
        return self._values.get("cluster_subnet_group_name")

    @builtins.property
    def cluster_type(self) -> typing.Optional[str]:
        return self._values.get("cluster_type")

    @builtins.property
    def cluster_version(self) -> typing.Optional[str]:
        return self._values.get("cluster_version")

    @builtins.property
    def database_name(self) -> typing.Optional[str]:
        return self._values.get("database_name")

    @builtins.property
    def elastic_ip(self) -> typing.Optional[str]:
        return self._values.get("elastic_ip")

    @builtins.property
    def enable_logging(self) -> typing.Optional[bool]:
        return self._values.get("enable_logging")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def endpoint(self) -> typing.Optional[str]:
        return self._values.get("endpoint")

    @builtins.property
    def enhanced_vpc_routing(self) -> typing.Optional[bool]:
        return self._values.get("enhanced_vpc_routing")

    @builtins.property
    def final_snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("final_snapshot_identifier")

    @builtins.property
    def iam_roles(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("iam_roles")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def logging(self) -> typing.Optional[typing.List["RedshiftClusterLogging"]]:
        """logging block."""
        return self._values.get("logging")

    @builtins.property
    def master_password(self) -> typing.Optional[str]:
        return self._values.get("master_password")

    @builtins.property
    def master_username(self) -> typing.Optional[str]:
        return self._values.get("master_username")

    @builtins.property
    def number_of_nodes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("number_of_nodes")

    @builtins.property
    def owner_account(self) -> typing.Optional[str]:
        return self._values.get("owner_account")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def preferred_maintenance_window(self) -> typing.Optional[str]:
        return self._values.get("preferred_maintenance_window")

    @builtins.property
    def publicly_accessible(self) -> typing.Optional[bool]:
        return self._values.get("publicly_accessible")

    @builtins.property
    def s3_key_prefix(self) -> typing.Optional[str]:
        return self._values.get("s3_key_prefix")

    @builtins.property
    def skip_final_snapshot(self) -> typing.Optional[bool]:
        return self._values.get("skip_final_snapshot")

    @builtins.property
    def snapshot_cluster_identifier(self) -> typing.Optional[str]:
        return self._values.get("snapshot_cluster_identifier")

    @builtins.property
    def snapshot_copy(
        self,
    ) -> typing.Optional[typing.List["RedshiftClusterSnapshotCopy"]]:
        """snapshot_copy block."""
        return self._values.get("snapshot_copy")

    @builtins.property
    def snapshot_identifier(self) -> typing.Optional[str]:
        return self._values.get("snapshot_identifier")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["RedshiftClusterTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftClusterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftClusterLogging",
    jsii_struct_bases=[],
    name_mapping={
        "enable": "enable",
        "bucket_name": "bucketName",
        "s3_key_prefix": "s3KeyPrefix",
    },
)
class RedshiftClusterLogging:
    def __init__(
        self,
        *,
        enable: bool,
        bucket_name: typing.Optional[str] = None,
        s3_key_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param enable: 
        :param bucket_name: 
        :param s3_key_prefix: 
        """
        self._values = {
            "enable": enable,
        }
        if bucket_name is not None:
            self._values["bucket_name"] = bucket_name
        if s3_key_prefix is not None:
            self._values["s3_key_prefix"] = s3_key_prefix

    @builtins.property
    def enable(self) -> bool:
        return self._values.get("enable")

    @builtins.property
    def bucket_name(self) -> typing.Optional[str]:
        return self._values.get("bucket_name")

    @builtins.property
    def s3_key_prefix(self) -> typing.Optional[str]:
        return self._values.get("s3_key_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftClusterLogging(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftClusterSnapshotCopy",
    jsii_struct_bases=[],
    name_mapping={
        "destination_region": "destinationRegion",
        "grant_name": "grantName",
        "retention_period": "retentionPeriod",
    },
)
class RedshiftClusterSnapshotCopy:
    def __init__(
        self,
        *,
        destination_region: str,
        grant_name: typing.Optional[str] = None,
        retention_period: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param destination_region: 
        :param grant_name: 
        :param retention_period: 
        """
        self._values = {
            "destination_region": destination_region,
        }
        if grant_name is not None:
            self._values["grant_name"] = grant_name
        if retention_period is not None:
            self._values["retention_period"] = retention_period

    @builtins.property
    def destination_region(self) -> str:
        return self._values.get("destination_region")

    @builtins.property
    def grant_name(self) -> typing.Optional[str]:
        return self._values.get("grant_name")

    @builtins.property
    def retention_period(self) -> typing.Optional[jsii.Number]:
        return self._values.get("retention_period")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftClusterSnapshotCopy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftClusterTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class RedshiftClusterTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftClusterTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftEventSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftEventSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        sns_topic_arn: str,
        enabled: typing.Optional[bool] = None,
        event_categories: typing.Optional[typing.List[str]] = None,
        severity: typing.Optional[str] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RedshiftEventSubscriptionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param sns_topic_arn: 
        :param enabled: 
        :param event_categories: 
        :param severity: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftEventSubscriptionConfig(
            name=name,
            sns_topic_arn=sns_topic_arn,
            enabled=enabled,
            event_categories=event_categories,
            severity=severity,
            source_ids=source_ids,
            source_type=source_type,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftEventSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="customerAwsId")
    def customer_aws_id(self) -> str:
        return jsii.get(self, "customerAwsId")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="snsTopicArn")
    def sns_topic_arn(self) -> str:
        return jsii.get(self, "snsTopicArn")

    @sns_topic_arn.setter
    def sns_topic_arn(self, value: str) -> None:
        jsii.set(self, "snsTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="eventCategories")
    def event_categories(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "eventCategories")

    @event_categories.setter
    def event_categories(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "eventCategories", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="severity")
    def severity(self) -> typing.Optional[str]:
        return jsii.get(self, "severity")

    @severity.setter
    def severity(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "severity", value)

    @builtins.property
    @jsii.member(jsii_name="sourceIds")
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "sourceIds")

    @source_ids.setter
    def source_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "sourceIds", value)

    @builtins.property
    @jsii.member(jsii_name="sourceType")
    def source_type(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceType")

    @source_type.setter
    def source_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceType", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RedshiftEventSubscriptionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["RedshiftEventSubscriptionTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftEventSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "sns_topic_arn": "snsTopicArn",
        "enabled": "enabled",
        "event_categories": "eventCategories",
        "severity": "severity",
        "source_ids": "sourceIds",
        "source_type": "sourceType",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class RedshiftEventSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        sns_topic_arn: str,
        enabled: typing.Optional[bool] = None,
        event_categories: typing.Optional[typing.List[str]] = None,
        severity: typing.Optional[str] = None,
        source_ids: typing.Optional[typing.List[str]] = None,
        source_type: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["RedshiftEventSubscriptionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param sns_topic_arn: 
        :param enabled: 
        :param event_categories: 
        :param severity: 
        :param source_ids: 
        :param source_type: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RedshiftEventSubscriptionTimeouts(**timeouts)
        self._values = {
            "name": name,
            "sns_topic_arn": sns_topic_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if event_categories is not None:
            self._values["event_categories"] = event_categories
        if severity is not None:
            self._values["severity"] = severity
        if source_ids is not None:
            self._values["source_ids"] = source_ids
        if source_type is not None:
            self._values["source_type"] = source_type
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def sns_topic_arn(self) -> str:
        return self._values.get("sns_topic_arn")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def event_categories(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("event_categories")

    @builtins.property
    def severity(self) -> typing.Optional[str]:
        return self._values.get("severity")

    @builtins.property
    def source_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("source_ids")

    @builtins.property
    def source_type(self) -> typing.Optional[str]:
        return self._values.get("source_type")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["RedshiftEventSubscriptionTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftEventSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftEventSubscriptionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class RedshiftEventSubscriptionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftEventSubscriptionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftParameterGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftParameterGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        family: str,
        name: str,
        description: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["RedshiftParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param family: 
        :param name: 
        :param description: 
        :param parameter: parameter block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftParameterGroupConfig(
            family=family,
            name=name,
            description=description,
            parameter=parameter,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftParameterGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="family")
    def family(self) -> str:
        return jsii.get(self, "family")

    @family.setter
    def family(self, value: str) -> None:
        jsii.set(self, "family", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="parameter")
    def parameter(
        self,
    ) -> typing.Optional[typing.List["RedshiftParameterGroupParameter"]]:
        return jsii.get(self, "parameter")

    @parameter.setter
    def parameter(
        self, value: typing.Optional[typing.List["RedshiftParameterGroupParameter"]]
    ) -> None:
        jsii.set(self, "parameter", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftParameterGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "family": "family",
        "name": "name",
        "description": "description",
        "parameter": "parameter",
        "tags": "tags",
    },
)
class RedshiftParameterGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        family: str,
        name: str,
        description: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List["RedshiftParameterGroupParameter"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param family: 
        :param name: 
        :param description: 
        :param parameter: parameter block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "family": family,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if parameter is not None:
            self._values["parameter"] = parameter
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def family(self) -> str:
        return self._values.get("family")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[typing.List["RedshiftParameterGroupParameter"]]:
        """parameter block."""
        return self._values.get("parameter")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftParameterGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftParameterGroupParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "value": "value"},
)
class RedshiftParameterGroupParameter:
    def __init__(self, *, name: str, value: str) -> None:
        """
        :param name: 
        :param value: 
        """
        self._values = {
            "name": name,
            "value": value,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftParameterGroupParameter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftSecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        ingress: typing.List["RedshiftSecurityGroupIngress"],
        name: str,
        description: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ingress: ingress block.
        :param name: 
        :param description: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftSecurityGroupConfig(
            ingress=ingress,
            name=name,
            description=description,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftSecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> typing.List["RedshiftSecurityGroupIngress"]:
        return jsii.get(self, "ingress")

    @ingress.setter
    def ingress(self, value: typing.List["RedshiftSecurityGroupIngress"]) -> None:
        jsii.set(self, "ingress", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ingress": "ingress",
        "name": "name",
        "description": "description",
    },
)
class RedshiftSecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ingress: typing.List["RedshiftSecurityGroupIngress"],
        name: str,
        description: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ingress: ingress block.
        :param name: 
        :param description: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "ingress": ingress,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def ingress(self) -> typing.List["RedshiftSecurityGroupIngress"]:
        """ingress block."""
        return self._values.get("ingress")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftSecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSecurityGroupIngress",
    jsii_struct_bases=[],
    name_mapping={
        "cidr": "cidr",
        "security_group_name": "securityGroupName",
        "security_group_owner_id": "securityGroupOwnerId",
    },
)
class RedshiftSecurityGroupIngress:
    def __init__(
        self,
        *,
        cidr: typing.Optional[str] = None,
        security_group_name: typing.Optional[str] = None,
        security_group_owner_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param cidr: 
        :param security_group_name: 
        :param security_group_owner_id: 
        """
        self._values = {}
        if cidr is not None:
            self._values["cidr"] = cidr
        if security_group_name is not None:
            self._values["security_group_name"] = security_group_name
        if security_group_owner_id is not None:
            self._values["security_group_owner_id"] = security_group_owner_id

    @builtins.property
    def cidr(self) -> typing.Optional[str]:
        return self._values.get("cidr")

    @builtins.property
    def security_group_name(self) -> typing.Optional[str]:
        return self._values.get("security_group_name")

    @builtins.property
    def security_group_owner_id(self) -> typing.Optional[str]:
        return self._values.get("security_group_owner_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftSecurityGroupIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftSnapshotCopyGrant(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSnapshotCopyGrant",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        snapshot_copy_grant_name: str,
        kms_key_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param snapshot_copy_grant_name: 
        :param kms_key_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftSnapshotCopyGrantConfig(
            snapshot_copy_grant_name=snapshot_copy_grant_name,
            kms_key_id=kms_key_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftSnapshotCopyGrant, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="snapshotCopyGrantName")
    def snapshot_copy_grant_name(self) -> str:
        return jsii.get(self, "snapshotCopyGrantName")

    @snapshot_copy_grant_name.setter
    def snapshot_copy_grant_name(self, value: str) -> None:
        jsii.set(self, "snapshotCopyGrantName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSnapshotCopyGrantConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "snapshot_copy_grant_name": "snapshotCopyGrantName",
        "kms_key_id": "kmsKeyId",
        "tags": "tags",
    },
)
class RedshiftSnapshotCopyGrantConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        snapshot_copy_grant_name: str,
        kms_key_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param snapshot_copy_grant_name: 
        :param kms_key_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "snapshot_copy_grant_name": snapshot_copy_grant_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def snapshot_copy_grant_name(self) -> str:
        return self._values.get("snapshot_copy_grant_name")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftSnapshotCopyGrantConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftSnapshotSchedule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSnapshotSchedule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        definitions: typing.List[str],
        description: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param definitions: 
        :param description: 
        :param force_destroy: 
        :param identifier: 
        :param identifier_prefix: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftSnapshotScheduleConfig(
            definitions=definitions,
            description=description,
            force_destroy=force_destroy,
            identifier=identifier,
            identifier_prefix=identifier_prefix,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftSnapshotSchedule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="definitions")
    def definitions(self) -> typing.List[str]:
        return jsii.get(self, "definitions")

    @definitions.setter
    def definitions(self, value: typing.List[str]) -> None:
        jsii.set(self, "definitions", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identifier")
    def identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "identifier")

    @identifier.setter
    def identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifier", value)

    @builtins.property
    @jsii.member(jsii_name="identifierPrefix")
    def identifier_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "identifierPrefix")

    @identifier_prefix.setter
    def identifier_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identifierPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class RedshiftSnapshotScheduleAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSnapshotScheduleAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cluster_identifier: str,
        schedule_identifier: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cluster_identifier: 
        :param schedule_identifier: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftSnapshotScheduleAssociationConfig(
            cluster_identifier=cluster_identifier,
            schedule_identifier=schedule_identifier,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftSnapshotScheduleAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="clusterIdentifier")
    def cluster_identifier(self) -> str:
        return jsii.get(self, "clusterIdentifier")

    @cluster_identifier.setter
    def cluster_identifier(self, value: str) -> None:
        jsii.set(self, "clusterIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="scheduleIdentifier")
    def schedule_identifier(self) -> str:
        return jsii.get(self, "scheduleIdentifier")

    @schedule_identifier.setter
    def schedule_identifier(self, value: str) -> None:
        jsii.set(self, "scheduleIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSnapshotScheduleAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cluster_identifier": "clusterIdentifier",
        "schedule_identifier": "scheduleIdentifier",
    },
)
class RedshiftSnapshotScheduleAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cluster_identifier: str,
        schedule_identifier: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cluster_identifier: 
        :param schedule_identifier: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cluster_identifier": cluster_identifier,
            "schedule_identifier": schedule_identifier,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cluster_identifier(self) -> str:
        return self._values.get("cluster_identifier")

    @builtins.property
    def schedule_identifier(self) -> str:
        return self._values.get("schedule_identifier")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftSnapshotScheduleAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSnapshotScheduleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "definitions": "definitions",
        "description": "description",
        "force_destroy": "forceDestroy",
        "identifier": "identifier",
        "identifier_prefix": "identifierPrefix",
        "tags": "tags",
    },
)
class RedshiftSnapshotScheduleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        definitions: typing.List[str],
        description: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        identifier: typing.Optional[str] = None,
        identifier_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param definitions: 
        :param description: 
        :param force_destroy: 
        :param identifier: 
        :param identifier_prefix: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "definitions": definitions,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if identifier is not None:
            self._values["identifier"] = identifier
        if identifier_prefix is not None:
            self._values["identifier_prefix"] = identifier_prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def definitions(self) -> typing.List[str]:
        return self._values.get("definitions")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    @builtins.property
    def identifier(self) -> typing.Optional[str]:
        return self._values.get("identifier")

    @builtins.property
    def identifier_prefix(self) -> typing.Optional[str]:
        return self._values.get("identifier_prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftSnapshotScheduleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RedshiftSubnetGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSubnetGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param subnet_ids: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RedshiftSubnetGroupConfig(
            name=name,
            subnet_ids=subnet_ids,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RedshiftSubnetGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.List[str]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RedshiftSubnetGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "subnet_ids": "subnetIds",
        "description": "description",
        "tags": "tags",
    },
)
class RedshiftSubnetGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        subnet_ids: typing.List[str],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param subnet_ids: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "subnet_ids": subnet_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RedshiftSubnetGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ResourcegroupsGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ResourcegroupsGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        resource_query: typing.List["ResourcegroupsGroupResourceQuery"],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_query: resource_query block.
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ResourcegroupsGroupConfig(
            name=name,
            resource_query=resource_query,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ResourcegroupsGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resourceQuery")
    def resource_query(self) -> typing.List["ResourcegroupsGroupResourceQuery"]:
        return jsii.get(self, "resourceQuery")

    @resource_query.setter
    def resource_query(
        self, value: typing.List["ResourcegroupsGroupResourceQuery"]
    ) -> None:
        jsii.set(self, "resourceQuery", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ResourcegroupsGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_query": "resourceQuery",
        "description": "description",
        "tags": "tags",
    },
)
class ResourcegroupsGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        resource_query: typing.List["ResourcegroupsGroupResourceQuery"],
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_query: resource_query block.
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "resource_query": resource_query,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def resource_query(self) -> typing.List["ResourcegroupsGroupResourceQuery"]:
        """resource_query block."""
        return self._values.get("resource_query")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcegroupsGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ResourcegroupsGroupResourceQuery",
    jsii_struct_bases=[],
    name_mapping={"query": "query", "type": "type"},
)
class ResourcegroupsGroupResourceQuery:
    def __init__(self, *, query: str, type: typing.Optional[str] = None) -> None:
        """
        :param query: 
        :param type: 
        """
        self._values = {
            "query": query,
        }
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def query(self) -> str:
        return self._values.get("query")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ResourcegroupsGroupResourceQuery(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        route_table_id: str,
        destination_cidr_block: typing.Optional[str] = None,
        destination_ipv6_cidr_block: typing.Optional[str] = None,
        egress_only_gateway_id: typing.Optional[str] = None,
        gateway_id: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        nat_gateway_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        timeouts: typing.Optional["RouteTimeouts"] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpc_peering_connection_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param route_table_id: 
        :param destination_cidr_block: 
        :param destination_ipv6_cidr_block: 
        :param egress_only_gateway_id: 
        :param gateway_id: 
        :param instance_id: 
        :param nat_gateway_id: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        :param transit_gateway_id: 
        :param vpc_peering_connection_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RouteConfig(
            route_table_id=route_table_id,
            destination_cidr_block=destination_cidr_block,
            destination_ipv6_cidr_block=destination_ipv6_cidr_block,
            egress_only_gateway_id=egress_only_gateway_id,
            gateway_id=gateway_id,
            instance_id=instance_id,
            nat_gateway_id=nat_gateway_id,
            network_interface_id=network_interface_id,
            timeouts=timeouts,
            transit_gateway_id=transit_gateway_id,
            vpc_peering_connection_id=vpc_peering_connection_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="destinationPrefixListId")
    def destination_prefix_list_id(self) -> str:
        return jsii.get(self, "destinationPrefixListId")

    @builtins.property
    @jsii.member(jsii_name="instanceOwnerId")
    def instance_owner_id(self) -> str:
        return jsii.get(self, "instanceOwnerId")

    @builtins.property
    @jsii.member(jsii_name="origin")
    def origin(self) -> str:
        return jsii.get(self, "origin")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> str:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter
    def route_table_id(self, value: str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "destinationCidrBlock")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "destinationCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="destinationIpv6CidrBlock")
    def destination_ipv6_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "destinationIpv6CidrBlock")

    @destination_ipv6_cidr_block.setter
    def destination_ipv6_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "destinationIpv6CidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="egressOnlyGatewayId")
    def egress_only_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "egressOnlyGatewayId")

    @egress_only_gateway_id.setter
    def egress_only_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "egressOnlyGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayId")
    def gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "gatewayId")

    @gateway_id.setter
    def gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "gatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceId")

    @instance_id.setter
    def instance_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property
    @jsii.member(jsii_name="natGatewayId")
    def nat_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "natGatewayId")

    @nat_gateway_id.setter
    def nat_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "natGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> typing.Optional[str]:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["RouteTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["RouteTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "transitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcPeeringConnectionId")
    def vpc_peering_connection_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcPeeringConnectionId")

    @vpc_peering_connection_id.setter
    def vpc_peering_connection_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcPeeringConnectionId", value)


class Route53DelegationSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53DelegationSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        reference_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param reference_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53DelegationSetConfig(
            reference_name=reference_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53DelegationSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="nameServers")
    def name_servers(self) -> typing.List[str]:
        return jsii.get(self, "nameServers")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="referenceName")
    def reference_name(self) -> typing.Optional[str]:
        return jsii.get(self, "referenceName")

    @reference_name.setter
    def reference_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "referenceName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53DelegationSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "reference_name": "referenceName",
    },
)
class Route53DelegationSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        reference_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param reference_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if reference_name is not None:
            self._values["reference_name"] = reference_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def reference_name(self) -> typing.Optional[str]:
        return self._values.get("reference_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53DelegationSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route53HealthCheck(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53HealthCheck",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        type: str,
        child_healthchecks: typing.Optional[typing.List[str]] = None,
        child_health_threshold: typing.Optional[jsii.Number] = None,
        cloudwatch_alarm_name: typing.Optional[str] = None,
        cloudwatch_alarm_region: typing.Optional[str] = None,
        enable_sni: typing.Optional[bool] = None,
        failure_threshold: typing.Optional[jsii.Number] = None,
        fqdn: typing.Optional[str] = None,
        insufficient_data_health_status: typing.Optional[str] = None,
        invert_healthcheck: typing.Optional[bool] = None,
        ip_address: typing.Optional[str] = None,
        measure_latency: typing.Optional[bool] = None,
        port: typing.Optional[jsii.Number] = None,
        reference_name: typing.Optional[str] = None,
        regions: typing.Optional[typing.List[str]] = None,
        request_interval: typing.Optional[jsii.Number] = None,
        resource_path: typing.Optional[str] = None,
        search_string: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param type: 
        :param child_healthchecks: 
        :param child_health_threshold: 
        :param cloudwatch_alarm_name: 
        :param cloudwatch_alarm_region: 
        :param enable_sni: 
        :param failure_threshold: 
        :param fqdn: 
        :param insufficient_data_health_status: 
        :param invert_healthcheck: 
        :param ip_address: 
        :param measure_latency: 
        :param port: 
        :param reference_name: 
        :param regions: 
        :param request_interval: 
        :param resource_path: 
        :param search_string: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53HealthCheckConfig(
            type=type,
            child_healthchecks=child_healthchecks,
            child_health_threshold=child_health_threshold,
            cloudwatch_alarm_name=cloudwatch_alarm_name,
            cloudwatch_alarm_region=cloudwatch_alarm_region,
            enable_sni=enable_sni,
            failure_threshold=failure_threshold,
            fqdn=fqdn,
            insufficient_data_health_status=insufficient_data_health_status,
            invert_healthcheck=invert_healthcheck,
            ip_address=ip_address,
            measure_latency=measure_latency,
            port=port,
            reference_name=reference_name,
            regions=regions,
            request_interval=request_interval,
            resource_path=resource_path,
            search_string=search_string,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53HealthCheck, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="childHealthchecks")
    def child_healthchecks(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "childHealthchecks")

    @child_healthchecks.setter
    def child_healthchecks(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "childHealthchecks", value)

    @builtins.property
    @jsii.member(jsii_name="childHealthThreshold")
    def child_health_threshold(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "childHealthThreshold")

    @child_health_threshold.setter
    def child_health_threshold(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "childHealthThreshold", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchAlarmName")
    def cloudwatch_alarm_name(self) -> typing.Optional[str]:
        return jsii.get(self, "cloudwatchAlarmName")

    @cloudwatch_alarm_name.setter
    def cloudwatch_alarm_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cloudwatchAlarmName", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchAlarmRegion")
    def cloudwatch_alarm_region(self) -> typing.Optional[str]:
        return jsii.get(self, "cloudwatchAlarmRegion")

    @cloudwatch_alarm_region.setter
    def cloudwatch_alarm_region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cloudwatchAlarmRegion", value)

    @builtins.property
    @jsii.member(jsii_name="enableSni")
    def enable_sni(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableSni")

    @enable_sni.setter
    def enable_sni(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableSni", value)

    @builtins.property
    @jsii.member(jsii_name="failureThreshold")
    def failure_threshold(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "failureThreshold")

    @failure_threshold.setter
    def failure_threshold(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "failureThreshold", value)

    @builtins.property
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> typing.Optional[str]:
        return jsii.get(self, "fqdn")

    @fqdn.setter
    def fqdn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "fqdn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="insufficientDataHealthStatus")
    def insufficient_data_health_status(self) -> typing.Optional[str]:
        return jsii.get(self, "insufficientDataHealthStatus")

    @insufficient_data_health_status.setter
    def insufficient_data_health_status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "insufficientDataHealthStatus", value)

    @builtins.property
    @jsii.member(jsii_name="invertHealthcheck")
    def invert_healthcheck(self) -> typing.Optional[bool]:
        return jsii.get(self, "invertHealthcheck")

    @invert_healthcheck.setter
    def invert_healthcheck(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "invertHealthcheck", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> typing.Optional[str]:
        return jsii.get(self, "ipAddress")

    @ip_address.setter
    def ip_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property
    @jsii.member(jsii_name="measureLatency")
    def measure_latency(self) -> typing.Optional[bool]:
        return jsii.get(self, "measureLatency")

    @measure_latency.setter
    def measure_latency(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "measureLatency", value)

    @builtins.property
    @jsii.member(jsii_name="port")
    def port(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "port")

    @port.setter
    def port(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "port", value)

    @builtins.property
    @jsii.member(jsii_name="referenceName")
    def reference_name(self) -> typing.Optional[str]:
        return jsii.get(self, "referenceName")

    @reference_name.setter
    def reference_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "referenceName", value)

    @builtins.property
    @jsii.member(jsii_name="regions")
    def regions(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "regions")

    @regions.setter
    def regions(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "regions", value)

    @builtins.property
    @jsii.member(jsii_name="requestInterval")
    def request_interval(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "requestInterval")

    @request_interval.setter
    def request_interval(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "requestInterval", value)

    @builtins.property
    @jsii.member(jsii_name="resourcePath")
    def resource_path(self) -> typing.Optional[str]:
        return jsii.get(self, "resourcePath")

    @resource_path.setter
    def resource_path(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resourcePath", value)

    @builtins.property
    @jsii.member(jsii_name="searchString")
    def search_string(self) -> typing.Optional[str]:
        return jsii.get(self, "searchString")

    @search_string.setter
    def search_string(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "searchString", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53HealthCheckConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "type": "type",
        "child_healthchecks": "childHealthchecks",
        "child_health_threshold": "childHealthThreshold",
        "cloudwatch_alarm_name": "cloudwatchAlarmName",
        "cloudwatch_alarm_region": "cloudwatchAlarmRegion",
        "enable_sni": "enableSni",
        "failure_threshold": "failureThreshold",
        "fqdn": "fqdn",
        "insufficient_data_health_status": "insufficientDataHealthStatus",
        "invert_healthcheck": "invertHealthcheck",
        "ip_address": "ipAddress",
        "measure_latency": "measureLatency",
        "port": "port",
        "reference_name": "referenceName",
        "regions": "regions",
        "request_interval": "requestInterval",
        "resource_path": "resourcePath",
        "search_string": "searchString",
        "tags": "tags",
    },
)
class Route53HealthCheckConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        type: str,
        child_healthchecks: typing.Optional[typing.List[str]] = None,
        child_health_threshold: typing.Optional[jsii.Number] = None,
        cloudwatch_alarm_name: typing.Optional[str] = None,
        cloudwatch_alarm_region: typing.Optional[str] = None,
        enable_sni: typing.Optional[bool] = None,
        failure_threshold: typing.Optional[jsii.Number] = None,
        fqdn: typing.Optional[str] = None,
        insufficient_data_health_status: typing.Optional[str] = None,
        invert_healthcheck: typing.Optional[bool] = None,
        ip_address: typing.Optional[str] = None,
        measure_latency: typing.Optional[bool] = None,
        port: typing.Optional[jsii.Number] = None,
        reference_name: typing.Optional[str] = None,
        regions: typing.Optional[typing.List[str]] = None,
        request_interval: typing.Optional[jsii.Number] = None,
        resource_path: typing.Optional[str] = None,
        search_string: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param type: 
        :param child_healthchecks: 
        :param child_health_threshold: 
        :param cloudwatch_alarm_name: 
        :param cloudwatch_alarm_region: 
        :param enable_sni: 
        :param failure_threshold: 
        :param fqdn: 
        :param insufficient_data_health_status: 
        :param invert_healthcheck: 
        :param ip_address: 
        :param measure_latency: 
        :param port: 
        :param reference_name: 
        :param regions: 
        :param request_interval: 
        :param resource_path: 
        :param search_string: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if child_healthchecks is not None:
            self._values["child_healthchecks"] = child_healthchecks
        if child_health_threshold is not None:
            self._values["child_health_threshold"] = child_health_threshold
        if cloudwatch_alarm_name is not None:
            self._values["cloudwatch_alarm_name"] = cloudwatch_alarm_name
        if cloudwatch_alarm_region is not None:
            self._values["cloudwatch_alarm_region"] = cloudwatch_alarm_region
        if enable_sni is not None:
            self._values["enable_sni"] = enable_sni
        if failure_threshold is not None:
            self._values["failure_threshold"] = failure_threshold
        if fqdn is not None:
            self._values["fqdn"] = fqdn
        if insufficient_data_health_status is not None:
            self._values[
                "insufficient_data_health_status"
            ] = insufficient_data_health_status
        if invert_healthcheck is not None:
            self._values["invert_healthcheck"] = invert_healthcheck
        if ip_address is not None:
            self._values["ip_address"] = ip_address
        if measure_latency is not None:
            self._values["measure_latency"] = measure_latency
        if port is not None:
            self._values["port"] = port
        if reference_name is not None:
            self._values["reference_name"] = reference_name
        if regions is not None:
            self._values["regions"] = regions
        if request_interval is not None:
            self._values["request_interval"] = request_interval
        if resource_path is not None:
            self._values["resource_path"] = resource_path
        if search_string is not None:
            self._values["search_string"] = search_string
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def child_healthchecks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("child_healthchecks")

    @builtins.property
    def child_health_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("child_health_threshold")

    @builtins.property
    def cloudwatch_alarm_name(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_alarm_name")

    @builtins.property
    def cloudwatch_alarm_region(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_alarm_region")

    @builtins.property
    def enable_sni(self) -> typing.Optional[bool]:
        return self._values.get("enable_sni")

    @builtins.property
    def failure_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("failure_threshold")

    @builtins.property
    def fqdn(self) -> typing.Optional[str]:
        return self._values.get("fqdn")

    @builtins.property
    def insufficient_data_health_status(self) -> typing.Optional[str]:
        return self._values.get("insufficient_data_health_status")

    @builtins.property
    def invert_healthcheck(self) -> typing.Optional[bool]:
        return self._values.get("invert_healthcheck")

    @builtins.property
    def ip_address(self) -> typing.Optional[str]:
        return self._values.get("ip_address")

    @builtins.property
    def measure_latency(self) -> typing.Optional[bool]:
        return self._values.get("measure_latency")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    @builtins.property
    def reference_name(self) -> typing.Optional[str]:
        return self._values.get("reference_name")

    @builtins.property
    def regions(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("regions")

    @builtins.property
    def request_interval(self) -> typing.Optional[jsii.Number]:
        return self._values.get("request_interval")

    @builtins.property
    def resource_path(self) -> typing.Optional[str]:
        return self._values.get("resource_path")

    @builtins.property
    def search_string(self) -> typing.Optional[str]:
        return self._values.get("search_string")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53HealthCheckConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route53QueryLog(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53QueryLog",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cloudwatch_log_group_arn: str,
        zone_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cloudwatch_log_group_arn: 
        :param zone_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53QueryLogConfig(
            cloudwatch_log_group_arn=cloudwatch_log_group_arn,
            zone_id=zone_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53QueryLog, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cloudwatchLogGroupArn")
    def cloudwatch_log_group_arn(self) -> str:
        return jsii.get(self, "cloudwatchLogGroupArn")

    @cloudwatch_log_group_arn.setter
    def cloudwatch_log_group_arn(self, value: str) -> None:
        jsii.set(self, "cloudwatchLogGroupArn", value)

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @zone_id.setter
    def zone_id(self, value: str) -> None:
        jsii.set(self, "zoneId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53QueryLogConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cloudwatch_log_group_arn": "cloudwatchLogGroupArn",
        "zone_id": "zoneId",
    },
)
class Route53QueryLogConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cloudwatch_log_group_arn: str,
        zone_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cloudwatch_log_group_arn: 
        :param zone_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cloudwatch_log_group_arn": cloudwatch_log_group_arn,
            "zone_id": zone_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cloudwatch_log_group_arn(self) -> str:
        return self._values.get("cloudwatch_log_group_arn")

    @builtins.property
    def zone_id(self) -> str:
        return self._values.get("zone_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53QueryLogConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route53Record(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53Record",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        type: str,
        zone_id: str,
        alias: typing.Optional[typing.List["Route53RecordAlias"]] = None,
        allow_overwrite: typing.Optional[bool] = None,
        failover_routing_policy: typing.Optional[
            typing.List["Route53RecordFailoverRoutingPolicy"]
        ] = None,
        geolocation_routing_policy: typing.Optional[
            typing.List["Route53RecordGeolocationRoutingPolicy"]
        ] = None,
        health_check_id: typing.Optional[str] = None,
        latency_routing_policy: typing.Optional[
            typing.List["Route53RecordLatencyRoutingPolicy"]
        ] = None,
        multivalue_answer_routing_policy: typing.Optional[bool] = None,
        records: typing.Optional[typing.List[str]] = None,
        set_identifier: typing.Optional[str] = None,
        ttl: typing.Optional[jsii.Number] = None,
        weighted_routing_policy: typing.Optional[
            typing.List["Route53RecordWeightedRoutingPolicy"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param type: 
        :param zone_id: 
        :param alias: alias block.
        :param allow_overwrite: 
        :param failover_routing_policy: failover_routing_policy block.
        :param geolocation_routing_policy: geolocation_routing_policy block.
        :param health_check_id: 
        :param latency_routing_policy: latency_routing_policy block.
        :param multivalue_answer_routing_policy: 
        :param records: 
        :param set_identifier: 
        :param ttl: 
        :param weighted_routing_policy: weighted_routing_policy block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53RecordConfig(
            name=name,
            type=type,
            zone_id=zone_id,
            alias=alias,
            allow_overwrite=allow_overwrite,
            failover_routing_policy=failover_routing_policy,
            geolocation_routing_policy=geolocation_routing_policy,
            health_check_id=health_check_id,
            latency_routing_policy=latency_routing_policy,
            multivalue_answer_routing_policy=multivalue_answer_routing_policy,
            records=records,
            set_identifier=set_identifier,
            ttl=ttl,
            weighted_routing_policy=weighted_routing_policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53Record, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="fqdn")
    def fqdn(self) -> str:
        return jsii.get(self, "fqdn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @zone_id.setter
    def zone_id(self, value: str) -> None:
        jsii.set(self, "zoneId", value)

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> typing.Optional[typing.List["Route53RecordAlias"]]:
        return jsii.get(self, "alias")

    @alias.setter
    def alias(self, value: typing.Optional[typing.List["Route53RecordAlias"]]) -> None:
        jsii.set(self, "alias", value)

    @builtins.property
    @jsii.member(jsii_name="allowOverwrite")
    def allow_overwrite(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowOverwrite")

    @allow_overwrite.setter
    def allow_overwrite(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowOverwrite", value)

    @builtins.property
    @jsii.member(jsii_name="failoverRoutingPolicy")
    def failover_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordFailoverRoutingPolicy"]]:
        return jsii.get(self, "failoverRoutingPolicy")

    @failover_routing_policy.setter
    def failover_routing_policy(
        self, value: typing.Optional[typing.List["Route53RecordFailoverRoutingPolicy"]]
    ) -> None:
        jsii.set(self, "failoverRoutingPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="geolocationRoutingPolicy")
    def geolocation_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordGeolocationRoutingPolicy"]]:
        return jsii.get(self, "geolocationRoutingPolicy")

    @geolocation_routing_policy.setter
    def geolocation_routing_policy(
        self,
        value: typing.Optional[typing.List["Route53RecordGeolocationRoutingPolicy"]],
    ) -> None:
        jsii.set(self, "geolocationRoutingPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckId")
    def health_check_id(self) -> typing.Optional[str]:
        return jsii.get(self, "healthCheckId")

    @health_check_id.setter
    def health_check_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "healthCheckId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="latencyRoutingPolicy")
    def latency_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordLatencyRoutingPolicy"]]:
        return jsii.get(self, "latencyRoutingPolicy")

    @latency_routing_policy.setter
    def latency_routing_policy(
        self, value: typing.Optional[typing.List["Route53RecordLatencyRoutingPolicy"]]
    ) -> None:
        jsii.set(self, "latencyRoutingPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="multivalueAnswerRoutingPolicy")
    def multivalue_answer_routing_policy(self) -> typing.Optional[bool]:
        return jsii.get(self, "multivalueAnswerRoutingPolicy")

    @multivalue_answer_routing_policy.setter
    def multivalue_answer_routing_policy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "multivalueAnswerRoutingPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="records")
    def records(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "records")

    @records.setter
    def records(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "records", value)

    @builtins.property
    @jsii.member(jsii_name="setIdentifier")
    def set_identifier(self) -> typing.Optional[str]:
        return jsii.get(self, "setIdentifier")

    @set_identifier.setter
    def set_identifier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "setIdentifier", value)

    @builtins.property
    @jsii.member(jsii_name="ttl")
    def ttl(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "ttl")

    @ttl.setter
    def ttl(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "ttl", value)

    @builtins.property
    @jsii.member(jsii_name="weightedRoutingPolicy")
    def weighted_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordWeightedRoutingPolicy"]]:
        return jsii.get(self, "weightedRoutingPolicy")

    @weighted_routing_policy.setter
    def weighted_routing_policy(
        self, value: typing.Optional[typing.List["Route53RecordWeightedRoutingPolicy"]]
    ) -> None:
        jsii.set(self, "weightedRoutingPolicy", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53RecordAlias",
    jsii_struct_bases=[],
    name_mapping={
        "evaluate_target_health": "evaluateTargetHealth",
        "name": "name",
        "zone_id": "zoneId",
    },
)
class Route53RecordAlias:
    def __init__(
        self, *, evaluate_target_health: bool, name: str, zone_id: str
    ) -> None:
        """
        :param evaluate_target_health: 
        :param name: 
        :param zone_id: 
        """
        self._values = {
            "evaluate_target_health": evaluate_target_health,
            "name": name,
            "zone_id": zone_id,
        }

    @builtins.property
    def evaluate_target_health(self) -> bool:
        return self._values.get("evaluate_target_health")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def zone_id(self) -> str:
        return self._values.get("zone_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53RecordAlias(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53RecordConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "type": "type",
        "zone_id": "zoneId",
        "alias": "alias",
        "allow_overwrite": "allowOverwrite",
        "failover_routing_policy": "failoverRoutingPolicy",
        "geolocation_routing_policy": "geolocationRoutingPolicy",
        "health_check_id": "healthCheckId",
        "latency_routing_policy": "latencyRoutingPolicy",
        "multivalue_answer_routing_policy": "multivalueAnswerRoutingPolicy",
        "records": "records",
        "set_identifier": "setIdentifier",
        "ttl": "ttl",
        "weighted_routing_policy": "weightedRoutingPolicy",
    },
)
class Route53RecordConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        type: str,
        zone_id: str,
        alias: typing.Optional[typing.List["Route53RecordAlias"]] = None,
        allow_overwrite: typing.Optional[bool] = None,
        failover_routing_policy: typing.Optional[
            typing.List["Route53RecordFailoverRoutingPolicy"]
        ] = None,
        geolocation_routing_policy: typing.Optional[
            typing.List["Route53RecordGeolocationRoutingPolicy"]
        ] = None,
        health_check_id: typing.Optional[str] = None,
        latency_routing_policy: typing.Optional[
            typing.List["Route53RecordLatencyRoutingPolicy"]
        ] = None,
        multivalue_answer_routing_policy: typing.Optional[bool] = None,
        records: typing.Optional[typing.List[str]] = None,
        set_identifier: typing.Optional[str] = None,
        ttl: typing.Optional[jsii.Number] = None,
        weighted_routing_policy: typing.Optional[
            typing.List["Route53RecordWeightedRoutingPolicy"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param type: 
        :param zone_id: 
        :param alias: alias block.
        :param allow_overwrite: 
        :param failover_routing_policy: failover_routing_policy block.
        :param geolocation_routing_policy: geolocation_routing_policy block.
        :param health_check_id: 
        :param latency_routing_policy: latency_routing_policy block.
        :param multivalue_answer_routing_policy: 
        :param records: 
        :param set_identifier: 
        :param ttl: 
        :param weighted_routing_policy: weighted_routing_policy block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "type": type,
            "zone_id": zone_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if alias is not None:
            self._values["alias"] = alias
        if allow_overwrite is not None:
            self._values["allow_overwrite"] = allow_overwrite
        if failover_routing_policy is not None:
            self._values["failover_routing_policy"] = failover_routing_policy
        if geolocation_routing_policy is not None:
            self._values["geolocation_routing_policy"] = geolocation_routing_policy
        if health_check_id is not None:
            self._values["health_check_id"] = health_check_id
        if latency_routing_policy is not None:
            self._values["latency_routing_policy"] = latency_routing_policy
        if multivalue_answer_routing_policy is not None:
            self._values[
                "multivalue_answer_routing_policy"
            ] = multivalue_answer_routing_policy
        if records is not None:
            self._values["records"] = records
        if set_identifier is not None:
            self._values["set_identifier"] = set_identifier
        if ttl is not None:
            self._values["ttl"] = ttl
        if weighted_routing_policy is not None:
            self._values["weighted_routing_policy"] = weighted_routing_policy

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def zone_id(self) -> str:
        return self._values.get("zone_id")

    @builtins.property
    def alias(self) -> typing.Optional[typing.List["Route53RecordAlias"]]:
        """alias block."""
        return self._values.get("alias")

    @builtins.property
    def allow_overwrite(self) -> typing.Optional[bool]:
        return self._values.get("allow_overwrite")

    @builtins.property
    def failover_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordFailoverRoutingPolicy"]]:
        """failover_routing_policy block."""
        return self._values.get("failover_routing_policy")

    @builtins.property
    def geolocation_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordGeolocationRoutingPolicy"]]:
        """geolocation_routing_policy block."""
        return self._values.get("geolocation_routing_policy")

    @builtins.property
    def health_check_id(self) -> typing.Optional[str]:
        return self._values.get("health_check_id")

    @builtins.property
    def latency_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordLatencyRoutingPolicy"]]:
        """latency_routing_policy block."""
        return self._values.get("latency_routing_policy")

    @builtins.property
    def multivalue_answer_routing_policy(self) -> typing.Optional[bool]:
        return self._values.get("multivalue_answer_routing_policy")

    @builtins.property
    def records(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("records")

    @builtins.property
    def set_identifier(self) -> typing.Optional[str]:
        return self._values.get("set_identifier")

    @builtins.property
    def ttl(self) -> typing.Optional[jsii.Number]:
        return self._values.get("ttl")

    @builtins.property
    def weighted_routing_policy(
        self,
    ) -> typing.Optional[typing.List["Route53RecordWeightedRoutingPolicy"]]:
        """weighted_routing_policy block."""
        return self._values.get("weighted_routing_policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53RecordConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53RecordFailoverRoutingPolicy",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class Route53RecordFailoverRoutingPolicy:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53RecordFailoverRoutingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53RecordGeolocationRoutingPolicy",
    jsii_struct_bases=[],
    name_mapping={
        "continent": "continent",
        "country": "country",
        "subdivision": "subdivision",
    },
)
class Route53RecordGeolocationRoutingPolicy:
    def __init__(
        self,
        *,
        continent: typing.Optional[str] = None,
        country: typing.Optional[str] = None,
        subdivision: typing.Optional[str] = None,
    ) -> None:
        """
        :param continent: 
        :param country: 
        :param subdivision: 
        """
        self._values = {}
        if continent is not None:
            self._values["continent"] = continent
        if country is not None:
            self._values["country"] = country
        if subdivision is not None:
            self._values["subdivision"] = subdivision

    @builtins.property
    def continent(self) -> typing.Optional[str]:
        return self._values.get("continent")

    @builtins.property
    def country(self) -> typing.Optional[str]:
        return self._values.get("country")

    @builtins.property
    def subdivision(self) -> typing.Optional[str]:
        return self._values.get("subdivision")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53RecordGeolocationRoutingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53RecordLatencyRoutingPolicy",
    jsii_struct_bases=[],
    name_mapping={"region": "region"},
)
class Route53RecordLatencyRoutingPolicy:
    def __init__(self, *, region: str) -> None:
        """
        :param region: 
        """
        self._values = {
            "region": region,
        }

    @builtins.property
    def region(self) -> str:
        return self._values.get("region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53RecordLatencyRoutingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53RecordWeightedRoutingPolicy",
    jsii_struct_bases=[],
    name_mapping={"weight": "weight"},
)
class Route53RecordWeightedRoutingPolicy:
    def __init__(self, *, weight: jsii.Number) -> None:
        """
        :param weight: 
        """
        self._values = {
            "weight": weight,
        }

    @builtins.property
    def weight(self) -> jsii.Number:
        return self._values.get("weight")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53RecordWeightedRoutingPolicy(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route53ResolverEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        direction: str,
        ip_address: typing.List["Route53ResolverEndpointIpAddress"],
        security_group_ids: typing.List[str],
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["Route53ResolverEndpointTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param direction: 
        :param ip_address: ip_address block.
        :param security_group_ids: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53ResolverEndpointConfig(
            direction=direction,
            ip_address=ip_address,
            security_group_ids=security_group_ids,
            name=name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53ResolverEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="hostVpcId")
    def host_vpc_id(self) -> str:
        return jsii.get(self, "hostVpcId")

    @builtins.property
    @jsii.member(jsii_name="direction")
    def direction(self) -> str:
        return jsii.get(self, "direction")

    @direction.setter
    def direction(self, value: str) -> None:
        jsii.set(self, "direction", value)

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> typing.List["Route53ResolverEndpointIpAddress"]:
        return jsii.get(self, "ipAddress")

    @ip_address.setter
    def ip_address(
        self, value: typing.List["Route53ResolverEndpointIpAddress"]
    ) -> None:
        jsii.set(self, "ipAddress", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.List[str]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["Route53ResolverEndpointTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["Route53ResolverEndpointTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "direction": "direction",
        "ip_address": "ipAddress",
        "security_group_ids": "securityGroupIds",
        "name": "name",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class Route53ResolverEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        direction: str,
        ip_address: typing.List["Route53ResolverEndpointIpAddress"],
        security_group_ids: typing.List[str],
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["Route53ResolverEndpointTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param direction: 
        :param ip_address: ip_address block.
        :param security_group_ids: 
        :param name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = Route53ResolverEndpointTimeouts(**timeouts)
        self._values = {
            "direction": direction,
            "ip_address": ip_address,
            "security_group_ids": security_group_ids,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def direction(self) -> str:
        return self._values.get("direction")

    @builtins.property
    def ip_address(self) -> typing.List["Route53ResolverEndpointIpAddress"]:
        """ip_address block."""
        return self._values.get("ip_address")

    @builtins.property
    def security_group_ids(self) -> typing.List[str]:
        return self._values.get("security_group_ids")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["Route53ResolverEndpointTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverEndpointIpAddress",
    jsii_struct_bases=[],
    name_mapping={"subnet_id": "subnetId", "ip": "ip"},
)
class Route53ResolverEndpointIpAddress:
    def __init__(self, *, subnet_id: str, ip: typing.Optional[str] = None) -> None:
        """
        :param subnet_id: 
        :param ip: 
        """
        self._values = {
            "subnet_id": subnet_id,
        }
        if ip is not None:
            self._values["ip"] = ip

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    @builtins.property
    def ip(self) -> typing.Optional[str]:
        return self._values.get("ip")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverEndpointIpAddress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverEndpointTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class Route53ResolverEndpointTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverEndpointTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route53ResolverRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: str,
        rule_type: str,
        name: typing.Optional[str] = None,
        resolver_endpoint_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_ip: typing.Optional[typing.List["Route53ResolverRuleTargetIp"]] = None,
        timeouts: typing.Optional["Route53ResolverRuleTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param rule_type: 
        :param name: 
        :param resolver_endpoint_id: 
        :param tags: 
        :param target_ip: target_ip block.
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53ResolverRuleConfig(
            domain_name=domain_name,
            rule_type=rule_type,
            name=name,
            resolver_endpoint_id=resolver_endpoint_id,
            tags=tags,
            target_ip=target_ip,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53ResolverRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="shareStatus")
    def share_status(self) -> str:
        return jsii.get(self, "shareStatus")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: str) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="ruleType")
    def rule_type(self) -> str:
        return jsii.get(self, "ruleType")

    @rule_type.setter
    def rule_type(self, value: str) -> None:
        jsii.set(self, "ruleType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resolverEndpointId")
    def resolver_endpoint_id(self) -> typing.Optional[str]:
        return jsii.get(self, "resolverEndpointId")

    @resolver_endpoint_id.setter
    def resolver_endpoint_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "resolverEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="targetIp")
    def target_ip(self) -> typing.Optional[typing.List["Route53ResolverRuleTargetIp"]]:
        return jsii.get(self, "targetIp")

    @target_ip.setter
    def target_ip(
        self, value: typing.Optional[typing.List["Route53ResolverRuleTargetIp"]]
    ) -> None:
        jsii.set(self, "targetIp", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["Route53ResolverRuleTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["Route53ResolverRuleTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


class Route53ResolverRuleAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverRuleAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        resolver_rule_id: str,
        vpc_id: str,
        name: typing.Optional[str] = None,
        timeouts: typing.Optional["Route53ResolverRuleAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resolver_rule_id: 
        :param vpc_id: 
        :param name: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53ResolverRuleAssociationConfig(
            resolver_rule_id=resolver_rule_id,
            vpc_id=vpc_id,
            name=name,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53ResolverRuleAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resolverRuleId")
    def resolver_rule_id(self) -> str:
        return jsii.get(self, "resolverRuleId")

    @resolver_rule_id.setter
    def resolver_rule_id(self, value: str) -> None:
        jsii.set(self, "resolverRuleId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["Route53ResolverRuleAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["Route53ResolverRuleAssociationTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverRuleAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resolver_rule_id": "resolverRuleId",
        "vpc_id": "vpcId",
        "name": "name",
        "timeouts": "timeouts",
    },
)
class Route53ResolverRuleAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resolver_rule_id: str,
        vpc_id: str,
        name: typing.Optional[str] = None,
        timeouts: typing.Optional["Route53ResolverRuleAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resolver_rule_id: 
        :param vpc_id: 
        :param name: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = Route53ResolverRuleAssociationTimeouts(**timeouts)
        self._values = {
            "resolver_rule_id": resolver_rule_id,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def resolver_rule_id(self) -> str:
        return self._values.get("resolver_rule_id")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def timeouts(self) -> typing.Optional["Route53ResolverRuleAssociationTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverRuleAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverRuleAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class Route53ResolverRuleAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverRuleAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
        "rule_type": "ruleType",
        "name": "name",
        "resolver_endpoint_id": "resolverEndpointId",
        "tags": "tags",
        "target_ip": "targetIp",
        "timeouts": "timeouts",
    },
)
class Route53ResolverRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: str,
        rule_type: str,
        name: typing.Optional[str] = None,
        resolver_endpoint_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_ip: typing.Optional[typing.List["Route53ResolverRuleTargetIp"]] = None,
        timeouts: typing.Optional["Route53ResolverRuleTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        :param rule_type: 
        :param name: 
        :param resolver_endpoint_id: 
        :param tags: 
        :param target_ip: target_ip block.
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = Route53ResolverRuleTimeouts(**timeouts)
        self._values = {
            "domain_name": domain_name,
            "rule_type": rule_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if resolver_endpoint_id is not None:
            self._values["resolver_endpoint_id"] = resolver_endpoint_id
        if tags is not None:
            self._values["tags"] = tags
        if target_ip is not None:
            self._values["target_ip"] = target_ip
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def rule_type(self) -> str:
        return self._values.get("rule_type")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def resolver_endpoint_id(self) -> typing.Optional[str]:
        return self._values.get("resolver_endpoint_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target_ip(self) -> typing.Optional[typing.List["Route53ResolverRuleTargetIp"]]:
        """target_ip block."""
        return self._values.get("target_ip")

    @builtins.property
    def timeouts(self) -> typing.Optional["Route53ResolverRuleTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverRuleTargetIp",
    jsii_struct_bases=[],
    name_mapping={"ip": "ip", "port": "port"},
)
class Route53ResolverRuleTargetIp:
    def __init__(self, *, ip: str, port: typing.Optional[jsii.Number] = None) -> None:
        """
        :param ip: 
        :param port: 
        """
        self._values = {
            "ip": ip,
        }
        if port is not None:
            self._values["port"] = port

    @builtins.property
    def ip(self) -> str:
        return self._values.get("ip")

    @builtins.property
    def port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverRuleTargetIp(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ResolverRuleTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class Route53ResolverRuleTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ResolverRuleTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Route53Zone(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53Zone",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        comment: typing.Optional[str] = None,
        delegation_set_id: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc: typing.Optional[typing.List["Route53ZoneVpc"]] = None,
        vpc_id: typing.Optional[str] = None,
        vpc_region: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param comment: 
        :param delegation_set_id: 
        :param force_destroy: 
        :param tags: 
        :param vpc: vpc block.
        :param vpc_id: 
        :param vpc_region: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53ZoneConfig(
            name=name,
            comment=comment,
            delegation_set_id=delegation_set_id,
            force_destroy=force_destroy,
            tags=tags,
            vpc=vpc,
            vpc_id=vpc_id,
            vpc_region=vpc_region,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53Zone, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="nameServers")
    def name_servers(self) -> typing.List[str]:
        return jsii.get(self, "nameServers")

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="comment")
    def comment(self) -> typing.Optional[str]:
        return jsii.get(self, "comment")

    @comment.setter
    def comment(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "comment", value)

    @builtins.property
    @jsii.member(jsii_name="delegationSetId")
    def delegation_set_id(self) -> typing.Optional[str]:
        return jsii.get(self, "delegationSetId")

    @delegation_set_id.setter
    def delegation_set_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "delegationSetId", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpc")
    def vpc(self) -> typing.Optional[typing.List["Route53ZoneVpc"]]:
        return jsii.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: typing.Optional[typing.List["Route53ZoneVpc"]]) -> None:
        jsii.set(self, "vpc", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcRegion")
    def vpc_region(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcRegion")

    @vpc_region.setter
    def vpc_region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcRegion", value)


class Route53ZoneAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ZoneAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_id: str,
        zone_id: str,
        vpc_region: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_id: 
        :param zone_id: 
        :param vpc_region: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Route53ZoneAssociationConfig(
            vpc_id=vpc_id,
            zone_id=zone_id,
            vpc_region=vpc_region,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Route53ZoneAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="zoneId")
    def zone_id(self) -> str:
        return jsii.get(self, "zoneId")

    @zone_id.setter
    def zone_id(self, value: str) -> None:
        jsii.set(self, "zoneId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="vpcRegion")
    def vpc_region(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcRegion")

    @vpc_region.setter
    def vpc_region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcRegion", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ZoneAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_id": "vpcId",
        "zone_id": "zoneId",
        "vpc_region": "vpcRegion",
    },
)
class Route53ZoneAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_id: str,
        zone_id: str,
        vpc_region: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_id: 
        :param zone_id: 
        :param vpc_region: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_id": vpc_id,
            "zone_id": zone_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if vpc_region is not None:
            self._values["vpc_region"] = vpc_region

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def zone_id(self) -> str:
        return self._values.get("zone_id")

    @builtins.property
    def vpc_region(self) -> typing.Optional[str]:
        return self._values.get("vpc_region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ZoneAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ZoneConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "comment": "comment",
        "delegation_set_id": "delegationSetId",
        "force_destroy": "forceDestroy",
        "tags": "tags",
        "vpc": "vpc",
        "vpc_id": "vpcId",
        "vpc_region": "vpcRegion",
    },
)
class Route53ZoneConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        comment: typing.Optional[str] = None,
        delegation_set_id: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc: typing.Optional[typing.List["Route53ZoneVpc"]] = None,
        vpc_id: typing.Optional[str] = None,
        vpc_region: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param comment: 
        :param delegation_set_id: 
        :param force_destroy: 
        :param tags: 
        :param vpc: vpc block.
        :param vpc_id: 
        :param vpc_region: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if comment is not None:
            self._values["comment"] = comment
        if delegation_set_id is not None:
            self._values["delegation_set_id"] = delegation_set_id
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if tags is not None:
            self._values["tags"] = tags
        if vpc is not None:
            self._values["vpc"] = vpc
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id
        if vpc_region is not None:
            self._values["vpc_region"] = vpc_region

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def comment(self) -> typing.Optional[str]:
        return self._values.get("comment")

    @builtins.property
    def delegation_set_id(self) -> typing.Optional[str]:
        return self._values.get("delegation_set_id")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc(self) -> typing.Optional[typing.List["Route53ZoneVpc"]]:
        """vpc block."""
        return self._values.get("vpc")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    @builtins.property
    def vpc_region(self) -> typing.Optional[str]:
        return self._values.get("vpc_region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ZoneConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Route53ZoneVpc",
    jsii_struct_bases=[],
    name_mapping={"vpc_id": "vpcId", "vpc_region": "vpcRegion"},
)
class Route53ZoneVpc:
    def __init__(self, *, vpc_id: str, vpc_region: typing.Optional[str] = None) -> None:
        """
        :param vpc_id: 
        :param vpc_region: 
        """
        self._values = {
            "vpc_id": vpc_id,
        }
        if vpc_region is not None:
            self._values["vpc_region"] = vpc_region

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def vpc_region(self) -> typing.Optional[str]:
        return self._values.get("vpc_region")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Route53ZoneVpc(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "route_table_id": "routeTableId",
        "destination_cidr_block": "destinationCidrBlock",
        "destination_ipv6_cidr_block": "destinationIpv6CidrBlock",
        "egress_only_gateway_id": "egressOnlyGatewayId",
        "gateway_id": "gatewayId",
        "instance_id": "instanceId",
        "nat_gateway_id": "natGatewayId",
        "network_interface_id": "networkInterfaceId",
        "timeouts": "timeouts",
        "transit_gateway_id": "transitGatewayId",
        "vpc_peering_connection_id": "vpcPeeringConnectionId",
    },
)
class RouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        route_table_id: str,
        destination_cidr_block: typing.Optional[str] = None,
        destination_ipv6_cidr_block: typing.Optional[str] = None,
        egress_only_gateway_id: typing.Optional[str] = None,
        gateway_id: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        nat_gateway_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        timeouts: typing.Optional["RouteTimeouts"] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpc_peering_connection_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param route_table_id: 
        :param destination_cidr_block: 
        :param destination_ipv6_cidr_block: 
        :param egress_only_gateway_id: 
        :param gateway_id: 
        :param instance_id: 
        :param nat_gateway_id: 
        :param network_interface_id: 
        :param timeouts: timeouts block.
        :param transit_gateway_id: 
        :param vpc_peering_connection_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = RouteTimeouts(**timeouts)
        self._values = {
            "route_table_id": route_table_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if destination_cidr_block is not None:
            self._values["destination_cidr_block"] = destination_cidr_block
        if destination_ipv6_cidr_block is not None:
            self._values["destination_ipv6_cidr_block"] = destination_ipv6_cidr_block
        if egress_only_gateway_id is not None:
            self._values["egress_only_gateway_id"] = egress_only_gateway_id
        if gateway_id is not None:
            self._values["gateway_id"] = gateway_id
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if nat_gateway_id is not None:
            self._values["nat_gateway_id"] = nat_gateway_id
        if network_interface_id is not None:
            self._values["network_interface_id"] = network_interface_id
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if transit_gateway_id is not None:
            self._values["transit_gateway_id"] = transit_gateway_id
        if vpc_peering_connection_id is not None:
            self._values["vpc_peering_connection_id"] = vpc_peering_connection_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def route_table_id(self) -> str:
        return self._values.get("route_table_id")

    @builtins.property
    def destination_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("destination_cidr_block")

    @builtins.property
    def destination_ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("destination_ipv6_cidr_block")

    @builtins.property
    def egress_only_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("egress_only_gateway_id")

    @builtins.property
    def gateway_id(self) -> typing.Optional[str]:
        return self._values.get("gateway_id")

    @builtins.property
    def instance_id(self) -> typing.Optional[str]:
        return self._values.get("instance_id")

    @builtins.property
    def nat_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("nat_gateway_id")

    @builtins.property
    def network_interface_id(self) -> typing.Optional[str]:
        return self._values.get("network_interface_id")

    @builtins.property
    def timeouts(self) -> typing.Optional["RouteTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def transit_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def vpc_peering_connection_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_peering_connection_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class RouteTable(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RouteTable",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_id: str,
        propagating_vgws: typing.Optional[typing.List[str]] = None,
        route: typing.Optional[typing.List["RouteTableRoute"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_id: 
        :param propagating_vgws: 
        :param route: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RouteTableConfig(
            vpc_id=vpc_id,
            propagating_vgws=propagating_vgws,
            route=route,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RouteTable, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="propagatingVgws")
    def propagating_vgws(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "propagatingVgws")

    @propagating_vgws.setter
    def propagating_vgws(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "propagatingVgws", value)

    @builtins.property
    @jsii.member(jsii_name="route")
    def route(self) -> typing.Optional[typing.List["RouteTableRoute"]]:
        return jsii.get(self, "route")

    @route.setter
    def route(self, value: typing.Optional[typing.List["RouteTableRoute"]]) -> None:
        jsii.set(self, "route", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class RouteTableAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.RouteTableAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        route_table_id: str,
        gateway_id: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param route_table_id: 
        :param gateway_id: 
        :param subnet_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = RouteTableAssociationConfig(
            route_table_id=route_table_id,
            gateway_id=gateway_id,
            subnet_id=subnet_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(RouteTableAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> str:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter
    def route_table_id(self, value: str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayId")
    def gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "gatewayId")

    @gateway_id.setter
    def gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "gatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RouteTableAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "route_table_id": "routeTableId",
        "gateway_id": "gatewayId",
        "subnet_id": "subnetId",
    },
)
class RouteTableAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        route_table_id: str,
        gateway_id: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param route_table_id: 
        :param gateway_id: 
        :param subnet_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "route_table_id": route_table_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if gateway_id is not None:
            self._values["gateway_id"] = gateway_id
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def route_table_id(self) -> str:
        return self._values.get("route_table_id")

    @builtins.property
    def gateway_id(self) -> typing.Optional[str]:
        return self._values.get("gateway_id")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTableAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RouteTableConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_id": "vpcId",
        "propagating_vgws": "propagatingVgws",
        "route": "route",
        "tags": "tags",
    },
)
class RouteTableConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_id: str,
        propagating_vgws: typing.Optional[typing.List[str]] = None,
        route: typing.Optional[typing.List["RouteTableRoute"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_id: 
        :param propagating_vgws: 
        :param route: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if propagating_vgws is not None:
            self._values["propagating_vgws"] = propagating_vgws
        if route is not None:
            self._values["route"] = route
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def propagating_vgws(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("propagating_vgws")

    @builtins.property
    def route(self) -> typing.Optional[typing.List["RouteTableRoute"]]:
        return self._values.get("route")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTableConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RouteTableRoute",
    jsii_struct_bases=[],
    name_mapping={
        "cidr_block": "cidrBlock",
        "egress_only_gateway_id": "egressOnlyGatewayId",
        "gateway_id": "gatewayId",
        "instance_id": "instanceId",
        "ipv6_cidr_block": "ipv6CidrBlock",
        "nat_gateway_id": "natGatewayId",
        "network_interface_id": "networkInterfaceId",
        "transit_gateway_id": "transitGatewayId",
        "vpc_peering_connection_id": "vpcPeeringConnectionId",
    },
)
class RouteTableRoute:
    def __init__(
        self,
        *,
        cidr_block: typing.Optional[str] = None,
        egress_only_gateway_id: typing.Optional[str] = None,
        gateway_id: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        nat_gateway_id: typing.Optional[str] = None,
        network_interface_id: typing.Optional[str] = None,
        transit_gateway_id: typing.Optional[str] = None,
        vpc_peering_connection_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param cidr_block: 
        :param egress_only_gateway_id: 
        :param gateway_id: 
        :param instance_id: 
        :param ipv6_cidr_block: 
        :param nat_gateway_id: 
        :param network_interface_id: 
        :param transit_gateway_id: 
        :param vpc_peering_connection_id: 
        """
        self._values = {}
        if cidr_block is not None:
            self._values["cidr_block"] = cidr_block
        if egress_only_gateway_id is not None:
            self._values["egress_only_gateway_id"] = egress_only_gateway_id
        if gateway_id is not None:
            self._values["gateway_id"] = gateway_id
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block
        if nat_gateway_id is not None:
            self._values["nat_gateway_id"] = nat_gateway_id
        if network_interface_id is not None:
            self._values["network_interface_id"] = network_interface_id
        if transit_gateway_id is not None:
            self._values["transit_gateway_id"] = transit_gateway_id
        if vpc_peering_connection_id is not None:
            self._values["vpc_peering_connection_id"] = vpc_peering_connection_id

    @builtins.property
    def cidr_block(self) -> typing.Optional[str]:
        return self._values.get("cidr_block")

    @builtins.property
    def egress_only_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("egress_only_gateway_id")

    @builtins.property
    def gateway_id(self) -> typing.Optional[str]:
        return self._values.get("gateway_id")

    @builtins.property
    def instance_id(self) -> typing.Optional[str]:
        return self._values.get("instance_id")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    @builtins.property
    def nat_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("nat_gateway_id")

    @builtins.property
    def network_interface_id(self) -> typing.Optional[str]:
        return self._values.get("network_interface_id")

    @builtins.property
    def transit_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def vpc_peering_connection_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_peering_connection_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTableRoute(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.RouteTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class RouteTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "RouteTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3AccessPoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3AccessPoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        name: str,
        account_id: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        public_access_block_configuration: typing.Optional[
            typing.List["S3AccessPointPublicAccessBlockConfiguration"]
        ] = None,
        vpc_configuration: typing.Optional[
            typing.List["S3AccessPointVpcConfiguration"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param name: 
        :param account_id: 
        :param policy: 
        :param public_access_block_configuration: public_access_block_configuration block.
        :param vpc_configuration: vpc_configuration block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3AccessPointConfig(
            bucket=bucket,
            name=name,
            account_id=account_id,
            policy=policy,
            public_access_block_configuration=public_access_block_configuration,
            vpc_configuration=vpc_configuration,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3AccessPoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> str:
        return jsii.get(self, "domainName")

    @builtins.property
    @jsii.member(jsii_name="hasPublicAccessPolicy")
    def has_public_access_policy(self) -> bool:
        return jsii.get(self, "hasPublicAccessPolicy")

    @builtins.property
    @jsii.member(jsii_name="networkOrigin")
    def network_origin(self) -> str:
        return jsii.get(self, "networkOrigin")

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="publicAccessBlockConfiguration")
    def public_access_block_configuration(
        self,
    ) -> typing.Optional[typing.List["S3AccessPointPublicAccessBlockConfiguration"]]:
        return jsii.get(self, "publicAccessBlockConfiguration")

    @public_access_block_configuration.setter
    def public_access_block_configuration(
        self,
        value: typing.Optional[
            typing.List["S3AccessPointPublicAccessBlockConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "publicAccessBlockConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConfiguration")
    def vpc_configuration(
        self,
    ) -> typing.Optional[typing.List["S3AccessPointVpcConfiguration"]]:
        return jsii.get(self, "vpcConfiguration")

    @vpc_configuration.setter
    def vpc_configuration(
        self, value: typing.Optional[typing.List["S3AccessPointVpcConfiguration"]]
    ) -> None:
        jsii.set(self, "vpcConfiguration", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3AccessPointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "name": "name",
        "account_id": "accountId",
        "policy": "policy",
        "public_access_block_configuration": "publicAccessBlockConfiguration",
        "vpc_configuration": "vpcConfiguration",
    },
)
class S3AccessPointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        name: str,
        account_id: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        public_access_block_configuration: typing.Optional[
            typing.List["S3AccessPointPublicAccessBlockConfiguration"]
        ] = None,
        vpc_configuration: typing.Optional[
            typing.List["S3AccessPointVpcConfiguration"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param name: 
        :param account_id: 
        :param policy: 
        :param public_access_block_configuration: public_access_block_configuration block.
        :param vpc_configuration: vpc_configuration block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if account_id is not None:
            self._values["account_id"] = account_id
        if policy is not None:
            self._values["policy"] = policy
        if public_access_block_configuration is not None:
            self._values[
                "public_access_block_configuration"
            ] = public_access_block_configuration
        if vpc_configuration is not None:
            self._values["vpc_configuration"] = vpc_configuration

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def account_id(self) -> typing.Optional[str]:
        return self._values.get("account_id")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def public_access_block_configuration(
        self,
    ) -> typing.Optional[typing.List["S3AccessPointPublicAccessBlockConfiguration"]]:
        """public_access_block_configuration block."""
        return self._values.get("public_access_block_configuration")

    @builtins.property
    def vpc_configuration(
        self,
    ) -> typing.Optional[typing.List["S3AccessPointVpcConfiguration"]]:
        """vpc_configuration block."""
        return self._values.get("vpc_configuration")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3AccessPointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3AccessPointPublicAccessBlockConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "block_public_acls": "blockPublicAcls",
        "block_public_policy": "blockPublicPolicy",
        "ignore_public_acls": "ignorePublicAcls",
        "restrict_public_buckets": "restrictPublicBuckets",
    },
)
class S3AccessPointPublicAccessBlockConfiguration:
    def __init__(
        self,
        *,
        block_public_acls: typing.Optional[bool] = None,
        block_public_policy: typing.Optional[bool] = None,
        ignore_public_acls: typing.Optional[bool] = None,
        restrict_public_buckets: typing.Optional[bool] = None,
    ) -> None:
        """
        :param block_public_acls: 
        :param block_public_policy: 
        :param ignore_public_acls: 
        :param restrict_public_buckets: 
        """
        self._values = {}
        if block_public_acls is not None:
            self._values["block_public_acls"] = block_public_acls
        if block_public_policy is not None:
            self._values["block_public_policy"] = block_public_policy
        if ignore_public_acls is not None:
            self._values["ignore_public_acls"] = ignore_public_acls
        if restrict_public_buckets is not None:
            self._values["restrict_public_buckets"] = restrict_public_buckets

    @builtins.property
    def block_public_acls(self) -> typing.Optional[bool]:
        return self._values.get("block_public_acls")

    @builtins.property
    def block_public_policy(self) -> typing.Optional[bool]:
        return self._values.get("block_public_policy")

    @builtins.property
    def ignore_public_acls(self) -> typing.Optional[bool]:
        return self._values.get("ignore_public_acls")

    @builtins.property
    def restrict_public_buckets(self) -> typing.Optional[bool]:
        return self._values.get("restrict_public_buckets")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3AccessPointPublicAccessBlockConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3AccessPointVpcConfiguration",
    jsii_struct_bases=[],
    name_mapping={"vpc_id": "vpcId"},
)
class S3AccessPointVpcConfiguration:
    def __init__(self, *, vpc_id: str) -> None:
        """
        :param vpc_id: 
        """
        self._values = {
            "vpc_id": vpc_id,
        }

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3AccessPointVpcConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3AccountPublicAccessBlock(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3AccountPublicAccessBlock",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_id: typing.Optional[str] = None,
        block_public_acls: typing.Optional[bool] = None,
        block_public_policy: typing.Optional[bool] = None,
        ignore_public_acls: typing.Optional[bool] = None,
        restrict_public_buckets: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_id: 
        :param block_public_acls: 
        :param block_public_policy: 
        :param ignore_public_acls: 
        :param restrict_public_buckets: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3AccountPublicAccessBlockConfig(
            account_id=account_id,
            block_public_acls=block_public_acls,
            block_public_policy=block_public_policy,
            ignore_public_acls=ignore_public_acls,
            restrict_public_buckets=restrict_public_buckets,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3AccountPublicAccessBlock, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> typing.Optional[str]:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="blockPublicAcls")
    def block_public_acls(self) -> typing.Optional[bool]:
        return jsii.get(self, "blockPublicAcls")

    @block_public_acls.setter
    def block_public_acls(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "blockPublicAcls", value)

    @builtins.property
    @jsii.member(jsii_name="blockPublicPolicy")
    def block_public_policy(self) -> typing.Optional[bool]:
        return jsii.get(self, "blockPublicPolicy")

    @block_public_policy.setter
    def block_public_policy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "blockPublicPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ignorePublicAcls")
    def ignore_public_acls(self) -> typing.Optional[bool]:
        return jsii.get(self, "ignorePublicAcls")

    @ignore_public_acls.setter
    def ignore_public_acls(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ignorePublicAcls", value)

    @builtins.property
    @jsii.member(jsii_name="restrictPublicBuckets")
    def restrict_public_buckets(self) -> typing.Optional[bool]:
        return jsii.get(self, "restrictPublicBuckets")

    @restrict_public_buckets.setter
    def restrict_public_buckets(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "restrictPublicBuckets", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3AccountPublicAccessBlockConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_id": "accountId",
        "block_public_acls": "blockPublicAcls",
        "block_public_policy": "blockPublicPolicy",
        "ignore_public_acls": "ignorePublicAcls",
        "restrict_public_buckets": "restrictPublicBuckets",
    },
)
class S3AccountPublicAccessBlockConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_id: typing.Optional[str] = None,
        block_public_acls: typing.Optional[bool] = None,
        block_public_policy: typing.Optional[bool] = None,
        ignore_public_acls: typing.Optional[bool] = None,
        restrict_public_buckets: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_id: 
        :param block_public_acls: 
        :param block_public_policy: 
        :param ignore_public_acls: 
        :param restrict_public_buckets: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if account_id is not None:
            self._values["account_id"] = account_id
        if block_public_acls is not None:
            self._values["block_public_acls"] = block_public_acls
        if block_public_policy is not None:
            self._values["block_public_policy"] = block_public_policy
        if ignore_public_acls is not None:
            self._values["ignore_public_acls"] = ignore_public_acls
        if restrict_public_buckets is not None:
            self._values["restrict_public_buckets"] = restrict_public_buckets

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_id(self) -> typing.Optional[str]:
        return self._values.get("account_id")

    @builtins.property
    def block_public_acls(self) -> typing.Optional[bool]:
        return self._values.get("block_public_acls")

    @builtins.property
    def block_public_policy(self) -> typing.Optional[bool]:
        return self._values.get("block_public_policy")

    @builtins.property
    def ignore_public_acls(self) -> typing.Optional[bool]:
        return self._values.get("ignore_public_acls")

    @builtins.property
    def restrict_public_buckets(self) -> typing.Optional[bool]:
        return self._values.get("restrict_public_buckets")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3AccountPublicAccessBlockConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3Bucket(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3Bucket",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        acceleration_status: typing.Optional[str] = None,
        acl: typing.Optional[str] = None,
        bucket: typing.Optional[str] = None,
        bucket_prefix: typing.Optional[str] = None,
        cors_rule: typing.Optional[typing.List["S3BucketCorsRule"]] = None,
        force_destroy: typing.Optional[bool] = None,
        grant: typing.Optional[typing.List["S3BucketGrant"]] = None,
        hosted_zone_id: typing.Optional[str] = None,
        lifecycle_rule: typing.Optional[typing.List["S3BucketLifecycleRule"]] = None,
        logging: typing.Optional[typing.List["S3BucketLogging"]] = None,
        object_lock_configuration: typing.Optional[
            typing.List["S3BucketObjectLockConfiguration"]
        ] = None,
        policy: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        replication_configuration: typing.Optional[
            typing.List["S3BucketReplicationConfiguration"]
        ] = None,
        request_payer: typing.Optional[str] = None,
        server_side_encryption_configuration: typing.Optional[
            typing.List["S3BucketServerSideEncryptionConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        versioning: typing.Optional[typing.List["S3BucketVersioning"]] = None,
        website: typing.Optional[typing.List["S3BucketWebsite"]] = None,
        website_domain: typing.Optional[str] = None,
        website_endpoint: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param acceleration_status: 
        :param acl: 
        :param bucket: 
        :param bucket_prefix: 
        :param cors_rule: cors_rule block.
        :param force_destroy: 
        :param grant: grant block.
        :param hosted_zone_id: 
        :param lifecycle_rule: lifecycle_rule block.
        :param logging: logging block.
        :param object_lock_configuration: object_lock_configuration block.
        :param policy: 
        :param region: 
        :param replication_configuration: replication_configuration block.
        :param request_payer: 
        :param server_side_encryption_configuration: server_side_encryption_configuration block.
        :param tags: 
        :param versioning: versioning block.
        :param website: website block.
        :param website_domain: 
        :param website_endpoint: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketConfig(
            acceleration_status=acceleration_status,
            acl=acl,
            bucket=bucket,
            bucket_prefix=bucket_prefix,
            cors_rule=cors_rule,
            force_destroy=force_destroy,
            grant=grant,
            hosted_zone_id=hosted_zone_id,
            lifecycle_rule=lifecycle_rule,
            logging=logging,
            object_lock_configuration=object_lock_configuration,
            policy=policy,
            region=region,
            replication_configuration=replication_configuration,
            request_payer=request_payer,
            server_side_encryption_configuration=server_side_encryption_configuration,
            tags=tags,
            versioning=versioning,
            website=website,
            website_domain=website_domain,
            website_endpoint=website_endpoint,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3Bucket, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucketDomainName")
    def bucket_domain_name(self) -> str:
        return jsii.get(self, "bucketDomainName")

    @builtins.property
    @jsii.member(jsii_name="bucketRegionalDomainName")
    def bucket_regional_domain_name(self) -> str:
        return jsii.get(self, "bucketRegionalDomainName")

    @builtins.property
    @jsii.member(jsii_name="accelerationStatus")
    def acceleration_status(self) -> typing.Optional[str]:
        return jsii.get(self, "accelerationStatus")

    @acceleration_status.setter
    def acceleration_status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "accelerationStatus", value)

    @builtins.property
    @jsii.member(jsii_name="acl")
    def acl(self) -> typing.Optional[str]:
        return jsii.get(self, "acl")

    @acl.setter
    def acl(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "acl", value)

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> typing.Optional[str]:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="bucketPrefix")
    def bucket_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "bucketPrefix")

    @bucket_prefix.setter
    def bucket_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "bucketPrefix", value)

    @builtins.property
    @jsii.member(jsii_name="corsRule")
    def cors_rule(self) -> typing.Optional[typing.List["S3BucketCorsRule"]]:
        return jsii.get(self, "corsRule")

    @cors_rule.setter
    def cors_rule(
        self, value: typing.Optional[typing.List["S3BucketCorsRule"]]
    ) -> None:
        jsii.set(self, "corsRule", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="grant")
    def grant(self) -> typing.Optional[typing.List["S3BucketGrant"]]:
        return jsii.get(self, "grant")

    @grant.setter
    def grant(self, value: typing.Optional[typing.List["S3BucketGrant"]]) -> None:
        jsii.set(self, "grant", value)

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> typing.Optional[str]:
        return jsii.get(self, "hostedZoneId")

    @hosted_zone_id.setter
    def hosted_zone_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "hostedZoneId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="lifecycleRule")
    def lifecycle_rule(self) -> typing.Optional[typing.List["S3BucketLifecycleRule"]]:
        return jsii.get(self, "lifecycleRule")

    @lifecycle_rule.setter
    def lifecycle_rule(
        self, value: typing.Optional[typing.List["S3BucketLifecycleRule"]]
    ) -> None:
        jsii.set(self, "lifecycleRule", value)

    @builtins.property
    @jsii.member(jsii_name="logging")
    def logging(self) -> typing.Optional[typing.List["S3BucketLogging"]]:
        return jsii.get(self, "logging")

    @logging.setter
    def logging(self, value: typing.Optional[typing.List["S3BucketLogging"]]) -> None:
        jsii.set(self, "logging", value)

    @builtins.property
    @jsii.member(jsii_name="objectLockConfiguration")
    def object_lock_configuration(
        self,
    ) -> typing.Optional[typing.List["S3BucketObjectLockConfiguration"]]:
        return jsii.get(self, "objectLockConfiguration")

    @object_lock_configuration.setter
    def object_lock_configuration(
        self, value: typing.Optional[typing.List["S3BucketObjectLockConfiguration"]]
    ) -> None:
        jsii.set(self, "objectLockConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="region")
    def region(self) -> typing.Optional[str]:
        return jsii.get(self, "region")

    @region.setter
    def region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "region", value)

    @builtins.property
    @jsii.member(jsii_name="replicationConfiguration")
    def replication_configuration(
        self,
    ) -> typing.Optional[typing.List["S3BucketReplicationConfiguration"]]:
        return jsii.get(self, "replicationConfiguration")

    @replication_configuration.setter
    def replication_configuration(
        self, value: typing.Optional[typing.List["S3BucketReplicationConfiguration"]]
    ) -> None:
        jsii.set(self, "replicationConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="requestPayer")
    def request_payer(self) -> typing.Optional[str]:
        return jsii.get(self, "requestPayer")

    @request_payer.setter
    def request_payer(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "requestPayer", value)

    @builtins.property
    @jsii.member(jsii_name="serverSideEncryptionConfiguration")
    def server_side_encryption_configuration(
        self,
    ) -> typing.Optional[typing.List["S3BucketServerSideEncryptionConfiguration"]]:
        return jsii.get(self, "serverSideEncryptionConfiguration")

    @server_side_encryption_configuration.setter
    def server_side_encryption_configuration(
        self,
        value: typing.Optional[
            typing.List["S3BucketServerSideEncryptionConfiguration"]
        ],
    ) -> None:
        jsii.set(self, "serverSideEncryptionConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="versioning")
    def versioning(self) -> typing.Optional[typing.List["S3BucketVersioning"]]:
        return jsii.get(self, "versioning")

    @versioning.setter
    def versioning(
        self, value: typing.Optional[typing.List["S3BucketVersioning"]]
    ) -> None:
        jsii.set(self, "versioning", value)

    @builtins.property
    @jsii.member(jsii_name="website")
    def website(self) -> typing.Optional[typing.List["S3BucketWebsite"]]:
        return jsii.get(self, "website")

    @website.setter
    def website(self, value: typing.Optional[typing.List["S3BucketWebsite"]]) -> None:
        jsii.set(self, "website", value)

    @builtins.property
    @jsii.member(jsii_name="websiteDomain")
    def website_domain(self) -> typing.Optional[str]:
        return jsii.get(self, "websiteDomain")

    @website_domain.setter
    def website_domain(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "websiteDomain", value)

    @builtins.property
    @jsii.member(jsii_name="websiteEndpoint")
    def website_endpoint(self) -> typing.Optional[str]:
        return jsii.get(self, "websiteEndpoint")

    @website_endpoint.setter
    def website_endpoint(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "websiteEndpoint", value)


class S3BucketAnalyticsConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketAnalyticsConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        name: str,
        filter: typing.Optional[
            typing.List["S3BucketAnalyticsConfigurationFilter"]
        ] = None,
        storage_class_analysis: typing.Optional[
            typing.List["S3BucketAnalyticsConfigurationStorageClassAnalysis"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param name: 
        :param filter: filter block.
        :param storage_class_analysis: storage_class_analysis block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketAnalyticsConfigurationConfig(
            bucket=bucket,
            name=name,
            filter=filter,
            storage_class_analysis=storage_class_analysis,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3BucketAnalyticsConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(
        self,
    ) -> typing.Optional[typing.List["S3BucketAnalyticsConfigurationFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self,
        value: typing.Optional[typing.List["S3BucketAnalyticsConfigurationFilter"]],
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="storageClassAnalysis")
    def storage_class_analysis(
        self,
    ) -> typing.Optional[
        typing.List["S3BucketAnalyticsConfigurationStorageClassAnalysis"]
    ]:
        return jsii.get(self, "storageClassAnalysis")

    @storage_class_analysis.setter
    def storage_class_analysis(
        self,
        value: typing.Optional[
            typing.List["S3BucketAnalyticsConfigurationStorageClassAnalysis"]
        ],
    ) -> None:
        jsii.set(self, "storageClassAnalysis", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketAnalyticsConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "name": "name",
        "filter": "filter",
        "storage_class_analysis": "storageClassAnalysis",
    },
)
class S3BucketAnalyticsConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        name: str,
        filter: typing.Optional[
            typing.List["S3BucketAnalyticsConfigurationFilter"]
        ] = None,
        storage_class_analysis: typing.Optional[
            typing.List["S3BucketAnalyticsConfigurationStorageClassAnalysis"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param name: 
        :param filter: filter block.
        :param storage_class_analysis: storage_class_analysis block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter
        if storage_class_analysis is not None:
            self._values["storage_class_analysis"] = storage_class_analysis

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["S3BucketAnalyticsConfigurationFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def storage_class_analysis(
        self,
    ) -> typing.Optional[
        typing.List["S3BucketAnalyticsConfigurationStorageClassAnalysis"]
    ]:
        """storage_class_analysis block."""
        return self._values.get("storage_class_analysis")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketAnalyticsConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketAnalyticsConfigurationFilter",
    jsii_struct_bases=[],
    name_mapping={"prefix": "prefix", "tags": "tags"},
)
class S3BucketAnalyticsConfigurationFilter:
    def __init__(
        self,
        *,
        prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param prefix: 
        :param tags: 
        """
        self._values = {}
        if prefix is not None:
            self._values["prefix"] = prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketAnalyticsConfigurationFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketAnalyticsConfigurationStorageClassAnalysis",
    jsii_struct_bases=[],
    name_mapping={"data_export": "dataExport"},
)
class S3BucketAnalyticsConfigurationStorageClassAnalysis:
    def __init__(
        self,
        *,
        data_export: typing.List[
            "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport"
        ],
    ) -> None:
        """
        :param data_export: data_export block.
        """
        self._values = {
            "data_export": data_export,
        }

    @builtins.property
    def data_export(
        self,
    ) -> typing.List["S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport"]:
        """data_export block."""
        return self._values.get("data_export")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketAnalyticsConfigurationStorageClassAnalysis(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport",
    jsii_struct_bases=[],
    name_mapping={
        "destination": "destination",
        "output_schema_version": "outputSchemaVersion",
    },
)
class S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport:
    def __init__(
        self,
        *,
        destination: typing.List[
            "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination"
        ],
        output_schema_version: typing.Optional[str] = None,
    ) -> None:
        """
        :param destination: destination block.
        :param output_schema_version: 
        """
        self._values = {
            "destination": destination,
        }
        if output_schema_version is not None:
            self._values["output_schema_version"] = output_schema_version

    @builtins.property
    def destination(
        self,
    ) -> typing.List[
        "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination"
    ]:
        """destination block."""
        return self._values.get("destination")

    @builtins.property
    def output_schema_version(self) -> typing.Optional[str]:
        return self._values.get("output_schema_version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination",
    jsii_struct_bases=[],
    name_mapping={"s3_bucket_destination": "s3BucketDestination"},
)
class S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination:
    def __init__(
        self,
        *,
        s3_bucket_destination: typing.List[
            "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination"
        ],
    ) -> None:
        """
        :param s3_bucket_destination: s3_bucket_destination block.
        """
        self._values = {
            "s3_bucket_destination": s3_bucket_destination,
        }

    @builtins.property
    def s3_bucket_destination(
        self,
    ) -> typing.List[
        "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination"
    ]:
        """s3_bucket_destination block."""
        return self._values.get("s3_bucket_destination")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_arn": "bucketArn",
        "bucket_account_id": "bucketAccountId",
        "format": "format",
        "prefix": "prefix",
    },
)
class S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination:
    def __init__(
        self,
        *,
        bucket_arn: str,
        bucket_account_id: typing.Optional[str] = None,
        format: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_arn: 
        :param bucket_account_id: 
        :param format: 
        :param prefix: 
        """
        self._values = {
            "bucket_arn": bucket_arn,
        }
        if bucket_account_id is not None:
            self._values["bucket_account_id"] = bucket_account_id
        if format is not None:
            self._values["format"] = format
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket_arn(self) -> str:
        return self._values.get("bucket_arn")

    @builtins.property
    def bucket_account_id(self) -> typing.Optional[str]:
        return self._values.get("bucket_account_id")

    @builtins.property
    def format(self) -> typing.Optional[str]:
        return self._values.get("format")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "acceleration_status": "accelerationStatus",
        "acl": "acl",
        "bucket": "bucket",
        "bucket_prefix": "bucketPrefix",
        "cors_rule": "corsRule",
        "force_destroy": "forceDestroy",
        "grant": "grant",
        "hosted_zone_id": "hostedZoneId",
        "lifecycle_rule": "lifecycleRule",
        "logging": "logging",
        "object_lock_configuration": "objectLockConfiguration",
        "policy": "policy",
        "region": "region",
        "replication_configuration": "replicationConfiguration",
        "request_payer": "requestPayer",
        "server_side_encryption_configuration": "serverSideEncryptionConfiguration",
        "tags": "tags",
        "versioning": "versioning",
        "website": "website",
        "website_domain": "websiteDomain",
        "website_endpoint": "websiteEndpoint",
    },
)
class S3BucketConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        acceleration_status: typing.Optional[str] = None,
        acl: typing.Optional[str] = None,
        bucket: typing.Optional[str] = None,
        bucket_prefix: typing.Optional[str] = None,
        cors_rule: typing.Optional[typing.List["S3BucketCorsRule"]] = None,
        force_destroy: typing.Optional[bool] = None,
        grant: typing.Optional[typing.List["S3BucketGrant"]] = None,
        hosted_zone_id: typing.Optional[str] = None,
        lifecycle_rule: typing.Optional[typing.List["S3BucketLifecycleRule"]] = None,
        logging: typing.Optional[typing.List["S3BucketLogging"]] = None,
        object_lock_configuration: typing.Optional[
            typing.List["S3BucketObjectLockConfiguration"]
        ] = None,
        policy: typing.Optional[str] = None,
        region: typing.Optional[str] = None,
        replication_configuration: typing.Optional[
            typing.List["S3BucketReplicationConfiguration"]
        ] = None,
        request_payer: typing.Optional[str] = None,
        server_side_encryption_configuration: typing.Optional[
            typing.List["S3BucketServerSideEncryptionConfiguration"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        versioning: typing.Optional[typing.List["S3BucketVersioning"]] = None,
        website: typing.Optional[typing.List["S3BucketWebsite"]] = None,
        website_domain: typing.Optional[str] = None,
        website_endpoint: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param acceleration_status: 
        :param acl: 
        :param bucket: 
        :param bucket_prefix: 
        :param cors_rule: cors_rule block.
        :param force_destroy: 
        :param grant: grant block.
        :param hosted_zone_id: 
        :param lifecycle_rule: lifecycle_rule block.
        :param logging: logging block.
        :param object_lock_configuration: object_lock_configuration block.
        :param policy: 
        :param region: 
        :param replication_configuration: replication_configuration block.
        :param request_payer: 
        :param server_side_encryption_configuration: server_side_encryption_configuration block.
        :param tags: 
        :param versioning: versioning block.
        :param website: website block.
        :param website_domain: 
        :param website_endpoint: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if acceleration_status is not None:
            self._values["acceleration_status"] = acceleration_status
        if acl is not None:
            self._values["acl"] = acl
        if bucket is not None:
            self._values["bucket"] = bucket
        if bucket_prefix is not None:
            self._values["bucket_prefix"] = bucket_prefix
        if cors_rule is not None:
            self._values["cors_rule"] = cors_rule
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if grant is not None:
            self._values["grant"] = grant
        if hosted_zone_id is not None:
            self._values["hosted_zone_id"] = hosted_zone_id
        if lifecycle_rule is not None:
            self._values["lifecycle_rule"] = lifecycle_rule
        if logging is not None:
            self._values["logging"] = logging
        if object_lock_configuration is not None:
            self._values["object_lock_configuration"] = object_lock_configuration
        if policy is not None:
            self._values["policy"] = policy
        if region is not None:
            self._values["region"] = region
        if replication_configuration is not None:
            self._values["replication_configuration"] = replication_configuration
        if request_payer is not None:
            self._values["request_payer"] = request_payer
        if server_side_encryption_configuration is not None:
            self._values[
                "server_side_encryption_configuration"
            ] = server_side_encryption_configuration
        if tags is not None:
            self._values["tags"] = tags
        if versioning is not None:
            self._values["versioning"] = versioning
        if website is not None:
            self._values["website"] = website
        if website_domain is not None:
            self._values["website_domain"] = website_domain
        if website_endpoint is not None:
            self._values["website_endpoint"] = website_endpoint

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def acceleration_status(self) -> typing.Optional[str]:
        return self._values.get("acceleration_status")

    @builtins.property
    def acl(self) -> typing.Optional[str]:
        return self._values.get("acl")

    @builtins.property
    def bucket(self) -> typing.Optional[str]:
        return self._values.get("bucket")

    @builtins.property
    def bucket_prefix(self) -> typing.Optional[str]:
        return self._values.get("bucket_prefix")

    @builtins.property
    def cors_rule(self) -> typing.Optional[typing.List["S3BucketCorsRule"]]:
        """cors_rule block."""
        return self._values.get("cors_rule")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    @builtins.property
    def grant(self) -> typing.Optional[typing.List["S3BucketGrant"]]:
        """grant block."""
        return self._values.get("grant")

    @builtins.property
    def hosted_zone_id(self) -> typing.Optional[str]:
        return self._values.get("hosted_zone_id")

    @builtins.property
    def lifecycle_rule(self) -> typing.Optional[typing.List["S3BucketLifecycleRule"]]:
        """lifecycle_rule block."""
        return self._values.get("lifecycle_rule")

    @builtins.property
    def logging(self) -> typing.Optional[typing.List["S3BucketLogging"]]:
        """logging block."""
        return self._values.get("logging")

    @builtins.property
    def object_lock_configuration(
        self,
    ) -> typing.Optional[typing.List["S3BucketObjectLockConfiguration"]]:
        """object_lock_configuration block."""
        return self._values.get("object_lock_configuration")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def region(self) -> typing.Optional[str]:
        return self._values.get("region")

    @builtins.property
    def replication_configuration(
        self,
    ) -> typing.Optional[typing.List["S3BucketReplicationConfiguration"]]:
        """replication_configuration block."""
        return self._values.get("replication_configuration")

    @builtins.property
    def request_payer(self) -> typing.Optional[str]:
        return self._values.get("request_payer")

    @builtins.property
    def server_side_encryption_configuration(
        self,
    ) -> typing.Optional[typing.List["S3BucketServerSideEncryptionConfiguration"]]:
        """server_side_encryption_configuration block."""
        return self._values.get("server_side_encryption_configuration")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def versioning(self) -> typing.Optional[typing.List["S3BucketVersioning"]]:
        """versioning block."""
        return self._values.get("versioning")

    @builtins.property
    def website(self) -> typing.Optional[typing.List["S3BucketWebsite"]]:
        """website block."""
        return self._values.get("website")

    @builtins.property
    def website_domain(self) -> typing.Optional[str]:
        return self._values.get("website_domain")

    @builtins.property
    def website_endpoint(self) -> typing.Optional[str]:
        return self._values.get("website_endpoint")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketCorsRule",
    jsii_struct_bases=[],
    name_mapping={
        "allowed_methods": "allowedMethods",
        "allowed_origins": "allowedOrigins",
        "allowed_headers": "allowedHeaders",
        "expose_headers": "exposeHeaders",
        "max_age_seconds": "maxAgeSeconds",
    },
)
class S3BucketCorsRule:
    def __init__(
        self,
        *,
        allowed_methods: typing.List[str],
        allowed_origins: typing.List[str],
        allowed_headers: typing.Optional[typing.List[str]] = None,
        expose_headers: typing.Optional[typing.List[str]] = None,
        max_age_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param allowed_methods: 
        :param allowed_origins: 
        :param allowed_headers: 
        :param expose_headers: 
        :param max_age_seconds: 
        """
        self._values = {
            "allowed_methods": allowed_methods,
            "allowed_origins": allowed_origins,
        }
        if allowed_headers is not None:
            self._values["allowed_headers"] = allowed_headers
        if expose_headers is not None:
            self._values["expose_headers"] = expose_headers
        if max_age_seconds is not None:
            self._values["max_age_seconds"] = max_age_seconds

    @builtins.property
    def allowed_methods(self) -> typing.List[str]:
        return self._values.get("allowed_methods")

    @builtins.property
    def allowed_origins(self) -> typing.List[str]:
        return self._values.get("allowed_origins")

    @builtins.property
    def allowed_headers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allowed_headers")

    @builtins.property
    def expose_headers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("expose_headers")

    @builtins.property
    def max_age_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_age_seconds")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketCorsRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketGrant",
    jsii_struct_bases=[],
    name_mapping={
        "permissions": "permissions",
        "type": "type",
        "id": "id",
        "uri": "uri",
    },
)
class S3BucketGrant:
    def __init__(
        self,
        *,
        permissions: typing.List[str],
        type: str,
        id: typing.Optional[str] = None,
        uri: typing.Optional[str] = None,
    ) -> None:
        """
        :param permissions: 
        :param type: 
        :param id: 
        :param uri: 
        """
        self._values = {
            "permissions": permissions,
            "type": type,
        }
        if id is not None:
            self._values["id"] = id
        if uri is not None:
            self._values["uri"] = uri

    @builtins.property
    def permissions(self) -> typing.List[str]:
        return self._values.get("permissions")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def uri(self) -> typing.Optional[str]:
        return self._values.get("uri")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketGrant(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketInventory(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventory",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        destination: typing.List["S3BucketInventoryDestination"],
        included_object_versions: str,
        name: str,
        schedule: typing.List["S3BucketInventorySchedule"],
        enabled: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["S3BucketInventoryFilter"]] = None,
        optional_fields: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param destination: destination block.
        :param included_object_versions: 
        :param name: 
        :param schedule: schedule block.
        :param enabled: 
        :param filter: filter block.
        :param optional_fields: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketInventoryConfig(
            bucket=bucket,
            destination=destination,
            included_object_versions=included_object_versions,
            name=name,
            schedule=schedule,
            enabled=enabled,
            filter=filter,
            optional_fields=optional_fields,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3BucketInventory, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="destination")
    def destination(self) -> typing.List["S3BucketInventoryDestination"]:
        return jsii.get(self, "destination")

    @destination.setter
    def destination(self, value: typing.List["S3BucketInventoryDestination"]) -> None:
        jsii.set(self, "destination", value)

    @builtins.property
    @jsii.member(jsii_name="includedObjectVersions")
    def included_object_versions(self) -> str:
        return jsii.get(self, "includedObjectVersions")

    @included_object_versions.setter
    def included_object_versions(self, value: str) -> None:
        jsii.set(self, "includedObjectVersions", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(self) -> typing.List["S3BucketInventorySchedule"]:
        return jsii.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: typing.List["S3BucketInventorySchedule"]) -> None:
        jsii.set(self, "schedule", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["S3BucketInventoryFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["S3BucketInventoryFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="optionalFields")
    def optional_fields(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "optionalFields")

    @optional_fields.setter
    def optional_fields(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "optionalFields", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "destination": "destination",
        "included_object_versions": "includedObjectVersions",
        "name": "name",
        "schedule": "schedule",
        "enabled": "enabled",
        "filter": "filter",
        "optional_fields": "optionalFields",
    },
)
class S3BucketInventoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        destination: typing.List["S3BucketInventoryDestination"],
        included_object_versions: str,
        name: str,
        schedule: typing.List["S3BucketInventorySchedule"],
        enabled: typing.Optional[bool] = None,
        filter: typing.Optional[typing.List["S3BucketInventoryFilter"]] = None,
        optional_fields: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param destination: destination block.
        :param included_object_versions: 
        :param name: 
        :param schedule: schedule block.
        :param enabled: 
        :param filter: filter block.
        :param optional_fields: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "destination": destination,
            "included_object_versions": included_object_versions,
            "name": name,
            "schedule": schedule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if enabled is not None:
            self._values["enabled"] = enabled
        if filter is not None:
            self._values["filter"] = filter
        if optional_fields is not None:
            self._values["optional_fields"] = optional_fields

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def destination(self) -> typing.List["S3BucketInventoryDestination"]:
        """destination block."""
        return self._values.get("destination")

    @builtins.property
    def included_object_versions(self) -> str:
        return self._values.get("included_object_versions")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def schedule(self) -> typing.List["S3BucketInventorySchedule"]:
        """schedule block."""
        return self._values.get("schedule")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["S3BucketInventoryFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def optional_fields(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("optional_fields")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventoryDestination",
    jsii_struct_bases=[],
    name_mapping={"bucket": "bucket"},
)
class S3BucketInventoryDestination:
    def __init__(
        self, *, bucket: typing.List["S3BucketInventoryDestinationBucket"]
    ) -> None:
        """
        :param bucket: bucket block.
        """
        self._values = {
            "bucket": bucket,
        }

    @builtins.property
    def bucket(self) -> typing.List["S3BucketInventoryDestinationBucket"]:
        """bucket block."""
        return self._values.get("bucket")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventoryDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventoryDestinationBucket",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_arn": "bucketArn",
        "format": "format",
        "account_id": "accountId",
        "encryption": "encryption",
        "prefix": "prefix",
    },
)
class S3BucketInventoryDestinationBucket:
    def __init__(
        self,
        *,
        bucket_arn: str,
        format: str,
        account_id: typing.Optional[str] = None,
        encryption: typing.Optional[
            typing.List["S3BucketInventoryDestinationBucketEncryption"]
        ] = None,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_arn: 
        :param format: 
        :param account_id: 
        :param encryption: encryption block.
        :param prefix: 
        """
        self._values = {
            "bucket_arn": bucket_arn,
            "format": format,
        }
        if account_id is not None:
            self._values["account_id"] = account_id
        if encryption is not None:
            self._values["encryption"] = encryption
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def bucket_arn(self) -> str:
        return self._values.get("bucket_arn")

    @builtins.property
    def format(self) -> str:
        return self._values.get("format")

    @builtins.property
    def account_id(self) -> typing.Optional[str]:
        return self._values.get("account_id")

    @builtins.property
    def encryption(
        self,
    ) -> typing.Optional[typing.List["S3BucketInventoryDestinationBucketEncryption"]]:
        """encryption block."""
        return self._values.get("encryption")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventoryDestinationBucket(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventoryDestinationBucketEncryption",
    jsii_struct_bases=[],
    name_mapping={"sse_kms": "sseKms", "sse_s3": "sseS3"},
)
class S3BucketInventoryDestinationBucketEncryption:
    def __init__(
        self,
        *,
        sse_kms: typing.Optional[
            typing.List["S3BucketInventoryDestinationBucketEncryptionSseKms"]
        ] = None,
        sse_s3: typing.Optional[
            typing.List["S3BucketInventoryDestinationBucketEncryptionSseS3"]
        ] = None,
    ) -> None:
        """
        :param sse_kms: sse_kms block.
        :param sse_s3: sse_s3 block.
        """
        self._values = {}
        if sse_kms is not None:
            self._values["sse_kms"] = sse_kms
        if sse_s3 is not None:
            self._values["sse_s3"] = sse_s3

    @builtins.property
    def sse_kms(
        self,
    ) -> typing.Optional[
        typing.List["S3BucketInventoryDestinationBucketEncryptionSseKms"]
    ]:
        """sse_kms block."""
        return self._values.get("sse_kms")

    @builtins.property
    def sse_s3(
        self,
    ) -> typing.Optional[
        typing.List["S3BucketInventoryDestinationBucketEncryptionSseS3"]
    ]:
        """sse_s3 block."""
        return self._values.get("sse_s3")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventoryDestinationBucketEncryption(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventoryDestinationBucketEncryptionSseKms",
    jsii_struct_bases=[],
    name_mapping={"key_id": "keyId"},
)
class S3BucketInventoryDestinationBucketEncryptionSseKms:
    def __init__(self, *, key_id: str) -> None:
        """
        :param key_id: 
        """
        self._values = {
            "key_id": key_id,
        }

    @builtins.property
    def key_id(self) -> str:
        return self._values.get("key_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventoryDestinationBucketEncryptionSseKms(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventoryDestinationBucketEncryptionSseS3",
    jsii_struct_bases=[],
    name_mapping={},
)
class S3BucketInventoryDestinationBucketEncryptionSseS3:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventoryDestinationBucketEncryptionSseS3(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventoryFilter",
    jsii_struct_bases=[],
    name_mapping={"prefix": "prefix"},
)
class S3BucketInventoryFilter:
    def __init__(self, *, prefix: typing.Optional[str] = None) -> None:
        """
        :param prefix: 
        """
        self._values = {}
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventoryFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketInventorySchedule",
    jsii_struct_bases=[],
    name_mapping={"frequency": "frequency"},
)
class S3BucketInventorySchedule:
    def __init__(self, *, frequency: str) -> None:
        """
        :param frequency: 
        """
        self._values = {
            "frequency": frequency,
        }

    @builtins.property
    def frequency(self) -> str:
        return self._values.get("frequency")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketInventorySchedule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketLifecycleRule",
    jsii_struct_bases=[],
    name_mapping={
        "enabled": "enabled",
        "abort_incomplete_multipart_upload_days": "abortIncompleteMultipartUploadDays",
        "expiration": "expiration",
        "id": "id",
        "noncurrent_version_expiration": "noncurrentVersionExpiration",
        "noncurrent_version_transition": "noncurrentVersionTransition",
        "prefix": "prefix",
        "tags": "tags",
        "transition": "transition",
    },
)
class S3BucketLifecycleRule:
    def __init__(
        self,
        *,
        enabled: bool,
        abort_incomplete_multipart_upload_days: typing.Optional[jsii.Number] = None,
        expiration: typing.Optional[
            typing.List["S3BucketLifecycleRuleExpiration"]
        ] = None,
        id: typing.Optional[str] = None,
        noncurrent_version_expiration: typing.Optional[
            typing.List["S3BucketLifecycleRuleNoncurrentVersionExpiration"]
        ] = None,
        noncurrent_version_transition: typing.Optional[
            typing.List["S3BucketLifecycleRuleNoncurrentVersionTransition"]
        ] = None,
        prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transition: typing.Optional[
            typing.List["S3BucketLifecycleRuleTransition"]
        ] = None,
    ) -> None:
        """
        :param enabled: 
        :param abort_incomplete_multipart_upload_days: 
        :param expiration: expiration block.
        :param id: 
        :param noncurrent_version_expiration: noncurrent_version_expiration block.
        :param noncurrent_version_transition: noncurrent_version_transition block.
        :param prefix: 
        :param tags: 
        :param transition: transition block.
        """
        self._values = {
            "enabled": enabled,
        }
        if abort_incomplete_multipart_upload_days is not None:
            self._values[
                "abort_incomplete_multipart_upload_days"
            ] = abort_incomplete_multipart_upload_days
        if expiration is not None:
            self._values["expiration"] = expiration
        if id is not None:
            self._values["id"] = id
        if noncurrent_version_expiration is not None:
            self._values[
                "noncurrent_version_expiration"
            ] = noncurrent_version_expiration
        if noncurrent_version_transition is not None:
            self._values[
                "noncurrent_version_transition"
            ] = noncurrent_version_transition
        if prefix is not None:
            self._values["prefix"] = prefix
        if tags is not None:
            self._values["tags"] = tags
        if transition is not None:
            self._values["transition"] = transition

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    @builtins.property
    def abort_incomplete_multipart_upload_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("abort_incomplete_multipart_upload_days")

    @builtins.property
    def expiration(
        self,
    ) -> typing.Optional[typing.List["S3BucketLifecycleRuleExpiration"]]:
        """expiration block."""
        return self._values.get("expiration")

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def noncurrent_version_expiration(
        self,
    ) -> typing.Optional[
        typing.List["S3BucketLifecycleRuleNoncurrentVersionExpiration"]
    ]:
        """noncurrent_version_expiration block."""
        return self._values.get("noncurrent_version_expiration")

    @builtins.property
    def noncurrent_version_transition(
        self,
    ) -> typing.Optional[
        typing.List["S3BucketLifecycleRuleNoncurrentVersionTransition"]
    ]:
        """noncurrent_version_transition block."""
        return self._values.get("noncurrent_version_transition")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def transition(
        self,
    ) -> typing.Optional[typing.List["S3BucketLifecycleRuleTransition"]]:
        """transition block."""
        return self._values.get("transition")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketLifecycleRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketLifecycleRuleExpiration",
    jsii_struct_bases=[],
    name_mapping={
        "date": "date",
        "days": "days",
        "expired_object_delete_marker": "expiredObjectDeleteMarker",
    },
)
class S3BucketLifecycleRuleExpiration:
    def __init__(
        self,
        *,
        date: typing.Optional[str] = None,
        days: typing.Optional[jsii.Number] = None,
        expired_object_delete_marker: typing.Optional[bool] = None,
    ) -> None:
        """
        :param date: 
        :param days: 
        :param expired_object_delete_marker: 
        """
        self._values = {}
        if date is not None:
            self._values["date"] = date
        if days is not None:
            self._values["days"] = days
        if expired_object_delete_marker is not None:
            self._values["expired_object_delete_marker"] = expired_object_delete_marker

    @builtins.property
    def date(self) -> typing.Optional[str]:
        return self._values.get("date")

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("days")

    @builtins.property
    def expired_object_delete_marker(self) -> typing.Optional[bool]:
        return self._values.get("expired_object_delete_marker")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketLifecycleRuleExpiration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketLifecycleRuleNoncurrentVersionExpiration",
    jsii_struct_bases=[],
    name_mapping={"days": "days"},
)
class S3BucketLifecycleRuleNoncurrentVersionExpiration:
    def __init__(self, *, days: typing.Optional[jsii.Number] = None) -> None:
        """
        :param days: 
        """
        self._values = {}
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("days")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketLifecycleRuleNoncurrentVersionExpiration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketLifecycleRuleNoncurrentVersionTransition",
    jsii_struct_bases=[],
    name_mapping={"storage_class": "storageClass", "days": "days"},
)
class S3BucketLifecycleRuleNoncurrentVersionTransition:
    def __init__(
        self, *, storage_class: str, days: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param storage_class: 
        :param days: 
        """
        self._values = {
            "storage_class": storage_class,
        }
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def storage_class(self) -> str:
        return self._values.get("storage_class")

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("days")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketLifecycleRuleNoncurrentVersionTransition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketLifecycleRuleTransition",
    jsii_struct_bases=[],
    name_mapping={"storage_class": "storageClass", "date": "date", "days": "days"},
)
class S3BucketLifecycleRuleTransition:
    def __init__(
        self,
        *,
        storage_class: str,
        date: typing.Optional[str] = None,
        days: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param storage_class: 
        :param date: 
        :param days: 
        """
        self._values = {
            "storage_class": storage_class,
        }
        if date is not None:
            self._values["date"] = date
        if days is not None:
            self._values["days"] = days

    @builtins.property
    def storage_class(self) -> str:
        return self._values.get("storage_class")

    @builtins.property
    def date(self) -> typing.Optional[str]:
        return self._values.get("date")

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("days")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketLifecycleRuleTransition(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketLogging",
    jsii_struct_bases=[],
    name_mapping={"target_bucket": "targetBucket", "target_prefix": "targetPrefix"},
)
class S3BucketLogging:
    def __init__(
        self, *, target_bucket: str, target_prefix: typing.Optional[str] = None
    ) -> None:
        """
        :param target_bucket: 
        :param target_prefix: 
        """
        self._values = {
            "target_bucket": target_bucket,
        }
        if target_prefix is not None:
            self._values["target_prefix"] = target_prefix

    @builtins.property
    def target_bucket(self) -> str:
        return self._values.get("target_bucket")

    @builtins.property
    def target_prefix(self) -> typing.Optional[str]:
        return self._values.get("target_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketLogging(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketMetric(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketMetric",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        name: str,
        filter: typing.Optional[typing.List["S3BucketMetricFilter"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param name: 
        :param filter: filter block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketMetricConfig(
            bucket=bucket,
            name=name,
            filter=filter,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3BucketMetric, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="filter")
    def filter(self) -> typing.Optional[typing.List["S3BucketMetricFilter"]]:
        return jsii.get(self, "filter")

    @filter.setter
    def filter(
        self, value: typing.Optional[typing.List["S3BucketMetricFilter"]]
    ) -> None:
        jsii.set(self, "filter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketMetricConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "name": "name",
        "filter": "filter",
    },
)
class S3BucketMetricConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        name: str,
        filter: typing.Optional[typing.List["S3BucketMetricFilter"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param name: 
        :param filter: filter block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if filter is not None:
            self._values["filter"] = filter

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def filter(self) -> typing.Optional[typing.List["S3BucketMetricFilter"]]:
        """filter block."""
        return self._values.get("filter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketMetricConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketMetricFilter",
    jsii_struct_bases=[],
    name_mapping={"prefix": "prefix", "tags": "tags"},
)
class S3BucketMetricFilter:
    def __init__(
        self,
        *,
        prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param prefix: 
        :param tags: 
        """
        self._values = {}
        if prefix is not None:
            self._values["prefix"] = prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketMetricFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketNotification(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketNotification",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        lambda_function: typing.Optional[
            typing.List["S3BucketNotificationLambdaFunction"]
        ] = None,
        queue: typing.Optional[typing.List["S3BucketNotificationQueue"]] = None,
        topic: typing.Optional[typing.List["S3BucketNotificationTopic"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param lambda_function: lambda_function block.
        :param queue: queue block.
        :param topic: topic block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketNotificationConfig(
            bucket=bucket,
            lambda_function=lambda_function,
            queue=queue,
            topic=topic,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3BucketNotification, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaFunction")
    def lambda_function(
        self,
    ) -> typing.Optional[typing.List["S3BucketNotificationLambdaFunction"]]:
        return jsii.get(self, "lambdaFunction")

    @lambda_function.setter
    def lambda_function(
        self, value: typing.Optional[typing.List["S3BucketNotificationLambdaFunction"]]
    ) -> None:
        jsii.set(self, "lambdaFunction", value)

    @builtins.property
    @jsii.member(jsii_name="queue")
    def queue(self) -> typing.Optional[typing.List["S3BucketNotificationQueue"]]:
        return jsii.get(self, "queue")

    @queue.setter
    def queue(
        self, value: typing.Optional[typing.List["S3BucketNotificationQueue"]]
    ) -> None:
        jsii.set(self, "queue", value)

    @builtins.property
    @jsii.member(jsii_name="topic")
    def topic(self) -> typing.Optional[typing.List["S3BucketNotificationTopic"]]:
        return jsii.get(self, "topic")

    @topic.setter
    def topic(
        self, value: typing.Optional[typing.List["S3BucketNotificationTopic"]]
    ) -> None:
        jsii.set(self, "topic", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketNotificationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "lambda_function": "lambdaFunction",
        "queue": "queue",
        "topic": "topic",
    },
)
class S3BucketNotificationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        lambda_function: typing.Optional[
            typing.List["S3BucketNotificationLambdaFunction"]
        ] = None,
        queue: typing.Optional[typing.List["S3BucketNotificationQueue"]] = None,
        topic: typing.Optional[typing.List["S3BucketNotificationTopic"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param lambda_function: lambda_function block.
        :param queue: queue block.
        :param topic: topic block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if lambda_function is not None:
            self._values["lambda_function"] = lambda_function
        if queue is not None:
            self._values["queue"] = queue
        if topic is not None:
            self._values["topic"] = topic

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def lambda_function(
        self,
    ) -> typing.Optional[typing.List["S3BucketNotificationLambdaFunction"]]:
        """lambda_function block."""
        return self._values.get("lambda_function")

    @builtins.property
    def queue(self) -> typing.Optional[typing.List["S3BucketNotificationQueue"]]:
        """queue block."""
        return self._values.get("queue")

    @builtins.property
    def topic(self) -> typing.Optional[typing.List["S3BucketNotificationTopic"]]:
        """topic block."""
        return self._values.get("topic")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketNotificationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketNotificationLambdaFunction",
    jsii_struct_bases=[],
    name_mapping={
        "events": "events",
        "filter_prefix": "filterPrefix",
        "filter_suffix": "filterSuffix",
        "id": "id",
        "lambda_function_arn": "lambdaFunctionArn",
    },
)
class S3BucketNotificationLambdaFunction:
    def __init__(
        self,
        *,
        events: typing.List[str],
        filter_prefix: typing.Optional[str] = None,
        filter_suffix: typing.Optional[str] = None,
        id: typing.Optional[str] = None,
        lambda_function_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param events: 
        :param filter_prefix: 
        :param filter_suffix: 
        :param id: 
        :param lambda_function_arn: 
        """
        self._values = {
            "events": events,
        }
        if filter_prefix is not None:
            self._values["filter_prefix"] = filter_prefix
        if filter_suffix is not None:
            self._values["filter_suffix"] = filter_suffix
        if id is not None:
            self._values["id"] = id
        if lambda_function_arn is not None:
            self._values["lambda_function_arn"] = lambda_function_arn

    @builtins.property
    def events(self) -> typing.List[str]:
        return self._values.get("events")

    @builtins.property
    def filter_prefix(self) -> typing.Optional[str]:
        return self._values.get("filter_prefix")

    @builtins.property
    def filter_suffix(self) -> typing.Optional[str]:
        return self._values.get("filter_suffix")

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def lambda_function_arn(self) -> typing.Optional[str]:
        return self._values.get("lambda_function_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketNotificationLambdaFunction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketNotificationQueue",
    jsii_struct_bases=[],
    name_mapping={
        "events": "events",
        "queue_arn": "queueArn",
        "filter_prefix": "filterPrefix",
        "filter_suffix": "filterSuffix",
        "id": "id",
    },
)
class S3BucketNotificationQueue:
    def __init__(
        self,
        *,
        events: typing.List[str],
        queue_arn: str,
        filter_prefix: typing.Optional[str] = None,
        filter_suffix: typing.Optional[str] = None,
        id: typing.Optional[str] = None,
    ) -> None:
        """
        :param events: 
        :param queue_arn: 
        :param filter_prefix: 
        :param filter_suffix: 
        :param id: 
        """
        self._values = {
            "events": events,
            "queue_arn": queue_arn,
        }
        if filter_prefix is not None:
            self._values["filter_prefix"] = filter_prefix
        if filter_suffix is not None:
            self._values["filter_suffix"] = filter_suffix
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def events(self) -> typing.List[str]:
        return self._values.get("events")

    @builtins.property
    def queue_arn(self) -> str:
        return self._values.get("queue_arn")

    @builtins.property
    def filter_prefix(self) -> typing.Optional[str]:
        return self._values.get("filter_prefix")

    @builtins.property
    def filter_suffix(self) -> typing.Optional[str]:
        return self._values.get("filter_suffix")

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketNotificationQueue(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketNotificationTopic",
    jsii_struct_bases=[],
    name_mapping={
        "events": "events",
        "topic_arn": "topicArn",
        "filter_prefix": "filterPrefix",
        "filter_suffix": "filterSuffix",
        "id": "id",
    },
)
class S3BucketNotificationTopic:
    def __init__(
        self,
        *,
        events: typing.List[str],
        topic_arn: str,
        filter_prefix: typing.Optional[str] = None,
        filter_suffix: typing.Optional[str] = None,
        id: typing.Optional[str] = None,
    ) -> None:
        """
        :param events: 
        :param topic_arn: 
        :param filter_prefix: 
        :param filter_suffix: 
        :param id: 
        """
        self._values = {
            "events": events,
            "topic_arn": topic_arn,
        }
        if filter_prefix is not None:
            self._values["filter_prefix"] = filter_prefix
        if filter_suffix is not None:
            self._values["filter_suffix"] = filter_suffix
        if id is not None:
            self._values["id"] = id

    @builtins.property
    def events(self) -> typing.List[str]:
        return self._values.get("events")

    @builtins.property
    def topic_arn(self) -> str:
        return self._values.get("topic_arn")

    @builtins.property
    def filter_prefix(self) -> typing.Optional[str]:
        return self._values.get("filter_prefix")

    @builtins.property
    def filter_suffix(self) -> typing.Optional[str]:
        return self._values.get("filter_suffix")

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketNotificationTopic(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketObject(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketObject",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        key: str,
        acl: typing.Optional[str] = None,
        cache_control: typing.Optional[str] = None,
        content: typing.Optional[str] = None,
        content_base64: typing.Optional[str] = None,
        content_disposition: typing.Optional[str] = None,
        content_encoding: typing.Optional[str] = None,
        content_language: typing.Optional[str] = None,
        content_type: typing.Optional[str] = None,
        etag: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        metadata: typing.Optional[typing.Mapping[str, str]] = None,
        object_lock_legal_hold_status: typing.Optional[str] = None,
        object_lock_mode: typing.Optional[str] = None,
        object_lock_retain_until_date: typing.Optional[str] = None,
        server_side_encryption: typing.Optional[str] = None,
        source: typing.Optional[str] = None,
        storage_class: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        website_redirect: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param key: 
        :param acl: 
        :param cache_control: 
        :param content: 
        :param content_base64: 
        :param content_disposition: 
        :param content_encoding: 
        :param content_language: 
        :param content_type: 
        :param etag: 
        :param force_destroy: 
        :param kms_key_id: 
        :param metadata: 
        :param object_lock_legal_hold_status: 
        :param object_lock_mode: 
        :param object_lock_retain_until_date: 
        :param server_side_encryption: 
        :param source: 
        :param storage_class: 
        :param tags: 
        :param website_redirect: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketObjectConfig(
            bucket=bucket,
            key=key,
            acl=acl,
            cache_control=cache_control,
            content=content,
            content_base64=content_base64,
            content_disposition=content_disposition,
            content_encoding=content_encoding,
            content_language=content_language,
            content_type=content_type,
            etag=etag,
            force_destroy=force_destroy,
            kms_key_id=kms_key_id,
            metadata=metadata,
            object_lock_legal_hold_status=object_lock_legal_hold_status,
            object_lock_mode=object_lock_mode,
            object_lock_retain_until_date=object_lock_retain_until_date,
            server_side_encryption=server_side_encryption,
            source=source,
            storage_class=storage_class,
            tags=tags,
            website_redirect=website_redirect,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3BucketObject, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="versionId")
    def version_id(self) -> str:
        return jsii.get(self, "versionId")

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="key")
    def key(self) -> str:
        return jsii.get(self, "key")

    @key.setter
    def key(self, value: str) -> None:
        jsii.set(self, "key", value)

    @builtins.property
    @jsii.member(jsii_name="acl")
    def acl(self) -> typing.Optional[str]:
        return jsii.get(self, "acl")

    @acl.setter
    def acl(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "acl", value)

    @builtins.property
    @jsii.member(jsii_name="cacheControl")
    def cache_control(self) -> typing.Optional[str]:
        return jsii.get(self, "cacheControl")

    @cache_control.setter
    def cache_control(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cacheControl", value)

    @builtins.property
    @jsii.member(jsii_name="content")
    def content(self) -> typing.Optional[str]:
        return jsii.get(self, "content")

    @content.setter
    def content(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "content", value)

    @builtins.property
    @jsii.member(jsii_name="contentBase64")
    def content_base64(self) -> typing.Optional[str]:
        return jsii.get(self, "contentBase64")

    @content_base64.setter
    def content_base64(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentBase64", value)

    @builtins.property
    @jsii.member(jsii_name="contentDisposition")
    def content_disposition(self) -> typing.Optional[str]:
        return jsii.get(self, "contentDisposition")

    @content_disposition.setter
    def content_disposition(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentDisposition", value)

    @builtins.property
    @jsii.member(jsii_name="contentEncoding")
    def content_encoding(self) -> typing.Optional[str]:
        return jsii.get(self, "contentEncoding")

    @content_encoding.setter
    def content_encoding(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentEncoding", value)

    @builtins.property
    @jsii.member(jsii_name="contentLanguage")
    def content_language(self) -> typing.Optional[str]:
        return jsii.get(self, "contentLanguage")

    @content_language.setter
    def content_language(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentLanguage", value)

    @builtins.property
    @jsii.member(jsii_name="contentType")
    def content_type(self) -> typing.Optional[str]:
        return jsii.get(self, "contentType")

    @content_type.setter
    def content_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "contentType", value)

    @builtins.property
    @jsii.member(jsii_name="etag")
    def etag(self) -> typing.Optional[str]:
        return jsii.get(self, "etag")

    @etag.setter
    def etag(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "etag", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="metadata")
    def metadata(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "metadata")

    @metadata.setter
    def metadata(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "metadata", value)

    @builtins.property
    @jsii.member(jsii_name="objectLockLegalHoldStatus")
    def object_lock_legal_hold_status(self) -> typing.Optional[str]:
        return jsii.get(self, "objectLockLegalHoldStatus")

    @object_lock_legal_hold_status.setter
    def object_lock_legal_hold_status(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "objectLockLegalHoldStatus", value)

    @builtins.property
    @jsii.member(jsii_name="objectLockMode")
    def object_lock_mode(self) -> typing.Optional[str]:
        return jsii.get(self, "objectLockMode")

    @object_lock_mode.setter
    def object_lock_mode(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "objectLockMode", value)

    @builtins.property
    @jsii.member(jsii_name="objectLockRetainUntilDate")
    def object_lock_retain_until_date(self) -> typing.Optional[str]:
        return jsii.get(self, "objectLockRetainUntilDate")

    @object_lock_retain_until_date.setter
    def object_lock_retain_until_date(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "objectLockRetainUntilDate", value)

    @builtins.property
    @jsii.member(jsii_name="serverSideEncryption")
    def server_side_encryption(self) -> typing.Optional[str]:
        return jsii.get(self, "serverSideEncryption")

    @server_side_encryption.setter
    def server_side_encryption(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "serverSideEncryption", value)

    @builtins.property
    @jsii.member(jsii_name="source")
    def source(self) -> typing.Optional[str]:
        return jsii.get(self, "source")

    @source.setter
    def source(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "source", value)

    @builtins.property
    @jsii.member(jsii_name="storageClass")
    def storage_class(self) -> typing.Optional[str]:
        return jsii.get(self, "storageClass")

    @storage_class.setter
    def storage_class(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "storageClass", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="websiteRedirect")
    def website_redirect(self) -> typing.Optional[str]:
        return jsii.get(self, "websiteRedirect")

    @website_redirect.setter
    def website_redirect(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "websiteRedirect", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketObjectConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "key": "key",
        "acl": "acl",
        "cache_control": "cacheControl",
        "content": "content",
        "content_base64": "contentBase64",
        "content_disposition": "contentDisposition",
        "content_encoding": "contentEncoding",
        "content_language": "contentLanguage",
        "content_type": "contentType",
        "etag": "etag",
        "force_destroy": "forceDestroy",
        "kms_key_id": "kmsKeyId",
        "metadata": "metadata",
        "object_lock_legal_hold_status": "objectLockLegalHoldStatus",
        "object_lock_mode": "objectLockMode",
        "object_lock_retain_until_date": "objectLockRetainUntilDate",
        "server_side_encryption": "serverSideEncryption",
        "source": "source",
        "storage_class": "storageClass",
        "tags": "tags",
        "website_redirect": "websiteRedirect",
    },
)
class S3BucketObjectConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        key: str,
        acl: typing.Optional[str] = None,
        cache_control: typing.Optional[str] = None,
        content: typing.Optional[str] = None,
        content_base64: typing.Optional[str] = None,
        content_disposition: typing.Optional[str] = None,
        content_encoding: typing.Optional[str] = None,
        content_language: typing.Optional[str] = None,
        content_type: typing.Optional[str] = None,
        etag: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        kms_key_id: typing.Optional[str] = None,
        metadata: typing.Optional[typing.Mapping[str, str]] = None,
        object_lock_legal_hold_status: typing.Optional[str] = None,
        object_lock_mode: typing.Optional[str] = None,
        object_lock_retain_until_date: typing.Optional[str] = None,
        server_side_encryption: typing.Optional[str] = None,
        source: typing.Optional[str] = None,
        storage_class: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        website_redirect: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param key: 
        :param acl: 
        :param cache_control: 
        :param content: 
        :param content_base64: 
        :param content_disposition: 
        :param content_encoding: 
        :param content_language: 
        :param content_type: 
        :param etag: 
        :param force_destroy: 
        :param kms_key_id: 
        :param metadata: 
        :param object_lock_legal_hold_status: 
        :param object_lock_mode: 
        :param object_lock_retain_until_date: 
        :param server_side_encryption: 
        :param source: 
        :param storage_class: 
        :param tags: 
        :param website_redirect: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "key": key,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if acl is not None:
            self._values["acl"] = acl
        if cache_control is not None:
            self._values["cache_control"] = cache_control
        if content is not None:
            self._values["content"] = content
        if content_base64 is not None:
            self._values["content_base64"] = content_base64
        if content_disposition is not None:
            self._values["content_disposition"] = content_disposition
        if content_encoding is not None:
            self._values["content_encoding"] = content_encoding
        if content_language is not None:
            self._values["content_language"] = content_language
        if content_type is not None:
            self._values["content_type"] = content_type
        if etag is not None:
            self._values["etag"] = etag
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if metadata is not None:
            self._values["metadata"] = metadata
        if object_lock_legal_hold_status is not None:
            self._values[
                "object_lock_legal_hold_status"
            ] = object_lock_legal_hold_status
        if object_lock_mode is not None:
            self._values["object_lock_mode"] = object_lock_mode
        if object_lock_retain_until_date is not None:
            self._values[
                "object_lock_retain_until_date"
            ] = object_lock_retain_until_date
        if server_side_encryption is not None:
            self._values["server_side_encryption"] = server_side_encryption
        if source is not None:
            self._values["source"] = source
        if storage_class is not None:
            self._values["storage_class"] = storage_class
        if tags is not None:
            self._values["tags"] = tags
        if website_redirect is not None:
            self._values["website_redirect"] = website_redirect

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def acl(self) -> typing.Optional[str]:
        return self._values.get("acl")

    @builtins.property
    def cache_control(self) -> typing.Optional[str]:
        return self._values.get("cache_control")

    @builtins.property
    def content(self) -> typing.Optional[str]:
        return self._values.get("content")

    @builtins.property
    def content_base64(self) -> typing.Optional[str]:
        return self._values.get("content_base64")

    @builtins.property
    def content_disposition(self) -> typing.Optional[str]:
        return self._values.get("content_disposition")

    @builtins.property
    def content_encoding(self) -> typing.Optional[str]:
        return self._values.get("content_encoding")

    @builtins.property
    def content_language(self) -> typing.Optional[str]:
        return self._values.get("content_language")

    @builtins.property
    def content_type(self) -> typing.Optional[str]:
        return self._values.get("content_type")

    @builtins.property
    def etag(self) -> typing.Optional[str]:
        return self._values.get("etag")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def metadata(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("metadata")

    @builtins.property
    def object_lock_legal_hold_status(self) -> typing.Optional[str]:
        return self._values.get("object_lock_legal_hold_status")

    @builtins.property
    def object_lock_mode(self) -> typing.Optional[str]:
        return self._values.get("object_lock_mode")

    @builtins.property
    def object_lock_retain_until_date(self) -> typing.Optional[str]:
        return self._values.get("object_lock_retain_until_date")

    @builtins.property
    def server_side_encryption(self) -> typing.Optional[str]:
        return self._values.get("server_side_encryption")

    @builtins.property
    def source(self) -> typing.Optional[str]:
        return self._values.get("source")

    @builtins.property
    def storage_class(self) -> typing.Optional[str]:
        return self._values.get("storage_class")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def website_redirect(self) -> typing.Optional[str]:
        return self._values.get("website_redirect")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketObjectConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketObjectLockConfiguration",
    jsii_struct_bases=[],
    name_mapping={"object_lock_enabled": "objectLockEnabled", "rule": "rule"},
)
class S3BucketObjectLockConfiguration:
    def __init__(
        self,
        *,
        object_lock_enabled: str,
        rule: typing.Optional[
            typing.List["S3BucketObjectLockConfigurationRule"]
        ] = None,
    ) -> None:
        """
        :param object_lock_enabled: 
        :param rule: rule block.
        """
        self._values = {
            "object_lock_enabled": object_lock_enabled,
        }
        if rule is not None:
            self._values["rule"] = rule

    @builtins.property
    def object_lock_enabled(self) -> str:
        return self._values.get("object_lock_enabled")

    @builtins.property
    def rule(
        self,
    ) -> typing.Optional[typing.List["S3BucketObjectLockConfigurationRule"]]:
        """rule block."""
        return self._values.get("rule")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketObjectLockConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketObjectLockConfigurationRule",
    jsii_struct_bases=[],
    name_mapping={"default_retention": "defaultRetention"},
)
class S3BucketObjectLockConfigurationRule:
    def __init__(
        self,
        *,
        default_retention: typing.List[
            "S3BucketObjectLockConfigurationRuleDefaultRetention"
        ],
    ) -> None:
        """
        :param default_retention: default_retention block.
        """
        self._values = {
            "default_retention": default_retention,
        }

    @builtins.property
    def default_retention(
        self,
    ) -> typing.List["S3BucketObjectLockConfigurationRuleDefaultRetention"]:
        """default_retention block."""
        return self._values.get("default_retention")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketObjectLockConfigurationRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketObjectLockConfigurationRuleDefaultRetention",
    jsii_struct_bases=[],
    name_mapping={"mode": "mode", "days": "days", "years": "years"},
)
class S3BucketObjectLockConfigurationRuleDefaultRetention:
    def __init__(
        self,
        *,
        mode: str,
        days: typing.Optional[jsii.Number] = None,
        years: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param mode: 
        :param days: 
        :param years: 
        """
        self._values = {
            "mode": mode,
        }
        if days is not None:
            self._values["days"] = days
        if years is not None:
            self._values["years"] = years

    @builtins.property
    def mode(self) -> str:
        return self._values.get("mode")

    @builtins.property
    def days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("days")

    @builtins.property
    def years(self) -> typing.Optional[jsii.Number]:
        return self._values.get("years")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketObjectLockConfigurationRuleDefaultRetention(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        policy: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param policy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketPolicyConfig(
            bucket=bucket,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3BucketPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "policy": "policy",
    },
)
class S3BucketPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        policy: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param policy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class S3BucketPublicAccessBlock(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketPublicAccessBlock",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        block_public_acls: typing.Optional[bool] = None,
        block_public_policy: typing.Optional[bool] = None,
        ignore_public_acls: typing.Optional[bool] = None,
        restrict_public_buckets: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param block_public_acls: 
        :param block_public_policy: 
        :param ignore_public_acls: 
        :param restrict_public_buckets: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = S3BucketPublicAccessBlockConfig(
            bucket=bucket,
            block_public_acls=block_public_acls,
            block_public_policy=block_public_policy,
            ignore_public_acls=ignore_public_acls,
            restrict_public_buckets=restrict_public_buckets,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(S3BucketPublicAccessBlock, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="blockPublicAcls")
    def block_public_acls(self) -> typing.Optional[bool]:
        return jsii.get(self, "blockPublicAcls")

    @block_public_acls.setter
    def block_public_acls(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "blockPublicAcls", value)

    @builtins.property
    @jsii.member(jsii_name="blockPublicPolicy")
    def block_public_policy(self) -> typing.Optional[bool]:
        return jsii.get(self, "blockPublicPolicy")

    @block_public_policy.setter
    def block_public_policy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "blockPublicPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ignorePublicAcls")
    def ignore_public_acls(self) -> typing.Optional[bool]:
        return jsii.get(self, "ignorePublicAcls")

    @ignore_public_acls.setter
    def ignore_public_acls(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ignorePublicAcls", value)

    @builtins.property
    @jsii.member(jsii_name="restrictPublicBuckets")
    def restrict_public_buckets(self) -> typing.Optional[bool]:
        return jsii.get(self, "restrictPublicBuckets")

    @restrict_public_buckets.setter
    def restrict_public_buckets(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "restrictPublicBuckets", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketPublicAccessBlockConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "block_public_acls": "blockPublicAcls",
        "block_public_policy": "blockPublicPolicy",
        "ignore_public_acls": "ignorePublicAcls",
        "restrict_public_buckets": "restrictPublicBuckets",
    },
)
class S3BucketPublicAccessBlockConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        block_public_acls: typing.Optional[bool] = None,
        block_public_policy: typing.Optional[bool] = None,
        ignore_public_acls: typing.Optional[bool] = None,
        restrict_public_buckets: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param block_public_acls: 
        :param block_public_policy: 
        :param ignore_public_acls: 
        :param restrict_public_buckets: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if block_public_acls is not None:
            self._values["block_public_acls"] = block_public_acls
        if block_public_policy is not None:
            self._values["block_public_policy"] = block_public_policy
        if ignore_public_acls is not None:
            self._values["ignore_public_acls"] = ignore_public_acls
        if restrict_public_buckets is not None:
            self._values["restrict_public_buckets"] = restrict_public_buckets

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def block_public_acls(self) -> typing.Optional[bool]:
        return self._values.get("block_public_acls")

    @builtins.property
    def block_public_policy(self) -> typing.Optional[bool]:
        return self._values.get("block_public_policy")

    @builtins.property
    def ignore_public_acls(self) -> typing.Optional[bool]:
        return self._values.get("ignore_public_acls")

    @builtins.property
    def restrict_public_buckets(self) -> typing.Optional[bool]:
        return self._values.get("restrict_public_buckets")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketPublicAccessBlockConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketReplicationConfiguration",
    jsii_struct_bases=[],
    name_mapping={"role": "role", "rules": "rules"},
)
class S3BucketReplicationConfiguration:
    def __init__(
        self, *, role: str, rules: typing.List["S3BucketReplicationConfigurationRules"]
    ) -> None:
        """
        :param role: 
        :param rules: rules block.
        """
        self._values = {
            "role": role,
            "rules": rules,
        }

    @builtins.property
    def role(self) -> str:
        return self._values.get("role")

    @builtins.property
    def rules(self) -> typing.List["S3BucketReplicationConfigurationRules"]:
        """rules block."""
        return self._values.get("rules")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketReplicationConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketReplicationConfigurationRules",
    jsii_struct_bases=[],
    name_mapping={
        "destination": "destination",
        "status": "status",
        "filter": "filter",
        "id": "id",
        "prefix": "prefix",
        "priority": "priority",
        "source_selection_criteria": "sourceSelectionCriteria",
    },
)
class S3BucketReplicationConfigurationRules:
    def __init__(
        self,
        *,
        destination: typing.List["S3BucketReplicationConfigurationRulesDestination"],
        status: str,
        filter: typing.Optional[
            typing.List["S3BucketReplicationConfigurationRulesFilter"]
        ] = None,
        id: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
        priority: typing.Optional[jsii.Number] = None,
        source_selection_criteria: typing.Optional[
            typing.List["S3BucketReplicationConfigurationRulesSourceSelectionCriteria"]
        ] = None,
    ) -> None:
        """
        :param destination: destination block.
        :param status: 
        :param filter: filter block.
        :param id: 
        :param prefix: 
        :param priority: 
        :param source_selection_criteria: source_selection_criteria block.
        """
        self._values = {
            "destination": destination,
            "status": status,
        }
        if filter is not None:
            self._values["filter"] = filter
        if id is not None:
            self._values["id"] = id
        if prefix is not None:
            self._values["prefix"] = prefix
        if priority is not None:
            self._values["priority"] = priority
        if source_selection_criteria is not None:
            self._values["source_selection_criteria"] = source_selection_criteria

    @builtins.property
    def destination(
        self,
    ) -> typing.List["S3BucketReplicationConfigurationRulesDestination"]:
        """destination block."""
        return self._values.get("destination")

    @builtins.property
    def status(self) -> str:
        return self._values.get("status")

    @builtins.property
    def filter(
        self,
    ) -> typing.Optional[typing.List["S3BucketReplicationConfigurationRulesFilter"]]:
        """filter block."""
        return self._values.get("filter")

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        return self._values.get("priority")

    @builtins.property
    def source_selection_criteria(
        self,
    ) -> typing.Optional[
        typing.List["S3BucketReplicationConfigurationRulesSourceSelectionCriteria"]
    ]:
        """source_selection_criteria block."""
        return self._values.get("source_selection_criteria")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketReplicationConfigurationRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketReplicationConfigurationRulesDestination",
    jsii_struct_bases=[],
    name_mapping={
        "bucket": "bucket",
        "access_control_translation": "accessControlTranslation",
        "account_id": "accountId",
        "replica_kms_key_id": "replicaKmsKeyId",
        "storage_class": "storageClass",
    },
)
class S3BucketReplicationConfigurationRulesDestination:
    def __init__(
        self,
        *,
        bucket: str,
        access_control_translation: typing.Optional[
            typing.List[
                "S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation"
            ]
        ] = None,
        account_id: typing.Optional[str] = None,
        replica_kms_key_id: typing.Optional[str] = None,
        storage_class: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket: 
        :param access_control_translation: access_control_translation block.
        :param account_id: 
        :param replica_kms_key_id: 
        :param storage_class: 
        """
        self._values = {
            "bucket": bucket,
        }
        if access_control_translation is not None:
            self._values["access_control_translation"] = access_control_translation
        if account_id is not None:
            self._values["account_id"] = account_id
        if replica_kms_key_id is not None:
            self._values["replica_kms_key_id"] = replica_kms_key_id
        if storage_class is not None:
            self._values["storage_class"] = storage_class

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def access_control_translation(
        self,
    ) -> typing.Optional[
        typing.List[
            "S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation"
        ]
    ]:
        """access_control_translation block."""
        return self._values.get("access_control_translation")

    @builtins.property
    def account_id(self) -> typing.Optional[str]:
        return self._values.get("account_id")

    @builtins.property
    def replica_kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("replica_kms_key_id")

    @builtins.property
    def storage_class(self) -> typing.Optional[str]:
        return self._values.get("storage_class")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketReplicationConfigurationRulesDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation",
    jsii_struct_bases=[],
    name_mapping={"owner": "owner"},
)
class S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation:
    def __init__(self, *, owner: str) -> None:
        """
        :param owner: 
        """
        self._values = {
            "owner": owner,
        }

    @builtins.property
    def owner(self) -> str:
        return self._values.get("owner")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketReplicationConfigurationRulesFilter",
    jsii_struct_bases=[],
    name_mapping={"prefix": "prefix", "tags": "tags"},
)
class S3BucketReplicationConfigurationRulesFilter:
    def __init__(
        self,
        *,
        prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param prefix: 
        :param tags: 
        """
        self._values = {}
        if prefix is not None:
            self._values["prefix"] = prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketReplicationConfigurationRulesFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketReplicationConfigurationRulesSourceSelectionCriteria",
    jsii_struct_bases=[],
    name_mapping={"sse_kms_encrypted_objects": "sseKmsEncryptedObjects"},
)
class S3BucketReplicationConfigurationRulesSourceSelectionCriteria:
    def __init__(
        self,
        *,
        sse_kms_encrypted_objects: typing.Optional[
            typing.List[
                "S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects"
            ]
        ] = None,
    ) -> None:
        """
        :param sse_kms_encrypted_objects: sse_kms_encrypted_objects block.
        """
        self._values = {}
        if sse_kms_encrypted_objects is not None:
            self._values["sse_kms_encrypted_objects"] = sse_kms_encrypted_objects

    @builtins.property
    def sse_kms_encrypted_objects(
        self,
    ) -> typing.Optional[
        typing.List[
            "S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects"
        ]
    ]:
        """sse_kms_encrypted_objects block."""
        return self._values.get("sse_kms_encrypted_objects")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "S3BucketReplicationConfigurationRulesSourceSelectionCriteria(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled"},
)
class S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects:
    def __init__(self, *, enabled: bool) -> None:
        """
        :param enabled: 
        """
        self._values = {
            "enabled": enabled,
        }

    @builtins.property
    def enabled(self) -> bool:
        return self._values.get("enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketServerSideEncryptionConfiguration",
    jsii_struct_bases=[],
    name_mapping={"rule": "rule"},
)
class S3BucketServerSideEncryptionConfiguration:
    def __init__(
        self, *, rule: typing.List["S3BucketServerSideEncryptionConfigurationRule"]
    ) -> None:
        """
        :param rule: rule block.
        """
        self._values = {
            "rule": rule,
        }

    @builtins.property
    def rule(self) -> typing.List["S3BucketServerSideEncryptionConfigurationRule"]:
        """rule block."""
        return self._values.get("rule")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketServerSideEncryptionConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketServerSideEncryptionConfigurationRule",
    jsii_struct_bases=[],
    name_mapping={
        "apply_server_side_encryption_by_default": "applyServerSideEncryptionByDefault"
    },
)
class S3BucketServerSideEncryptionConfigurationRule:
    def __init__(
        self,
        *,
        apply_server_side_encryption_by_default: typing.List[
            "S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault"
        ],
    ) -> None:
        """
        :param apply_server_side_encryption_by_default: apply_server_side_encryption_by_default block.
        """
        self._values = {
            "apply_server_side_encryption_by_default": apply_server_side_encryption_by_default,
        }

    @builtins.property
    def apply_server_side_encryption_by_default(
        self,
    ) -> typing.List[
        "S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault"
    ]:
        """apply_server_side_encryption_by_default block."""
        return self._values.get("apply_server_side_encryption_by_default")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketServerSideEncryptionConfigurationRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault",
    jsii_struct_bases=[],
    name_mapping={
        "sse_algorithm": "sseAlgorithm",
        "kms_master_key_id": "kmsMasterKeyId",
    },
)
class S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault:
    def __init__(
        self, *, sse_algorithm: str, kms_master_key_id: typing.Optional[str] = None
    ) -> None:
        """
        :param sse_algorithm: 
        :param kms_master_key_id: 
        """
        self._values = {
            "sse_algorithm": sse_algorithm,
        }
        if kms_master_key_id is not None:
            self._values["kms_master_key_id"] = kms_master_key_id

    @builtins.property
    def sse_algorithm(self) -> str:
        return self._values.get("sse_algorithm")

    @builtins.property
    def kms_master_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_master_key_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketVersioning",
    jsii_struct_bases=[],
    name_mapping={"enabled": "enabled", "mfa_delete": "mfaDelete"},
)
class S3BucketVersioning:
    def __init__(
        self,
        *,
        enabled: typing.Optional[bool] = None,
        mfa_delete: typing.Optional[bool] = None,
    ) -> None:
        """
        :param enabled: 
        :param mfa_delete: 
        """
        self._values = {}
        if enabled is not None:
            self._values["enabled"] = enabled
        if mfa_delete is not None:
            self._values["mfa_delete"] = mfa_delete

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def mfa_delete(self) -> typing.Optional[bool]:
        return self._values.get("mfa_delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketVersioning(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.S3BucketWebsite",
    jsii_struct_bases=[],
    name_mapping={
        "error_document": "errorDocument",
        "index_document": "indexDocument",
        "redirect_all_requests_to": "redirectAllRequestsTo",
        "routing_rules": "routingRules",
    },
)
class S3BucketWebsite:
    def __init__(
        self,
        *,
        error_document: typing.Optional[str] = None,
        index_document: typing.Optional[str] = None,
        redirect_all_requests_to: typing.Optional[str] = None,
        routing_rules: typing.Optional[str] = None,
    ) -> None:
        """
        :param error_document: 
        :param index_document: 
        :param redirect_all_requests_to: 
        :param routing_rules: 
        """
        self._values = {}
        if error_document is not None:
            self._values["error_document"] = error_document
        if index_document is not None:
            self._values["index_document"] = index_document
        if redirect_all_requests_to is not None:
            self._values["redirect_all_requests_to"] = redirect_all_requests_to
        if routing_rules is not None:
            self._values["routing_rules"] = routing_rules

    @builtins.property
    def error_document(self) -> typing.Optional[str]:
        return self._values.get("error_document")

    @builtins.property
    def index_document(self) -> typing.Optional[str]:
        return self._values.get("index_document")

    @builtins.property
    def redirect_all_requests_to(self) -> typing.Optional[str]:
        return self._values.get("redirect_all_requests_to")

    @builtins.property
    def routing_rules(self) -> typing.Optional[str]:
        return self._values.get("routing_rules")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "S3BucketWebsite(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SagemakerEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        endpoint_config_name: str,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param endpoint_config_name: 
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SagemakerEndpointConfig(
            endpoint_config_name=endpoint_config_name,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SagemakerEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="endpointConfigName")
    def endpoint_config_name(self) -> str:
        return jsii.get(self, "endpointConfigName")

    @endpoint_config_name.setter
    def endpoint_config_name(self, value: str) -> None:
        jsii.set(self, "endpointConfigName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "endpoint_config_name": "endpointConfigName",
        "name": "name",
        "tags": "tags",
    },
)
class SagemakerEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        endpoint_config_name: str,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param endpoint_config_name: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "endpoint_config_name": endpoint_config_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def endpoint_config_name(self) -> str:
        return self._values.get("endpoint_config_name")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SagemakerEndpointConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerEndpointConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        production_variants: typing.List[
            "SagemakerEndpointConfigurationProductionVariants"
        ],
        kms_key_arn: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param production_variants: production_variants block.
        :param kms_key_arn: 
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SagemakerEndpointConfigurationConfig(
            production_variants=production_variants,
            kms_key_arn=kms_key_arn,
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SagemakerEndpointConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="productionVariants")
    def production_variants(
        self,
    ) -> typing.List["SagemakerEndpointConfigurationProductionVariants"]:
        return jsii.get(self, "productionVariants")

    @production_variants.setter
    def production_variants(
        self, value: typing.List["SagemakerEndpointConfigurationProductionVariants"]
    ) -> None:
        jsii.set(self, "productionVariants", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerEndpointConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "production_variants": "productionVariants",
        "kms_key_arn": "kmsKeyArn",
        "name": "name",
        "tags": "tags",
    },
)
class SagemakerEndpointConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        production_variants: typing.List[
            "SagemakerEndpointConfigurationProductionVariants"
        ],
        kms_key_arn: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param production_variants: production_variants block.
        :param kms_key_arn: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "production_variants": production_variants,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if name is not None:
            self._values["name"] = name
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def production_variants(
        self,
    ) -> typing.List["SagemakerEndpointConfigurationProductionVariants"]:
        """production_variants block."""
        return self._values.get("production_variants")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerEndpointConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerEndpointConfigurationProductionVariants",
    jsii_struct_bases=[],
    name_mapping={
        "initial_instance_count": "initialInstanceCount",
        "instance_type": "instanceType",
        "model_name": "modelName",
        "accelerator_type": "acceleratorType",
        "initial_variant_weight": "initialVariantWeight",
        "variant_name": "variantName",
    },
)
class SagemakerEndpointConfigurationProductionVariants:
    def __init__(
        self,
        *,
        initial_instance_count: jsii.Number,
        instance_type: str,
        model_name: str,
        accelerator_type: typing.Optional[str] = None,
        initial_variant_weight: typing.Optional[jsii.Number] = None,
        variant_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param initial_instance_count: 
        :param instance_type: 
        :param model_name: 
        :param accelerator_type: 
        :param initial_variant_weight: 
        :param variant_name: 
        """
        self._values = {
            "initial_instance_count": initial_instance_count,
            "instance_type": instance_type,
            "model_name": model_name,
        }
        if accelerator_type is not None:
            self._values["accelerator_type"] = accelerator_type
        if initial_variant_weight is not None:
            self._values["initial_variant_weight"] = initial_variant_weight
        if variant_name is not None:
            self._values["variant_name"] = variant_name

    @builtins.property
    def initial_instance_count(self) -> jsii.Number:
        return self._values.get("initial_instance_count")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def model_name(self) -> str:
        return self._values.get("model_name")

    @builtins.property
    def accelerator_type(self) -> typing.Optional[str]:
        return self._values.get("accelerator_type")

    @builtins.property
    def initial_variant_weight(self) -> typing.Optional[jsii.Number]:
        return self._values.get("initial_variant_weight")

    @builtins.property
    def variant_name(self) -> typing.Optional[str]:
        return self._values.get("variant_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerEndpointConfigurationProductionVariants(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SagemakerModel(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerModel",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        execution_role_arn: str,
        container: typing.Optional[typing.List["SagemakerModelContainer"]] = None,
        enable_network_isolation: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        primary_container: typing.Optional[
            typing.List["SagemakerModelPrimaryContainer"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_config: typing.Optional[typing.List["SagemakerModelVpcConfig"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param execution_role_arn: 
        :param container: container block.
        :param enable_network_isolation: 
        :param name: 
        :param primary_container: primary_container block.
        :param tags: 
        :param vpc_config: vpc_config block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SagemakerModelConfig(
            execution_role_arn=execution_role_arn,
            container=container,
            enable_network_isolation=enable_network_isolation,
            name=name,
            primary_container=primary_container,
            tags=tags,
            vpc_config=vpc_config,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SagemakerModel, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="executionRoleArn")
    def execution_role_arn(self) -> str:
        return jsii.get(self, "executionRoleArn")

    @execution_role_arn.setter
    def execution_role_arn(self, value: str) -> None:
        jsii.set(self, "executionRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="container")
    def container(self) -> typing.Optional[typing.List["SagemakerModelContainer"]]:
        return jsii.get(self, "container")

    @container.setter
    def container(
        self, value: typing.Optional[typing.List["SagemakerModelContainer"]]
    ) -> None:
        jsii.set(self, "container", value)

    @builtins.property
    @jsii.member(jsii_name="enableNetworkIsolation")
    def enable_network_isolation(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableNetworkIsolation")

    @enable_network_isolation.setter
    def enable_network_isolation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableNetworkIsolation", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="primaryContainer")
    def primary_container(
        self,
    ) -> typing.Optional[typing.List["SagemakerModelPrimaryContainer"]]:
        return jsii.get(self, "primaryContainer")

    @primary_container.setter
    def primary_container(
        self, value: typing.Optional[typing.List["SagemakerModelPrimaryContainer"]]
    ) -> None:
        jsii.set(self, "primaryContainer", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcConfig")
    def vpc_config(self) -> typing.Optional[typing.List["SagemakerModelVpcConfig"]]:
        return jsii.get(self, "vpcConfig")

    @vpc_config.setter
    def vpc_config(
        self, value: typing.Optional[typing.List["SagemakerModelVpcConfig"]]
    ) -> None:
        jsii.set(self, "vpcConfig", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerModelConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "execution_role_arn": "executionRoleArn",
        "container": "container",
        "enable_network_isolation": "enableNetworkIsolation",
        "name": "name",
        "primary_container": "primaryContainer",
        "tags": "tags",
        "vpc_config": "vpcConfig",
    },
)
class SagemakerModelConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        execution_role_arn: str,
        container: typing.Optional[typing.List["SagemakerModelContainer"]] = None,
        enable_network_isolation: typing.Optional[bool] = None,
        name: typing.Optional[str] = None,
        primary_container: typing.Optional[
            typing.List["SagemakerModelPrimaryContainer"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_config: typing.Optional[typing.List["SagemakerModelVpcConfig"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param execution_role_arn: 
        :param container: container block.
        :param enable_network_isolation: 
        :param name: 
        :param primary_container: primary_container block.
        :param tags: 
        :param vpc_config: vpc_config block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "execution_role_arn": execution_role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if container is not None:
            self._values["container"] = container
        if enable_network_isolation is not None:
            self._values["enable_network_isolation"] = enable_network_isolation
        if name is not None:
            self._values["name"] = name
        if primary_container is not None:
            self._values["primary_container"] = primary_container
        if tags is not None:
            self._values["tags"] = tags
        if vpc_config is not None:
            self._values["vpc_config"] = vpc_config

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def execution_role_arn(self) -> str:
        return self._values.get("execution_role_arn")

    @builtins.property
    def container(self) -> typing.Optional[typing.List["SagemakerModelContainer"]]:
        """container block."""
        return self._values.get("container")

    @builtins.property
    def enable_network_isolation(self) -> typing.Optional[bool]:
        return self._values.get("enable_network_isolation")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def primary_container(
        self,
    ) -> typing.Optional[typing.List["SagemakerModelPrimaryContainer"]]:
        """primary_container block."""
        return self._values.get("primary_container")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_config(self) -> typing.Optional[typing.List["SagemakerModelVpcConfig"]]:
        """vpc_config block."""
        return self._values.get("vpc_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerModelConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerModelContainer",
    jsii_struct_bases=[],
    name_mapping={
        "image": "image",
        "container_hostname": "containerHostname",
        "environment": "environment",
        "model_data_url": "modelDataUrl",
    },
)
class SagemakerModelContainer:
    def __init__(
        self,
        *,
        image: str,
        container_hostname: typing.Optional[str] = None,
        environment: typing.Optional[typing.Mapping[str, str]] = None,
        model_data_url: typing.Optional[str] = None,
    ) -> None:
        """
        :param image: 
        :param container_hostname: 
        :param environment: 
        :param model_data_url: 
        """
        self._values = {
            "image": image,
        }
        if container_hostname is not None:
            self._values["container_hostname"] = container_hostname
        if environment is not None:
            self._values["environment"] = environment
        if model_data_url is not None:
            self._values["model_data_url"] = model_data_url

    @builtins.property
    def image(self) -> str:
        return self._values.get("image")

    @builtins.property
    def container_hostname(self) -> typing.Optional[str]:
        return self._values.get("container_hostname")

    @builtins.property
    def environment(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("environment")

    @builtins.property
    def model_data_url(self) -> typing.Optional[str]:
        return self._values.get("model_data_url")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerModelContainer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerModelPrimaryContainer",
    jsii_struct_bases=[],
    name_mapping={
        "image": "image",
        "container_hostname": "containerHostname",
        "environment": "environment",
        "model_data_url": "modelDataUrl",
    },
)
class SagemakerModelPrimaryContainer:
    def __init__(
        self,
        *,
        image: str,
        container_hostname: typing.Optional[str] = None,
        environment: typing.Optional[typing.Mapping[str, str]] = None,
        model_data_url: typing.Optional[str] = None,
    ) -> None:
        """
        :param image: 
        :param container_hostname: 
        :param environment: 
        :param model_data_url: 
        """
        self._values = {
            "image": image,
        }
        if container_hostname is not None:
            self._values["container_hostname"] = container_hostname
        if environment is not None:
            self._values["environment"] = environment
        if model_data_url is not None:
            self._values["model_data_url"] = model_data_url

    @builtins.property
    def image(self) -> str:
        return self._values.get("image")

    @builtins.property
    def container_hostname(self) -> typing.Optional[str]:
        return self._values.get("container_hostname")

    @builtins.property
    def environment(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("environment")

    @builtins.property
    def model_data_url(self) -> typing.Optional[str]:
        return self._values.get("model_data_url")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerModelPrimaryContainer(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerModelVpcConfig",
    jsii_struct_bases=[],
    name_mapping={"security_group_ids": "securityGroupIds", "subnets": "subnets"},
)
class SagemakerModelVpcConfig:
    def __init__(
        self, *, security_group_ids: typing.List[str], subnets: typing.List[str]
    ) -> None:
        """
        :param security_group_ids: 
        :param subnets: 
        """
        self._values = {
            "security_group_ids": security_group_ids,
            "subnets": subnets,
        }

    @builtins.property
    def security_group_ids(self) -> typing.List[str]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnets(self) -> typing.List[str]:
        return self._values.get("subnets")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerModelVpcConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SagemakerNotebookInstance(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerNotebookInstance",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        instance_type: str,
        name: str,
        role_arn: str,
        direct_internet_access: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        lifecycle_config_name: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param instance_type: 
        :param name: 
        :param role_arn: 
        :param direct_internet_access: 
        :param kms_key_id: 
        :param lifecycle_config_name: 
        :param security_groups: 
        :param subnet_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SagemakerNotebookInstanceConfig(
            instance_type=instance_type,
            name=name,
            role_arn=role_arn,
            direct_internet_access=direct_internet_access,
            kms_key_id=kms_key_id,
            lifecycle_config_name=lifecycle_config_name,
            security_groups=security_groups,
            subnet_id=subnet_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SagemakerNotebookInstance, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: str) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="directInternetAccess")
    def direct_internet_access(self) -> typing.Optional[str]:
        return jsii.get(self, "directInternetAccess")

    @direct_internet_access.setter
    def direct_internet_access(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "directInternetAccess", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="lifecycleConfigName")
    def lifecycle_config_name(self) -> typing.Optional[str]:
        return jsii.get(self, "lifecycleConfigName")

    @lifecycle_config_name.setter
    def lifecycle_config_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "lifecycleConfigName", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerNotebookInstanceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "instance_type": "instanceType",
        "name": "name",
        "role_arn": "roleArn",
        "direct_internet_access": "directInternetAccess",
        "kms_key_id": "kmsKeyId",
        "lifecycle_config_name": "lifecycleConfigName",
        "security_groups": "securityGroups",
        "subnet_id": "subnetId",
        "tags": "tags",
    },
)
class SagemakerNotebookInstanceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        instance_type: str,
        name: str,
        role_arn: str,
        direct_internet_access: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        lifecycle_config_name: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param instance_type: 
        :param name: 
        :param role_arn: 
        :param direct_internet_access: 
        :param kms_key_id: 
        :param lifecycle_config_name: 
        :param security_groups: 
        :param subnet_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "instance_type": instance_type,
            "name": name,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if direct_internet_access is not None:
            self._values["direct_internet_access"] = direct_internet_access
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if lifecycle_config_name is not None:
            self._values["lifecycle_config_name"] = lifecycle_config_name
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def direct_internet_access(self) -> typing.Optional[str]:
        return self._values.get("direct_internet_access")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def lifecycle_config_name(self) -> typing.Optional[str]:
        return self._values.get("lifecycle_config_name")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerNotebookInstanceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SagemakerNotebookInstanceLifecycleConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerNotebookInstanceLifecycleConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: typing.Optional[str] = None,
        on_create: typing.Optional[str] = None,
        on_start: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param on_create: 
        :param on_start: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SagemakerNotebookInstanceLifecycleConfigurationConfig(
            name=name,
            on_create=on_create,
            on_start=on_start,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(
            SagemakerNotebookInstanceLifecycleConfiguration, self, [scope, id, config]
        )

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="onCreate")
    def on_create(self) -> typing.Optional[str]:
        return jsii.get(self, "onCreate")

    @on_create.setter
    def on_create(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "onCreate", value)

    @builtins.property
    @jsii.member(jsii_name="onStart")
    def on_start(self) -> typing.Optional[str]:
        return jsii.get(self, "onStart")

    @on_start.setter
    def on_start(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "onStart", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SagemakerNotebookInstanceLifecycleConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "on_create": "onCreate",
        "on_start": "onStart",
    },
)
class SagemakerNotebookInstanceLifecycleConfigurationConfig(
    cdktf.TerraformMetaArguments
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: typing.Optional[str] = None,
        on_create: typing.Optional[str] = None,
        on_start: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param on_create: 
        :param on_start: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if name is not None:
            self._values["name"] = name
        if on_create is not None:
            self._values["on_create"] = on_create
        if on_start is not None:
            self._values["on_start"] = on_start

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def on_create(self) -> typing.Optional[str]:
        return self._values.get("on_create")

    @builtins.property
    def on_start(self) -> typing.Optional[str]:
        return self._values.get("on_start")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SagemakerNotebookInstanceLifecycleConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecretsmanagerSecret(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecret",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        description: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        recovery_window_in_days: typing.Optional[jsii.Number] = None,
        rotation_lambda_arn: typing.Optional[str] = None,
        rotation_rules: typing.Optional[
            typing.List["SecretsmanagerSecretRotationRules"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param description: 
        :param kms_key_id: 
        :param name: 
        :param name_prefix: 
        :param policy: 
        :param recovery_window_in_days: 
        :param rotation_lambda_arn: 
        :param rotation_rules: rotation_rules block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecretsmanagerSecretConfig(
            description=description,
            kms_key_id=kms_key_id,
            name=name,
            name_prefix=name_prefix,
            policy=policy,
            recovery_window_in_days=recovery_window_in_days,
            rotation_lambda_arn=rotation_lambda_arn,
            rotation_rules=rotation_rules,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecretsmanagerSecret, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="rotationEnabled")
    def rotation_enabled(self) -> bool:
        return jsii.get(self, "rotationEnabled")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyId")
    def kms_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyId")

    @kms_key_id.setter
    def kms_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="recoveryWindowInDays")
    def recovery_window_in_days(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "recoveryWindowInDays")

    @recovery_window_in_days.setter
    def recovery_window_in_days(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "recoveryWindowInDays", value)

    @builtins.property
    @jsii.member(jsii_name="rotationLambdaArn")
    def rotation_lambda_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "rotationLambdaArn")

    @rotation_lambda_arn.setter
    def rotation_lambda_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "rotationLambdaArn", value)

    @builtins.property
    @jsii.member(jsii_name="rotationRules")
    def rotation_rules(
        self,
    ) -> typing.Optional[typing.List["SecretsmanagerSecretRotationRules"]]:
        return jsii.get(self, "rotationRules")

    @rotation_rules.setter
    def rotation_rules(
        self, value: typing.Optional[typing.List["SecretsmanagerSecretRotationRules"]]
    ) -> None:
        jsii.set(self, "rotationRules", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecretConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "kms_key_id": "kmsKeyId",
        "name": "name",
        "name_prefix": "namePrefix",
        "policy": "policy",
        "recovery_window_in_days": "recoveryWindowInDays",
        "rotation_lambda_arn": "rotationLambdaArn",
        "rotation_rules": "rotationRules",
        "tags": "tags",
    },
)
class SecretsmanagerSecretConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[str] = None,
        kms_key_id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        recovery_window_in_days: typing.Optional[jsii.Number] = None,
        rotation_lambda_arn: typing.Optional[str] = None,
        rotation_rules: typing.Optional[
            typing.List["SecretsmanagerSecretRotationRules"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: 
        :param kms_key_id: 
        :param name: 
        :param name_prefix: 
        :param policy: 
        :param recovery_window_in_days: 
        :param rotation_lambda_arn: 
        :param rotation_rules: rotation_rules block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if policy is not None:
            self._values["policy"] = policy
        if recovery_window_in_days is not None:
            self._values["recovery_window_in_days"] = recovery_window_in_days
        if rotation_lambda_arn is not None:
            self._values["rotation_lambda_arn"] = rotation_lambda_arn
        if rotation_rules is not None:
            self._values["rotation_rules"] = rotation_rules
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def recovery_window_in_days(self) -> typing.Optional[jsii.Number]:
        return self._values.get("recovery_window_in_days")

    @builtins.property
    def rotation_lambda_arn(self) -> typing.Optional[str]:
        return self._values.get("rotation_lambda_arn")

    @builtins.property
    def rotation_rules(
        self,
    ) -> typing.Optional[typing.List["SecretsmanagerSecretRotationRules"]]:
        """rotation_rules block."""
        return self._values.get("rotation_rules")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretsmanagerSecretConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecretsmanagerSecretRotation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecretRotation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        rotation_lambda_arn: str,
        rotation_rules: typing.List["SecretsmanagerSecretRotationRotationRules"],
        secret_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param rotation_lambda_arn: 
        :param rotation_rules: rotation_rules block.
        :param secret_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecretsmanagerSecretRotationConfig(
            rotation_lambda_arn=rotation_lambda_arn,
            rotation_rules=rotation_rules,
            secret_id=secret_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecretsmanagerSecretRotation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="rotationEnabled")
    def rotation_enabled(self) -> bool:
        return jsii.get(self, "rotationEnabled")

    @builtins.property
    @jsii.member(jsii_name="rotationLambdaArn")
    def rotation_lambda_arn(self) -> str:
        return jsii.get(self, "rotationLambdaArn")

    @rotation_lambda_arn.setter
    def rotation_lambda_arn(self, value: str) -> None:
        jsii.set(self, "rotationLambdaArn", value)

    @builtins.property
    @jsii.member(jsii_name="rotationRules")
    def rotation_rules(
        self,
    ) -> typing.List["SecretsmanagerSecretRotationRotationRules"]:
        return jsii.get(self, "rotationRules")

    @rotation_rules.setter
    def rotation_rules(
        self, value: typing.List["SecretsmanagerSecretRotationRotationRules"]
    ) -> None:
        jsii.set(self, "rotationRules", value)

    @builtins.property
    @jsii.member(jsii_name="secretId")
    def secret_id(self) -> str:
        return jsii.get(self, "secretId")

    @secret_id.setter
    def secret_id(self, value: str) -> None:
        jsii.set(self, "secretId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecretRotationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "rotation_lambda_arn": "rotationLambdaArn",
        "rotation_rules": "rotationRules",
        "secret_id": "secretId",
        "tags": "tags",
    },
)
class SecretsmanagerSecretRotationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        rotation_lambda_arn: str,
        rotation_rules: typing.List["SecretsmanagerSecretRotationRotationRules"],
        secret_id: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param rotation_lambda_arn: 
        :param rotation_rules: rotation_rules block.
        :param secret_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "rotation_lambda_arn": rotation_lambda_arn,
            "rotation_rules": rotation_rules,
            "secret_id": secret_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def rotation_lambda_arn(self) -> str:
        return self._values.get("rotation_lambda_arn")

    @builtins.property
    def rotation_rules(
        self,
    ) -> typing.List["SecretsmanagerSecretRotationRotationRules"]:
        """rotation_rules block."""
        return self._values.get("rotation_rules")

    @builtins.property
    def secret_id(self) -> str:
        return self._values.get("secret_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretsmanagerSecretRotationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecretRotationRotationRules",
    jsii_struct_bases=[],
    name_mapping={"automatically_after_days": "automaticallyAfterDays"},
)
class SecretsmanagerSecretRotationRotationRules:
    def __init__(self, *, automatically_after_days: jsii.Number) -> None:
        """
        :param automatically_after_days: 
        """
        self._values = {
            "automatically_after_days": automatically_after_days,
        }

    @builtins.property
    def automatically_after_days(self) -> jsii.Number:
        return self._values.get("automatically_after_days")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretsmanagerSecretRotationRotationRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecretRotationRules",
    jsii_struct_bases=[],
    name_mapping={"automatically_after_days": "automaticallyAfterDays"},
)
class SecretsmanagerSecretRotationRules:
    def __init__(self, *, automatically_after_days: jsii.Number) -> None:
        """
        :param automatically_after_days: 
        """
        self._values = {
            "automatically_after_days": automatically_after_days,
        }

    @builtins.property
    def automatically_after_days(self) -> jsii.Number:
        return self._values.get("automatically_after_days")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretsmanagerSecretRotationRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecretsmanagerSecretVersion(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecretVersion",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        secret_id: str,
        secret_binary: typing.Optional[str] = None,
        secret_string: typing.Optional[str] = None,
        version_stages: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param secret_id: 
        :param secret_binary: 
        :param secret_string: 
        :param version_stages: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecretsmanagerSecretVersionConfig(
            secret_id=secret_id,
            secret_binary=secret_binary,
            secret_string=secret_string,
            version_stages=version_stages,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecretsmanagerSecretVersion, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="versionId")
    def version_id(self) -> str:
        return jsii.get(self, "versionId")

    @builtins.property
    @jsii.member(jsii_name="secretId")
    def secret_id(self) -> str:
        return jsii.get(self, "secretId")

    @secret_id.setter
    def secret_id(self, value: str) -> None:
        jsii.set(self, "secretId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="secretBinary")
    def secret_binary(self) -> typing.Optional[str]:
        return jsii.get(self, "secretBinary")

    @secret_binary.setter
    def secret_binary(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "secretBinary", value)

    @builtins.property
    @jsii.member(jsii_name="secretString")
    def secret_string(self) -> typing.Optional[str]:
        return jsii.get(self, "secretString")

    @secret_string.setter
    def secret_string(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "secretString", value)

    @builtins.property
    @jsii.member(jsii_name="versionStages")
    def version_stages(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "versionStages")

    @version_stages.setter
    def version_stages(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "versionStages", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecretsmanagerSecretVersionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "secret_id": "secretId",
        "secret_binary": "secretBinary",
        "secret_string": "secretString",
        "version_stages": "versionStages",
    },
)
class SecretsmanagerSecretVersionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        secret_id: str,
        secret_binary: typing.Optional[str] = None,
        secret_string: typing.Optional[str] = None,
        version_stages: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param secret_id: 
        :param secret_binary: 
        :param secret_string: 
        :param version_stages: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "secret_id": secret_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if secret_binary is not None:
            self._values["secret_binary"] = secret_binary
        if secret_string is not None:
            self._values["secret_string"] = secret_string
        if version_stages is not None:
            self._values["version_stages"] = version_stages

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def secret_id(self) -> str:
        return self._values.get("secret_id")

    @builtins.property
    def secret_binary(self) -> typing.Optional[str]:
        return self._values.get("secret_binary")

    @builtins.property
    def secret_string(self) -> typing.Optional[str]:
        return self._values.get("secret_string")

    @builtins.property
    def version_stages(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("version_stages")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecretsmanagerSecretVersionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        description: typing.Optional[str] = None,
        egress: typing.Optional[typing.List["SecurityGroupEgress"]] = None,
        ingress: typing.Optional[typing.List["SecurityGroupIngress"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        revoke_rules_on_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["SecurityGroupTimeouts"] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param description: 
        :param egress: 
        :param ingress: 
        :param name: 
        :param name_prefix: 
        :param revoke_rules_on_delete: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityGroupConfig(
            description=description,
            egress=egress,
            ingress=ingress,
            name=name,
            name_prefix=name_prefix,
            revoke_rules_on_delete=revoke_rules_on_delete,
            tags=tags,
            timeouts=timeouts,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="egress")
    def egress(self) -> typing.Optional[typing.List["SecurityGroupEgress"]]:
        return jsii.get(self, "egress")

    @egress.setter
    def egress(
        self, value: typing.Optional[typing.List["SecurityGroupEgress"]]
    ) -> None:
        jsii.set(self, "egress", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ingress")
    def ingress(self) -> typing.Optional[typing.List["SecurityGroupIngress"]]:
        return jsii.get(self, "ingress")

    @ingress.setter
    def ingress(
        self, value: typing.Optional[typing.List["SecurityGroupIngress"]]
    ) -> None:
        jsii.set(self, "ingress", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="revokeRulesOnDelete")
    def revoke_rules_on_delete(self) -> typing.Optional[bool]:
        return jsii.get(self, "revokeRulesOnDelete")

    @revoke_rules_on_delete.setter
    def revoke_rules_on_delete(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "revokeRulesOnDelete", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SecurityGroupTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["SecurityGroupTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "description": "description",
        "egress": "egress",
        "ingress": "ingress",
        "name": "name",
        "name_prefix": "namePrefix",
        "revoke_rules_on_delete": "revokeRulesOnDelete",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_id": "vpcId",
    },
)
class SecurityGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        description: typing.Optional[str] = None,
        egress: typing.Optional[typing.List["SecurityGroupEgress"]] = None,
        ingress: typing.Optional[typing.List["SecurityGroupIngress"]] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        revoke_rules_on_delete: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["SecurityGroupTimeouts"] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param description: 
        :param egress: 
        :param ingress: 
        :param name: 
        :param name_prefix: 
        :param revoke_rules_on_delete: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SecurityGroupTimeouts(**timeouts)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if egress is not None:
            self._values["egress"] = egress
        if ingress is not None:
            self._values["ingress"] = ingress
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if revoke_rules_on_delete is not None:
            self._values["revoke_rules_on_delete"] = revoke_rules_on_delete
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def egress(self) -> typing.Optional[typing.List["SecurityGroupEgress"]]:
        return self._values.get("egress")

    @builtins.property
    def ingress(self) -> typing.Optional[typing.List["SecurityGroupIngress"]]:
        return self._values.get("ingress")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def revoke_rules_on_delete(self) -> typing.Optional[bool]:
        return self._values.get("revoke_rules_on_delete")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["SecurityGroupTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityGroupEgress",
    jsii_struct_bases=[],
    name_mapping={
        "cidr_blocks": "cidrBlocks",
        "description": "description",
        "from_port": "fromPort",
        "ipv6_cidr_blocks": "ipv6CidrBlocks",
        "prefix_list_ids": "prefixListIds",
        "protocol": "protocol",
        "security_groups": "securityGroups",
        "self_attribute": "selfAttribute",
        "to_port": "toPort",
    },
)
class SecurityGroupEgress:
    def __init__(
        self,
        *,
        cidr_blocks: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        ipv6_cidr_blocks: typing.Optional[typing.List[str]] = None,
        prefix_list_ids: typing.Optional[typing.List[str]] = None,
        protocol: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        self_attribute: typing.Optional[bool] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param cidr_blocks: 
        :param description: 
        :param from_port: 
        :param ipv6_cidr_blocks: 
        :param prefix_list_ids: 
        :param protocol: 
        :param security_groups: 
        :param self_attribute: 
        :param to_port: 
        """
        self._values = {}
        if cidr_blocks is not None:
            self._values["cidr_blocks"] = cidr_blocks
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if ipv6_cidr_blocks is not None:
            self._values["ipv6_cidr_blocks"] = ipv6_cidr_blocks
        if prefix_list_ids is not None:
            self._values["prefix_list_ids"] = prefix_list_ids
        if protocol is not None:
            self._values["protocol"] = protocol
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if self_attribute is not None:
            self._values["self_attribute"] = self_attribute
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cidr_blocks")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def ipv6_cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_cidr_blocks")

    @builtins.property
    def prefix_list_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("prefix_list_ids")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def self_attribute(self) -> typing.Optional[bool]:
        return self._values.get("self_attribute")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityGroupEgress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityGroupIngress",
    jsii_struct_bases=[],
    name_mapping={
        "cidr_blocks": "cidrBlocks",
        "description": "description",
        "from_port": "fromPort",
        "ipv6_cidr_blocks": "ipv6CidrBlocks",
        "prefix_list_ids": "prefixListIds",
        "protocol": "protocol",
        "security_groups": "securityGroups",
        "self_attribute": "selfAttribute",
        "to_port": "toPort",
    },
)
class SecurityGroupIngress:
    def __init__(
        self,
        *,
        cidr_blocks: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        from_port: typing.Optional[jsii.Number] = None,
        ipv6_cidr_blocks: typing.Optional[typing.List[str]] = None,
        prefix_list_ids: typing.Optional[typing.List[str]] = None,
        protocol: typing.Optional[str] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        self_attribute: typing.Optional[bool] = None,
        to_port: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param cidr_blocks: 
        :param description: 
        :param from_port: 
        :param ipv6_cidr_blocks: 
        :param prefix_list_ids: 
        :param protocol: 
        :param security_groups: 
        :param self_attribute: 
        :param to_port: 
        """
        self._values = {}
        if cidr_blocks is not None:
            self._values["cidr_blocks"] = cidr_blocks
        if description is not None:
            self._values["description"] = description
        if from_port is not None:
            self._values["from_port"] = from_port
        if ipv6_cidr_blocks is not None:
            self._values["ipv6_cidr_blocks"] = ipv6_cidr_blocks
        if prefix_list_ids is not None:
            self._values["prefix_list_ids"] = prefix_list_ids
        if protocol is not None:
            self._values["protocol"] = protocol
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if self_attribute is not None:
            self._values["self_attribute"] = self_attribute
        if to_port is not None:
            self._values["to_port"] = to_port

    @builtins.property
    def cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cidr_blocks")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def from_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("from_port")

    @builtins.property
    def ipv6_cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_cidr_blocks")

    @builtins.property
    def prefix_list_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("prefix_list_ids")

    @builtins.property
    def protocol(self) -> typing.Optional[str]:
        return self._values.get("protocol")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def self_attribute(self) -> typing.Optional[bool]:
        return self._values.get("self_attribute")

    @builtins.property
    def to_port(self) -> typing.Optional[jsii.Number]:
        return self._values.get("to_port")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityGroupIngress(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityGroupRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityGroupRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        from_port: jsii.Number,
        protocol: str,
        security_group_id: str,
        to_port: jsii.Number,
        type: str,
        cidr_blocks: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        ipv6_cidr_blocks: typing.Optional[typing.List[str]] = None,
        prefix_list_ids: typing.Optional[typing.List[str]] = None,
        self_attribute: typing.Optional[bool] = None,
        source_security_group_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param from_port: 
        :param protocol: 
        :param security_group_id: 
        :param to_port: 
        :param type: Type of rule, ingress (inbound) or egress (outbound).
        :param cidr_blocks: 
        :param description: 
        :param ipv6_cidr_blocks: 
        :param prefix_list_ids: 
        :param self_attribute: 
        :param source_security_group_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityGroupRuleConfig(
            from_port=from_port,
            protocol=protocol,
            security_group_id=security_group_id,
            to_port=to_port,
            type=type,
            cidr_blocks=cidr_blocks,
            description=description,
            ipv6_cidr_blocks=ipv6_cidr_blocks,
            prefix_list_ids=prefix_list_ids,
            self_attribute=self_attribute,
            source_security_group_id=source_security_group_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityGroupRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="fromPort")
    def from_port(self) -> jsii.Number:
        return jsii.get(self, "fromPort")

    @from_port.setter
    def from_port(self, value: jsii.Number) -> None:
        jsii.set(self, "fromPort", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupId")
    def security_group_id(self) -> str:
        return jsii.get(self, "securityGroupId")

    @security_group_id.setter
    def security_group_id(self, value: str) -> None:
        jsii.set(self, "securityGroupId", value)

    @builtins.property
    @jsii.member(jsii_name="toPort")
    def to_port(self) -> jsii.Number:
        return jsii.get(self, "toPort")

    @to_port.setter
    def to_port(self, value: jsii.Number) -> None:
        jsii.set(self, "toPort", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="cidrBlocks")
    def cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "cidrBlocks")

    @cidr_blocks.setter
    def cidr_blocks(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "cidrBlocks", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlocks")
    def ipv6_cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "ipv6CidrBlocks")

    @ipv6_cidr_blocks.setter
    def ipv6_cidr_blocks(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "ipv6CidrBlocks", value)

    @builtins.property
    @jsii.member(jsii_name="prefixListIds")
    def prefix_list_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "prefixListIds")

    @prefix_list_ids.setter
    def prefix_list_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "prefixListIds", value)

    @builtins.property
    @jsii.member(jsii_name="selfAttribute")
    def self_attribute(self) -> typing.Optional[bool]:
        return jsii.get(self, "selfAttribute")

    @self_attribute.setter
    def self_attribute(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "selfAttribute", value)

    @builtins.property
    @jsii.member(jsii_name="sourceSecurityGroupId")
    def source_security_group_id(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceSecurityGroupId")

    @source_security_group_id.setter
    def source_security_group_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceSecurityGroupId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityGroupRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "from_port": "fromPort",
        "protocol": "protocol",
        "security_group_id": "securityGroupId",
        "to_port": "toPort",
        "type": "type",
        "cidr_blocks": "cidrBlocks",
        "description": "description",
        "ipv6_cidr_blocks": "ipv6CidrBlocks",
        "prefix_list_ids": "prefixListIds",
        "self_attribute": "selfAttribute",
        "source_security_group_id": "sourceSecurityGroupId",
    },
)
class SecurityGroupRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        from_port: jsii.Number,
        protocol: str,
        security_group_id: str,
        to_port: jsii.Number,
        type: str,
        cidr_blocks: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        ipv6_cidr_blocks: typing.Optional[typing.List[str]] = None,
        prefix_list_ids: typing.Optional[typing.List[str]] = None,
        self_attribute: typing.Optional[bool] = None,
        source_security_group_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param from_port: 
        :param protocol: 
        :param security_group_id: 
        :param to_port: 
        :param type: Type of rule, ingress (inbound) or egress (outbound).
        :param cidr_blocks: 
        :param description: 
        :param ipv6_cidr_blocks: 
        :param prefix_list_ids: 
        :param self_attribute: 
        :param source_security_group_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "from_port": from_port,
            "protocol": protocol,
            "security_group_id": security_group_id,
            "to_port": to_port,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cidr_blocks is not None:
            self._values["cidr_blocks"] = cidr_blocks
        if description is not None:
            self._values["description"] = description
        if ipv6_cidr_blocks is not None:
            self._values["ipv6_cidr_blocks"] = ipv6_cidr_blocks
        if prefix_list_ids is not None:
            self._values["prefix_list_ids"] = prefix_list_ids
        if self_attribute is not None:
            self._values["self_attribute"] = self_attribute
        if source_security_group_id is not None:
            self._values["source_security_group_id"] = source_security_group_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def from_port(self) -> jsii.Number:
        return self._values.get("from_port")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def security_group_id(self) -> str:
        return self._values.get("security_group_id")

    @builtins.property
    def to_port(self) -> jsii.Number:
        return self._values.get("to_port")

    @builtins.property
    def type(self) -> str:
        """Type of rule, ingress (inbound) or egress (outbound)."""
        return self._values.get("type")

    @builtins.property
    def cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("cidr_blocks")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def ipv6_cidr_blocks(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_cidr_blocks")

    @builtins.property
    def prefix_list_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("prefix_list_ids")

    @builtins.property
    def self_attribute(self) -> typing.Optional[bool]:
        return self._values.get("self_attribute")

    @builtins.property
    def source_security_group_id(self) -> typing.Optional[str]:
        return self._values.get("source_security_group_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityGroupRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityGroupTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class SecurityGroupTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityGroupTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityhubAccount(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubAccount",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityhubAccountConfig(
            count=count, depends_on=depends_on, lifecycle=lifecycle, provider=provider
        )

        jsii.create(SecurityhubAccount, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubAccountConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
    },
)
class SecurityhubAccountConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityhubAccountConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityhubMember(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubMember",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_id: str,
        email: str,
        invite: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_id: 
        :param email: 
        :param invite: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityhubMemberConfig(
            account_id=account_id,
            email=email,
            invite=invite,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityhubMember, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="masterId")
    def master_id(self) -> str:
        return jsii.get(self, "masterId")

    @builtins.property
    @jsii.member(jsii_name="memberStatus")
    def member_status(self) -> str:
        return jsii.get(self, "memberStatus")

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: str) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @email.setter
    def email(self, value: str) -> None:
        jsii.set(self, "email", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="invite")
    def invite(self) -> typing.Optional[bool]:
        return jsii.get(self, "invite")

    @invite.setter
    def invite(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "invite", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubMemberConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_id": "accountId",
        "email": "email",
        "invite": "invite",
    },
)
class SecurityhubMemberConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_id: str,
        email: str,
        invite: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_id: 
        :param email: 
        :param invite: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "account_id": account_id,
            "email": email,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if invite is not None:
            self._values["invite"] = invite

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_id(self) -> str:
        return self._values.get("account_id")

    @builtins.property
    def email(self) -> str:
        return self._values.get("email")

    @builtins.property
    def invite(self) -> typing.Optional[bool]:
        return self._values.get("invite")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityhubMemberConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityhubProductSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubProductSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        product_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param product_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityhubProductSubscriptionConfig(
            product_arn=product_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityhubProductSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="productArn")
    def product_arn(self) -> str:
        return jsii.get(self, "productArn")

    @product_arn.setter
    def product_arn(self, value: str) -> None:
        jsii.set(self, "productArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubProductSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "product_arn": "productArn",
    },
)
class SecurityhubProductSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        product_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param product_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "product_arn": product_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def product_arn(self) -> str:
        return self._values.get("product_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityhubProductSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SecurityhubStandardsSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubStandardsSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        standards_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param standards_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SecurityhubStandardsSubscriptionConfig(
            standards_arn=standards_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SecurityhubStandardsSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="standardsArn")
    def standards_arn(self) -> str:
        return jsii.get(self, "standardsArn")

    @standards_arn.setter
    def standards_arn(self, value: str) -> None:
        jsii.set(self, "standardsArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SecurityhubStandardsSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "standards_arn": "standardsArn",
    },
)
class SecurityhubStandardsSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        standards_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param standards_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "standards_arn": standards_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def standards_arn(self) -> str:
        return self._values.get("standards_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SecurityhubStandardsSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServiceDiscoveryHttpNamespace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryHttpNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServiceDiscoveryHttpNamespaceConfig(
            name=name,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServiceDiscoveryHttpNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryHttpNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "tags": "tags",
    },
)
class ServiceDiscoveryHttpNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryHttpNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServiceDiscoveryPrivateDnsNamespace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryPrivateDnsNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        vpc: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param vpc: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServiceDiscoveryPrivateDnsNamespaceConfig(
            name=name,
            vpc=vpc,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServiceDiscoveryPrivateDnsNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="hostedZone")
    def hosted_zone(self) -> str:
        return jsii.get(self, "hostedZone")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="vpc")
    def vpc(self) -> str:
        return jsii.get(self, "vpc")

    @vpc.setter
    def vpc(self, value: str) -> None:
        jsii.set(self, "vpc", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryPrivateDnsNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "vpc": "vpc",
        "description": "description",
        "tags": "tags",
    },
)
class ServiceDiscoveryPrivateDnsNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        vpc: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param vpc: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "vpc": vpc,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def vpc(self) -> str:
        return self._values.get("vpc")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryPrivateDnsNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServiceDiscoveryPublicDnsNamespace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryPublicDnsNamespace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServiceDiscoveryPublicDnsNamespaceConfig(
            name=name,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServiceDiscoveryPublicDnsNamespace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="hostedZone")
    def hosted_zone(self) -> str:
        return jsii.get(self, "hostedZone")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryPublicDnsNamespaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "tags": "tags",
    },
)
class ServiceDiscoveryPublicDnsNamespaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryPublicDnsNamespaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServiceDiscoveryService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        dns_config: typing.Optional[
            typing.List["ServiceDiscoveryServiceDnsConfig"]
        ] = None,
        health_check_config: typing.Optional[
            typing.List["ServiceDiscoveryServiceHealthCheckConfig"]
        ] = None,
        health_check_custom_config: typing.Optional[
            typing.List["ServiceDiscoveryServiceHealthCheckCustomConfig"]
        ] = None,
        namespace_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param dns_config: dns_config block.
        :param health_check_config: health_check_config block.
        :param health_check_custom_config: health_check_custom_config block.
        :param namespace_id: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServiceDiscoveryServiceConfig(
            name=name,
            description=description,
            dns_config=dns_config,
            health_check_config=health_check_config,
            health_check_custom_config=health_check_custom_config,
            namespace_id=namespace_id,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServiceDiscoveryService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="dnsConfig")
    def dns_config(
        self,
    ) -> typing.Optional[typing.List["ServiceDiscoveryServiceDnsConfig"]]:
        return jsii.get(self, "dnsConfig")

    @dns_config.setter
    def dns_config(
        self, value: typing.Optional[typing.List["ServiceDiscoveryServiceDnsConfig"]]
    ) -> None:
        jsii.set(self, "dnsConfig", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckConfig")
    def health_check_config(
        self,
    ) -> typing.Optional[typing.List["ServiceDiscoveryServiceHealthCheckConfig"]]:
        return jsii.get(self, "healthCheckConfig")

    @health_check_config.setter
    def health_check_config(
        self,
        value: typing.Optional[typing.List["ServiceDiscoveryServiceHealthCheckConfig"]],
    ) -> None:
        jsii.set(self, "healthCheckConfig", value)

    @builtins.property
    @jsii.member(jsii_name="healthCheckCustomConfig")
    def health_check_custom_config(
        self,
    ) -> typing.Optional[typing.List["ServiceDiscoveryServiceHealthCheckCustomConfig"]]:
        return jsii.get(self, "healthCheckCustomConfig")

    @health_check_custom_config.setter
    def health_check_custom_config(
        self,
        value: typing.Optional[
            typing.List["ServiceDiscoveryServiceHealthCheckCustomConfig"]
        ],
    ) -> None:
        jsii.set(self, "healthCheckCustomConfig", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="namespaceId")
    def namespace_id(self) -> typing.Optional[str]:
        return jsii.get(self, "namespaceId")

    @namespace_id.setter
    def namespace_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namespaceId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "dns_config": "dnsConfig",
        "health_check_config": "healthCheckConfig",
        "health_check_custom_config": "healthCheckCustomConfig",
        "namespace_id": "namespaceId",
        "tags": "tags",
    },
)
class ServiceDiscoveryServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        dns_config: typing.Optional[
            typing.List["ServiceDiscoveryServiceDnsConfig"]
        ] = None,
        health_check_config: typing.Optional[
            typing.List["ServiceDiscoveryServiceHealthCheckConfig"]
        ] = None,
        health_check_custom_config: typing.Optional[
            typing.List["ServiceDiscoveryServiceHealthCheckCustomConfig"]
        ] = None,
        namespace_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param dns_config: dns_config block.
        :param health_check_config: health_check_config block.
        :param health_check_custom_config: health_check_custom_config block.
        :param namespace_id: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if dns_config is not None:
            self._values["dns_config"] = dns_config
        if health_check_config is not None:
            self._values["health_check_config"] = health_check_config
        if health_check_custom_config is not None:
            self._values["health_check_custom_config"] = health_check_custom_config
        if namespace_id is not None:
            self._values["namespace_id"] = namespace_id
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def dns_config(
        self,
    ) -> typing.Optional[typing.List["ServiceDiscoveryServiceDnsConfig"]]:
        """dns_config block."""
        return self._values.get("dns_config")

    @builtins.property
    def health_check_config(
        self,
    ) -> typing.Optional[typing.List["ServiceDiscoveryServiceHealthCheckConfig"]]:
        """health_check_config block."""
        return self._values.get("health_check_config")

    @builtins.property
    def health_check_custom_config(
        self,
    ) -> typing.Optional[typing.List["ServiceDiscoveryServiceHealthCheckCustomConfig"]]:
        """health_check_custom_config block."""
        return self._values.get("health_check_custom_config")

    @builtins.property
    def namespace_id(self) -> typing.Optional[str]:
        return self._values.get("namespace_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryServiceDnsConfig",
    jsii_struct_bases=[],
    name_mapping={
        "dns_records": "dnsRecords",
        "namespace_id": "namespaceId",
        "routing_policy": "routingPolicy",
    },
)
class ServiceDiscoveryServiceDnsConfig:
    def __init__(
        self,
        *,
        dns_records: typing.List["ServiceDiscoveryServiceDnsConfigDnsRecords"],
        namespace_id: str,
        routing_policy: typing.Optional[str] = None,
    ) -> None:
        """
        :param dns_records: dns_records block.
        :param namespace_id: 
        :param routing_policy: 
        """
        self._values = {
            "dns_records": dns_records,
            "namespace_id": namespace_id,
        }
        if routing_policy is not None:
            self._values["routing_policy"] = routing_policy

    @builtins.property
    def dns_records(self) -> typing.List["ServiceDiscoveryServiceDnsConfigDnsRecords"]:
        """dns_records block."""
        return self._values.get("dns_records")

    @builtins.property
    def namespace_id(self) -> str:
        return self._values.get("namespace_id")

    @builtins.property
    def routing_policy(self) -> typing.Optional[str]:
        return self._values.get("routing_policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryServiceDnsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryServiceDnsConfigDnsRecords",
    jsii_struct_bases=[],
    name_mapping={"ttl": "ttl", "type": "type"},
)
class ServiceDiscoveryServiceDnsConfigDnsRecords:
    def __init__(self, *, ttl: jsii.Number, type: str) -> None:
        """
        :param ttl: 
        :param type: 
        """
        self._values = {
            "ttl": ttl,
            "type": type,
        }

    @builtins.property
    def ttl(self) -> jsii.Number:
        return self._values.get("ttl")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryServiceDnsConfigDnsRecords(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryServiceHealthCheckConfig",
    jsii_struct_bases=[],
    name_mapping={
        "failure_threshold": "failureThreshold",
        "resource_path": "resourcePath",
        "type": "type",
    },
)
class ServiceDiscoveryServiceHealthCheckConfig:
    def __init__(
        self,
        *,
        failure_threshold: typing.Optional[jsii.Number] = None,
        resource_path: typing.Optional[str] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param failure_threshold: 
        :param resource_path: 
        :param type: 
        """
        self._values = {}
        if failure_threshold is not None:
            self._values["failure_threshold"] = failure_threshold
        if resource_path is not None:
            self._values["resource_path"] = resource_path
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def failure_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("failure_threshold")

    @builtins.property
    def resource_path(self) -> typing.Optional[str]:
        return self._values.get("resource_path")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryServiceHealthCheckConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServiceDiscoveryServiceHealthCheckCustomConfig",
    jsii_struct_bases=[],
    name_mapping={"failure_threshold": "failureThreshold"},
)
class ServiceDiscoveryServiceHealthCheckCustomConfig:
    def __init__(
        self, *, failure_threshold: typing.Optional[jsii.Number] = None
    ) -> None:
        """
        :param failure_threshold: 
        """
        self._values = {}
        if failure_threshold is not None:
            self._values["failure_threshold"] = failure_threshold

    @builtins.property
    def failure_threshold(self) -> typing.Optional[jsii.Number]:
        return self._values.get("failure_threshold")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServiceDiscoveryServiceHealthCheckCustomConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServicecatalogPortfolio(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ServicecatalogPortfolio",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        provider_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["ServicecatalogPortfolioTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param provider_name: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicecatalogPortfolioConfig(
            name=name,
            description=description,
            provider_name=provider_name,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicecatalogPortfolio, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdTime")
    def created_time(self) -> str:
        return jsii.get(self, "createdTime")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="providerName")
    def provider_name(self) -> typing.Optional[str]:
        return jsii.get(self, "providerName")

    @provider_name.setter
    def provider_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "providerName", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["ServicecatalogPortfolioTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["ServicecatalogPortfolioTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServicecatalogPortfolioConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "provider_name": "providerName",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class ServicecatalogPortfolioConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        provider_name: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["ServicecatalogPortfolioTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param provider_name: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = ServicecatalogPortfolioTimeouts(**timeouts)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if provider_name is not None:
            self._values["provider_name"] = provider_name
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def provider_name(self) -> typing.Optional[str]:
        return self._values.get("provider_name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["ServicecatalogPortfolioTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicecatalogPortfolioConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServicecatalogPortfolioTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class ServicecatalogPortfolioTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicecatalogPortfolioTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ServicequotasServiceQuota(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ServicequotasServiceQuota",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        quota_code: str,
        service_code: str,
        value: jsii.Number,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param quota_code: 
        :param service_code: 
        :param value: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ServicequotasServiceQuotaConfig(
            quota_code=quota_code,
            service_code=service_code,
            value=value,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ServicequotasServiceQuota, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="adjustable")
    def adjustable(self) -> bool:
        return jsii.get(self, "adjustable")

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultValue")
    def default_value(self) -> jsii.Number:
        return jsii.get(self, "defaultValue")

    @builtins.property
    @jsii.member(jsii_name="quotaName")
    def quota_name(self) -> str:
        return jsii.get(self, "quotaName")

    @builtins.property
    @jsii.member(jsii_name="requestId")
    def request_id(self) -> str:
        return jsii.get(self, "requestId")

    @builtins.property
    @jsii.member(jsii_name="requestStatus")
    def request_status(self) -> str:
        return jsii.get(self, "requestStatus")

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> str:
        return jsii.get(self, "serviceName")

    @builtins.property
    @jsii.member(jsii_name="quotaCode")
    def quota_code(self) -> str:
        return jsii.get(self, "quotaCode")

    @quota_code.setter
    def quota_code(self, value: str) -> None:
        jsii.set(self, "quotaCode", value)

    @builtins.property
    @jsii.member(jsii_name="serviceCode")
    def service_code(self) -> str:
        return jsii.get(self, "serviceCode")

    @service_code.setter
    def service_code(self, value: str) -> None:
        jsii.set(self, "serviceCode", value)

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> jsii.Number:
        return jsii.get(self, "value")

    @value.setter
    def value(self, value: jsii.Number) -> None:
        jsii.set(self, "value", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ServicequotasServiceQuotaConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "quota_code": "quotaCode",
        "service_code": "serviceCode",
        "value": "value",
    },
)
class ServicequotasServiceQuotaConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        quota_code: str,
        service_code: str,
        value: jsii.Number,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param quota_code: 
        :param service_code: 
        :param value: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "quota_code": quota_code,
            "service_code": service_code,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def quota_code(self) -> str:
        return self._values.get("quota_code")

    @builtins.property
    def service_code(self) -> str:
        return self._values.get("service_code")

    @builtins.property
    def value(self) -> jsii.Number:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ServicequotasServiceQuotaConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesActiveReceiptRuleSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesActiveReceiptRuleSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        rule_set_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param rule_set_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesActiveReceiptRuleSetConfig(
            rule_set_name=rule_set_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesActiveReceiptRuleSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ruleSetName")
    def rule_set_name(self) -> str:
        return jsii.get(self, "ruleSetName")

    @rule_set_name.setter
    def rule_set_name(self, value: str) -> None:
        jsii.set(self, "ruleSetName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesActiveReceiptRuleSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "rule_set_name": "ruleSetName",
    },
)
class SesActiveReceiptRuleSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        rule_set_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param rule_set_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "rule_set_name": rule_set_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def rule_set_name(self) -> str:
        return self._values.get("rule_set_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesActiveReceiptRuleSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesConfigurationSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesConfigurationSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesConfigurationSetConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesConfigurationSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesConfigurationSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class SesConfigurationSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesConfigurationSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesDomainDkim(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainDkim",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesDomainDkimConfig(
            domain=domain,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesDomainDkim, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dkimTokens")
    def dkim_tokens(self) -> typing.List[str]:
        return jsii.get(self, "dkimTokens")

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: str) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainDkimConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain": "domain",
    },
)
class SesDomainDkimConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain": domain,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain(self) -> str:
        return self._values.get("domain")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesDomainDkimConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesDomainIdentity(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainIdentity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesDomainIdentityConfig(
            domain=domain,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesDomainIdentity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="verificationToken")
    def verification_token(self) -> str:
        return jsii.get(self, "verificationToken")

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: str) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainIdentityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain": "domain",
    },
)
class SesDomainIdentityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain": domain,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain(self) -> str:
        return self._values.get("domain")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesDomainIdentityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesDomainIdentityVerification(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainIdentityVerification",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain: str,
        timeouts: typing.Optional["SesDomainIdentityVerificationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesDomainIdentityVerificationConfig(
            domain=domain,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesDomainIdentityVerification, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: str) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SesDomainIdentityVerificationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["SesDomainIdentityVerificationTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainIdentityVerificationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain": "domain",
        "timeouts": "timeouts",
    },
)
class SesDomainIdentityVerificationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain: str,
        timeouts: typing.Optional["SesDomainIdentityVerificationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SesDomainIdentityVerificationTimeouts(**timeouts)
        self._values = {
            "domain": domain,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain(self) -> str:
        return self._values.get("domain")

    @builtins.property
    def timeouts(self) -> typing.Optional["SesDomainIdentityVerificationTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesDomainIdentityVerificationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainIdentityVerificationTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class SesDomainIdentityVerificationTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesDomainIdentityVerificationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesDomainMailFrom(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainMailFrom",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain: str,
        mail_from_domain: str,
        behavior_on_mx_failure: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain: 
        :param mail_from_domain: 
        :param behavior_on_mx_failure: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesDomainMailFromConfig(
            domain=domain,
            mail_from_domain=mail_from_domain,
            behavior_on_mx_failure=behavior_on_mx_failure,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesDomainMailFrom, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="domain")
    def domain(self) -> str:
        return jsii.get(self, "domain")

    @domain.setter
    def domain(self, value: str) -> None:
        jsii.set(self, "domain", value)

    @builtins.property
    @jsii.member(jsii_name="mailFromDomain")
    def mail_from_domain(self) -> str:
        return jsii.get(self, "mailFromDomain")

    @mail_from_domain.setter
    def mail_from_domain(self, value: str) -> None:
        jsii.set(self, "mailFromDomain", value)

    @builtins.property
    @jsii.member(jsii_name="behaviorOnMxFailure")
    def behavior_on_mx_failure(self) -> typing.Optional[str]:
        return jsii.get(self, "behaviorOnMxFailure")

    @behavior_on_mx_failure.setter
    def behavior_on_mx_failure(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "behaviorOnMxFailure", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesDomainMailFromConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain": "domain",
        "mail_from_domain": "mailFromDomain",
        "behavior_on_mx_failure": "behaviorOnMxFailure",
    },
)
class SesDomainMailFromConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain: str,
        mail_from_domain: str,
        behavior_on_mx_failure: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain: 
        :param mail_from_domain: 
        :param behavior_on_mx_failure: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "domain": domain,
            "mail_from_domain": mail_from_domain,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if behavior_on_mx_failure is not None:
            self._values["behavior_on_mx_failure"] = behavior_on_mx_failure

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain(self) -> str:
        return self._values.get("domain")

    @builtins.property
    def mail_from_domain(self) -> str:
        return self._values.get("mail_from_domain")

    @builtins.property
    def behavior_on_mx_failure(self) -> typing.Optional[str]:
        return self._values.get("behavior_on_mx_failure")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesDomainMailFromConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesEmailIdentity(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesEmailIdentity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        email: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param email: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesEmailIdentityConfig(
            email=email,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesEmailIdentity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="email")
    def email(self) -> str:
        return jsii.get(self, "email")

    @email.setter
    def email(self, value: str) -> None:
        jsii.set(self, "email", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesEmailIdentityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "email": "email",
    },
)
class SesEmailIdentityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        email: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param email: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "email": email,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def email(self) -> str:
        return self._values.get("email")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesEmailIdentityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesEventDestination(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesEventDestination",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        configuration_set_name: str,
        matching_types: typing.List[str],
        name: str,
        cloudwatch_destination: typing.Optional[
            typing.List["SesEventDestinationCloudwatchDestination"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        kinesis_destination: typing.Optional[
            typing.List["SesEventDestinationKinesisDestination"]
        ] = None,
        sns_destination: typing.Optional[
            typing.List["SesEventDestinationSnsDestination"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param configuration_set_name: 
        :param matching_types: 
        :param name: 
        :param cloudwatch_destination: cloudwatch_destination block.
        :param enabled: 
        :param kinesis_destination: kinesis_destination block.
        :param sns_destination: sns_destination block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesEventDestinationConfig(
            configuration_set_name=configuration_set_name,
            matching_types=matching_types,
            name=name,
            cloudwatch_destination=cloudwatch_destination,
            enabled=enabled,
            kinesis_destination=kinesis_destination,
            sns_destination=sns_destination,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesEventDestination, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="configurationSetName")
    def configuration_set_name(self) -> str:
        return jsii.get(self, "configurationSetName")

    @configuration_set_name.setter
    def configuration_set_name(self, value: str) -> None:
        jsii.set(self, "configurationSetName", value)

    @builtins.property
    @jsii.member(jsii_name="matchingTypes")
    def matching_types(self) -> typing.List[str]:
        return jsii.get(self, "matchingTypes")

    @matching_types.setter
    def matching_types(self, value: typing.List[str]) -> None:
        jsii.set(self, "matchingTypes", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchDestination")
    def cloudwatch_destination(
        self,
    ) -> typing.Optional[typing.List["SesEventDestinationCloudwatchDestination"]]:
        return jsii.get(self, "cloudwatchDestination")

    @cloudwatch_destination.setter
    def cloudwatch_destination(
        self,
        value: typing.Optional[typing.List["SesEventDestinationCloudwatchDestination"]],
    ) -> None:
        jsii.set(self, "cloudwatchDestination", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kinesisDestination")
    def kinesis_destination(
        self,
    ) -> typing.Optional[typing.List["SesEventDestinationKinesisDestination"]]:
        return jsii.get(self, "kinesisDestination")

    @kinesis_destination.setter
    def kinesis_destination(
        self,
        value: typing.Optional[typing.List["SesEventDestinationKinesisDestination"]],
    ) -> None:
        jsii.set(self, "kinesisDestination", value)

    @builtins.property
    @jsii.member(jsii_name="snsDestination")
    def sns_destination(
        self,
    ) -> typing.Optional[typing.List["SesEventDestinationSnsDestination"]]:
        return jsii.get(self, "snsDestination")

    @sns_destination.setter
    def sns_destination(
        self, value: typing.Optional[typing.List["SesEventDestinationSnsDestination"]]
    ) -> None:
        jsii.set(self, "snsDestination", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesEventDestinationCloudwatchDestination",
    jsii_struct_bases=[],
    name_mapping={
        "default_value": "defaultValue",
        "dimension_name": "dimensionName",
        "value_source": "valueSource",
    },
)
class SesEventDestinationCloudwatchDestination:
    def __init__(
        self, *, default_value: str, dimension_name: str, value_source: str
    ) -> None:
        """
        :param default_value: 
        :param dimension_name: 
        :param value_source: 
        """
        self._values = {
            "default_value": default_value,
            "dimension_name": dimension_name,
            "value_source": value_source,
        }

    @builtins.property
    def default_value(self) -> str:
        return self._values.get("default_value")

    @builtins.property
    def dimension_name(self) -> str:
        return self._values.get("dimension_name")

    @builtins.property
    def value_source(self) -> str:
        return self._values.get("value_source")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesEventDestinationCloudwatchDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesEventDestinationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "configuration_set_name": "configurationSetName",
        "matching_types": "matchingTypes",
        "name": "name",
        "cloudwatch_destination": "cloudwatchDestination",
        "enabled": "enabled",
        "kinesis_destination": "kinesisDestination",
        "sns_destination": "snsDestination",
    },
)
class SesEventDestinationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        configuration_set_name: str,
        matching_types: typing.List[str],
        name: str,
        cloudwatch_destination: typing.Optional[
            typing.List["SesEventDestinationCloudwatchDestination"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        kinesis_destination: typing.Optional[
            typing.List["SesEventDestinationKinesisDestination"]
        ] = None,
        sns_destination: typing.Optional[
            typing.List["SesEventDestinationSnsDestination"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param configuration_set_name: 
        :param matching_types: 
        :param name: 
        :param cloudwatch_destination: cloudwatch_destination block.
        :param enabled: 
        :param kinesis_destination: kinesis_destination block.
        :param sns_destination: sns_destination block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "configuration_set_name": configuration_set_name,
            "matching_types": matching_types,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if cloudwatch_destination is not None:
            self._values["cloudwatch_destination"] = cloudwatch_destination
        if enabled is not None:
            self._values["enabled"] = enabled
        if kinesis_destination is not None:
            self._values["kinesis_destination"] = kinesis_destination
        if sns_destination is not None:
            self._values["sns_destination"] = sns_destination

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def configuration_set_name(self) -> str:
        return self._values.get("configuration_set_name")

    @builtins.property
    def matching_types(self) -> typing.List[str]:
        return self._values.get("matching_types")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def cloudwatch_destination(
        self,
    ) -> typing.Optional[typing.List["SesEventDestinationCloudwatchDestination"]]:
        """cloudwatch_destination block."""
        return self._values.get("cloudwatch_destination")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def kinesis_destination(
        self,
    ) -> typing.Optional[typing.List["SesEventDestinationKinesisDestination"]]:
        """kinesis_destination block."""
        return self._values.get("kinesis_destination")

    @builtins.property
    def sns_destination(
        self,
    ) -> typing.Optional[typing.List["SesEventDestinationSnsDestination"]]:
        """sns_destination block."""
        return self._values.get("sns_destination")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesEventDestinationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesEventDestinationKinesisDestination",
    jsii_struct_bases=[],
    name_mapping={"role_arn": "roleArn", "stream_arn": "streamArn"},
)
class SesEventDestinationKinesisDestination:
    def __init__(self, *, role_arn: str, stream_arn: str) -> None:
        """
        :param role_arn: 
        :param stream_arn: 
        """
        self._values = {
            "role_arn": role_arn,
            "stream_arn": stream_arn,
        }

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def stream_arn(self) -> str:
        return self._values.get("stream_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesEventDestinationKinesisDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesEventDestinationSnsDestination",
    jsii_struct_bases=[],
    name_mapping={"topic_arn": "topicArn"},
)
class SesEventDestinationSnsDestination:
    def __init__(self, *, topic_arn: str) -> None:
        """
        :param topic_arn: 
        """
        self._values = {
            "topic_arn": topic_arn,
        }

    @builtins.property
    def topic_arn(self) -> str:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesEventDestinationSnsDestination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesIdentityNotificationTopic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesIdentityNotificationTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        identity: str,
        notification_type: str,
        include_original_headers: typing.Optional[bool] = None,
        topic_arn: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param identity: 
        :param notification_type: 
        :param include_original_headers: 
        :param topic_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesIdentityNotificationTopicConfig(
            identity=identity,
            notification_type=notification_type,
            include_original_headers=include_original_headers,
            topic_arn=topic_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesIdentityNotificationTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="identity")
    def identity(self) -> str:
        return jsii.get(self, "identity")

    @identity.setter
    def identity(self, value: str) -> None:
        jsii.set(self, "identity", value)

    @builtins.property
    @jsii.member(jsii_name="notificationType")
    def notification_type(self) -> str:
        return jsii.get(self, "notificationType")

    @notification_type.setter
    def notification_type(self, value: str) -> None:
        jsii.set(self, "notificationType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="includeOriginalHeaders")
    def include_original_headers(self) -> typing.Optional[bool]:
        return jsii.get(self, "includeOriginalHeaders")

    @include_original_headers.setter
    def include_original_headers(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "includeOriginalHeaders", value)

    @builtins.property
    @jsii.member(jsii_name="topicArn")
    def topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "topicArn")

    @topic_arn.setter
    def topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "topicArn", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesIdentityNotificationTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "identity": "identity",
        "notification_type": "notificationType",
        "include_original_headers": "includeOriginalHeaders",
        "topic_arn": "topicArn",
    },
)
class SesIdentityNotificationTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        identity: str,
        notification_type: str,
        include_original_headers: typing.Optional[bool] = None,
        topic_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param identity: 
        :param notification_type: 
        :param include_original_headers: 
        :param topic_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "identity": identity,
            "notification_type": notification_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if include_original_headers is not None:
            self._values["include_original_headers"] = include_original_headers
        if topic_arn is not None:
            self._values["topic_arn"] = topic_arn

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def identity(self) -> str:
        return self._values.get("identity")

    @builtins.property
    def notification_type(self) -> str:
        return self._values.get("notification_type")

    @builtins.property
    def include_original_headers(self) -> typing.Optional[bool]:
        return self._values.get("include_original_headers")

    @builtins.property
    def topic_arn(self) -> typing.Optional[str]:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesIdentityNotificationTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesIdentityPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesIdentityPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        identity: str,
        name: str,
        policy: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param identity: 
        :param name: 
        :param policy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesIdentityPolicyConfig(
            identity=identity,
            name=name,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesIdentityPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="identity")
    def identity(self) -> str:
        return jsii.get(self, "identity")

    @identity.setter
    def identity(self, value: str) -> None:
        jsii.set(self, "identity", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesIdentityPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "identity": "identity",
        "name": "name",
        "policy": "policy",
    },
)
class SesIdentityPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        identity: str,
        name: str,
        policy: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param identity: 
        :param name: 
        :param policy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "identity": identity,
            "name": name,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def identity(self) -> str:
        return self._values.get("identity")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesIdentityPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesReceiptFilter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptFilter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cidr: str,
        name: str,
        policy: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cidr: 
        :param name: 
        :param policy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesReceiptFilterConfig(
            cidr=cidr,
            name=name,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesReceiptFilter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="cidr")
    def cidr(self) -> str:
        return jsii.get(self, "cidr")

    @cidr.setter
    def cidr(self, value: str) -> None:
        jsii.set(self, "cidr", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptFilterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cidr": "cidr",
        "name": "name",
        "policy": "policy",
    },
)
class SesReceiptFilterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cidr: str,
        name: str,
        policy: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cidr: 
        :param name: 
        :param policy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cidr": cidr,
            "name": name,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cidr(self) -> str:
        return self._values.get("cidr")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptFilterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesReceiptRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        rule_set_name: str,
        add_header_action: typing.Optional[
            typing.List["SesReceiptRuleAddHeaderAction"]
        ] = None,
        after: typing.Optional[str] = None,
        bounce_action: typing.Optional[
            typing.List["SesReceiptRuleBounceAction"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        lambda_action: typing.Optional[
            typing.List["SesReceiptRuleLambdaAction"]
        ] = None,
        recipients: typing.Optional[typing.List[str]] = None,
        s3_action: typing.Optional[typing.List["SesReceiptRuleS3Action"]] = None,
        scan_enabled: typing.Optional[bool] = None,
        sns_action: typing.Optional[typing.List["SesReceiptRuleSnsAction"]] = None,
        stop_action: typing.Optional[typing.List["SesReceiptRuleStopAction"]] = None,
        tls_policy: typing.Optional[str] = None,
        workmail_action: typing.Optional[
            typing.List["SesReceiptRuleWorkmailAction"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param rule_set_name: 
        :param add_header_action: add_header_action block.
        :param after: 
        :param bounce_action: bounce_action block.
        :param enabled: 
        :param lambda_action: lambda_action block.
        :param recipients: 
        :param s3_action: s3_action block.
        :param scan_enabled: 
        :param sns_action: sns_action block.
        :param stop_action: stop_action block.
        :param tls_policy: 
        :param workmail_action: workmail_action block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesReceiptRuleConfig(
            name=name,
            rule_set_name=rule_set_name,
            add_header_action=add_header_action,
            after=after,
            bounce_action=bounce_action,
            enabled=enabled,
            lambda_action=lambda_action,
            recipients=recipients,
            s3_action=s3_action,
            scan_enabled=scan_enabled,
            sns_action=sns_action,
            stop_action=stop_action,
            tls_policy=tls_policy,
            workmail_action=workmail_action,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesReceiptRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="ruleSetName")
    def rule_set_name(self) -> str:
        return jsii.get(self, "ruleSetName")

    @rule_set_name.setter
    def rule_set_name(self, value: str) -> None:
        jsii.set(self, "ruleSetName", value)

    @builtins.property
    @jsii.member(jsii_name="addHeaderAction")
    def add_header_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleAddHeaderAction"]]:
        return jsii.get(self, "addHeaderAction")

    @add_header_action.setter
    def add_header_action(
        self, value: typing.Optional[typing.List["SesReceiptRuleAddHeaderAction"]]
    ) -> None:
        jsii.set(self, "addHeaderAction", value)

    @builtins.property
    @jsii.member(jsii_name="after")
    def after(self) -> typing.Optional[str]:
        return jsii.get(self, "after")

    @after.setter
    def after(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "after", value)

    @builtins.property
    @jsii.member(jsii_name="bounceAction")
    def bounce_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleBounceAction"]]:
        return jsii.get(self, "bounceAction")

    @bounce_action.setter
    def bounce_action(
        self, value: typing.Optional[typing.List["SesReceiptRuleBounceAction"]]
    ) -> None:
        jsii.set(self, "bounceAction", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaAction")
    def lambda_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleLambdaAction"]]:
        return jsii.get(self, "lambdaAction")

    @lambda_action.setter
    def lambda_action(
        self, value: typing.Optional[typing.List["SesReceiptRuleLambdaAction"]]
    ) -> None:
        jsii.set(self, "lambdaAction", value)

    @builtins.property
    @jsii.member(jsii_name="recipients")
    def recipients(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "recipients")

    @recipients.setter
    def recipients(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "recipients", value)

    @builtins.property
    @jsii.member(jsii_name="s3Action")
    def s3_action(self) -> typing.Optional[typing.List["SesReceiptRuleS3Action"]]:
        return jsii.get(self, "s3Action")

    @s3_action.setter
    def s3_action(
        self, value: typing.Optional[typing.List["SesReceiptRuleS3Action"]]
    ) -> None:
        jsii.set(self, "s3Action", value)

    @builtins.property
    @jsii.member(jsii_name="scanEnabled")
    def scan_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "scanEnabled")

    @scan_enabled.setter
    def scan_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "scanEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="snsAction")
    def sns_action(self) -> typing.Optional[typing.List["SesReceiptRuleSnsAction"]]:
        return jsii.get(self, "snsAction")

    @sns_action.setter
    def sns_action(
        self, value: typing.Optional[typing.List["SesReceiptRuleSnsAction"]]
    ) -> None:
        jsii.set(self, "snsAction", value)

    @builtins.property
    @jsii.member(jsii_name="stopAction")
    def stop_action(self) -> typing.Optional[typing.List["SesReceiptRuleStopAction"]]:
        return jsii.get(self, "stopAction")

    @stop_action.setter
    def stop_action(
        self, value: typing.Optional[typing.List["SesReceiptRuleStopAction"]]
    ) -> None:
        jsii.set(self, "stopAction", value)

    @builtins.property
    @jsii.member(jsii_name="tlsPolicy")
    def tls_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "tlsPolicy")

    @tls_policy.setter
    def tls_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tlsPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="workmailAction")
    def workmail_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleWorkmailAction"]]:
        return jsii.get(self, "workmailAction")

    @workmail_action.setter
    def workmail_action(
        self, value: typing.Optional[typing.List["SesReceiptRuleWorkmailAction"]]
    ) -> None:
        jsii.set(self, "workmailAction", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleAddHeaderAction",
    jsii_struct_bases=[],
    name_mapping={
        "header_name": "headerName",
        "header_value": "headerValue",
        "position": "position",
    },
)
class SesReceiptRuleAddHeaderAction:
    def __init__(
        self, *, header_name: str, header_value: str, position: jsii.Number
    ) -> None:
        """
        :param header_name: 
        :param header_value: 
        :param position: 
        """
        self._values = {
            "header_name": header_name,
            "header_value": header_value,
            "position": position,
        }

    @builtins.property
    def header_name(self) -> str:
        return self._values.get("header_name")

    @builtins.property
    def header_value(self) -> str:
        return self._values.get("header_value")

    @builtins.property
    def position(self) -> jsii.Number:
        return self._values.get("position")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleAddHeaderAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleBounceAction",
    jsii_struct_bases=[],
    name_mapping={
        "message": "message",
        "position": "position",
        "sender": "sender",
        "smtp_reply_code": "smtpReplyCode",
        "status_code": "statusCode",
        "topic_arn": "topicArn",
    },
)
class SesReceiptRuleBounceAction:
    def __init__(
        self,
        *,
        message: str,
        position: jsii.Number,
        sender: str,
        smtp_reply_code: str,
        status_code: typing.Optional[str] = None,
        topic_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param message: 
        :param position: 
        :param sender: 
        :param smtp_reply_code: 
        :param status_code: 
        :param topic_arn: 
        """
        self._values = {
            "message": message,
            "position": position,
            "sender": sender,
            "smtp_reply_code": smtp_reply_code,
        }
        if status_code is not None:
            self._values["status_code"] = status_code
        if topic_arn is not None:
            self._values["topic_arn"] = topic_arn

    @builtins.property
    def message(self) -> str:
        return self._values.get("message")

    @builtins.property
    def position(self) -> jsii.Number:
        return self._values.get("position")

    @builtins.property
    def sender(self) -> str:
        return self._values.get("sender")

    @builtins.property
    def smtp_reply_code(self) -> str:
        return self._values.get("smtp_reply_code")

    @builtins.property
    def status_code(self) -> typing.Optional[str]:
        return self._values.get("status_code")

    @builtins.property
    def topic_arn(self) -> typing.Optional[str]:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleBounceAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "rule_set_name": "ruleSetName",
        "add_header_action": "addHeaderAction",
        "after": "after",
        "bounce_action": "bounceAction",
        "enabled": "enabled",
        "lambda_action": "lambdaAction",
        "recipients": "recipients",
        "s3_action": "s3Action",
        "scan_enabled": "scanEnabled",
        "sns_action": "snsAction",
        "stop_action": "stopAction",
        "tls_policy": "tlsPolicy",
        "workmail_action": "workmailAction",
    },
)
class SesReceiptRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        rule_set_name: str,
        add_header_action: typing.Optional[
            typing.List["SesReceiptRuleAddHeaderAction"]
        ] = None,
        after: typing.Optional[str] = None,
        bounce_action: typing.Optional[
            typing.List["SesReceiptRuleBounceAction"]
        ] = None,
        enabled: typing.Optional[bool] = None,
        lambda_action: typing.Optional[
            typing.List["SesReceiptRuleLambdaAction"]
        ] = None,
        recipients: typing.Optional[typing.List[str]] = None,
        s3_action: typing.Optional[typing.List["SesReceiptRuleS3Action"]] = None,
        scan_enabled: typing.Optional[bool] = None,
        sns_action: typing.Optional[typing.List["SesReceiptRuleSnsAction"]] = None,
        stop_action: typing.Optional[typing.List["SesReceiptRuleStopAction"]] = None,
        tls_policy: typing.Optional[str] = None,
        workmail_action: typing.Optional[
            typing.List["SesReceiptRuleWorkmailAction"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param rule_set_name: 
        :param add_header_action: add_header_action block.
        :param after: 
        :param bounce_action: bounce_action block.
        :param enabled: 
        :param lambda_action: lambda_action block.
        :param recipients: 
        :param s3_action: s3_action block.
        :param scan_enabled: 
        :param sns_action: sns_action block.
        :param stop_action: stop_action block.
        :param tls_policy: 
        :param workmail_action: workmail_action block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "rule_set_name": rule_set_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if add_header_action is not None:
            self._values["add_header_action"] = add_header_action
        if after is not None:
            self._values["after"] = after
        if bounce_action is not None:
            self._values["bounce_action"] = bounce_action
        if enabled is not None:
            self._values["enabled"] = enabled
        if lambda_action is not None:
            self._values["lambda_action"] = lambda_action
        if recipients is not None:
            self._values["recipients"] = recipients
        if s3_action is not None:
            self._values["s3_action"] = s3_action
        if scan_enabled is not None:
            self._values["scan_enabled"] = scan_enabled
        if sns_action is not None:
            self._values["sns_action"] = sns_action
        if stop_action is not None:
            self._values["stop_action"] = stop_action
        if tls_policy is not None:
            self._values["tls_policy"] = tls_policy
        if workmail_action is not None:
            self._values["workmail_action"] = workmail_action

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rule_set_name(self) -> str:
        return self._values.get("rule_set_name")

    @builtins.property
    def add_header_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleAddHeaderAction"]]:
        """add_header_action block."""
        return self._values.get("add_header_action")

    @builtins.property
    def after(self) -> typing.Optional[str]:
        return self._values.get("after")

    @builtins.property
    def bounce_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleBounceAction"]]:
        """bounce_action block."""
        return self._values.get("bounce_action")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def lambda_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleLambdaAction"]]:
        """lambda_action block."""
        return self._values.get("lambda_action")

    @builtins.property
    def recipients(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("recipients")

    @builtins.property
    def s3_action(self) -> typing.Optional[typing.List["SesReceiptRuleS3Action"]]:
        """s3_action block."""
        return self._values.get("s3_action")

    @builtins.property
    def scan_enabled(self) -> typing.Optional[bool]:
        return self._values.get("scan_enabled")

    @builtins.property
    def sns_action(self) -> typing.Optional[typing.List["SesReceiptRuleSnsAction"]]:
        """sns_action block."""
        return self._values.get("sns_action")

    @builtins.property
    def stop_action(self) -> typing.Optional[typing.List["SesReceiptRuleStopAction"]]:
        """stop_action block."""
        return self._values.get("stop_action")

    @builtins.property
    def tls_policy(self) -> typing.Optional[str]:
        return self._values.get("tls_policy")

    @builtins.property
    def workmail_action(
        self,
    ) -> typing.Optional[typing.List["SesReceiptRuleWorkmailAction"]]:
        """workmail_action block."""
        return self._values.get("workmail_action")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleLambdaAction",
    jsii_struct_bases=[],
    name_mapping={
        "function_arn": "functionArn",
        "position": "position",
        "invocation_type": "invocationType",
        "topic_arn": "topicArn",
    },
)
class SesReceiptRuleLambdaAction:
    def __init__(
        self,
        *,
        function_arn: str,
        position: jsii.Number,
        invocation_type: typing.Optional[str] = None,
        topic_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param function_arn: 
        :param position: 
        :param invocation_type: 
        :param topic_arn: 
        """
        self._values = {
            "function_arn": function_arn,
            "position": position,
        }
        if invocation_type is not None:
            self._values["invocation_type"] = invocation_type
        if topic_arn is not None:
            self._values["topic_arn"] = topic_arn

    @builtins.property
    def function_arn(self) -> str:
        return self._values.get("function_arn")

    @builtins.property
    def position(self) -> jsii.Number:
        return self._values.get("position")

    @builtins.property
    def invocation_type(self) -> typing.Optional[str]:
        return self._values.get("invocation_type")

    @builtins.property
    def topic_arn(self) -> typing.Optional[str]:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleLambdaAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleS3Action",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_name": "bucketName",
        "position": "position",
        "kms_key_arn": "kmsKeyArn",
        "object_key_prefix": "objectKeyPrefix",
        "topic_arn": "topicArn",
    },
)
class SesReceiptRuleS3Action:
    def __init__(
        self,
        *,
        bucket_name: str,
        position: jsii.Number,
        kms_key_arn: typing.Optional[str] = None,
        object_key_prefix: typing.Optional[str] = None,
        topic_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_name: 
        :param position: 
        :param kms_key_arn: 
        :param object_key_prefix: 
        :param topic_arn: 
        """
        self._values = {
            "bucket_name": bucket_name,
            "position": position,
        }
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if object_key_prefix is not None:
            self._values["object_key_prefix"] = object_key_prefix
        if topic_arn is not None:
            self._values["topic_arn"] = topic_arn

    @builtins.property
    def bucket_name(self) -> str:
        return self._values.get("bucket_name")

    @builtins.property
    def position(self) -> jsii.Number:
        return self._values.get("position")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def object_key_prefix(self) -> typing.Optional[str]:
        return self._values.get("object_key_prefix")

    @builtins.property
    def topic_arn(self) -> typing.Optional[str]:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleS3Action(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesReceiptRuleSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        rule_set_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param rule_set_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesReceiptRuleSetConfig(
            rule_set_name=rule_set_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesReceiptRuleSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="ruleSetName")
    def rule_set_name(self) -> str:
        return jsii.get(self, "ruleSetName")

    @rule_set_name.setter
    def rule_set_name(self, value: str) -> None:
        jsii.set(self, "ruleSetName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "rule_set_name": "ruleSetName",
    },
)
class SesReceiptRuleSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        rule_set_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param rule_set_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "rule_set_name": rule_set_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def rule_set_name(self) -> str:
        return self._values.get("rule_set_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleSnsAction",
    jsii_struct_bases=[],
    name_mapping={"position": "position", "topic_arn": "topicArn"},
)
class SesReceiptRuleSnsAction:
    def __init__(self, *, position: jsii.Number, topic_arn: str) -> None:
        """
        :param position: 
        :param topic_arn: 
        """
        self._values = {
            "position": position,
            "topic_arn": topic_arn,
        }

    @builtins.property
    def position(self) -> jsii.Number:
        return self._values.get("position")

    @builtins.property
    def topic_arn(self) -> str:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleSnsAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleStopAction",
    jsii_struct_bases=[],
    name_mapping={"position": "position", "scope": "scope", "topic_arn": "topicArn"},
)
class SesReceiptRuleStopAction:
    def __init__(
        self,
        *,
        position: jsii.Number,
        scope: str,
        topic_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param position: 
        :param scope: 
        :param topic_arn: 
        """
        self._values = {
            "position": position,
            "scope": scope,
        }
        if topic_arn is not None:
            self._values["topic_arn"] = topic_arn

    @builtins.property
    def position(self) -> jsii.Number:
        return self._values.get("position")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    @builtins.property
    def topic_arn(self) -> typing.Optional[str]:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleStopAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesReceiptRuleWorkmailAction",
    jsii_struct_bases=[],
    name_mapping={
        "organization_arn": "organizationArn",
        "position": "position",
        "topic_arn": "topicArn",
    },
)
class SesReceiptRuleWorkmailAction:
    def __init__(
        self,
        *,
        organization_arn: str,
        position: jsii.Number,
        topic_arn: typing.Optional[str] = None,
    ) -> None:
        """
        :param organization_arn: 
        :param position: 
        :param topic_arn: 
        """
        self._values = {
            "organization_arn": organization_arn,
            "position": position,
        }
        if topic_arn is not None:
            self._values["topic_arn"] = topic_arn

    @builtins.property
    def organization_arn(self) -> str:
        return self._values.get("organization_arn")

    @builtins.property
    def position(self) -> jsii.Number:
        return self._values.get("position")

    @builtins.property
    def topic_arn(self) -> typing.Optional[str]:
        return self._values.get("topic_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesReceiptRuleWorkmailAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SesTemplate(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SesTemplate",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        html: typing.Optional[str] = None,
        subject: typing.Optional[str] = None,
        text: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param html: 
        :param subject: 
        :param text: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SesTemplateConfig(
            name=name,
            html=html,
            subject=subject,
            text=text,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SesTemplate, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="html")
    def html(self) -> typing.Optional[str]:
        return jsii.get(self, "html")

    @html.setter
    def html(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "html", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="subject")
    def subject(self) -> typing.Optional[str]:
        return jsii.get(self, "subject")

    @subject.setter
    def subject(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subject", value)

    @builtins.property
    @jsii.member(jsii_name="text")
    def text(self) -> typing.Optional[str]:
        return jsii.get(self, "text")

    @text.setter
    def text(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "text", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SesTemplateConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "html": "html",
        "subject": "subject",
        "text": "text",
    },
)
class SesTemplateConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        html: typing.Optional[str] = None,
        subject: typing.Optional[str] = None,
        text: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param html: 
        :param subject: 
        :param text: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if html is not None:
            self._values["html"] = html
        if subject is not None:
            self._values["subject"] = subject
        if text is not None:
            self._values["text"] = text

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def html(self) -> typing.Optional[str]:
        return self._values.get("html")

    @builtins.property
    def subject(self) -> typing.Optional[str]:
        return self._values.get("subject")

    @builtins.property
    def text(self) -> typing.Optional[str]:
        return self._values.get("text")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SesTemplateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SfnActivity(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SfnActivity",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SfnActivityConfig(
            name=name,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SfnActivity, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SfnActivityConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "tags": "tags",
    },
)
class SfnActivityConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SfnActivityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SfnStateMachine(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SfnStateMachine",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        definition: str,
        name: str,
        role_arn: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param definition: 
        :param name: 
        :param role_arn: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SfnStateMachineConfig(
            definition=definition,
            name=name,
            role_arn=role_arn,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SfnStateMachine, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="creationDate")
    def creation_date(self) -> str:
        return jsii.get(self, "creationDate")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="definition")
    def definition(self) -> str:
        return jsii.get(self, "definition")

    @definition.setter
    def definition(self, value: str) -> None:
        jsii.set(self, "definition", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SfnStateMachineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "definition": "definition",
        "name": "name",
        "role_arn": "roleArn",
        "tags": "tags",
    },
)
class SfnStateMachineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        definition: str,
        name: str,
        role_arn: str,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param definition: 
        :param name: 
        :param role_arn: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "definition": definition,
            "name": name,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def definition(self) -> str:
        return self._values.get("definition")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SfnStateMachineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class ShieldProtection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.ShieldProtection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        resource_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param resource_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = ShieldProtectionConfig(
            name=name,
            resource_arn=resource_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(ShieldProtection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="resourceArn")
    def resource_arn(self) -> str:
        return jsii.get(self, "resourceArn")

    @resource_arn.setter
    def resource_arn(self, value: str) -> None:
        jsii.set(self, "resourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.ShieldProtectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "resource_arn": "resourceArn",
    },
)
class ShieldProtectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        resource_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param resource_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "resource_arn": resource_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "ShieldProtectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SimpledbDomain(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SimpledbDomain",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SimpledbDomainConfig(
            name=name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SimpledbDomain, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SimpledbDomainConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
    },
)
class SimpledbDomainConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SimpledbDomainConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnapshotCreateVolumePermission(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SnapshotCreateVolumePermission",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        account_id: str,
        snapshot_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param account_id: 
        :param snapshot_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SnapshotCreateVolumePermissionConfig(
            account_id=account_id,
            snapshot_id=snapshot_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SnapshotCreateVolumePermission, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="accountId")
    def account_id(self) -> str:
        return jsii.get(self, "accountId")

    @account_id.setter
    def account_id(self, value: str) -> None:
        jsii.set(self, "accountId", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> str:
        return jsii.get(self, "snapshotId")

    @snapshot_id.setter
    def snapshot_id(self, value: str) -> None:
        jsii.set(self, "snapshotId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SnapshotCreateVolumePermissionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "account_id": "accountId",
        "snapshot_id": "snapshotId",
    },
)
class SnapshotCreateVolumePermissionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        account_id: str,
        snapshot_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param account_id: 
        :param snapshot_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "account_id": account_id,
            "snapshot_id": snapshot_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def account_id(self) -> str:
        return self._values.get("account_id")

    @builtins.property
    def snapshot_id(self) -> str:
        return self._values.get("snapshot_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnapshotCreateVolumePermissionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnsPlatformApplication(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SnsPlatformApplication",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        platform: str,
        platform_credential: str,
        event_delivery_failure_topic_arn: typing.Optional[str] = None,
        event_endpoint_created_topic_arn: typing.Optional[str] = None,
        event_endpoint_deleted_topic_arn: typing.Optional[str] = None,
        event_endpoint_updated_topic_arn: typing.Optional[str] = None,
        failure_feedback_role_arn: typing.Optional[str] = None,
        platform_principal: typing.Optional[str] = None,
        success_feedback_role_arn: typing.Optional[str] = None,
        success_feedback_sample_rate: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param platform: 
        :param platform_credential: 
        :param event_delivery_failure_topic_arn: 
        :param event_endpoint_created_topic_arn: 
        :param event_endpoint_deleted_topic_arn: 
        :param event_endpoint_updated_topic_arn: 
        :param failure_feedback_role_arn: 
        :param platform_principal: 
        :param success_feedback_role_arn: 
        :param success_feedback_sample_rate: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SnsPlatformApplicationConfig(
            name=name,
            platform=platform,
            platform_credential=platform_credential,
            event_delivery_failure_topic_arn=event_delivery_failure_topic_arn,
            event_endpoint_created_topic_arn=event_endpoint_created_topic_arn,
            event_endpoint_deleted_topic_arn=event_endpoint_deleted_topic_arn,
            event_endpoint_updated_topic_arn=event_endpoint_updated_topic_arn,
            failure_feedback_role_arn=failure_feedback_role_arn,
            platform_principal=platform_principal,
            success_feedback_role_arn=success_feedback_role_arn,
            success_feedback_sample_rate=success_feedback_sample_rate,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SnsPlatformApplication, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="platform")
    def platform(self) -> str:
        return jsii.get(self, "platform")

    @platform.setter
    def platform(self, value: str) -> None:
        jsii.set(self, "platform", value)

    @builtins.property
    @jsii.member(jsii_name="platformCredential")
    def platform_credential(self) -> str:
        return jsii.get(self, "platformCredential")

    @platform_credential.setter
    def platform_credential(self, value: str) -> None:
        jsii.set(self, "platformCredential", value)

    @builtins.property
    @jsii.member(jsii_name="eventDeliveryFailureTopicArn")
    def event_delivery_failure_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "eventDeliveryFailureTopicArn")

    @event_delivery_failure_topic_arn.setter
    def event_delivery_failure_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "eventDeliveryFailureTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="eventEndpointCreatedTopicArn")
    def event_endpoint_created_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "eventEndpointCreatedTopicArn")

    @event_endpoint_created_topic_arn.setter
    def event_endpoint_created_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "eventEndpointCreatedTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="eventEndpointDeletedTopicArn")
    def event_endpoint_deleted_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "eventEndpointDeletedTopicArn")

    @event_endpoint_deleted_topic_arn.setter
    def event_endpoint_deleted_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "eventEndpointDeletedTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="eventEndpointUpdatedTopicArn")
    def event_endpoint_updated_topic_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "eventEndpointUpdatedTopicArn")

    @event_endpoint_updated_topic_arn.setter
    def event_endpoint_updated_topic_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "eventEndpointUpdatedTopicArn", value)

    @builtins.property
    @jsii.member(jsii_name="failureFeedbackRoleArn")
    def failure_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "failureFeedbackRoleArn")

    @failure_feedback_role_arn.setter
    def failure_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "failureFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="platformPrincipal")
    def platform_principal(self) -> typing.Optional[str]:
        return jsii.get(self, "platformPrincipal")

    @platform_principal.setter
    def platform_principal(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "platformPrincipal", value)

    @builtins.property
    @jsii.member(jsii_name="successFeedbackRoleArn")
    def success_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "successFeedbackRoleArn")

    @success_feedback_role_arn.setter
    def success_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "successFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="successFeedbackSampleRate")
    def success_feedback_sample_rate(self) -> typing.Optional[str]:
        return jsii.get(self, "successFeedbackSampleRate")

    @success_feedback_sample_rate.setter
    def success_feedback_sample_rate(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "successFeedbackSampleRate", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SnsPlatformApplicationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "platform": "platform",
        "platform_credential": "platformCredential",
        "event_delivery_failure_topic_arn": "eventDeliveryFailureTopicArn",
        "event_endpoint_created_topic_arn": "eventEndpointCreatedTopicArn",
        "event_endpoint_deleted_topic_arn": "eventEndpointDeletedTopicArn",
        "event_endpoint_updated_topic_arn": "eventEndpointUpdatedTopicArn",
        "failure_feedback_role_arn": "failureFeedbackRoleArn",
        "platform_principal": "platformPrincipal",
        "success_feedback_role_arn": "successFeedbackRoleArn",
        "success_feedback_sample_rate": "successFeedbackSampleRate",
    },
)
class SnsPlatformApplicationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        platform: str,
        platform_credential: str,
        event_delivery_failure_topic_arn: typing.Optional[str] = None,
        event_endpoint_created_topic_arn: typing.Optional[str] = None,
        event_endpoint_deleted_topic_arn: typing.Optional[str] = None,
        event_endpoint_updated_topic_arn: typing.Optional[str] = None,
        failure_feedback_role_arn: typing.Optional[str] = None,
        platform_principal: typing.Optional[str] = None,
        success_feedback_role_arn: typing.Optional[str] = None,
        success_feedback_sample_rate: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param platform: 
        :param platform_credential: 
        :param event_delivery_failure_topic_arn: 
        :param event_endpoint_created_topic_arn: 
        :param event_endpoint_deleted_topic_arn: 
        :param event_endpoint_updated_topic_arn: 
        :param failure_feedback_role_arn: 
        :param platform_principal: 
        :param success_feedback_role_arn: 
        :param success_feedback_sample_rate: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "platform": platform,
            "platform_credential": platform_credential,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if event_delivery_failure_topic_arn is not None:
            self._values[
                "event_delivery_failure_topic_arn"
            ] = event_delivery_failure_topic_arn
        if event_endpoint_created_topic_arn is not None:
            self._values[
                "event_endpoint_created_topic_arn"
            ] = event_endpoint_created_topic_arn
        if event_endpoint_deleted_topic_arn is not None:
            self._values[
                "event_endpoint_deleted_topic_arn"
            ] = event_endpoint_deleted_topic_arn
        if event_endpoint_updated_topic_arn is not None:
            self._values[
                "event_endpoint_updated_topic_arn"
            ] = event_endpoint_updated_topic_arn
        if failure_feedback_role_arn is not None:
            self._values["failure_feedback_role_arn"] = failure_feedback_role_arn
        if platform_principal is not None:
            self._values["platform_principal"] = platform_principal
        if success_feedback_role_arn is not None:
            self._values["success_feedback_role_arn"] = success_feedback_role_arn
        if success_feedback_sample_rate is not None:
            self._values["success_feedback_sample_rate"] = success_feedback_sample_rate

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def platform(self) -> str:
        return self._values.get("platform")

    @builtins.property
    def platform_credential(self) -> str:
        return self._values.get("platform_credential")

    @builtins.property
    def event_delivery_failure_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("event_delivery_failure_topic_arn")

    @builtins.property
    def event_endpoint_created_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("event_endpoint_created_topic_arn")

    @builtins.property
    def event_endpoint_deleted_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("event_endpoint_deleted_topic_arn")

    @builtins.property
    def event_endpoint_updated_topic_arn(self) -> typing.Optional[str]:
        return self._values.get("event_endpoint_updated_topic_arn")

    @builtins.property
    def failure_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("failure_feedback_role_arn")

    @builtins.property
    def platform_principal(self) -> typing.Optional[str]:
        return self._values.get("platform_principal")

    @builtins.property
    def success_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("success_feedback_role_arn")

    @builtins.property
    def success_feedback_sample_rate(self) -> typing.Optional[str]:
        return self._values.get("success_feedback_sample_rate")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsPlatformApplicationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnsSmsPreferences(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SnsSmsPreferences",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_sender_id: typing.Optional[str] = None,
        default_sms_type: typing.Optional[str] = None,
        delivery_status_iam_role_arn: typing.Optional[str] = None,
        delivery_status_success_sampling_rate: typing.Optional[str] = None,
        monthly_spend_limit: typing.Optional[str] = None,
        usage_report_s3_bucket: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_sender_id: 
        :param default_sms_type: 
        :param delivery_status_iam_role_arn: 
        :param delivery_status_success_sampling_rate: 
        :param monthly_spend_limit: 
        :param usage_report_s3_bucket: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SnsSmsPreferencesConfig(
            default_sender_id=default_sender_id,
            default_sms_type=default_sms_type,
            delivery_status_iam_role_arn=delivery_status_iam_role_arn,
            delivery_status_success_sampling_rate=delivery_status_success_sampling_rate,
            monthly_spend_limit=monthly_spend_limit,
            usage_report_s3_bucket=usage_report_s3_bucket,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SnsSmsPreferences, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="defaultSenderId")
    def default_sender_id(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultSenderId")

    @default_sender_id.setter
    def default_sender_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultSenderId", value)

    @builtins.property
    @jsii.member(jsii_name="defaultSmsType")
    def default_sms_type(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultSmsType")

    @default_sms_type.setter
    def default_sms_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultSmsType", value)

    @builtins.property
    @jsii.member(jsii_name="deliveryStatusIamRoleArn")
    def delivery_status_iam_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "deliveryStatusIamRoleArn")

    @delivery_status_iam_role_arn.setter
    def delivery_status_iam_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deliveryStatusIamRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="deliveryStatusSuccessSamplingRate")
    def delivery_status_success_sampling_rate(self) -> typing.Optional[str]:
        return jsii.get(self, "deliveryStatusSuccessSamplingRate")

    @delivery_status_success_sampling_rate.setter
    def delivery_status_success_sampling_rate(
        self, value: typing.Optional[str]
    ) -> None:
        jsii.set(self, "deliveryStatusSuccessSamplingRate", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="monthlySpendLimit")
    def monthly_spend_limit(self) -> typing.Optional[str]:
        return jsii.get(self, "monthlySpendLimit")

    @monthly_spend_limit.setter
    def monthly_spend_limit(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "monthlySpendLimit", value)

    @builtins.property
    @jsii.member(jsii_name="usageReportS3Bucket")
    def usage_report_s3_bucket(self) -> typing.Optional[str]:
        return jsii.get(self, "usageReportS3Bucket")

    @usage_report_s3_bucket.setter
    def usage_report_s3_bucket(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "usageReportS3Bucket", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SnsSmsPreferencesConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_sender_id": "defaultSenderId",
        "default_sms_type": "defaultSmsType",
        "delivery_status_iam_role_arn": "deliveryStatusIamRoleArn",
        "delivery_status_success_sampling_rate": "deliveryStatusSuccessSamplingRate",
        "monthly_spend_limit": "monthlySpendLimit",
        "usage_report_s3_bucket": "usageReportS3Bucket",
    },
)
class SnsSmsPreferencesConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_sender_id: typing.Optional[str] = None,
        default_sms_type: typing.Optional[str] = None,
        delivery_status_iam_role_arn: typing.Optional[str] = None,
        delivery_status_success_sampling_rate: typing.Optional[str] = None,
        monthly_spend_limit: typing.Optional[str] = None,
        usage_report_s3_bucket: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_sender_id: 
        :param default_sms_type: 
        :param delivery_status_iam_role_arn: 
        :param delivery_status_success_sampling_rate: 
        :param monthly_spend_limit: 
        :param usage_report_s3_bucket: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_sender_id is not None:
            self._values["default_sender_id"] = default_sender_id
        if default_sms_type is not None:
            self._values["default_sms_type"] = default_sms_type
        if delivery_status_iam_role_arn is not None:
            self._values["delivery_status_iam_role_arn"] = delivery_status_iam_role_arn
        if delivery_status_success_sampling_rate is not None:
            self._values[
                "delivery_status_success_sampling_rate"
            ] = delivery_status_success_sampling_rate
        if monthly_spend_limit is not None:
            self._values["monthly_spend_limit"] = monthly_spend_limit
        if usage_report_s3_bucket is not None:
            self._values["usage_report_s3_bucket"] = usage_report_s3_bucket

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_sender_id(self) -> typing.Optional[str]:
        return self._values.get("default_sender_id")

    @builtins.property
    def default_sms_type(self) -> typing.Optional[str]:
        return self._values.get("default_sms_type")

    @builtins.property
    def delivery_status_iam_role_arn(self) -> typing.Optional[str]:
        return self._values.get("delivery_status_iam_role_arn")

    @builtins.property
    def delivery_status_success_sampling_rate(self) -> typing.Optional[str]:
        return self._values.get("delivery_status_success_sampling_rate")

    @builtins.property
    def monthly_spend_limit(self) -> typing.Optional[str]:
        return self._values.get("monthly_spend_limit")

    @builtins.property
    def usage_report_s3_bucket(self) -> typing.Optional[str]:
        return self._values.get("usage_report_s3_bucket")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsSmsPreferencesConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnsTopic(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SnsTopic",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        application_failure_feedback_role_arn: typing.Optional[str] = None,
        application_success_feedback_role_arn: typing.Optional[str] = None,
        application_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        delivery_policy: typing.Optional[str] = None,
        display_name: typing.Optional[str] = None,
        http_failure_feedback_role_arn: typing.Optional[str] = None,
        http_success_feedback_role_arn: typing.Optional[str] = None,
        http_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        kms_master_key_id: typing.Optional[str] = None,
        lambda_failure_feedback_role_arn: typing.Optional[str] = None,
        lambda_success_feedback_role_arn: typing.Optional[str] = None,
        lambda_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        sqs_failure_feedback_role_arn: typing.Optional[str] = None,
        sqs_success_feedback_role_arn: typing.Optional[str] = None,
        sqs_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param application_failure_feedback_role_arn: 
        :param application_success_feedback_role_arn: 
        :param application_success_feedback_sample_rate: 
        :param delivery_policy: 
        :param display_name: 
        :param http_failure_feedback_role_arn: 
        :param http_success_feedback_role_arn: 
        :param http_success_feedback_sample_rate: 
        :param kms_master_key_id: 
        :param lambda_failure_feedback_role_arn: 
        :param lambda_success_feedback_role_arn: 
        :param lambda_success_feedback_sample_rate: 
        :param name: 
        :param name_prefix: 
        :param policy: 
        :param sqs_failure_feedback_role_arn: 
        :param sqs_success_feedback_role_arn: 
        :param sqs_success_feedback_sample_rate: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SnsTopicConfig(
            application_failure_feedback_role_arn=application_failure_feedback_role_arn,
            application_success_feedback_role_arn=application_success_feedback_role_arn,
            application_success_feedback_sample_rate=application_success_feedback_sample_rate,
            delivery_policy=delivery_policy,
            display_name=display_name,
            http_failure_feedback_role_arn=http_failure_feedback_role_arn,
            http_success_feedback_role_arn=http_success_feedback_role_arn,
            http_success_feedback_sample_rate=http_success_feedback_sample_rate,
            kms_master_key_id=kms_master_key_id,
            lambda_failure_feedback_role_arn=lambda_failure_feedback_role_arn,
            lambda_success_feedback_role_arn=lambda_success_feedback_role_arn,
            lambda_success_feedback_sample_rate=lambda_success_feedback_sample_rate,
            name=name,
            name_prefix=name_prefix,
            policy=policy,
            sqs_failure_feedback_role_arn=sqs_failure_feedback_role_arn,
            sqs_success_feedback_role_arn=sqs_success_feedback_role_arn,
            sqs_success_feedback_sample_rate=sqs_success_feedback_sample_rate,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SnsTopic, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="applicationFailureFeedbackRoleArn")
    def application_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "applicationFailureFeedbackRoleArn")

    @application_failure_feedback_role_arn.setter
    def application_failure_feedback_role_arn(
        self, value: typing.Optional[str]
    ) -> None:
        jsii.set(self, "applicationFailureFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="applicationSuccessFeedbackRoleArn")
    def application_success_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "applicationSuccessFeedbackRoleArn")

    @application_success_feedback_role_arn.setter
    def application_success_feedback_role_arn(
        self, value: typing.Optional[str]
    ) -> None:
        jsii.set(self, "applicationSuccessFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="applicationSuccessFeedbackSampleRate")
    def application_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "applicationSuccessFeedbackSampleRate")

    @application_success_feedback_sample_rate.setter
    def application_success_feedback_sample_rate(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "applicationSuccessFeedbackSampleRate", value)

    @builtins.property
    @jsii.member(jsii_name="deliveryPolicy")
    def delivery_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "deliveryPolicy")

    @delivery_policy.setter
    def delivery_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deliveryPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[str]:
        return jsii.get(self, "displayName")

    @display_name.setter
    def display_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property
    @jsii.member(jsii_name="httpFailureFeedbackRoleArn")
    def http_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "httpFailureFeedbackRoleArn")

    @http_failure_feedback_role_arn.setter
    def http_failure_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "httpFailureFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="httpSuccessFeedbackRoleArn")
    def http_success_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "httpSuccessFeedbackRoleArn")

    @http_success_feedback_role_arn.setter
    def http_success_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "httpSuccessFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="httpSuccessFeedbackSampleRate")
    def http_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "httpSuccessFeedbackSampleRate")

    @http_success_feedback_sample_rate.setter
    def http_success_feedback_sample_rate(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "httpSuccessFeedbackSampleRate", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsMasterKeyId")
    def kms_master_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsMasterKeyId")

    @kms_master_key_id.setter
    def kms_master_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsMasterKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaFailureFeedbackRoleArn")
    def lambda_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "lambdaFailureFeedbackRoleArn")

    @lambda_failure_feedback_role_arn.setter
    def lambda_failure_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "lambdaFailureFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaSuccessFeedbackRoleArn")
    def lambda_success_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "lambdaSuccessFeedbackRoleArn")

    @lambda_success_feedback_role_arn.setter
    def lambda_success_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "lambdaSuccessFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="lambdaSuccessFeedbackSampleRate")
    def lambda_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "lambdaSuccessFeedbackSampleRate")

    @lambda_success_feedback_sample_rate.setter
    def lambda_success_feedback_sample_rate(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "lambdaSuccessFeedbackSampleRate", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="sqsFailureFeedbackRoleArn")
    def sqs_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "sqsFailureFeedbackRoleArn")

    @sqs_failure_feedback_role_arn.setter
    def sqs_failure_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sqsFailureFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="sqsSuccessFeedbackRoleArn")
    def sqs_success_feedback_role_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "sqsSuccessFeedbackRoleArn")

    @sqs_success_feedback_role_arn.setter
    def sqs_success_feedback_role_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sqsSuccessFeedbackRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="sqsSuccessFeedbackSampleRate")
    def sqs_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "sqsSuccessFeedbackSampleRate")

    @sqs_success_feedback_sample_rate.setter
    def sqs_success_feedback_sample_rate(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "sqsSuccessFeedbackSampleRate", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SnsTopicConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "application_failure_feedback_role_arn": "applicationFailureFeedbackRoleArn",
        "application_success_feedback_role_arn": "applicationSuccessFeedbackRoleArn",
        "application_success_feedback_sample_rate": "applicationSuccessFeedbackSampleRate",
        "delivery_policy": "deliveryPolicy",
        "display_name": "displayName",
        "http_failure_feedback_role_arn": "httpFailureFeedbackRoleArn",
        "http_success_feedback_role_arn": "httpSuccessFeedbackRoleArn",
        "http_success_feedback_sample_rate": "httpSuccessFeedbackSampleRate",
        "kms_master_key_id": "kmsMasterKeyId",
        "lambda_failure_feedback_role_arn": "lambdaFailureFeedbackRoleArn",
        "lambda_success_feedback_role_arn": "lambdaSuccessFeedbackRoleArn",
        "lambda_success_feedback_sample_rate": "lambdaSuccessFeedbackSampleRate",
        "name": "name",
        "name_prefix": "namePrefix",
        "policy": "policy",
        "sqs_failure_feedback_role_arn": "sqsFailureFeedbackRoleArn",
        "sqs_success_feedback_role_arn": "sqsSuccessFeedbackRoleArn",
        "sqs_success_feedback_sample_rate": "sqsSuccessFeedbackSampleRate",
        "tags": "tags",
    },
)
class SnsTopicConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        application_failure_feedback_role_arn: typing.Optional[str] = None,
        application_success_feedback_role_arn: typing.Optional[str] = None,
        application_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        delivery_policy: typing.Optional[str] = None,
        display_name: typing.Optional[str] = None,
        http_failure_feedback_role_arn: typing.Optional[str] = None,
        http_success_feedback_role_arn: typing.Optional[str] = None,
        http_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        kms_master_key_id: typing.Optional[str] = None,
        lambda_failure_feedback_role_arn: typing.Optional[str] = None,
        lambda_success_feedback_role_arn: typing.Optional[str] = None,
        lambda_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        sqs_failure_feedback_role_arn: typing.Optional[str] = None,
        sqs_success_feedback_role_arn: typing.Optional[str] = None,
        sqs_success_feedback_sample_rate: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param application_failure_feedback_role_arn: 
        :param application_success_feedback_role_arn: 
        :param application_success_feedback_sample_rate: 
        :param delivery_policy: 
        :param display_name: 
        :param http_failure_feedback_role_arn: 
        :param http_success_feedback_role_arn: 
        :param http_success_feedback_sample_rate: 
        :param kms_master_key_id: 
        :param lambda_failure_feedback_role_arn: 
        :param lambda_success_feedback_role_arn: 
        :param lambda_success_feedback_sample_rate: 
        :param name: 
        :param name_prefix: 
        :param policy: 
        :param sqs_failure_feedback_role_arn: 
        :param sqs_success_feedback_role_arn: 
        :param sqs_success_feedback_sample_rate: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if application_failure_feedback_role_arn is not None:
            self._values[
                "application_failure_feedback_role_arn"
            ] = application_failure_feedback_role_arn
        if application_success_feedback_role_arn is not None:
            self._values[
                "application_success_feedback_role_arn"
            ] = application_success_feedback_role_arn
        if application_success_feedback_sample_rate is not None:
            self._values[
                "application_success_feedback_sample_rate"
            ] = application_success_feedback_sample_rate
        if delivery_policy is not None:
            self._values["delivery_policy"] = delivery_policy
        if display_name is not None:
            self._values["display_name"] = display_name
        if http_failure_feedback_role_arn is not None:
            self._values[
                "http_failure_feedback_role_arn"
            ] = http_failure_feedback_role_arn
        if http_success_feedback_role_arn is not None:
            self._values[
                "http_success_feedback_role_arn"
            ] = http_success_feedback_role_arn
        if http_success_feedback_sample_rate is not None:
            self._values[
                "http_success_feedback_sample_rate"
            ] = http_success_feedback_sample_rate
        if kms_master_key_id is not None:
            self._values["kms_master_key_id"] = kms_master_key_id
        if lambda_failure_feedback_role_arn is not None:
            self._values[
                "lambda_failure_feedback_role_arn"
            ] = lambda_failure_feedback_role_arn
        if lambda_success_feedback_role_arn is not None:
            self._values[
                "lambda_success_feedback_role_arn"
            ] = lambda_success_feedback_role_arn
        if lambda_success_feedback_sample_rate is not None:
            self._values[
                "lambda_success_feedback_sample_rate"
            ] = lambda_success_feedback_sample_rate
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if policy is not None:
            self._values["policy"] = policy
        if sqs_failure_feedback_role_arn is not None:
            self._values[
                "sqs_failure_feedback_role_arn"
            ] = sqs_failure_feedback_role_arn
        if sqs_success_feedback_role_arn is not None:
            self._values[
                "sqs_success_feedback_role_arn"
            ] = sqs_success_feedback_role_arn
        if sqs_success_feedback_sample_rate is not None:
            self._values[
                "sqs_success_feedback_sample_rate"
            ] = sqs_success_feedback_sample_rate
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def application_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("application_failure_feedback_role_arn")

    @builtins.property
    def application_success_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("application_success_feedback_role_arn")

    @builtins.property
    def application_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return self._values.get("application_success_feedback_sample_rate")

    @builtins.property
    def delivery_policy(self) -> typing.Optional[str]:
        return self._values.get("delivery_policy")

    @builtins.property
    def display_name(self) -> typing.Optional[str]:
        return self._values.get("display_name")

    @builtins.property
    def http_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("http_failure_feedback_role_arn")

    @builtins.property
    def http_success_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("http_success_feedback_role_arn")

    @builtins.property
    def http_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return self._values.get("http_success_feedback_sample_rate")

    @builtins.property
    def kms_master_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_master_key_id")

    @builtins.property
    def lambda_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("lambda_failure_feedback_role_arn")

    @builtins.property
    def lambda_success_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("lambda_success_feedback_role_arn")

    @builtins.property
    def lambda_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return self._values.get("lambda_success_feedback_sample_rate")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def sqs_failure_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("sqs_failure_feedback_role_arn")

    @builtins.property
    def sqs_success_feedback_role_arn(self) -> typing.Optional[str]:
        return self._values.get("sqs_success_feedback_role_arn")

    @builtins.property
    def sqs_success_feedback_sample_rate(self) -> typing.Optional[jsii.Number]:
        return self._values.get("sqs_success_feedback_sample_rate")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsTopicConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnsTopicPolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SnsTopicPolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        arn: str,
        policy: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param arn: 
        :param policy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SnsTopicPolicyConfig(
            arn=arn,
            policy=policy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SnsTopicPolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: str) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SnsTopicPolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "arn": "arn",
        "policy": "policy",
    },
)
class SnsTopicPolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        arn: str,
        policy: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param arn: 
        :param policy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "arn": arn,
            "policy": policy,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsTopicPolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SnsTopicSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SnsTopicSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        endpoint: str,
        protocol: str,
        topic_arn: str,
        confirmation_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        delivery_policy: typing.Optional[str] = None,
        endpoint_auto_confirms: typing.Optional[bool] = None,
        filter_policy: typing.Optional[str] = None,
        raw_message_delivery: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param endpoint: 
        :param protocol: 
        :param topic_arn: 
        :param confirmation_timeout_in_minutes: 
        :param delivery_policy: 
        :param endpoint_auto_confirms: 
        :param filter_policy: 
        :param raw_message_delivery: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SnsTopicSubscriptionConfig(
            endpoint=endpoint,
            protocol=protocol,
            topic_arn=topic_arn,
            confirmation_timeout_in_minutes=confirmation_timeout_in_minutes,
            delivery_policy=delivery_policy,
            endpoint_auto_confirms=endpoint_auto_confirms,
            filter_policy=filter_policy,
            raw_message_delivery=raw_message_delivery,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SnsTopicSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @endpoint.setter
    def endpoint(self, value: str) -> None:
        jsii.set(self, "endpoint", value)

    @builtins.property
    @jsii.member(jsii_name="protocol")
    def protocol(self) -> str:
        return jsii.get(self, "protocol")

    @protocol.setter
    def protocol(self, value: str) -> None:
        jsii.set(self, "protocol", value)

    @builtins.property
    @jsii.member(jsii_name="topicArn")
    def topic_arn(self) -> str:
        return jsii.get(self, "topicArn")

    @topic_arn.setter
    def topic_arn(self, value: str) -> None:
        jsii.set(self, "topicArn", value)

    @builtins.property
    @jsii.member(jsii_name="confirmationTimeoutInMinutes")
    def confirmation_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "confirmationTimeoutInMinutes")

    @confirmation_timeout_in_minutes.setter
    def confirmation_timeout_in_minutes(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "confirmationTimeoutInMinutes", value)

    @builtins.property
    @jsii.member(jsii_name="deliveryPolicy")
    def delivery_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "deliveryPolicy")

    @delivery_policy.setter
    def delivery_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deliveryPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="endpointAutoConfirms")
    def endpoint_auto_confirms(self) -> typing.Optional[bool]:
        return jsii.get(self, "endpointAutoConfirms")

    @endpoint_auto_confirms.setter
    def endpoint_auto_confirms(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "endpointAutoConfirms", value)

    @builtins.property
    @jsii.member(jsii_name="filterPolicy")
    def filter_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "filterPolicy")

    @filter_policy.setter
    def filter_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "filterPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="rawMessageDelivery")
    def raw_message_delivery(self) -> typing.Optional[bool]:
        return jsii.get(self, "rawMessageDelivery")

    @raw_message_delivery.setter
    def raw_message_delivery(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "rawMessageDelivery", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SnsTopicSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "endpoint": "endpoint",
        "protocol": "protocol",
        "topic_arn": "topicArn",
        "confirmation_timeout_in_minutes": "confirmationTimeoutInMinutes",
        "delivery_policy": "deliveryPolicy",
        "endpoint_auto_confirms": "endpointAutoConfirms",
        "filter_policy": "filterPolicy",
        "raw_message_delivery": "rawMessageDelivery",
    },
)
class SnsTopicSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        endpoint: str,
        protocol: str,
        topic_arn: str,
        confirmation_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        delivery_policy: typing.Optional[str] = None,
        endpoint_auto_confirms: typing.Optional[bool] = None,
        filter_policy: typing.Optional[str] = None,
        raw_message_delivery: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param endpoint: 
        :param protocol: 
        :param topic_arn: 
        :param confirmation_timeout_in_minutes: 
        :param delivery_policy: 
        :param endpoint_auto_confirms: 
        :param filter_policy: 
        :param raw_message_delivery: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "endpoint": endpoint,
            "protocol": protocol,
            "topic_arn": topic_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if confirmation_timeout_in_minutes is not None:
            self._values[
                "confirmation_timeout_in_minutes"
            ] = confirmation_timeout_in_minutes
        if delivery_policy is not None:
            self._values["delivery_policy"] = delivery_policy
        if endpoint_auto_confirms is not None:
            self._values["endpoint_auto_confirms"] = endpoint_auto_confirms
        if filter_policy is not None:
            self._values["filter_policy"] = filter_policy
        if raw_message_delivery is not None:
            self._values["raw_message_delivery"] = raw_message_delivery

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def endpoint(self) -> str:
        return self._values.get("endpoint")

    @builtins.property
    def protocol(self) -> str:
        return self._values.get("protocol")

    @builtins.property
    def topic_arn(self) -> str:
        return self._values.get("topic_arn")

    @builtins.property
    def confirmation_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("confirmation_timeout_in_minutes")

    @builtins.property
    def delivery_policy(self) -> typing.Optional[str]:
        return self._values.get("delivery_policy")

    @builtins.property
    def endpoint_auto_confirms(self) -> typing.Optional[bool]:
        return self._values.get("endpoint_auto_confirms")

    @builtins.property
    def filter_policy(self) -> typing.Optional[str]:
        return self._values.get("filter_policy")

    @builtins.property
    def raw_message_delivery(self) -> typing.Optional[bool]:
        return self._values.get("raw_message_delivery")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SnsTopicSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SpotDatafeedSubscription(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SpotDatafeedSubscription",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bucket: str,
        prefix: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bucket: 
        :param prefix: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SpotDatafeedSubscriptionConfig(
            bucket=bucket,
            prefix=prefix,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SpotDatafeedSubscription, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="bucket")
    def bucket(self) -> str:
        return jsii.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: str) -> None:
        jsii.set(self, "bucket", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="prefix")
    def prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "prefix")

    @prefix.setter
    def prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "prefix", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotDatafeedSubscriptionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bucket": "bucket",
        "prefix": "prefix",
    },
)
class SpotDatafeedSubscriptionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bucket: str,
        prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bucket: 
        :param prefix: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bucket": bucket,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if prefix is not None:
            self._values["prefix"] = prefix

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bucket(self) -> str:
        return self._values.get("bucket")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotDatafeedSubscriptionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SpotFleetRequest(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequest",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        iam_fleet_role: str,
        target_capacity: jsii.Number,
        allocation_strategy: typing.Optional[str] = None,
        excess_capacity_termination_policy: typing.Optional[str] = None,
        fleet_type: typing.Optional[str] = None,
        instance_interruption_behaviour: typing.Optional[str] = None,
        instance_pools_to_use_count: typing.Optional[jsii.Number] = None,
        launch_specification: typing.Optional[
            typing.List["SpotFleetRequestLaunchSpecification"]
        ] = None,
        launch_template_config: typing.Optional[
            typing.List["SpotFleetRequestLaunchTemplateConfig"]
        ] = None,
        load_balancers: typing.Optional[typing.List[str]] = None,
        replace_unhealthy_instances: typing.Optional[bool] = None,
        spot_price: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_group_arns: typing.Optional[typing.List[str]] = None,
        terminate_instances_with_expiration: typing.Optional[bool] = None,
        timeouts: typing.Optional["SpotFleetRequestTimeouts"] = None,
        valid_from: typing.Optional[str] = None,
        valid_until: typing.Optional[str] = None,
        wait_for_fulfillment: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param iam_fleet_role: 
        :param target_capacity: 
        :param allocation_strategy: 
        :param excess_capacity_termination_policy: 
        :param fleet_type: 
        :param instance_interruption_behaviour: 
        :param instance_pools_to_use_count: 
        :param launch_specification: launch_specification block.
        :param launch_template_config: launch_template_config block.
        :param load_balancers: 
        :param replace_unhealthy_instances: 
        :param spot_price: 
        :param tags: 
        :param target_group_arns: 
        :param terminate_instances_with_expiration: 
        :param timeouts: timeouts block.
        :param valid_from: 
        :param valid_until: 
        :param wait_for_fulfillment: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SpotFleetRequestConfig(
            iam_fleet_role=iam_fleet_role,
            target_capacity=target_capacity,
            allocation_strategy=allocation_strategy,
            excess_capacity_termination_policy=excess_capacity_termination_policy,
            fleet_type=fleet_type,
            instance_interruption_behaviour=instance_interruption_behaviour,
            instance_pools_to_use_count=instance_pools_to_use_count,
            launch_specification=launch_specification,
            launch_template_config=launch_template_config,
            load_balancers=load_balancers,
            replace_unhealthy_instances=replace_unhealthy_instances,
            spot_price=spot_price,
            tags=tags,
            target_group_arns=target_group_arns,
            terminate_instances_with_expiration=terminate_instances_with_expiration,
            timeouts=timeouts,
            valid_from=valid_from,
            valid_until=valid_until,
            wait_for_fulfillment=wait_for_fulfillment,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SpotFleetRequest, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="clientToken")
    def client_token(self) -> str:
        return jsii.get(self, "clientToken")

    @builtins.property
    @jsii.member(jsii_name="spotRequestState")
    def spot_request_state(self) -> str:
        return jsii.get(self, "spotRequestState")

    @builtins.property
    @jsii.member(jsii_name="iamFleetRole")
    def iam_fleet_role(self) -> str:
        return jsii.get(self, "iamFleetRole")

    @iam_fleet_role.setter
    def iam_fleet_role(self, value: str) -> None:
        jsii.set(self, "iamFleetRole", value)

    @builtins.property
    @jsii.member(jsii_name="targetCapacity")
    def target_capacity(self) -> jsii.Number:
        return jsii.get(self, "targetCapacity")

    @target_capacity.setter
    def target_capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "targetCapacity", value)

    @builtins.property
    @jsii.member(jsii_name="allocationStrategy")
    def allocation_strategy(self) -> typing.Optional[str]:
        return jsii.get(self, "allocationStrategy")

    @allocation_strategy.setter
    def allocation_strategy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "allocationStrategy", value)

    @builtins.property
    @jsii.member(jsii_name="excessCapacityTerminationPolicy")
    def excess_capacity_termination_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "excessCapacityTerminationPolicy")

    @excess_capacity_termination_policy.setter
    def excess_capacity_termination_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "excessCapacityTerminationPolicy", value)

    @builtins.property
    @jsii.member(jsii_name="fleetType")
    def fleet_type(self) -> typing.Optional[str]:
        return jsii.get(self, "fleetType")

    @fleet_type.setter
    def fleet_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "fleetType", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceInterruptionBehaviour")
    def instance_interruption_behaviour(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceInterruptionBehaviour")

    @instance_interruption_behaviour.setter
    def instance_interruption_behaviour(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceInterruptionBehaviour", value)

    @builtins.property
    @jsii.member(jsii_name="instancePoolsToUseCount")
    def instance_pools_to_use_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "instancePoolsToUseCount")

    @instance_pools_to_use_count.setter
    def instance_pools_to_use_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "instancePoolsToUseCount", value)

    @builtins.property
    @jsii.member(jsii_name="launchSpecification")
    def launch_specification(
        self,
    ) -> typing.Optional[typing.List["SpotFleetRequestLaunchSpecification"]]:
        return jsii.get(self, "launchSpecification")

    @launch_specification.setter
    def launch_specification(
        self, value: typing.Optional[typing.List["SpotFleetRequestLaunchSpecification"]]
    ) -> None:
        jsii.set(self, "launchSpecification", value)

    @builtins.property
    @jsii.member(jsii_name="launchTemplateConfig")
    def launch_template_config(
        self,
    ) -> typing.Optional[typing.List["SpotFleetRequestLaunchTemplateConfig"]]:
        return jsii.get(self, "launchTemplateConfig")

    @launch_template_config.setter
    def launch_template_config(
        self,
        value: typing.Optional[typing.List["SpotFleetRequestLaunchTemplateConfig"]],
    ) -> None:
        jsii.set(self, "launchTemplateConfig", value)

    @builtins.property
    @jsii.member(jsii_name="loadBalancers")
    def load_balancers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "loadBalancers")

    @load_balancers.setter
    def load_balancers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "loadBalancers", value)

    @builtins.property
    @jsii.member(jsii_name="replaceUnhealthyInstances")
    def replace_unhealthy_instances(self) -> typing.Optional[bool]:
        return jsii.get(self, "replaceUnhealthyInstances")

    @replace_unhealthy_instances.setter
    def replace_unhealthy_instances(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "replaceUnhealthyInstances", value)

    @builtins.property
    @jsii.member(jsii_name="spotPrice")
    def spot_price(self) -> typing.Optional[str]:
        return jsii.get(self, "spotPrice")

    @spot_price.setter
    def spot_price(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "spotPrice", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="targetGroupArns")
    def target_group_arns(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "targetGroupArns")

    @target_group_arns.setter
    def target_group_arns(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "targetGroupArns", value)

    @builtins.property
    @jsii.member(jsii_name="terminateInstancesWithExpiration")
    def terminate_instances_with_expiration(self) -> typing.Optional[bool]:
        return jsii.get(self, "terminateInstancesWithExpiration")

    @terminate_instances_with_expiration.setter
    def terminate_instances_with_expiration(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "terminateInstancesWithExpiration", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SpotFleetRequestTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["SpotFleetRequestTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="validFrom")
    def valid_from(self) -> typing.Optional[str]:
        return jsii.get(self, "validFrom")

    @valid_from.setter
    def valid_from(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "validFrom", value)

    @builtins.property
    @jsii.member(jsii_name="validUntil")
    def valid_until(self) -> typing.Optional[str]:
        return jsii.get(self, "validUntil")

    @valid_until.setter
    def valid_until(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "validUntil", value)

    @builtins.property
    @jsii.member(jsii_name="waitForFulfillment")
    def wait_for_fulfillment(self) -> typing.Optional[bool]:
        return jsii.get(self, "waitForFulfillment")

    @wait_for_fulfillment.setter
    def wait_for_fulfillment(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "waitForFulfillment", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "iam_fleet_role": "iamFleetRole",
        "target_capacity": "targetCapacity",
        "allocation_strategy": "allocationStrategy",
        "excess_capacity_termination_policy": "excessCapacityTerminationPolicy",
        "fleet_type": "fleetType",
        "instance_interruption_behaviour": "instanceInterruptionBehaviour",
        "instance_pools_to_use_count": "instancePoolsToUseCount",
        "launch_specification": "launchSpecification",
        "launch_template_config": "launchTemplateConfig",
        "load_balancers": "loadBalancers",
        "replace_unhealthy_instances": "replaceUnhealthyInstances",
        "spot_price": "spotPrice",
        "tags": "tags",
        "target_group_arns": "targetGroupArns",
        "terminate_instances_with_expiration": "terminateInstancesWithExpiration",
        "timeouts": "timeouts",
        "valid_from": "validFrom",
        "valid_until": "validUntil",
        "wait_for_fulfillment": "waitForFulfillment",
    },
)
class SpotFleetRequestConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        iam_fleet_role: str,
        target_capacity: jsii.Number,
        allocation_strategy: typing.Optional[str] = None,
        excess_capacity_termination_policy: typing.Optional[str] = None,
        fleet_type: typing.Optional[str] = None,
        instance_interruption_behaviour: typing.Optional[str] = None,
        instance_pools_to_use_count: typing.Optional[jsii.Number] = None,
        launch_specification: typing.Optional[
            typing.List["SpotFleetRequestLaunchSpecification"]
        ] = None,
        launch_template_config: typing.Optional[
            typing.List["SpotFleetRequestLaunchTemplateConfig"]
        ] = None,
        load_balancers: typing.Optional[typing.List[str]] = None,
        replace_unhealthy_instances: typing.Optional[bool] = None,
        spot_price: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_group_arns: typing.Optional[typing.List[str]] = None,
        terminate_instances_with_expiration: typing.Optional[bool] = None,
        timeouts: typing.Optional["SpotFleetRequestTimeouts"] = None,
        valid_from: typing.Optional[str] = None,
        valid_until: typing.Optional[str] = None,
        wait_for_fulfillment: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param iam_fleet_role: 
        :param target_capacity: 
        :param allocation_strategy: 
        :param excess_capacity_termination_policy: 
        :param fleet_type: 
        :param instance_interruption_behaviour: 
        :param instance_pools_to_use_count: 
        :param launch_specification: launch_specification block.
        :param launch_template_config: launch_template_config block.
        :param load_balancers: 
        :param replace_unhealthy_instances: 
        :param spot_price: 
        :param tags: 
        :param target_group_arns: 
        :param terminate_instances_with_expiration: 
        :param timeouts: timeouts block.
        :param valid_from: 
        :param valid_until: 
        :param wait_for_fulfillment: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SpotFleetRequestTimeouts(**timeouts)
        self._values = {
            "iam_fleet_role": iam_fleet_role,
            "target_capacity": target_capacity,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allocation_strategy is not None:
            self._values["allocation_strategy"] = allocation_strategy
        if excess_capacity_termination_policy is not None:
            self._values[
                "excess_capacity_termination_policy"
            ] = excess_capacity_termination_policy
        if fleet_type is not None:
            self._values["fleet_type"] = fleet_type
        if instance_interruption_behaviour is not None:
            self._values[
                "instance_interruption_behaviour"
            ] = instance_interruption_behaviour
        if instance_pools_to_use_count is not None:
            self._values["instance_pools_to_use_count"] = instance_pools_to_use_count
        if launch_specification is not None:
            self._values["launch_specification"] = launch_specification
        if launch_template_config is not None:
            self._values["launch_template_config"] = launch_template_config
        if load_balancers is not None:
            self._values["load_balancers"] = load_balancers
        if replace_unhealthy_instances is not None:
            self._values["replace_unhealthy_instances"] = replace_unhealthy_instances
        if spot_price is not None:
            self._values["spot_price"] = spot_price
        if tags is not None:
            self._values["tags"] = tags
        if target_group_arns is not None:
            self._values["target_group_arns"] = target_group_arns
        if terminate_instances_with_expiration is not None:
            self._values[
                "terminate_instances_with_expiration"
            ] = terminate_instances_with_expiration
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if valid_from is not None:
            self._values["valid_from"] = valid_from
        if valid_until is not None:
            self._values["valid_until"] = valid_until
        if wait_for_fulfillment is not None:
            self._values["wait_for_fulfillment"] = wait_for_fulfillment

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def iam_fleet_role(self) -> str:
        return self._values.get("iam_fleet_role")

    @builtins.property
    def target_capacity(self) -> jsii.Number:
        return self._values.get("target_capacity")

    @builtins.property
    def allocation_strategy(self) -> typing.Optional[str]:
        return self._values.get("allocation_strategy")

    @builtins.property
    def excess_capacity_termination_policy(self) -> typing.Optional[str]:
        return self._values.get("excess_capacity_termination_policy")

    @builtins.property
    def fleet_type(self) -> typing.Optional[str]:
        return self._values.get("fleet_type")

    @builtins.property
    def instance_interruption_behaviour(self) -> typing.Optional[str]:
        return self._values.get("instance_interruption_behaviour")

    @builtins.property
    def instance_pools_to_use_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("instance_pools_to_use_count")

    @builtins.property
    def launch_specification(
        self,
    ) -> typing.Optional[typing.List["SpotFleetRequestLaunchSpecification"]]:
        """launch_specification block."""
        return self._values.get("launch_specification")

    @builtins.property
    def launch_template_config(
        self,
    ) -> typing.Optional[typing.List["SpotFleetRequestLaunchTemplateConfig"]]:
        """launch_template_config block."""
        return self._values.get("launch_template_config")

    @builtins.property
    def load_balancers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("load_balancers")

    @builtins.property
    def replace_unhealthy_instances(self) -> typing.Optional[bool]:
        return self._values.get("replace_unhealthy_instances")

    @builtins.property
    def spot_price(self) -> typing.Optional[str]:
        return self._values.get("spot_price")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target_group_arns(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("target_group_arns")

    @builtins.property
    def terminate_instances_with_expiration(self) -> typing.Optional[bool]:
        return self._values.get("terminate_instances_with_expiration")

    @builtins.property
    def timeouts(self) -> typing.Optional["SpotFleetRequestTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def valid_from(self) -> typing.Optional[str]:
        return self._values.get("valid_from")

    @builtins.property
    def valid_until(self) -> typing.Optional[str]:
        return self._values.get("valid_until")

    @builtins.property
    def wait_for_fulfillment(self) -> typing.Optional[bool]:
        return self._values.get("wait_for_fulfillment")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotFleetRequestConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestLaunchSpecification",
    jsii_struct_bases=[],
    name_mapping={
        "ami": "ami",
        "instance_type": "instanceType",
        "associate_public_ip_address": "associatePublicIpAddress",
        "availability_zone": "availabilityZone",
        "ebs_block_device": "ebsBlockDevice",
        "ebs_optimized": "ebsOptimized",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "iam_instance_profile": "iamInstanceProfile",
        "iam_instance_profile_arn": "iamInstanceProfileArn",
        "key_name": "keyName",
        "monitoring": "monitoring",
        "placement_group": "placementGroup",
        "placement_tenancy": "placementTenancy",
        "root_block_device": "rootBlockDevice",
        "spot_price": "spotPrice",
        "subnet_id": "subnetId",
        "tags": "tags",
        "user_data": "userData",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
        "weighted_capacity": "weightedCapacity",
    },
)
class SpotFleetRequestLaunchSpecification:
    def __init__(
        self,
        *,
        ami: str,
        instance_type: str,
        associate_public_ip_address: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        ebs_block_device: typing.Optional[
            typing.List["SpotFleetRequestLaunchSpecificationEbsBlockDevice"]
        ] = None,
        ebs_optimized: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["SpotFleetRequestLaunchSpecificationEphemeralBlockDevice"]
        ] = None,
        iam_instance_profile: typing.Optional[str] = None,
        iam_instance_profile_arn: typing.Optional[str] = None,
        key_name: typing.Optional[str] = None,
        monitoring: typing.Optional[bool] = None,
        placement_group: typing.Optional[str] = None,
        placement_tenancy: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["SpotFleetRequestLaunchSpecificationRootBlockDevice"]
        ] = None,
        spot_price: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        user_data: typing.Optional[str] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        weighted_capacity: typing.Optional[str] = None,
    ) -> None:
        """
        :param ami: 
        :param instance_type: 
        :param associate_public_ip_address: 
        :param availability_zone: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param iam_instance_profile: 
        :param iam_instance_profile_arn: 
        :param key_name: 
        :param monitoring: 
        :param placement_group: 
        :param placement_tenancy: 
        :param root_block_device: root_block_device block.
        :param spot_price: 
        :param subnet_id: 
        :param tags: 
        :param user_data: 
        :param vpc_security_group_ids: 
        :param weighted_capacity: 
        """
        self._values = {
            "ami": ami,
            "instance_type": instance_type,
        }
        if associate_public_ip_address is not None:
            self._values["associate_public_ip_address"] = associate_public_ip_address
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if iam_instance_profile is not None:
            self._values["iam_instance_profile"] = iam_instance_profile
        if iam_instance_profile_arn is not None:
            self._values["iam_instance_profile_arn"] = iam_instance_profile_arn
        if key_name is not None:
            self._values["key_name"] = key_name
        if monitoring is not None:
            self._values["monitoring"] = monitoring
        if placement_group is not None:
            self._values["placement_group"] = placement_group
        if placement_tenancy is not None:
            self._values["placement_tenancy"] = placement_tenancy
        if root_block_device is not None:
            self._values["root_block_device"] = root_block_device
        if spot_price is not None:
            self._values["spot_price"] = spot_price
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags
        if user_data is not None:
            self._values["user_data"] = user_data
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids
        if weighted_capacity is not None:
            self._values["weighted_capacity"] = weighted_capacity

    @builtins.property
    def ami(self) -> str:
        return self._values.get("ami")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def associate_public_ip_address(self) -> typing.Optional[bool]:
        return self._values.get("associate_public_ip_address")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def ebs_block_device(
        self,
    ) -> typing.Optional[
        typing.List["SpotFleetRequestLaunchSpecificationEbsBlockDevice"]
    ]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[bool]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[
        typing.List["SpotFleetRequestLaunchSpecificationEphemeralBlockDevice"]
    ]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def iam_instance_profile(self) -> typing.Optional[str]:
        return self._values.get("iam_instance_profile")

    @builtins.property
    def iam_instance_profile_arn(self) -> typing.Optional[str]:
        return self._values.get("iam_instance_profile_arn")

    @builtins.property
    def key_name(self) -> typing.Optional[str]:
        return self._values.get("key_name")

    @builtins.property
    def monitoring(self) -> typing.Optional[bool]:
        return self._values.get("monitoring")

    @builtins.property
    def placement_group(self) -> typing.Optional[str]:
        return self._values.get("placement_group")

    @builtins.property
    def placement_tenancy(self) -> typing.Optional[str]:
        return self._values.get("placement_tenancy")

    @builtins.property
    def root_block_device(
        self,
    ) -> typing.Optional[
        typing.List["SpotFleetRequestLaunchSpecificationRootBlockDevice"]
    ]:
        """root_block_device block."""
        return self._values.get("root_block_device")

    @builtins.property
    def spot_price(self) -> typing.Optional[str]:
        return self._values.get("spot_price")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def user_data(self) -> typing.Optional[str]:
        return self._values.get("user_data")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    @builtins.property
    def weighted_capacity(self) -> typing.Optional[str]:
        return self._values.get("weighted_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotFleetRequestLaunchSpecification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestLaunchSpecificationEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "snapshot_id": "snapshotId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class SpotFleetRequestLaunchSpecificationEbsBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        snapshot_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param snapshot_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {
            "device_name": device_name,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotFleetRequestLaunchSpecificationEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestLaunchSpecificationEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={"device_name": "deviceName", "virtual_name": "virtualName"},
)
class SpotFleetRequestLaunchSpecificationEphemeralBlockDevice:
    def __init__(self, *, device_name: str, virtual_name: str) -> None:
        """
        :param device_name: 
        :param virtual_name: 
        """
        self._values = {
            "device_name": device_name,
            "virtual_name": virtual_name,
        }

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def virtual_name(self) -> str:
        return self._values.get("virtual_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SpotFleetRequestLaunchSpecificationEphemeralBlockDevice(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestLaunchSpecificationRootBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class SpotFleetRequestLaunchSpecificationRootBlockDevice:
    def __init__(
        self,
        *,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {}
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotFleetRequestLaunchSpecificationRootBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestLaunchTemplateConfig",
    jsii_struct_bases=[],
    name_mapping={
        "launch_template_specification": "launchTemplateSpecification",
        "overrides": "overrides",
    },
)
class SpotFleetRequestLaunchTemplateConfig:
    def __init__(
        self,
        *,
        launch_template_specification: typing.List[
            "SpotFleetRequestLaunchTemplateConfigLaunchTemplateSpecification"
        ],
        overrides: typing.Optional[
            typing.List["SpotFleetRequestLaunchTemplateConfigOverrides"]
        ] = None,
    ) -> None:
        """
        :param launch_template_specification: launch_template_specification block.
        :param overrides: overrides block.
        """
        self._values = {
            "launch_template_specification": launch_template_specification,
        }
        if overrides is not None:
            self._values["overrides"] = overrides

    @builtins.property
    def launch_template_specification(
        self,
    ) -> typing.List["SpotFleetRequestLaunchTemplateConfigLaunchTemplateSpecification"]:
        """launch_template_specification block."""
        return self._values.get("launch_template_specification")

    @builtins.property
    def overrides(
        self,
    ) -> typing.Optional[typing.List["SpotFleetRequestLaunchTemplateConfigOverrides"]]:
        """overrides block."""
        return self._values.get("overrides")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotFleetRequestLaunchTemplateConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestLaunchTemplateConfigLaunchTemplateSpecification",
    jsii_struct_bases=[],
    name_mapping={"id": "id", "name": "name", "version": "version"},
)
class SpotFleetRequestLaunchTemplateConfigLaunchTemplateSpecification:
    def __init__(
        self,
        *,
        id: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        version: typing.Optional[str] = None,
    ) -> None:
        """
        :param id: 
        :param name: 
        :param version: 
        """
        self._values = {}
        if id is not None:
            self._values["id"] = id
        if name is not None:
            self._values["name"] = name
        if version is not None:
            self._values["version"] = version

    @builtins.property
    def id(self) -> typing.Optional[str]:
        return self._values.get("id")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def version(self) -> typing.Optional[str]:
        return self._values.get("version")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SpotFleetRequestLaunchTemplateConfigLaunchTemplateSpecification(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestLaunchTemplateConfigOverrides",
    jsii_struct_bases=[],
    name_mapping={
        "availability_zone": "availabilityZone",
        "instance_type": "instanceType",
        "priority": "priority",
        "spot_price": "spotPrice",
        "subnet_id": "subnetId",
        "weighted_capacity": "weightedCapacity",
    },
)
class SpotFleetRequestLaunchTemplateConfigOverrides:
    def __init__(
        self,
        *,
        availability_zone: typing.Optional[str] = None,
        instance_type: typing.Optional[str] = None,
        priority: typing.Optional[jsii.Number] = None,
        spot_price: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        weighted_capacity: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param availability_zone: 
        :param instance_type: 
        :param priority: 
        :param spot_price: 
        :param subnet_id: 
        :param weighted_capacity: 
        """
        self._values = {}
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if instance_type is not None:
            self._values["instance_type"] = instance_type
        if priority is not None:
            self._values["priority"] = priority
        if spot_price is not None:
            self._values["spot_price"] = spot_price
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if weighted_capacity is not None:
            self._values["weighted_capacity"] = weighted_capacity

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def instance_type(self) -> typing.Optional[str]:
        return self._values.get("instance_type")

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        return self._values.get("priority")

    @builtins.property
    def spot_price(self) -> typing.Optional[str]:
        return self._values.get("spot_price")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def weighted_capacity(self) -> typing.Optional[jsii.Number]:
        return self._values.get("weighted_capacity")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotFleetRequestLaunchTemplateConfigOverrides(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotFleetRequestTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class SpotFleetRequestTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotFleetRequestTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SpotInstanceRequest(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequest",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        ami: str,
        instance_type: str,
        associate_public_ip_address: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        block_duration_minutes: typing.Optional[jsii.Number] = None,
        cpu_core_count: typing.Optional[jsii.Number] = None,
        cpu_threads_per_core: typing.Optional[jsii.Number] = None,
        credit_specification: typing.Optional[
            typing.List["SpotInstanceRequestCreditSpecification"]
        ] = None,
        disable_api_termination: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[
            typing.List["SpotInstanceRequestEbsBlockDevice"]
        ] = None,
        ebs_optimized: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["SpotInstanceRequestEphemeralBlockDevice"]
        ] = None,
        fetch_password_data: typing.Optional[bool] = None,
        hibernation: typing.Optional[bool] = None,
        host_id: typing.Optional[str] = None,
        iam_instance_profile: typing.Optional[str] = None,
        instance_initiated_shutdown_behavior: typing.Optional[str] = None,
        instance_interruption_behaviour: typing.Optional[str] = None,
        ipv6_address_count: typing.Optional[jsii.Number] = None,
        ipv6_addresses: typing.Optional[typing.List[str]] = None,
        key_name: typing.Optional[str] = None,
        launch_group: typing.Optional[str] = None,
        metadata_options: typing.Optional[
            typing.List["SpotInstanceRequestMetadataOptions"]
        ] = None,
        monitoring: typing.Optional[bool] = None,
        network_interface: typing.Optional[
            typing.List["SpotInstanceRequestNetworkInterface"]
        ] = None,
        placement_group: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["SpotInstanceRequestRootBlockDevice"]
        ] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_dest_check: typing.Optional[bool] = None,
        spot_price: typing.Optional[str] = None,
        spot_type: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tenancy: typing.Optional[str] = None,
        timeouts: typing.Optional["SpotInstanceRequestTimeouts"] = None,
        user_data: typing.Optional[str] = None,
        user_data_base64: typing.Optional[str] = None,
        valid_from: typing.Optional[str] = None,
        valid_until: typing.Optional[str] = None,
        volume_tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        wait_for_fulfillment: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param ami: 
        :param instance_type: 
        :param associate_public_ip_address: 
        :param availability_zone: 
        :param block_duration_minutes: 
        :param cpu_core_count: 
        :param cpu_threads_per_core: 
        :param credit_specification: credit_specification block.
        :param disable_api_termination: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param fetch_password_data: 
        :param hibernation: 
        :param host_id: 
        :param iam_instance_profile: 
        :param instance_initiated_shutdown_behavior: 
        :param instance_interruption_behaviour: 
        :param ipv6_address_count: 
        :param ipv6_addresses: 
        :param key_name: 
        :param launch_group: 
        :param metadata_options: metadata_options block.
        :param monitoring: 
        :param network_interface: network_interface block.
        :param placement_group: 
        :param private_ip: 
        :param root_block_device: root_block_device block.
        :param security_groups: 
        :param source_dest_check: 
        :param spot_price: 
        :param spot_type: 
        :param subnet_id: 
        :param tags: 
        :param tenancy: 
        :param timeouts: timeouts block.
        :param user_data: 
        :param user_data_base64: 
        :param valid_from: 
        :param valid_until: 
        :param volume_tags: 
        :param vpc_security_group_ids: 
        :param wait_for_fulfillment: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SpotInstanceRequestConfig(
            ami=ami,
            instance_type=instance_type,
            associate_public_ip_address=associate_public_ip_address,
            availability_zone=availability_zone,
            block_duration_minutes=block_duration_minutes,
            cpu_core_count=cpu_core_count,
            cpu_threads_per_core=cpu_threads_per_core,
            credit_specification=credit_specification,
            disable_api_termination=disable_api_termination,
            ebs_block_device=ebs_block_device,
            ebs_optimized=ebs_optimized,
            ephemeral_block_device=ephemeral_block_device,
            fetch_password_data=fetch_password_data,
            hibernation=hibernation,
            host_id=host_id,
            iam_instance_profile=iam_instance_profile,
            instance_initiated_shutdown_behavior=instance_initiated_shutdown_behavior,
            instance_interruption_behaviour=instance_interruption_behaviour,
            ipv6_address_count=ipv6_address_count,
            ipv6_addresses=ipv6_addresses,
            key_name=key_name,
            launch_group=launch_group,
            metadata_options=metadata_options,
            monitoring=monitoring,
            network_interface=network_interface,
            placement_group=placement_group,
            private_ip=private_ip,
            root_block_device=root_block_device,
            security_groups=security_groups,
            source_dest_check=source_dest_check,
            spot_price=spot_price,
            spot_type=spot_type,
            subnet_id=subnet_id,
            tags=tags,
            tenancy=tenancy,
            timeouts=timeouts,
            user_data=user_data,
            user_data_base64=user_data_base64,
            valid_from=valid_from,
            valid_until=valid_until,
            volume_tags=volume_tags,
            vpc_security_group_ids=vpc_security_group_ids,
            wait_for_fulfillment=wait_for_fulfillment,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SpotInstanceRequest, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="instanceState")
    def instance_state(self) -> str:
        return jsii.get(self, "instanceState")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> str:
        return jsii.get(self, "outpostArn")

    @builtins.property
    @jsii.member(jsii_name="passwordData")
    def password_data(self) -> str:
        return jsii.get(self, "passwordData")

    @builtins.property
    @jsii.member(jsii_name="primaryNetworkInterfaceId")
    def primary_network_interface_id(self) -> str:
        return jsii.get(self, "primaryNetworkInterfaceId")

    @builtins.property
    @jsii.member(jsii_name="privateDns")
    def private_dns(self) -> str:
        return jsii.get(self, "privateDns")

    @builtins.property
    @jsii.member(jsii_name="publicDns")
    def public_dns(self) -> str:
        return jsii.get(self, "publicDns")

    @builtins.property
    @jsii.member(jsii_name="publicIp")
    def public_ip(self) -> str:
        return jsii.get(self, "publicIp")

    @builtins.property
    @jsii.member(jsii_name="spotBidStatus")
    def spot_bid_status(self) -> str:
        return jsii.get(self, "spotBidStatus")

    @builtins.property
    @jsii.member(jsii_name="spotInstanceId")
    def spot_instance_id(self) -> str:
        return jsii.get(self, "spotInstanceId")

    @builtins.property
    @jsii.member(jsii_name="spotRequestState")
    def spot_request_state(self) -> str:
        return jsii.get(self, "spotRequestState")

    @builtins.property
    @jsii.member(jsii_name="ami")
    def ami(self) -> str:
        return jsii.get(self, "ami")

    @ami.setter
    def ami(self, value: str) -> None:
        jsii.set(self, "ami", value)

    @builtins.property
    @jsii.member(jsii_name="instanceType")
    def instance_type(self) -> str:
        return jsii.get(self, "instanceType")

    @instance_type.setter
    def instance_type(self, value: str) -> None:
        jsii.set(self, "instanceType", value)

    @builtins.property
    @jsii.member(jsii_name="associatePublicIpAddress")
    def associate_public_ip_address(self) -> typing.Optional[bool]:
        return jsii.get(self, "associatePublicIpAddress")

    @associate_public_ip_address.setter
    def associate_public_ip_address(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "associatePublicIpAddress", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="blockDurationMinutes")
    def block_duration_minutes(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "blockDurationMinutes")

    @block_duration_minutes.setter
    def block_duration_minutes(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "blockDurationMinutes", value)

    @builtins.property
    @jsii.member(jsii_name="cpuCoreCount")
    def cpu_core_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cpuCoreCount")

    @cpu_core_count.setter
    def cpu_core_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cpuCoreCount", value)

    @builtins.property
    @jsii.member(jsii_name="cpuThreadsPerCore")
    def cpu_threads_per_core(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "cpuThreadsPerCore")

    @cpu_threads_per_core.setter
    def cpu_threads_per_core(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "cpuThreadsPerCore", value)

    @builtins.property
    @jsii.member(jsii_name="creditSpecification")
    def credit_specification(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestCreditSpecification"]]:
        return jsii.get(self, "creditSpecification")

    @credit_specification.setter
    def credit_specification(
        self,
        value: typing.Optional[typing.List["SpotInstanceRequestCreditSpecification"]],
    ) -> None:
        jsii.set(self, "creditSpecification", value)

    @builtins.property
    @jsii.member(jsii_name="disableApiTermination")
    def disable_api_termination(self) -> typing.Optional[bool]:
        return jsii.get(self, "disableApiTermination")

    @disable_api_termination.setter
    def disable_api_termination(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "disableApiTermination", value)

    @builtins.property
    @jsii.member(jsii_name="ebsBlockDevice")
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestEbsBlockDevice"]]:
        return jsii.get(self, "ebsBlockDevice")

    @ebs_block_device.setter
    def ebs_block_device(
        self, value: typing.Optional[typing.List["SpotInstanceRequestEbsBlockDevice"]]
    ) -> None:
        jsii.set(self, "ebsBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="ebsOptimized")
    def ebs_optimized(self) -> typing.Optional[bool]:
        return jsii.get(self, "ebsOptimized")

    @ebs_optimized.setter
    def ebs_optimized(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "ebsOptimized", value)

    @builtins.property
    @jsii.member(jsii_name="ephemeralBlockDevice")
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestEphemeralBlockDevice"]]:
        return jsii.get(self, "ephemeralBlockDevice")

    @ephemeral_block_device.setter
    def ephemeral_block_device(
        self,
        value: typing.Optional[typing.List["SpotInstanceRequestEphemeralBlockDevice"]],
    ) -> None:
        jsii.set(self, "ephemeralBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="fetchPasswordData")
    def fetch_password_data(self) -> typing.Optional[bool]:
        return jsii.get(self, "fetchPasswordData")

    @fetch_password_data.setter
    def fetch_password_data(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "fetchPasswordData", value)

    @builtins.property
    @jsii.member(jsii_name="hibernation")
    def hibernation(self) -> typing.Optional[bool]:
        return jsii.get(self, "hibernation")

    @hibernation.setter
    def hibernation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "hibernation", value)

    @builtins.property
    @jsii.member(jsii_name="hostId")
    def host_id(self) -> typing.Optional[str]:
        return jsii.get(self, "hostId")

    @host_id.setter
    def host_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "hostId", value)

    @builtins.property
    @jsii.member(jsii_name="iamInstanceProfile")
    def iam_instance_profile(self) -> typing.Optional[str]:
        return jsii.get(self, "iamInstanceProfile")

    @iam_instance_profile.setter
    def iam_instance_profile(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "iamInstanceProfile", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceInitiatedShutdownBehavior")
    def instance_initiated_shutdown_behavior(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceInitiatedShutdownBehavior")

    @instance_initiated_shutdown_behavior.setter
    def instance_initiated_shutdown_behavior(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceInitiatedShutdownBehavior", value)

    @builtins.property
    @jsii.member(jsii_name="instanceInterruptionBehaviour")
    def instance_interruption_behaviour(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceInterruptionBehaviour")

    @instance_interruption_behaviour.setter
    def instance_interruption_behaviour(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceInterruptionBehaviour", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6AddressCount")
    def ipv6_address_count(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "ipv6AddressCount")

    @ipv6_address_count.setter
    def ipv6_address_count(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "ipv6AddressCount", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6Addresses")
    def ipv6_addresses(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "ipv6Addresses")

    @ipv6_addresses.setter
    def ipv6_addresses(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "ipv6Addresses", value)

    @builtins.property
    @jsii.member(jsii_name="keyName")
    def key_name(self) -> typing.Optional[str]:
        return jsii.get(self, "keyName")

    @key_name.setter
    def key_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyName", value)

    @builtins.property
    @jsii.member(jsii_name="launchGroup")
    def launch_group(self) -> typing.Optional[str]:
        return jsii.get(self, "launchGroup")

    @launch_group.setter
    def launch_group(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "launchGroup", value)

    @builtins.property
    @jsii.member(jsii_name="metadataOptions")
    def metadata_options(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestMetadataOptions"]]:
        return jsii.get(self, "metadataOptions")

    @metadata_options.setter
    def metadata_options(
        self, value: typing.Optional[typing.List["SpotInstanceRequestMetadataOptions"]]
    ) -> None:
        jsii.set(self, "metadataOptions", value)

    @builtins.property
    @jsii.member(jsii_name="monitoring")
    def monitoring(self) -> typing.Optional[bool]:
        return jsii.get(self, "monitoring")

    @monitoring.setter
    def monitoring(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "monitoring", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterface")
    def network_interface(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestNetworkInterface"]]:
        return jsii.get(self, "networkInterface")

    @network_interface.setter
    def network_interface(
        self, value: typing.Optional[typing.List["SpotInstanceRequestNetworkInterface"]]
    ) -> None:
        jsii.set(self, "networkInterface", value)

    @builtins.property
    @jsii.member(jsii_name="placementGroup")
    def placement_group(self) -> typing.Optional[str]:
        return jsii.get(self, "placementGroup")

    @placement_group.setter
    def placement_group(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "placementGroup", value)

    @builtins.property
    @jsii.member(jsii_name="privateIp")
    def private_ip(self) -> typing.Optional[str]:
        return jsii.get(self, "privateIp")

    @private_ip.setter
    def private_ip(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "privateIp", value)

    @builtins.property
    @jsii.member(jsii_name="rootBlockDevice")
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestRootBlockDevice"]]:
        return jsii.get(self, "rootBlockDevice")

    @root_block_device.setter
    def root_block_device(
        self, value: typing.Optional[typing.List["SpotInstanceRequestRootBlockDevice"]]
    ) -> None:
        jsii.set(self, "rootBlockDevice", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroups")
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroups")

    @security_groups.setter
    def security_groups(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroups", value)

    @builtins.property
    @jsii.member(jsii_name="sourceDestCheck")
    def source_dest_check(self) -> typing.Optional[bool]:
        return jsii.get(self, "sourceDestCheck")

    @source_dest_check.setter
    def source_dest_check(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "sourceDestCheck", value)

    @builtins.property
    @jsii.member(jsii_name="spotPrice")
    def spot_price(self) -> typing.Optional[str]:
        return jsii.get(self, "spotPrice")

    @spot_price.setter
    def spot_price(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "spotPrice", value)

    @builtins.property
    @jsii.member(jsii_name="spotType")
    def spot_type(self) -> typing.Optional[str]:
        return jsii.get(self, "spotType")

    @spot_type.setter
    def spot_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "spotType", value)

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> typing.Optional[str]:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="tenancy")
    def tenancy(self) -> typing.Optional[str]:
        return jsii.get(self, "tenancy")

    @tenancy.setter
    def tenancy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tenancy", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SpotInstanceRequestTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["SpotInstanceRequestTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="userData")
    def user_data(self) -> typing.Optional[str]:
        return jsii.get(self, "userData")

    @user_data.setter
    def user_data(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userData", value)

    @builtins.property
    @jsii.member(jsii_name="userDataBase64")
    def user_data_base64(self) -> typing.Optional[str]:
        return jsii.get(self, "userDataBase64")

    @user_data_base64.setter
    def user_data_base64(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "userDataBase64", value)

    @builtins.property
    @jsii.member(jsii_name="validFrom")
    def valid_from(self) -> typing.Optional[str]:
        return jsii.get(self, "validFrom")

    @valid_from.setter
    def valid_from(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "validFrom", value)

    @builtins.property
    @jsii.member(jsii_name="validUntil")
    def valid_until(self) -> typing.Optional[str]:
        return jsii.get(self, "validUntil")

    @valid_until.setter
    def valid_until(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "validUntil", value)

    @builtins.property
    @jsii.member(jsii_name="volumeTags")
    def volume_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "volumeTags")

    @volume_tags.setter
    def volume_tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "volumeTags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcSecurityGroupIds")
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "vpcSecurityGroupIds")

    @vpc_security_group_ids.setter
    def vpc_security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "vpcSecurityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="waitForFulfillment")
    def wait_for_fulfillment(self) -> typing.Optional[bool]:
        return jsii.get(self, "waitForFulfillment")

    @wait_for_fulfillment.setter
    def wait_for_fulfillment(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "waitForFulfillment", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ami": "ami",
        "instance_type": "instanceType",
        "associate_public_ip_address": "associatePublicIpAddress",
        "availability_zone": "availabilityZone",
        "block_duration_minutes": "blockDurationMinutes",
        "cpu_core_count": "cpuCoreCount",
        "cpu_threads_per_core": "cpuThreadsPerCore",
        "credit_specification": "creditSpecification",
        "disable_api_termination": "disableApiTermination",
        "ebs_block_device": "ebsBlockDevice",
        "ebs_optimized": "ebsOptimized",
        "ephemeral_block_device": "ephemeralBlockDevice",
        "fetch_password_data": "fetchPasswordData",
        "hibernation": "hibernation",
        "host_id": "hostId",
        "iam_instance_profile": "iamInstanceProfile",
        "instance_initiated_shutdown_behavior": "instanceInitiatedShutdownBehavior",
        "instance_interruption_behaviour": "instanceInterruptionBehaviour",
        "ipv6_address_count": "ipv6AddressCount",
        "ipv6_addresses": "ipv6Addresses",
        "key_name": "keyName",
        "launch_group": "launchGroup",
        "metadata_options": "metadataOptions",
        "monitoring": "monitoring",
        "network_interface": "networkInterface",
        "placement_group": "placementGroup",
        "private_ip": "privateIp",
        "root_block_device": "rootBlockDevice",
        "security_groups": "securityGroups",
        "source_dest_check": "sourceDestCheck",
        "spot_price": "spotPrice",
        "spot_type": "spotType",
        "subnet_id": "subnetId",
        "tags": "tags",
        "tenancy": "tenancy",
        "timeouts": "timeouts",
        "user_data": "userData",
        "user_data_base64": "userDataBase64",
        "valid_from": "validFrom",
        "valid_until": "validUntil",
        "volume_tags": "volumeTags",
        "vpc_security_group_ids": "vpcSecurityGroupIds",
        "wait_for_fulfillment": "waitForFulfillment",
    },
)
class SpotInstanceRequestConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ami: str,
        instance_type: str,
        associate_public_ip_address: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        block_duration_minutes: typing.Optional[jsii.Number] = None,
        cpu_core_count: typing.Optional[jsii.Number] = None,
        cpu_threads_per_core: typing.Optional[jsii.Number] = None,
        credit_specification: typing.Optional[
            typing.List["SpotInstanceRequestCreditSpecification"]
        ] = None,
        disable_api_termination: typing.Optional[bool] = None,
        ebs_block_device: typing.Optional[
            typing.List["SpotInstanceRequestEbsBlockDevice"]
        ] = None,
        ebs_optimized: typing.Optional[bool] = None,
        ephemeral_block_device: typing.Optional[
            typing.List["SpotInstanceRequestEphemeralBlockDevice"]
        ] = None,
        fetch_password_data: typing.Optional[bool] = None,
        hibernation: typing.Optional[bool] = None,
        host_id: typing.Optional[str] = None,
        iam_instance_profile: typing.Optional[str] = None,
        instance_initiated_shutdown_behavior: typing.Optional[str] = None,
        instance_interruption_behaviour: typing.Optional[str] = None,
        ipv6_address_count: typing.Optional[jsii.Number] = None,
        ipv6_addresses: typing.Optional[typing.List[str]] = None,
        key_name: typing.Optional[str] = None,
        launch_group: typing.Optional[str] = None,
        metadata_options: typing.Optional[
            typing.List["SpotInstanceRequestMetadataOptions"]
        ] = None,
        monitoring: typing.Optional[bool] = None,
        network_interface: typing.Optional[
            typing.List["SpotInstanceRequestNetworkInterface"]
        ] = None,
        placement_group: typing.Optional[str] = None,
        private_ip: typing.Optional[str] = None,
        root_block_device: typing.Optional[
            typing.List["SpotInstanceRequestRootBlockDevice"]
        ] = None,
        security_groups: typing.Optional[typing.List[str]] = None,
        source_dest_check: typing.Optional[bool] = None,
        spot_price: typing.Optional[str] = None,
        spot_type: typing.Optional[str] = None,
        subnet_id: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tenancy: typing.Optional[str] = None,
        timeouts: typing.Optional["SpotInstanceRequestTimeouts"] = None,
        user_data: typing.Optional[str] = None,
        user_data_base64: typing.Optional[str] = None,
        valid_from: typing.Optional[str] = None,
        valid_until: typing.Optional[str] = None,
        volume_tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_security_group_ids: typing.Optional[typing.List[str]] = None,
        wait_for_fulfillment: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ami: 
        :param instance_type: 
        :param associate_public_ip_address: 
        :param availability_zone: 
        :param block_duration_minutes: 
        :param cpu_core_count: 
        :param cpu_threads_per_core: 
        :param credit_specification: credit_specification block.
        :param disable_api_termination: 
        :param ebs_block_device: ebs_block_device block.
        :param ebs_optimized: 
        :param ephemeral_block_device: ephemeral_block_device block.
        :param fetch_password_data: 
        :param hibernation: 
        :param host_id: 
        :param iam_instance_profile: 
        :param instance_initiated_shutdown_behavior: 
        :param instance_interruption_behaviour: 
        :param ipv6_address_count: 
        :param ipv6_addresses: 
        :param key_name: 
        :param launch_group: 
        :param metadata_options: metadata_options block.
        :param monitoring: 
        :param network_interface: network_interface block.
        :param placement_group: 
        :param private_ip: 
        :param root_block_device: root_block_device block.
        :param security_groups: 
        :param source_dest_check: 
        :param spot_price: 
        :param spot_type: 
        :param subnet_id: 
        :param tags: 
        :param tenancy: 
        :param timeouts: timeouts block.
        :param user_data: 
        :param user_data_base64: 
        :param valid_from: 
        :param valid_until: 
        :param volume_tags: 
        :param vpc_security_group_ids: 
        :param wait_for_fulfillment: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SpotInstanceRequestTimeouts(**timeouts)
        self._values = {
            "ami": ami,
            "instance_type": instance_type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if associate_public_ip_address is not None:
            self._values["associate_public_ip_address"] = associate_public_ip_address
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if block_duration_minutes is not None:
            self._values["block_duration_minutes"] = block_duration_minutes
        if cpu_core_count is not None:
            self._values["cpu_core_count"] = cpu_core_count
        if cpu_threads_per_core is not None:
            self._values["cpu_threads_per_core"] = cpu_threads_per_core
        if credit_specification is not None:
            self._values["credit_specification"] = credit_specification
        if disable_api_termination is not None:
            self._values["disable_api_termination"] = disable_api_termination
        if ebs_block_device is not None:
            self._values["ebs_block_device"] = ebs_block_device
        if ebs_optimized is not None:
            self._values["ebs_optimized"] = ebs_optimized
        if ephemeral_block_device is not None:
            self._values["ephemeral_block_device"] = ephemeral_block_device
        if fetch_password_data is not None:
            self._values["fetch_password_data"] = fetch_password_data
        if hibernation is not None:
            self._values["hibernation"] = hibernation
        if host_id is not None:
            self._values["host_id"] = host_id
        if iam_instance_profile is not None:
            self._values["iam_instance_profile"] = iam_instance_profile
        if instance_initiated_shutdown_behavior is not None:
            self._values[
                "instance_initiated_shutdown_behavior"
            ] = instance_initiated_shutdown_behavior
        if instance_interruption_behaviour is not None:
            self._values[
                "instance_interruption_behaviour"
            ] = instance_interruption_behaviour
        if ipv6_address_count is not None:
            self._values["ipv6_address_count"] = ipv6_address_count
        if ipv6_addresses is not None:
            self._values["ipv6_addresses"] = ipv6_addresses
        if key_name is not None:
            self._values["key_name"] = key_name
        if launch_group is not None:
            self._values["launch_group"] = launch_group
        if metadata_options is not None:
            self._values["metadata_options"] = metadata_options
        if monitoring is not None:
            self._values["monitoring"] = monitoring
        if network_interface is not None:
            self._values["network_interface"] = network_interface
        if placement_group is not None:
            self._values["placement_group"] = placement_group
        if private_ip is not None:
            self._values["private_ip"] = private_ip
        if root_block_device is not None:
            self._values["root_block_device"] = root_block_device
        if security_groups is not None:
            self._values["security_groups"] = security_groups
        if source_dest_check is not None:
            self._values["source_dest_check"] = source_dest_check
        if spot_price is not None:
            self._values["spot_price"] = spot_price
        if spot_type is not None:
            self._values["spot_type"] = spot_type
        if subnet_id is not None:
            self._values["subnet_id"] = subnet_id
        if tags is not None:
            self._values["tags"] = tags
        if tenancy is not None:
            self._values["tenancy"] = tenancy
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if user_data is not None:
            self._values["user_data"] = user_data
        if user_data_base64 is not None:
            self._values["user_data_base64"] = user_data_base64
        if valid_from is not None:
            self._values["valid_from"] = valid_from
        if valid_until is not None:
            self._values["valid_until"] = valid_until
        if volume_tags is not None:
            self._values["volume_tags"] = volume_tags
        if vpc_security_group_ids is not None:
            self._values["vpc_security_group_ids"] = vpc_security_group_ids
        if wait_for_fulfillment is not None:
            self._values["wait_for_fulfillment"] = wait_for_fulfillment

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def ami(self) -> str:
        return self._values.get("ami")

    @builtins.property
    def instance_type(self) -> str:
        return self._values.get("instance_type")

    @builtins.property
    def associate_public_ip_address(self) -> typing.Optional[bool]:
        return self._values.get("associate_public_ip_address")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def block_duration_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("block_duration_minutes")

    @builtins.property
    def cpu_core_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cpu_core_count")

    @builtins.property
    def cpu_threads_per_core(self) -> typing.Optional[jsii.Number]:
        return self._values.get("cpu_threads_per_core")

    @builtins.property
    def credit_specification(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestCreditSpecification"]]:
        """credit_specification block."""
        return self._values.get("credit_specification")

    @builtins.property
    def disable_api_termination(self) -> typing.Optional[bool]:
        return self._values.get("disable_api_termination")

    @builtins.property
    def ebs_block_device(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestEbsBlockDevice"]]:
        """ebs_block_device block."""
        return self._values.get("ebs_block_device")

    @builtins.property
    def ebs_optimized(self) -> typing.Optional[bool]:
        return self._values.get("ebs_optimized")

    @builtins.property
    def ephemeral_block_device(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestEphemeralBlockDevice"]]:
        """ephemeral_block_device block."""
        return self._values.get("ephemeral_block_device")

    @builtins.property
    def fetch_password_data(self) -> typing.Optional[bool]:
        return self._values.get("fetch_password_data")

    @builtins.property
    def hibernation(self) -> typing.Optional[bool]:
        return self._values.get("hibernation")

    @builtins.property
    def host_id(self) -> typing.Optional[str]:
        return self._values.get("host_id")

    @builtins.property
    def iam_instance_profile(self) -> typing.Optional[str]:
        return self._values.get("iam_instance_profile")

    @builtins.property
    def instance_initiated_shutdown_behavior(self) -> typing.Optional[str]:
        return self._values.get("instance_initiated_shutdown_behavior")

    @builtins.property
    def instance_interruption_behaviour(self) -> typing.Optional[str]:
        return self._values.get("instance_interruption_behaviour")

    @builtins.property
    def ipv6_address_count(self) -> typing.Optional[jsii.Number]:
        return self._values.get("ipv6_address_count")

    @builtins.property
    def ipv6_addresses(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ipv6_addresses")

    @builtins.property
    def key_name(self) -> typing.Optional[str]:
        return self._values.get("key_name")

    @builtins.property
    def launch_group(self) -> typing.Optional[str]:
        return self._values.get("launch_group")

    @builtins.property
    def metadata_options(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestMetadataOptions"]]:
        """metadata_options block."""
        return self._values.get("metadata_options")

    @builtins.property
    def monitoring(self) -> typing.Optional[bool]:
        return self._values.get("monitoring")

    @builtins.property
    def network_interface(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestNetworkInterface"]]:
        """network_interface block."""
        return self._values.get("network_interface")

    @builtins.property
    def placement_group(self) -> typing.Optional[str]:
        return self._values.get("placement_group")

    @builtins.property
    def private_ip(self) -> typing.Optional[str]:
        return self._values.get("private_ip")

    @builtins.property
    def root_block_device(
        self,
    ) -> typing.Optional[typing.List["SpotInstanceRequestRootBlockDevice"]]:
        """root_block_device block."""
        return self._values.get("root_block_device")

    @builtins.property
    def security_groups(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_groups")

    @builtins.property
    def source_dest_check(self) -> typing.Optional[bool]:
        return self._values.get("source_dest_check")

    @builtins.property
    def spot_price(self) -> typing.Optional[str]:
        return self._values.get("spot_price")

    @builtins.property
    def spot_type(self) -> typing.Optional[str]:
        return self._values.get("spot_type")

    @builtins.property
    def subnet_id(self) -> typing.Optional[str]:
        return self._values.get("subnet_id")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def tenancy(self) -> typing.Optional[str]:
        return self._values.get("tenancy")

    @builtins.property
    def timeouts(self) -> typing.Optional["SpotInstanceRequestTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def user_data(self) -> typing.Optional[str]:
        return self._values.get("user_data")

    @builtins.property
    def user_data_base64(self) -> typing.Optional[str]:
        return self._values.get("user_data_base64")

    @builtins.property
    def valid_from(self) -> typing.Optional[str]:
        return self._values.get("valid_from")

    @builtins.property
    def valid_until(self) -> typing.Optional[str]:
        return self._values.get("valid_until")

    @builtins.property
    def volume_tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("volume_tags")

    @builtins.property
    def vpc_security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("vpc_security_group_ids")

    @builtins.property
    def wait_for_fulfillment(self) -> typing.Optional[bool]:
        return self._values.get("wait_for_fulfillment")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestCreditSpecification",
    jsii_struct_bases=[],
    name_mapping={"cpu_credits": "cpuCredits"},
)
class SpotInstanceRequestCreditSpecification:
    def __init__(self, *, cpu_credits: typing.Optional[str] = None) -> None:
        """
        :param cpu_credits: 
        """
        self._values = {}
        if cpu_credits is not None:
            self._values["cpu_credits"] = cpu_credits

    @builtins.property
    def cpu_credits(self) -> typing.Optional[str]:
        return self._values.get("cpu_credits")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestCreditSpecification(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestEbsBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "snapshot_id": "snapshotId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class SpotInstanceRequestEbsBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        snapshot_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param snapshot_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {
            "device_name": device_name,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestEbsBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestEphemeralBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "device_name": "deviceName",
        "no_device": "noDevice",
        "virtual_name": "virtualName",
    },
)
class SpotInstanceRequestEphemeralBlockDevice:
    def __init__(
        self,
        *,
        device_name: str,
        no_device: typing.Optional[bool] = None,
        virtual_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param device_name: 
        :param no_device: 
        :param virtual_name: 
        """
        self._values = {
            "device_name": device_name,
        }
        if no_device is not None:
            self._values["no_device"] = no_device
        if virtual_name is not None:
            self._values["virtual_name"] = virtual_name

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def no_device(self) -> typing.Optional[bool]:
        return self._values.get("no_device")

    @builtins.property
    def virtual_name(self) -> typing.Optional[str]:
        return self._values.get("virtual_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestEphemeralBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestMetadataOptions",
    jsii_struct_bases=[],
    name_mapping={
        "http_endpoint": "httpEndpoint",
        "http_put_response_hop_limit": "httpPutResponseHopLimit",
        "http_tokens": "httpTokens",
    },
)
class SpotInstanceRequestMetadataOptions:
    def __init__(
        self,
        *,
        http_endpoint: typing.Optional[str] = None,
        http_put_response_hop_limit: typing.Optional[jsii.Number] = None,
        http_tokens: typing.Optional[str] = None,
    ) -> None:
        """
        :param http_endpoint: 
        :param http_put_response_hop_limit: 
        :param http_tokens: 
        """
        self._values = {}
        if http_endpoint is not None:
            self._values["http_endpoint"] = http_endpoint
        if http_put_response_hop_limit is not None:
            self._values["http_put_response_hop_limit"] = http_put_response_hop_limit
        if http_tokens is not None:
            self._values["http_tokens"] = http_tokens

    @builtins.property
    def http_endpoint(self) -> typing.Optional[str]:
        return self._values.get("http_endpoint")

    @builtins.property
    def http_put_response_hop_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("http_put_response_hop_limit")

    @builtins.property
    def http_tokens(self) -> typing.Optional[str]:
        return self._values.get("http_tokens")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestMetadataOptions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestNetworkInterface",
    jsii_struct_bases=[],
    name_mapping={
        "device_index": "deviceIndex",
        "network_interface_id": "networkInterfaceId",
        "delete_on_termination": "deleteOnTermination",
    },
)
class SpotInstanceRequestNetworkInterface:
    def __init__(
        self,
        *,
        device_index: jsii.Number,
        network_interface_id: str,
        delete_on_termination: typing.Optional[bool] = None,
    ) -> None:
        """
        :param device_index: 
        :param network_interface_id: 
        :param delete_on_termination: 
        """
        self._values = {
            "device_index": device_index,
            "network_interface_id": network_interface_id,
        }
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination

    @builtins.property
    def device_index(self) -> jsii.Number:
        return self._values.get("device_index")

    @builtins.property
    def network_interface_id(self) -> str:
        return self._values.get("network_interface_id")

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestNetworkInterface(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestRootBlockDevice",
    jsii_struct_bases=[],
    name_mapping={
        "delete_on_termination": "deleteOnTermination",
        "encrypted": "encrypted",
        "iops": "iops",
        "kms_key_id": "kmsKeyId",
        "volume_size": "volumeSize",
        "volume_type": "volumeType",
    },
)
class SpotInstanceRequestRootBlockDevice:
    def __init__(
        self,
        *,
        delete_on_termination: typing.Optional[bool] = None,
        encrypted: typing.Optional[bool] = None,
        iops: typing.Optional[jsii.Number] = None,
        kms_key_id: typing.Optional[str] = None,
        volume_size: typing.Optional[jsii.Number] = None,
        volume_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param delete_on_termination: 
        :param encrypted: 
        :param iops: 
        :param kms_key_id: 
        :param volume_size: 
        :param volume_type: 
        """
        self._values = {}
        if delete_on_termination is not None:
            self._values["delete_on_termination"] = delete_on_termination
        if encrypted is not None:
            self._values["encrypted"] = encrypted
        if iops is not None:
            self._values["iops"] = iops
        if kms_key_id is not None:
            self._values["kms_key_id"] = kms_key_id
        if volume_size is not None:
            self._values["volume_size"] = volume_size
        if volume_type is not None:
            self._values["volume_type"] = volume_type

    @builtins.property
    def delete_on_termination(self) -> typing.Optional[bool]:
        return self._values.get("delete_on_termination")

    @builtins.property
    def encrypted(self) -> typing.Optional[bool]:
        return self._values.get("encrypted")

    @builtins.property
    def iops(self) -> typing.Optional[jsii.Number]:
        return self._values.get("iops")

    @builtins.property
    def kms_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_key_id")

    @builtins.property
    def volume_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("volume_size")

    @builtins.property
    def volume_type(self) -> typing.Optional[str]:
        return self._values.get("volume_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestRootBlockDevice(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SpotInstanceRequestTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class SpotInstanceRequestTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SpotInstanceRequestTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqsQueue(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SqsQueue",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        content_based_deduplication: typing.Optional[bool] = None,
        delay_seconds: typing.Optional[jsii.Number] = None,
        fifo_queue: typing.Optional[bool] = None,
        kms_data_key_reuse_period_seconds: typing.Optional[jsii.Number] = None,
        kms_master_key_id: typing.Optional[str] = None,
        max_message_size: typing.Optional[jsii.Number] = None,
        message_retention_seconds: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        receive_wait_time_seconds: typing.Optional[jsii.Number] = None,
        redrive_policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        visibility_timeout_seconds: typing.Optional[jsii.Number] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param content_based_deduplication: 
        :param delay_seconds: 
        :param fifo_queue: 
        :param kms_data_key_reuse_period_seconds: 
        :param kms_master_key_id: 
        :param max_message_size: 
        :param message_retention_seconds: 
        :param name: 
        :param name_prefix: 
        :param policy: 
        :param receive_wait_time_seconds: 
        :param redrive_policy: 
        :param tags: 
        :param visibility_timeout_seconds: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqsQueueConfig(
            content_based_deduplication=content_based_deduplication,
            delay_seconds=delay_seconds,
            fifo_queue=fifo_queue,
            kms_data_key_reuse_period_seconds=kms_data_key_reuse_period_seconds,
            kms_master_key_id=kms_master_key_id,
            max_message_size=max_message_size,
            message_retention_seconds=message_retention_seconds,
            name=name,
            name_prefix=name_prefix,
            policy=policy,
            receive_wait_time_seconds=receive_wait_time_seconds,
            redrive_policy=redrive_policy,
            tags=tags,
            visibility_timeout_seconds=visibility_timeout_seconds,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqsQueue, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="contentBasedDeduplication")
    def content_based_deduplication(self) -> typing.Optional[bool]:
        return jsii.get(self, "contentBasedDeduplication")

    @content_based_deduplication.setter
    def content_based_deduplication(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "contentBasedDeduplication", value)

    @builtins.property
    @jsii.member(jsii_name="delaySeconds")
    def delay_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "delaySeconds")

    @delay_seconds.setter
    def delay_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "delaySeconds", value)

    @builtins.property
    @jsii.member(jsii_name="fifoQueue")
    def fifo_queue(self) -> typing.Optional[bool]:
        return jsii.get(self, "fifoQueue")

    @fifo_queue.setter
    def fifo_queue(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "fifoQueue", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsDataKeyReusePeriodSeconds")
    def kms_data_key_reuse_period_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "kmsDataKeyReusePeriodSeconds")

    @kms_data_key_reuse_period_seconds.setter
    def kms_data_key_reuse_period_seconds(
        self, value: typing.Optional[jsii.Number]
    ) -> None:
        jsii.set(self, "kmsDataKeyReusePeriodSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="kmsMasterKeyId")
    def kms_master_key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsMasterKeyId")

    @kms_master_key_id.setter
    def kms_master_key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsMasterKeyId", value)

    @builtins.property
    @jsii.member(jsii_name="maxMessageSize")
    def max_message_size(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "maxMessageSize")

    @max_message_size.setter
    def max_message_size(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "maxMessageSize", value)

    @builtins.property
    @jsii.member(jsii_name="messageRetentionSeconds")
    def message_retention_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "messageRetentionSeconds")

    @message_retention_seconds.setter
    def message_retention_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "messageRetentionSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="receiveWaitTimeSeconds")
    def receive_wait_time_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "receiveWaitTimeSeconds")

    @receive_wait_time_seconds.setter
    def receive_wait_time_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "receiveWaitTimeSeconds", value)

    @builtins.property
    @jsii.member(jsii_name="redrivePolicy")
    def redrive_policy(self) -> typing.Optional[str]:
        return jsii.get(self, "redrivePolicy")

    @redrive_policy.setter
    def redrive_policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "redrivePolicy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="visibilityTimeoutSeconds")
    def visibility_timeout_seconds(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "visibilityTimeoutSeconds")

    @visibility_timeout_seconds.setter
    def visibility_timeout_seconds(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "visibilityTimeoutSeconds", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SqsQueueConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "content_based_deduplication": "contentBasedDeduplication",
        "delay_seconds": "delaySeconds",
        "fifo_queue": "fifoQueue",
        "kms_data_key_reuse_period_seconds": "kmsDataKeyReusePeriodSeconds",
        "kms_master_key_id": "kmsMasterKeyId",
        "max_message_size": "maxMessageSize",
        "message_retention_seconds": "messageRetentionSeconds",
        "name": "name",
        "name_prefix": "namePrefix",
        "policy": "policy",
        "receive_wait_time_seconds": "receiveWaitTimeSeconds",
        "redrive_policy": "redrivePolicy",
        "tags": "tags",
        "visibility_timeout_seconds": "visibilityTimeoutSeconds",
    },
)
class SqsQueueConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        content_based_deduplication: typing.Optional[bool] = None,
        delay_seconds: typing.Optional[jsii.Number] = None,
        fifo_queue: typing.Optional[bool] = None,
        kms_data_key_reuse_period_seconds: typing.Optional[jsii.Number] = None,
        kms_master_key_id: typing.Optional[str] = None,
        max_message_size: typing.Optional[jsii.Number] = None,
        message_retention_seconds: typing.Optional[jsii.Number] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        receive_wait_time_seconds: typing.Optional[jsii.Number] = None,
        redrive_policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        visibility_timeout_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param content_based_deduplication: 
        :param delay_seconds: 
        :param fifo_queue: 
        :param kms_data_key_reuse_period_seconds: 
        :param kms_master_key_id: 
        :param max_message_size: 
        :param message_retention_seconds: 
        :param name: 
        :param name_prefix: 
        :param policy: 
        :param receive_wait_time_seconds: 
        :param redrive_policy: 
        :param tags: 
        :param visibility_timeout_seconds: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if content_based_deduplication is not None:
            self._values["content_based_deduplication"] = content_based_deduplication
        if delay_seconds is not None:
            self._values["delay_seconds"] = delay_seconds
        if fifo_queue is not None:
            self._values["fifo_queue"] = fifo_queue
        if kms_data_key_reuse_period_seconds is not None:
            self._values[
                "kms_data_key_reuse_period_seconds"
            ] = kms_data_key_reuse_period_seconds
        if kms_master_key_id is not None:
            self._values["kms_master_key_id"] = kms_master_key_id
        if max_message_size is not None:
            self._values["max_message_size"] = max_message_size
        if message_retention_seconds is not None:
            self._values["message_retention_seconds"] = message_retention_seconds
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if policy is not None:
            self._values["policy"] = policy
        if receive_wait_time_seconds is not None:
            self._values["receive_wait_time_seconds"] = receive_wait_time_seconds
        if redrive_policy is not None:
            self._values["redrive_policy"] = redrive_policy
        if tags is not None:
            self._values["tags"] = tags
        if visibility_timeout_seconds is not None:
            self._values["visibility_timeout_seconds"] = visibility_timeout_seconds

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def content_based_deduplication(self) -> typing.Optional[bool]:
        return self._values.get("content_based_deduplication")

    @builtins.property
    def delay_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("delay_seconds")

    @builtins.property
    def fifo_queue(self) -> typing.Optional[bool]:
        return self._values.get("fifo_queue")

    @builtins.property
    def kms_data_key_reuse_period_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("kms_data_key_reuse_period_seconds")

    @builtins.property
    def kms_master_key_id(self) -> typing.Optional[str]:
        return self._values.get("kms_master_key_id")

    @builtins.property
    def max_message_size(self) -> typing.Optional[jsii.Number]:
        return self._values.get("max_message_size")

    @builtins.property
    def message_retention_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("message_retention_seconds")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def receive_wait_time_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("receive_wait_time_seconds")

    @builtins.property
    def redrive_policy(self) -> typing.Optional[str]:
        return self._values.get("redrive_policy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def visibility_timeout_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("visibility_timeout_seconds")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqsQueueConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SqsQueuePolicy(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SqsQueuePolicy",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        policy: str,
        queue_url: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param policy: 
        :param queue_url: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SqsQueuePolicyConfig(
            policy=policy,
            queue_url=queue_url,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SqsQueuePolicy, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> str:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: str) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="queueUrl")
    def queue_url(self) -> str:
        return jsii.get(self, "queueUrl")

    @queue_url.setter
    def queue_url(self, value: str) -> None:
        jsii.set(self, "queueUrl", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SqsQueuePolicyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "policy": "policy",
        "queue_url": "queueUrl",
    },
)
class SqsQueuePolicyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        policy: str,
        queue_url: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param policy: 
        :param queue_url: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "policy": policy,
            "queue_url": queue_url,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def policy(self) -> str:
        return self._values.get("policy")

    @builtins.property
    def queue_url(self) -> str:
        return self._values.get("queue_url")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SqsQueuePolicyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmActivation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmActivation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        iam_role: str,
        description: typing.Optional[str] = None,
        expiration_date: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        registration_limit: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param iam_role: 
        :param description: 
        :param expiration_date: 
        :param name: 
        :param registration_limit: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmActivationConfig(
            iam_role=iam_role,
            description=description,
            expiration_date=expiration_date,
            name=name,
            registration_limit=registration_limit,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmActivation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="activationCode")
    def activation_code(self) -> str:
        return jsii.get(self, "activationCode")

    @builtins.property
    @jsii.member(jsii_name="expired")
    def expired(self) -> bool:
        return jsii.get(self, "expired")

    @builtins.property
    @jsii.member(jsii_name="registrationCount")
    def registration_count(self) -> jsii.Number:
        return jsii.get(self, "registrationCount")

    @builtins.property
    @jsii.member(jsii_name="iamRole")
    def iam_role(self) -> str:
        return jsii.get(self, "iamRole")

    @iam_role.setter
    def iam_role(self, value: str) -> None:
        jsii.set(self, "iamRole", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="expirationDate")
    def expiration_date(self) -> typing.Optional[str]:
        return jsii.get(self, "expirationDate")

    @expiration_date.setter
    def expiration_date(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "expirationDate", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="registrationLimit")
    def registration_limit(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "registrationLimit")

    @registration_limit.setter
    def registration_limit(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "registrationLimit", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmActivationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "iam_role": "iamRole",
        "description": "description",
        "expiration_date": "expirationDate",
        "name": "name",
        "registration_limit": "registrationLimit",
        "tags": "tags",
    },
)
class SsmActivationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        iam_role: str,
        description: typing.Optional[str] = None,
        expiration_date: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        registration_limit: typing.Optional[jsii.Number] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param iam_role: 
        :param description: 
        :param expiration_date: 
        :param name: 
        :param registration_limit: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "iam_role": iam_role,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if expiration_date is not None:
            self._values["expiration_date"] = expiration_date
        if name is not None:
            self._values["name"] = name
        if registration_limit is not None:
            self._values["registration_limit"] = registration_limit
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def iam_role(self) -> str:
        return self._values.get("iam_role")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def expiration_date(self) -> typing.Optional[str]:
        return self._values.get("expiration_date")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def registration_limit(self) -> typing.Optional[jsii.Number]:
        return self._values.get("registration_limit")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmActivationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        association_name: typing.Optional[str] = None,
        automation_target_parameter_name: typing.Optional[str] = None,
        compliance_severity: typing.Optional[str] = None,
        document_version: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        max_concurrency: typing.Optional[str] = None,
        max_errors: typing.Optional[str] = None,
        output_location: typing.Optional[
            typing.List["SsmAssociationOutputLocation"]
        ] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        schedule_expression: typing.Optional[str] = None,
        targets: typing.Optional[typing.List["SsmAssociationTargets"]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param association_name: 
        :param automation_target_parameter_name: 
        :param compliance_severity: 
        :param document_version: 
        :param instance_id: 
        :param max_concurrency: 
        :param max_errors: 
        :param output_location: output_location block.
        :param parameters: 
        :param schedule_expression: 
        :param targets: targets block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmAssociationConfig(
            name=name,
            association_name=association_name,
            automation_target_parameter_name=automation_target_parameter_name,
            compliance_severity=compliance_severity,
            document_version=document_version,
            instance_id=instance_id,
            max_concurrency=max_concurrency,
            max_errors=max_errors,
            output_location=output_location,
            parameters=parameters,
            schedule_expression=schedule_expression,
            targets=targets,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="associationId")
    def association_id(self) -> str:
        return jsii.get(self, "associationId")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="associationName")
    def association_name(self) -> typing.Optional[str]:
        return jsii.get(self, "associationName")

    @association_name.setter
    def association_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "associationName", value)

    @builtins.property
    @jsii.member(jsii_name="automationTargetParameterName")
    def automation_target_parameter_name(self) -> typing.Optional[str]:
        return jsii.get(self, "automationTargetParameterName")

    @automation_target_parameter_name.setter
    def automation_target_parameter_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "automationTargetParameterName", value)

    @builtins.property
    @jsii.member(jsii_name="complianceSeverity")
    def compliance_severity(self) -> typing.Optional[str]:
        return jsii.get(self, "complianceSeverity")

    @compliance_severity.setter
    def compliance_severity(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "complianceSeverity", value)

    @builtins.property
    @jsii.member(jsii_name="documentVersion")
    def document_version(self) -> typing.Optional[str]:
        return jsii.get(self, "documentVersion")

    @document_version.setter
    def document_version(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "documentVersion", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceId")

    @instance_id.setter
    def instance_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property
    @jsii.member(jsii_name="maxConcurrency")
    def max_concurrency(self) -> typing.Optional[str]:
        return jsii.get(self, "maxConcurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maxConcurrency", value)

    @builtins.property
    @jsii.member(jsii_name="maxErrors")
    def max_errors(self) -> typing.Optional[str]:
        return jsii.get(self, "maxErrors")

    @max_errors.setter
    def max_errors(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "maxErrors", value)

    @builtins.property
    @jsii.member(jsii_name="outputLocation")
    def output_location(
        self,
    ) -> typing.Optional[typing.List["SsmAssociationOutputLocation"]]:
        return jsii.get(self, "outputLocation")

    @output_location.setter
    def output_location(
        self, value: typing.Optional[typing.List["SsmAssociationOutputLocation"]]
    ) -> None:
        jsii.set(self, "outputLocation", value)

    @builtins.property
    @jsii.member(jsii_name="parameters")
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "parameters")

    @parameters.setter
    def parameters(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "parameters", value)

    @builtins.property
    @jsii.member(jsii_name="scheduleExpression")
    def schedule_expression(self) -> typing.Optional[str]:
        return jsii.get(self, "scheduleExpression")

    @schedule_expression.setter
    def schedule_expression(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "scheduleExpression", value)

    @builtins.property
    @jsii.member(jsii_name="targets")
    def targets(self) -> typing.Optional[typing.List["SsmAssociationTargets"]]:
        return jsii.get(self, "targets")

    @targets.setter
    def targets(
        self, value: typing.Optional[typing.List["SsmAssociationTargets"]]
    ) -> None:
        jsii.set(self, "targets", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "association_name": "associationName",
        "automation_target_parameter_name": "automationTargetParameterName",
        "compliance_severity": "complianceSeverity",
        "document_version": "documentVersion",
        "instance_id": "instanceId",
        "max_concurrency": "maxConcurrency",
        "max_errors": "maxErrors",
        "output_location": "outputLocation",
        "parameters": "parameters",
        "schedule_expression": "scheduleExpression",
        "targets": "targets",
    },
)
class SsmAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        association_name: typing.Optional[str] = None,
        automation_target_parameter_name: typing.Optional[str] = None,
        compliance_severity: typing.Optional[str] = None,
        document_version: typing.Optional[str] = None,
        instance_id: typing.Optional[str] = None,
        max_concurrency: typing.Optional[str] = None,
        max_errors: typing.Optional[str] = None,
        output_location: typing.Optional[
            typing.List["SsmAssociationOutputLocation"]
        ] = None,
        parameters: typing.Optional[typing.Mapping[str, str]] = None,
        schedule_expression: typing.Optional[str] = None,
        targets: typing.Optional[typing.List["SsmAssociationTargets"]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param association_name: 
        :param automation_target_parameter_name: 
        :param compliance_severity: 
        :param document_version: 
        :param instance_id: 
        :param max_concurrency: 
        :param max_errors: 
        :param output_location: output_location block.
        :param parameters: 
        :param schedule_expression: 
        :param targets: targets block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if association_name is not None:
            self._values["association_name"] = association_name
        if automation_target_parameter_name is not None:
            self._values[
                "automation_target_parameter_name"
            ] = automation_target_parameter_name
        if compliance_severity is not None:
            self._values["compliance_severity"] = compliance_severity
        if document_version is not None:
            self._values["document_version"] = document_version
        if instance_id is not None:
            self._values["instance_id"] = instance_id
        if max_concurrency is not None:
            self._values["max_concurrency"] = max_concurrency
        if max_errors is not None:
            self._values["max_errors"] = max_errors
        if output_location is not None:
            self._values["output_location"] = output_location
        if parameters is not None:
            self._values["parameters"] = parameters
        if schedule_expression is not None:
            self._values["schedule_expression"] = schedule_expression
        if targets is not None:
            self._values["targets"] = targets

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def association_name(self) -> typing.Optional[str]:
        return self._values.get("association_name")

    @builtins.property
    def automation_target_parameter_name(self) -> typing.Optional[str]:
        return self._values.get("automation_target_parameter_name")

    @builtins.property
    def compliance_severity(self) -> typing.Optional[str]:
        return self._values.get("compliance_severity")

    @builtins.property
    def document_version(self) -> typing.Optional[str]:
        return self._values.get("document_version")

    @builtins.property
    def instance_id(self) -> typing.Optional[str]:
        return self._values.get("instance_id")

    @builtins.property
    def max_concurrency(self) -> typing.Optional[str]:
        return self._values.get("max_concurrency")

    @builtins.property
    def max_errors(self) -> typing.Optional[str]:
        return self._values.get("max_errors")

    @builtins.property
    def output_location(
        self,
    ) -> typing.Optional[typing.List["SsmAssociationOutputLocation"]]:
        """output_location block."""
        return self._values.get("output_location")

    @builtins.property
    def parameters(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("parameters")

    @builtins.property
    def schedule_expression(self) -> typing.Optional[str]:
        return self._values.get("schedule_expression")

    @builtins.property
    def targets(self) -> typing.Optional[typing.List["SsmAssociationTargets"]]:
        """targets block."""
        return self._values.get("targets")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmAssociationOutputLocation",
    jsii_struct_bases=[],
    name_mapping={"s3_bucket_name": "s3BucketName", "s3_key_prefix": "s3KeyPrefix"},
)
class SsmAssociationOutputLocation:
    def __init__(
        self, *, s3_bucket_name: str, s3_key_prefix: typing.Optional[str] = None
    ) -> None:
        """
        :param s3_bucket_name: 
        :param s3_key_prefix: 
        """
        self._values = {
            "s3_bucket_name": s3_bucket_name,
        }
        if s3_key_prefix is not None:
            self._values["s3_key_prefix"] = s3_key_prefix

    @builtins.property
    def s3_bucket_name(self) -> str:
        return self._values.get("s3_bucket_name")

    @builtins.property
    def s3_key_prefix(self) -> typing.Optional[str]:
        return self._values.get("s3_key_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmAssociationOutputLocation(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmAssociationTargets",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "values": "values"},
)
class SsmAssociationTargets:
    def __init__(self, *, key: str, values: typing.List[str]) -> None:
        """
        :param key: 
        :param values: 
        """
        self._values = {
            "key": key,
            "values": values,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmAssociationTargets(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmDocument(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmDocument",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        content: str,
        document_type: str,
        name: str,
        attachments_source: typing.Optional[
            typing.List["SsmDocumentAttachmentsSource"]
        ] = None,
        document_format: typing.Optional[str] = None,
        permissions: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param content: 
        :param document_type: 
        :param name: 
        :param attachments_source: attachments_source block.
        :param document_format: 
        :param permissions: 
        :param tags: 
        :param target_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmDocumentConfig(
            content=content,
            document_type=document_type,
            name=name,
            attachments_source=attachments_source,
            document_format=document_format,
            permissions=permissions,
            tags=tags,
            target_type=target_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmDocument, self, [scope, id, config])

    @jsii.member(jsii_name="parameter")
    def parameter(self, index: str) -> "SsmDocumentParameter":
        """
        :param index: -
        """
        return jsii.invoke(self, "parameter", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="createdDate")
    def created_date(self) -> str:
        return jsii.get(self, "createdDate")

    @builtins.property
    @jsii.member(jsii_name="defaultVersion")
    def default_version(self) -> str:
        return jsii.get(self, "defaultVersion")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="documentVersion")
    def document_version(self) -> str:
        return jsii.get(self, "documentVersion")

    @builtins.property
    @jsii.member(jsii_name="hash")
    def hash(self) -> str:
        return jsii.get(self, "hash")

    @builtins.property
    @jsii.member(jsii_name="hashType")
    def hash_type(self) -> str:
        return jsii.get(self, "hashType")

    @builtins.property
    @jsii.member(jsii_name="latestVersion")
    def latest_version(self) -> str:
        return jsii.get(self, "latestVersion")

    @builtins.property
    @jsii.member(jsii_name="owner")
    def owner(self) -> str:
        return jsii.get(self, "owner")

    @builtins.property
    @jsii.member(jsii_name="platformTypes")
    def platform_types(self) -> typing.List[str]:
        return jsii.get(self, "platformTypes")

    @builtins.property
    @jsii.member(jsii_name="schemaVersion")
    def schema_version(self) -> str:
        return jsii.get(self, "schemaVersion")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="content")
    def content(self) -> str:
        return jsii.get(self, "content")

    @content.setter
    def content(self, value: str) -> None:
        jsii.set(self, "content", value)

    @builtins.property
    @jsii.member(jsii_name="documentType")
    def document_type(self) -> str:
        return jsii.get(self, "documentType")

    @document_type.setter
    def document_type(self, value: str) -> None:
        jsii.set(self, "documentType", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="attachmentsSource")
    def attachments_source(
        self,
    ) -> typing.Optional[typing.List["SsmDocumentAttachmentsSource"]]:
        return jsii.get(self, "attachmentsSource")

    @attachments_source.setter
    def attachments_source(
        self, value: typing.Optional[typing.List["SsmDocumentAttachmentsSource"]]
    ) -> None:
        jsii.set(self, "attachmentsSource", value)

    @builtins.property
    @jsii.member(jsii_name="documentFormat")
    def document_format(self) -> typing.Optional[str]:
        return jsii.get(self, "documentFormat")

    @document_format.setter
    def document_format(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "documentFormat", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="permissions")
    def permissions(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "permissions")

    @permissions.setter
    def permissions(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "permissions", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="targetType")
    def target_type(self) -> typing.Optional[str]:
        return jsii.get(self, "targetType")

    @target_type.setter
    def target_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "targetType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmDocumentAttachmentsSource",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "values": "values", "name": "name"},
)
class SsmDocumentAttachmentsSource:
    def __init__(
        self, *, key: str, values: typing.List[str], name: typing.Optional[str] = None
    ) -> None:
        """
        :param key: 
        :param values: 
        :param name: 
        """
        self._values = {
            "key": key,
            "values": values,
        }
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmDocumentAttachmentsSource(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmDocumentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "content": "content",
        "document_type": "documentType",
        "name": "name",
        "attachments_source": "attachmentsSource",
        "document_format": "documentFormat",
        "permissions": "permissions",
        "tags": "tags",
        "target_type": "targetType",
    },
)
class SsmDocumentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        content: str,
        document_type: str,
        name: str,
        attachments_source: typing.Optional[
            typing.List["SsmDocumentAttachmentsSource"]
        ] = None,
        document_format: typing.Optional[str] = None,
        permissions: typing.Optional[typing.Mapping[str, str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        target_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param content: 
        :param document_type: 
        :param name: 
        :param attachments_source: attachments_source block.
        :param document_format: 
        :param permissions: 
        :param tags: 
        :param target_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "content": content,
            "document_type": document_type,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attachments_source is not None:
            self._values["attachments_source"] = attachments_source
        if document_format is not None:
            self._values["document_format"] = document_format
        if permissions is not None:
            self._values["permissions"] = permissions
        if tags is not None:
            self._values["tags"] = tags
        if target_type is not None:
            self._values["target_type"] = target_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def content(self) -> str:
        return self._values.get("content")

    @builtins.property
    def document_type(self) -> str:
        return self._values.get("document_type")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def attachments_source(
        self,
    ) -> typing.Optional[typing.List["SsmDocumentAttachmentsSource"]]:
        """attachments_source block."""
        return self._values.get("attachments_source")

    @builtins.property
    def document_format(self) -> typing.Optional[str]:
        return self._values.get("document_format")

    @builtins.property
    def permissions(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("permissions")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def target_type(self) -> typing.Optional[str]:
        return self._values.get("target_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmDocumentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmDocumentParameter(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmDocumentParameter",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            SsmDocumentParameter, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="defaultValue")
    def default_value(self) -> str:
        return jsii.get(self, "defaultValue")

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> str:
        return jsii.get(self, "description")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")


class SsmMaintenanceWindow(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindow",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cutoff: jsii.Number,
        duration: jsii.Number,
        name: str,
        schedule: str,
        allow_unassociated_targets: typing.Optional[bool] = None,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        end_date: typing.Optional[str] = None,
        schedule_timezone: typing.Optional[str] = None,
        start_date: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cutoff: 
        :param duration: 
        :param name: 
        :param schedule: 
        :param allow_unassociated_targets: 
        :param description: 
        :param enabled: 
        :param end_date: 
        :param schedule_timezone: 
        :param start_date: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmMaintenanceWindowConfig(
            cutoff=cutoff,
            duration=duration,
            name=name,
            schedule=schedule,
            allow_unassociated_targets=allow_unassociated_targets,
            description=description,
            enabled=enabled,
            end_date=end_date,
            schedule_timezone=schedule_timezone,
            start_date=start_date,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmMaintenanceWindow, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cutoff")
    def cutoff(self) -> jsii.Number:
        return jsii.get(self, "cutoff")

    @cutoff.setter
    def cutoff(self, value: jsii.Number) -> None:
        jsii.set(self, "cutoff", value)

    @builtins.property
    @jsii.member(jsii_name="duration")
    def duration(self) -> jsii.Number:
        return jsii.get(self, "duration")

    @duration.setter
    def duration(self, value: jsii.Number) -> None:
        jsii.set(self, "duration", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="schedule")
    def schedule(self) -> str:
        return jsii.get(self, "schedule")

    @schedule.setter
    def schedule(self, value: str) -> None:
        jsii.set(self, "schedule", value)

    @builtins.property
    @jsii.member(jsii_name="allowUnassociatedTargets")
    def allow_unassociated_targets(self) -> typing.Optional[bool]:
        return jsii.get(self, "allowUnassociatedTargets")

    @allow_unassociated_targets.setter
    def allow_unassociated_targets(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "allowUnassociatedTargets", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="enabled")
    def enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "enabled")

    @enabled.setter
    def enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enabled", value)

    @builtins.property
    @jsii.member(jsii_name="endDate")
    def end_date(self) -> typing.Optional[str]:
        return jsii.get(self, "endDate")

    @end_date.setter
    def end_date(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endDate", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="scheduleTimezone")
    def schedule_timezone(self) -> typing.Optional[str]:
        return jsii.get(self, "scheduleTimezone")

    @schedule_timezone.setter
    def schedule_timezone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "scheduleTimezone", value)

    @builtins.property
    @jsii.member(jsii_name="startDate")
    def start_date(self) -> typing.Optional[str]:
        return jsii.get(self, "startDate")

    @start_date.setter
    def start_date(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "startDate", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cutoff": "cutoff",
        "duration": "duration",
        "name": "name",
        "schedule": "schedule",
        "allow_unassociated_targets": "allowUnassociatedTargets",
        "description": "description",
        "enabled": "enabled",
        "end_date": "endDate",
        "schedule_timezone": "scheduleTimezone",
        "start_date": "startDate",
        "tags": "tags",
    },
)
class SsmMaintenanceWindowConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cutoff: jsii.Number,
        duration: jsii.Number,
        name: str,
        schedule: str,
        allow_unassociated_targets: typing.Optional[bool] = None,
        description: typing.Optional[str] = None,
        enabled: typing.Optional[bool] = None,
        end_date: typing.Optional[str] = None,
        schedule_timezone: typing.Optional[str] = None,
        start_date: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cutoff: 
        :param duration: 
        :param name: 
        :param schedule: 
        :param allow_unassociated_targets: 
        :param description: 
        :param enabled: 
        :param end_date: 
        :param schedule_timezone: 
        :param start_date: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cutoff": cutoff,
            "duration": duration,
            "name": name,
            "schedule": schedule,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allow_unassociated_targets is not None:
            self._values["allow_unassociated_targets"] = allow_unassociated_targets
        if description is not None:
            self._values["description"] = description
        if enabled is not None:
            self._values["enabled"] = enabled
        if end_date is not None:
            self._values["end_date"] = end_date
        if schedule_timezone is not None:
            self._values["schedule_timezone"] = schedule_timezone
        if start_date is not None:
            self._values["start_date"] = start_date
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cutoff(self) -> jsii.Number:
        return self._values.get("cutoff")

    @builtins.property
    def duration(self) -> jsii.Number:
        return self._values.get("duration")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def schedule(self) -> str:
        return self._values.get("schedule")

    @builtins.property
    def allow_unassociated_targets(self) -> typing.Optional[bool]:
        return self._values.get("allow_unassociated_targets")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def enabled(self) -> typing.Optional[bool]:
        return self._values.get("enabled")

    @builtins.property
    def end_date(self) -> typing.Optional[str]:
        return self._values.get("end_date")

    @builtins.property
    def schedule_timezone(self) -> typing.Optional[str]:
        return self._values.get("schedule_timezone")

    @builtins.property
    def start_date(self) -> typing.Optional[str]:
        return self._values.get("start_date")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmMaintenanceWindowTarget(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTarget",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        resource_type: str,
        targets: typing.List["SsmMaintenanceWindowTargetTargets"],
        window_id: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        owner_information: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_type: 
        :param targets: targets block.
        :param window_id: 
        :param description: 
        :param name: 
        :param owner_information: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmMaintenanceWindowTargetConfig(
            resource_type=resource_type,
            targets=targets,
            window_id=window_id,
            description=description,
            name=name,
            owner_information=owner_information,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmMaintenanceWindowTarget, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resourceType")
    def resource_type(self) -> str:
        return jsii.get(self, "resourceType")

    @resource_type.setter
    def resource_type(self, value: str) -> None:
        jsii.set(self, "resourceType", value)

    @builtins.property
    @jsii.member(jsii_name="targets")
    def targets(self) -> typing.List["SsmMaintenanceWindowTargetTargets"]:
        return jsii.get(self, "targets")

    @targets.setter
    def targets(self, value: typing.List["SsmMaintenanceWindowTargetTargets"]) -> None:
        jsii.set(self, "targets", value)

    @builtins.property
    @jsii.member(jsii_name="windowId")
    def window_id(self) -> str:
        return jsii.get(self, "windowId")

    @window_id.setter
    def window_id(self, value: str) -> None:
        jsii.set(self, "windowId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="ownerInformation")
    def owner_information(self) -> typing.Optional[str]:
        return jsii.get(self, "ownerInformation")

    @owner_information.setter
    def owner_information(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ownerInformation", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTargetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_type": "resourceType",
        "targets": "targets",
        "window_id": "windowId",
        "description": "description",
        "name": "name",
        "owner_information": "ownerInformation",
    },
)
class SsmMaintenanceWindowTargetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_type: str,
        targets: typing.List["SsmMaintenanceWindowTargetTargets"],
        window_id: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        owner_information: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_type: 
        :param targets: targets block.
        :param window_id: 
        :param description: 
        :param name: 
        :param owner_information: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "resource_type": resource_type,
            "targets": targets,
            "window_id": window_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if owner_information is not None:
            self._values["owner_information"] = owner_information

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def resource_type(self) -> str:
        return self._values.get("resource_type")

    @builtins.property
    def targets(self) -> typing.List["SsmMaintenanceWindowTargetTargets"]:
        """targets block."""
        return self._values.get("targets")

    @builtins.property
    def window_id(self) -> str:
        return self._values.get("window_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def owner_information(self) -> typing.Optional[str]:
        return self._values.get("owner_information")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowTargetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTargetTargets",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "values": "values"},
)
class SsmMaintenanceWindowTargetTargets:
    def __init__(self, *, key: str, values: typing.List[str]) -> None:
        """
        :param key: 
        :param values: 
        """
        self._values = {
            "key": key,
            "values": values,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowTargetTargets(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmMaintenanceWindowTask(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTask",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        max_concurrency: str,
        max_errors: str,
        service_role_arn: str,
        targets: typing.List["SsmMaintenanceWindowTaskTargets"],
        task_arn: str,
        task_type: str,
        window_id: str,
        description: typing.Optional[str] = None,
        logging_info: typing.Optional[
            typing.List["SsmMaintenanceWindowTaskLoggingInfo"]
        ] = None,
        name: typing.Optional[str] = None,
        priority: typing.Optional[jsii.Number] = None,
        task_invocation_parameters: typing.Optional[
            typing.List["SsmMaintenanceWindowTaskTaskInvocationParameters"]
        ] = None,
        task_parameters: typing.Optional[
            typing.List["SsmMaintenanceWindowTaskTaskParameters"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param max_concurrency: 
        :param max_errors: 
        :param service_role_arn: 
        :param targets: targets block.
        :param task_arn: 
        :param task_type: 
        :param window_id: 
        :param description: 
        :param logging_info: logging_info block.
        :param name: 
        :param priority: 
        :param task_invocation_parameters: task_invocation_parameters block.
        :param task_parameters: task_parameters block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmMaintenanceWindowTaskConfig(
            max_concurrency=max_concurrency,
            max_errors=max_errors,
            service_role_arn=service_role_arn,
            targets=targets,
            task_arn=task_arn,
            task_type=task_type,
            window_id=window_id,
            description=description,
            logging_info=logging_info,
            name=name,
            priority=priority,
            task_invocation_parameters=task_invocation_parameters,
            task_parameters=task_parameters,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmMaintenanceWindowTask, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="maxConcurrency")
    def max_concurrency(self) -> str:
        return jsii.get(self, "maxConcurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: str) -> None:
        jsii.set(self, "maxConcurrency", value)

    @builtins.property
    @jsii.member(jsii_name="maxErrors")
    def max_errors(self) -> str:
        return jsii.get(self, "maxErrors")

    @max_errors.setter
    def max_errors(self, value: str) -> None:
        jsii.set(self, "maxErrors", value)

    @builtins.property
    @jsii.member(jsii_name="serviceRoleArn")
    def service_role_arn(self) -> str:
        return jsii.get(self, "serviceRoleArn")

    @service_role_arn.setter
    def service_role_arn(self, value: str) -> None:
        jsii.set(self, "serviceRoleArn", value)

    @builtins.property
    @jsii.member(jsii_name="targets")
    def targets(self) -> typing.List["SsmMaintenanceWindowTaskTargets"]:
        return jsii.get(self, "targets")

    @targets.setter
    def targets(self, value: typing.List["SsmMaintenanceWindowTaskTargets"]) -> None:
        jsii.set(self, "targets", value)

    @builtins.property
    @jsii.member(jsii_name="taskArn")
    def task_arn(self) -> str:
        return jsii.get(self, "taskArn")

    @task_arn.setter
    def task_arn(self, value: str) -> None:
        jsii.set(self, "taskArn", value)

    @builtins.property
    @jsii.member(jsii_name="taskType")
    def task_type(self) -> str:
        return jsii.get(self, "taskType")

    @task_type.setter
    def task_type(self, value: str) -> None:
        jsii.set(self, "taskType", value)

    @builtins.property
    @jsii.member(jsii_name="windowId")
    def window_id(self) -> str:
        return jsii.get(self, "windowId")

    @window_id.setter
    def window_id(self, value: str) -> None:
        jsii.set(self, "windowId", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="loggingInfo")
    def logging_info(
        self,
    ) -> typing.Optional[typing.List["SsmMaintenanceWindowTaskLoggingInfo"]]:
        return jsii.get(self, "loggingInfo")

    @logging_info.setter
    def logging_info(
        self, value: typing.Optional[typing.List["SsmMaintenanceWindowTaskLoggingInfo"]]
    ) -> None:
        jsii.set(self, "loggingInfo", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="priority")
    def priority(self) -> typing.Optional[jsii.Number]:
        return jsii.get(self, "priority")

    @priority.setter
    def priority(self, value: typing.Optional[jsii.Number]) -> None:
        jsii.set(self, "priority", value)

    @builtins.property
    @jsii.member(jsii_name="taskInvocationParameters")
    def task_invocation_parameters(
        self,
    ) -> typing.Optional[
        typing.List["SsmMaintenanceWindowTaskTaskInvocationParameters"]
    ]:
        return jsii.get(self, "taskInvocationParameters")

    @task_invocation_parameters.setter
    def task_invocation_parameters(
        self,
        value: typing.Optional[
            typing.List["SsmMaintenanceWindowTaskTaskInvocationParameters"]
        ],
    ) -> None:
        jsii.set(self, "taskInvocationParameters", value)

    @builtins.property
    @jsii.member(jsii_name="taskParameters")
    def task_parameters(
        self,
    ) -> typing.Optional[typing.List["SsmMaintenanceWindowTaskTaskParameters"]]:
        return jsii.get(self, "taskParameters")

    @task_parameters.setter
    def task_parameters(
        self,
        value: typing.Optional[typing.List["SsmMaintenanceWindowTaskTaskParameters"]],
    ) -> None:
        jsii.set(self, "taskParameters", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "max_concurrency": "maxConcurrency",
        "max_errors": "maxErrors",
        "service_role_arn": "serviceRoleArn",
        "targets": "targets",
        "task_arn": "taskArn",
        "task_type": "taskType",
        "window_id": "windowId",
        "description": "description",
        "logging_info": "loggingInfo",
        "name": "name",
        "priority": "priority",
        "task_invocation_parameters": "taskInvocationParameters",
        "task_parameters": "taskParameters",
    },
)
class SsmMaintenanceWindowTaskConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        max_concurrency: str,
        max_errors: str,
        service_role_arn: str,
        targets: typing.List["SsmMaintenanceWindowTaskTargets"],
        task_arn: str,
        task_type: str,
        window_id: str,
        description: typing.Optional[str] = None,
        logging_info: typing.Optional[
            typing.List["SsmMaintenanceWindowTaskLoggingInfo"]
        ] = None,
        name: typing.Optional[str] = None,
        priority: typing.Optional[jsii.Number] = None,
        task_invocation_parameters: typing.Optional[
            typing.List["SsmMaintenanceWindowTaskTaskInvocationParameters"]
        ] = None,
        task_parameters: typing.Optional[
            typing.List["SsmMaintenanceWindowTaskTaskParameters"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param max_concurrency: 
        :param max_errors: 
        :param service_role_arn: 
        :param targets: targets block.
        :param task_arn: 
        :param task_type: 
        :param window_id: 
        :param description: 
        :param logging_info: logging_info block.
        :param name: 
        :param priority: 
        :param task_invocation_parameters: task_invocation_parameters block.
        :param task_parameters: task_parameters block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "max_concurrency": max_concurrency,
            "max_errors": max_errors,
            "service_role_arn": service_role_arn,
            "targets": targets,
            "task_arn": task_arn,
            "task_type": task_type,
            "window_id": window_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if logging_info is not None:
            self._values["logging_info"] = logging_info
        if name is not None:
            self._values["name"] = name
        if priority is not None:
            self._values["priority"] = priority
        if task_invocation_parameters is not None:
            self._values["task_invocation_parameters"] = task_invocation_parameters
        if task_parameters is not None:
            self._values["task_parameters"] = task_parameters

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def max_concurrency(self) -> str:
        return self._values.get("max_concurrency")

    @builtins.property
    def max_errors(self) -> str:
        return self._values.get("max_errors")

    @builtins.property
    def service_role_arn(self) -> str:
        return self._values.get("service_role_arn")

    @builtins.property
    def targets(self) -> typing.List["SsmMaintenanceWindowTaskTargets"]:
        """targets block."""
        return self._values.get("targets")

    @builtins.property
    def task_arn(self) -> str:
        return self._values.get("task_arn")

    @builtins.property
    def task_type(self) -> str:
        return self._values.get("task_type")

    @builtins.property
    def window_id(self) -> str:
        return self._values.get("window_id")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def logging_info(
        self,
    ) -> typing.Optional[typing.List["SsmMaintenanceWindowTaskLoggingInfo"]]:
        """logging_info block."""
        return self._values.get("logging_info")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def priority(self) -> typing.Optional[jsii.Number]:
        return self._values.get("priority")

    @builtins.property
    def task_invocation_parameters(
        self,
    ) -> typing.Optional[
        typing.List["SsmMaintenanceWindowTaskTaskInvocationParameters"]
    ]:
        """task_invocation_parameters block."""
        return self._values.get("task_invocation_parameters")

    @builtins.property
    def task_parameters(
        self,
    ) -> typing.Optional[typing.List["SsmMaintenanceWindowTaskTaskParameters"]]:
        """task_parameters block."""
        return self._values.get("task_parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowTaskConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskLoggingInfo",
    jsii_struct_bases=[],
    name_mapping={
        "s3_bucket_name": "s3BucketName",
        "s3_region": "s3Region",
        "s3_bucket_prefix": "s3BucketPrefix",
    },
)
class SsmMaintenanceWindowTaskLoggingInfo:
    def __init__(
        self,
        *,
        s3_bucket_name: str,
        s3_region: str,
        s3_bucket_prefix: typing.Optional[str] = None,
    ) -> None:
        """
        :param s3_bucket_name: 
        :param s3_region: 
        :param s3_bucket_prefix: 
        """
        self._values = {
            "s3_bucket_name": s3_bucket_name,
            "s3_region": s3_region,
        }
        if s3_bucket_prefix is not None:
            self._values["s3_bucket_prefix"] = s3_bucket_prefix

    @builtins.property
    def s3_bucket_name(self) -> str:
        return self._values.get("s3_bucket_name")

    @builtins.property
    def s3_region(self) -> str:
        return self._values.get("s3_region")

    @builtins.property
    def s3_bucket_prefix(self) -> typing.Optional[str]:
        return self._values.get("s3_bucket_prefix")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowTaskLoggingInfo(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTargets",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "values": "values"},
)
class SsmMaintenanceWindowTaskTargets:
    def __init__(self, *, key: str, values: typing.List[str]) -> None:
        """
        :param key: 
        :param values: 
        """
        self._values = {
            "key": key,
            "values": values,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowTaskTargets(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParameters",
    jsii_struct_bases=[],
    name_mapping={
        "automation_parameters": "automationParameters",
        "lambda_parameters": "lambdaParameters",
        "run_command_parameters": "runCommandParameters",
        "step_functions_parameters": "stepFunctionsParameters",
    },
)
class SsmMaintenanceWindowTaskTaskInvocationParameters:
    def __init__(
        self,
        *,
        automation_parameters: typing.Optional[
            typing.List[
                "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters"
            ]
        ] = None,
        lambda_parameters: typing.Optional[
            typing.List[
                "SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters"
            ]
        ] = None,
        run_command_parameters: typing.Optional[
            typing.List[
                "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters"
            ]
        ] = None,
        step_functions_parameters: typing.Optional[
            typing.List[
                "SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters"
            ]
        ] = None,
    ) -> None:
        """
        :param automation_parameters: automation_parameters block.
        :param lambda_parameters: lambda_parameters block.
        :param run_command_parameters: run_command_parameters block.
        :param step_functions_parameters: step_functions_parameters block.
        """
        self._values = {}
        if automation_parameters is not None:
            self._values["automation_parameters"] = automation_parameters
        if lambda_parameters is not None:
            self._values["lambda_parameters"] = lambda_parameters
        if run_command_parameters is not None:
            self._values["run_command_parameters"] = run_command_parameters
        if step_functions_parameters is not None:
            self._values["step_functions_parameters"] = step_functions_parameters

    @builtins.property
    def automation_parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters"
        ]
    ]:
        """automation_parameters block."""
        return self._values.get("automation_parameters")

    @builtins.property
    def lambda_parameters(
        self,
    ) -> typing.Optional[
        typing.List["SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters"]
    ]:
        """lambda_parameters block."""
        return self._values.get("lambda_parameters")

    @builtins.property
    def run_command_parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters"
        ]
    ]:
        """run_command_parameters block."""
        return self._values.get("run_command_parameters")

    @builtins.property
    def step_functions_parameters(
        self,
    ) -> typing.Optional[
        typing.List[
            "SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters"
        ]
    ]:
        """step_functions_parameters block."""
        return self._values.get("step_functions_parameters")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowTaskTaskInvocationParameters(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters",
    jsii_struct_bases=[],
    name_mapping={"document_version": "documentVersion", "parameter": "parameter"},
)
class SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters:
    def __init__(
        self,
        *,
        document_version: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List[
                "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter"
            ]
        ] = None,
    ) -> None:
        """
        :param document_version: 
        :param parameter: parameter block.
        """
        self._values = {}
        if document_version is not None:
            self._values["document_version"] = document_version
        if parameter is not None:
            self._values["parameter"] = parameter

    @builtins.property
    def document_version(self) -> typing.Optional[str]:
        return self._values.get("document_version")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[
        typing.List[
            "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter"
        ]
    ]:
        """parameter block."""
        return self._values.get("parameter")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters",
    jsii_struct_bases=[],
    name_mapping={
        "client_context": "clientContext",
        "payload": "payload",
        "qualifier": "qualifier",
    },
)
class SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters:
    def __init__(
        self,
        *,
        client_context: typing.Optional[str] = None,
        payload: typing.Optional[str] = None,
        qualifier: typing.Optional[str] = None,
    ) -> None:
        """
        :param client_context: 
        :param payload: 
        :param qualifier: 
        """
        self._values = {}
        if client_context is not None:
            self._values["client_context"] = client_context
        if payload is not None:
            self._values["payload"] = payload
        if qualifier is not None:
            self._values["qualifier"] = qualifier

    @builtins.property
    def client_context(self) -> typing.Optional[str]:
        return self._values.get("client_context")

    @builtins.property
    def payload(self) -> typing.Optional[str]:
        return self._values.get("payload")

    @builtins.property
    def qualifier(self) -> typing.Optional[str]:
        return self._values.get("qualifier")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters",
    jsii_struct_bases=[],
    name_mapping={
        "comment": "comment",
        "document_hash": "documentHash",
        "document_hash_type": "documentHashType",
        "notification_config": "notificationConfig",
        "output_s3_bucket": "outputS3Bucket",
        "output_s3_key_prefix": "outputS3KeyPrefix",
        "parameter": "parameter",
        "service_role_arn": "serviceRoleArn",
        "timeout_seconds": "timeoutSeconds",
    },
)
class SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters:
    def __init__(
        self,
        *,
        comment: typing.Optional[str] = None,
        document_hash: typing.Optional[str] = None,
        document_hash_type: typing.Optional[str] = None,
        notification_config: typing.Optional[
            typing.List[
                "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig"
            ]
        ] = None,
        output_s3_bucket: typing.Optional[str] = None,
        output_s3_key_prefix: typing.Optional[str] = None,
        parameter: typing.Optional[
            typing.List[
                "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter"
            ]
        ] = None,
        service_role_arn: typing.Optional[str] = None,
        timeout_seconds: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param comment: 
        :param document_hash: 
        :param document_hash_type: 
        :param notification_config: notification_config block.
        :param output_s3_bucket: 
        :param output_s3_key_prefix: 
        :param parameter: parameter block.
        :param service_role_arn: 
        :param timeout_seconds: 
        """
        self._values = {}
        if comment is not None:
            self._values["comment"] = comment
        if document_hash is not None:
            self._values["document_hash"] = document_hash
        if document_hash_type is not None:
            self._values["document_hash_type"] = document_hash_type
        if notification_config is not None:
            self._values["notification_config"] = notification_config
        if output_s3_bucket is not None:
            self._values["output_s3_bucket"] = output_s3_bucket
        if output_s3_key_prefix is not None:
            self._values["output_s3_key_prefix"] = output_s3_key_prefix
        if parameter is not None:
            self._values["parameter"] = parameter
        if service_role_arn is not None:
            self._values["service_role_arn"] = service_role_arn
        if timeout_seconds is not None:
            self._values["timeout_seconds"] = timeout_seconds

    @builtins.property
    def comment(self) -> typing.Optional[str]:
        return self._values.get("comment")

    @builtins.property
    def document_hash(self) -> typing.Optional[str]:
        return self._values.get("document_hash")

    @builtins.property
    def document_hash_type(self) -> typing.Optional[str]:
        return self._values.get("document_hash_type")

    @builtins.property
    def notification_config(
        self,
    ) -> typing.Optional[
        typing.List[
            "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig"
        ]
    ]:
        """notification_config block."""
        return self._values.get("notification_config")

    @builtins.property
    def output_s3_bucket(self) -> typing.Optional[str]:
        return self._values.get("output_s3_bucket")

    @builtins.property
    def output_s3_key_prefix(self) -> typing.Optional[str]:
        return self._values.get("output_s3_key_prefix")

    @builtins.property
    def parameter(
        self,
    ) -> typing.Optional[
        typing.List[
            "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter"
        ]
    ]:
        """parameter block."""
        return self._values.get("parameter")

    @builtins.property
    def service_role_arn(self) -> typing.Optional[str]:
        return self._values.get("service_role_arn")

    @builtins.property
    def timeout_seconds(self) -> typing.Optional[jsii.Number]:
        return self._values.get("timeout_seconds")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig",
    jsii_struct_bases=[],
    name_mapping={
        "notification_arn": "notificationArn",
        "notification_events": "notificationEvents",
        "notification_type": "notificationType",
    },
)
class SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig:
    def __init__(
        self,
        *,
        notification_arn: typing.Optional[str] = None,
        notification_events: typing.Optional[typing.List[str]] = None,
        notification_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param notification_arn: 
        :param notification_events: 
        :param notification_type: 
        """
        self._values = {}
        if notification_arn is not None:
            self._values["notification_arn"] = notification_arn
        if notification_events is not None:
            self._values["notification_events"] = notification_events
        if notification_type is not None:
            self._values["notification_type"] = notification_type

    @builtins.property
    def notification_arn(self) -> typing.Optional[str]:
        return self._values.get("notification_arn")

    @builtins.property
    def notification_events(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("notification_events")

    @builtins.property
    def notification_type(self) -> typing.Optional[str]:
        return self._values.get("notification_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters",
    jsii_struct_bases=[],
    name_mapping={"input": "input", "name": "name"},
)
class SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters:
    def __init__(
        self, *, input: typing.Optional[str] = None, name: typing.Optional[str] = None
    ) -> None:
        """
        :param input: 
        :param name: 
        """
        self._values = {}
        if input is not None:
            self._values["input"] = input
        if name is not None:
            self._values["name"] = name

    @builtins.property
    def input(self) -> typing.Optional[str]:
        return self._values.get("input")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmMaintenanceWindowTaskTaskParameters",
    jsii_struct_bases=[],
    name_mapping={"name": "name", "values": "values"},
)
class SsmMaintenanceWindowTaskTaskParameters:
    def __init__(self, *, name: str, values: typing.List[str]) -> None:
        """
        :param name: 
        :param values: 
        """
        self._values = {
            "name": name,
            "values": values,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmMaintenanceWindowTaskTaskParameters(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmParameter(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmParameter",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        type: str,
        value: str,
        allowed_pattern: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        key_id: typing.Optional[str] = None,
        overwrite: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tier: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param type: 
        :param value: 
        :param allowed_pattern: 
        :param description: 
        :param key_id: 
        :param overwrite: 
        :param tags: 
        :param tier: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmParameterConfig(
            name=name,
            type=type,
            value=value,
            allowed_pattern=allowed_pattern,
            description=description,
            key_id=key_id,
            overwrite=overwrite,
            tags=tags,
            tier=tier,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmParameter, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> jsii.Number:
        return jsii.get(self, "version")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="value")
    def value(self) -> str:
        return jsii.get(self, "value")

    @value.setter
    def value(self, value: str) -> None:
        jsii.set(self, "value", value)

    @builtins.property
    @jsii.member(jsii_name="allowedPattern")
    def allowed_pattern(self) -> typing.Optional[str]:
        return jsii.get(self, "allowedPattern")

    @allowed_pattern.setter
    def allowed_pattern(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "allowedPattern", value)

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> typing.Optional[str]:
        return jsii.get(self, "arn")

    @arn.setter
    def arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "arn", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="keyId")
    def key_id(self) -> typing.Optional[str]:
        return jsii.get(self, "keyId")

    @key_id.setter
    def key_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "keyId", value)

    @builtins.property
    @jsii.member(jsii_name="overwrite")
    def overwrite(self) -> typing.Optional[bool]:
        return jsii.get(self, "overwrite")

    @overwrite.setter
    def overwrite(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "overwrite", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="tier")
    def tier(self) -> typing.Optional[str]:
        return jsii.get(self, "tier")

    @tier.setter
    def tier(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tier", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmParameterConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "type": "type",
        "value": "value",
        "allowed_pattern": "allowedPattern",
        "description": "description",
        "key_id": "keyId",
        "overwrite": "overwrite",
        "tags": "tags",
        "tier": "tier",
    },
)
class SsmParameterConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        type: str,
        value: str,
        allowed_pattern: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        key_id: typing.Optional[str] = None,
        overwrite: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tier: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param type: 
        :param value: 
        :param allowed_pattern: 
        :param description: 
        :param key_id: 
        :param overwrite: 
        :param tags: 
        :param tier: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "type": type,
            "value": value,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allowed_pattern is not None:
            self._values["allowed_pattern"] = allowed_pattern
        if description is not None:
            self._values["description"] = description
        if key_id is not None:
            self._values["key_id"] = key_id
        if overwrite is not None:
            self._values["overwrite"] = overwrite
        if tags is not None:
            self._values["tags"] = tags
        if tier is not None:
            self._values["tier"] = tier

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    @builtins.property
    def allowed_pattern(self) -> typing.Optional[str]:
        return self._values.get("allowed_pattern")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def key_id(self) -> typing.Optional[str]:
        return self._values.get("key_id")

    @builtins.property
    def overwrite(self) -> typing.Optional[bool]:
        return self._values.get("overwrite")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def tier(self) -> typing.Optional[str]:
        return self._values.get("tier")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmParameterConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmPatchBaseline(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmPatchBaseline",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        approval_rule: typing.Optional[
            typing.List["SsmPatchBaselineApprovalRule"]
        ] = None,
        approved_patches: typing.Optional[typing.List[str]] = None,
        approved_patches_compliance_level: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        global_filter: typing.Optional[
            typing.List["SsmPatchBaselineGlobalFilter"]
        ] = None,
        operating_system: typing.Optional[str] = None,
        rejected_patches: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param approval_rule: approval_rule block.
        :param approved_patches: 
        :param approved_patches_compliance_level: 
        :param description: 
        :param global_filter: global_filter block.
        :param operating_system: 
        :param rejected_patches: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmPatchBaselineConfig(
            name=name,
            approval_rule=approval_rule,
            approved_patches=approved_patches,
            approved_patches_compliance_level=approved_patches_compliance_level,
            description=description,
            global_filter=global_filter,
            operating_system=operating_system,
            rejected_patches=rejected_patches,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmPatchBaseline, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="approvalRule")
    def approval_rule(
        self,
    ) -> typing.Optional[typing.List["SsmPatchBaselineApprovalRule"]]:
        return jsii.get(self, "approvalRule")

    @approval_rule.setter
    def approval_rule(
        self, value: typing.Optional[typing.List["SsmPatchBaselineApprovalRule"]]
    ) -> None:
        jsii.set(self, "approvalRule", value)

    @builtins.property
    @jsii.member(jsii_name="approvedPatches")
    def approved_patches(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "approvedPatches")

    @approved_patches.setter
    def approved_patches(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "approvedPatches", value)

    @builtins.property
    @jsii.member(jsii_name="approvedPatchesComplianceLevel")
    def approved_patches_compliance_level(self) -> typing.Optional[str]:
        return jsii.get(self, "approvedPatchesComplianceLevel")

    @approved_patches_compliance_level.setter
    def approved_patches_compliance_level(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "approvedPatchesComplianceLevel", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="globalFilter")
    def global_filter(
        self,
    ) -> typing.Optional[typing.List["SsmPatchBaselineGlobalFilter"]]:
        return jsii.get(self, "globalFilter")

    @global_filter.setter
    def global_filter(
        self, value: typing.Optional[typing.List["SsmPatchBaselineGlobalFilter"]]
    ) -> None:
        jsii.set(self, "globalFilter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="operatingSystem")
    def operating_system(self) -> typing.Optional[str]:
        return jsii.get(self, "operatingSystem")

    @operating_system.setter
    def operating_system(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "operatingSystem", value)

    @builtins.property
    @jsii.member(jsii_name="rejectedPatches")
    def rejected_patches(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "rejectedPatches")

    @rejected_patches.setter
    def rejected_patches(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "rejectedPatches", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmPatchBaselineApprovalRule",
    jsii_struct_bases=[],
    name_mapping={
        "approve_after_days": "approveAfterDays",
        "patch_filter": "patchFilter",
        "compliance_level": "complianceLevel",
        "enable_non_security": "enableNonSecurity",
    },
)
class SsmPatchBaselineApprovalRule:
    def __init__(
        self,
        *,
        approve_after_days: jsii.Number,
        patch_filter: typing.List["SsmPatchBaselineApprovalRulePatchFilter"],
        compliance_level: typing.Optional[str] = None,
        enable_non_security: typing.Optional[bool] = None,
    ) -> None:
        """
        :param approve_after_days: 
        :param patch_filter: patch_filter block.
        :param compliance_level: 
        :param enable_non_security: 
        """
        self._values = {
            "approve_after_days": approve_after_days,
            "patch_filter": patch_filter,
        }
        if compliance_level is not None:
            self._values["compliance_level"] = compliance_level
        if enable_non_security is not None:
            self._values["enable_non_security"] = enable_non_security

    @builtins.property
    def approve_after_days(self) -> jsii.Number:
        return self._values.get("approve_after_days")

    @builtins.property
    def patch_filter(self) -> typing.List["SsmPatchBaselineApprovalRulePatchFilter"]:
        """patch_filter block."""
        return self._values.get("patch_filter")

    @builtins.property
    def compliance_level(self) -> typing.Optional[str]:
        return self._values.get("compliance_level")

    @builtins.property
    def enable_non_security(self) -> typing.Optional[bool]:
        return self._values.get("enable_non_security")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmPatchBaselineApprovalRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmPatchBaselineApprovalRulePatchFilter",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "values": "values"},
)
class SsmPatchBaselineApprovalRulePatchFilter:
    def __init__(self, *, key: str, values: typing.List[str]) -> None:
        """
        :param key: 
        :param values: 
        """
        self._values = {
            "key": key,
            "values": values,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmPatchBaselineApprovalRulePatchFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmPatchBaselineConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "approval_rule": "approvalRule",
        "approved_patches": "approvedPatches",
        "approved_patches_compliance_level": "approvedPatchesComplianceLevel",
        "description": "description",
        "global_filter": "globalFilter",
        "operating_system": "operatingSystem",
        "rejected_patches": "rejectedPatches",
        "tags": "tags",
    },
)
class SsmPatchBaselineConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        approval_rule: typing.Optional[
            typing.List["SsmPatchBaselineApprovalRule"]
        ] = None,
        approved_patches: typing.Optional[typing.List[str]] = None,
        approved_patches_compliance_level: typing.Optional[str] = None,
        description: typing.Optional[str] = None,
        global_filter: typing.Optional[
            typing.List["SsmPatchBaselineGlobalFilter"]
        ] = None,
        operating_system: typing.Optional[str] = None,
        rejected_patches: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param approval_rule: approval_rule block.
        :param approved_patches: 
        :param approved_patches_compliance_level: 
        :param description: 
        :param global_filter: global_filter block.
        :param operating_system: 
        :param rejected_patches: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if approval_rule is not None:
            self._values["approval_rule"] = approval_rule
        if approved_patches is not None:
            self._values["approved_patches"] = approved_patches
        if approved_patches_compliance_level is not None:
            self._values[
                "approved_patches_compliance_level"
            ] = approved_patches_compliance_level
        if description is not None:
            self._values["description"] = description
        if global_filter is not None:
            self._values["global_filter"] = global_filter
        if operating_system is not None:
            self._values["operating_system"] = operating_system
        if rejected_patches is not None:
            self._values["rejected_patches"] = rejected_patches
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def approval_rule(
        self,
    ) -> typing.Optional[typing.List["SsmPatchBaselineApprovalRule"]]:
        """approval_rule block."""
        return self._values.get("approval_rule")

    @builtins.property
    def approved_patches(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("approved_patches")

    @builtins.property
    def approved_patches_compliance_level(self) -> typing.Optional[str]:
        return self._values.get("approved_patches_compliance_level")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def global_filter(
        self,
    ) -> typing.Optional[typing.List["SsmPatchBaselineGlobalFilter"]]:
        """global_filter block."""
        return self._values.get("global_filter")

    @builtins.property
    def operating_system(self) -> typing.Optional[str]:
        return self._values.get("operating_system")

    @builtins.property
    def rejected_patches(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("rejected_patches")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmPatchBaselineConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmPatchBaselineGlobalFilter",
    jsii_struct_bases=[],
    name_mapping={"key": "key", "values": "values"},
)
class SsmPatchBaselineGlobalFilter:
    def __init__(self, *, key: str, values: typing.List[str]) -> None:
        """
        :param key: 
        :param values: 
        """
        self._values = {
            "key": key,
            "values": values,
        }

    @builtins.property
    def key(self) -> str:
        return self._values.get("key")

    @builtins.property
    def values(self) -> typing.List[str]:
        return self._values.get("values")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmPatchBaselineGlobalFilter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmPatchGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmPatchGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        baseline_id: str,
        patch_group: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param baseline_id: 
        :param patch_group: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmPatchGroupConfig(
            baseline_id=baseline_id,
            patch_group=patch_group,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmPatchGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="baselineId")
    def baseline_id(self) -> str:
        return jsii.get(self, "baselineId")

    @baseline_id.setter
    def baseline_id(self, value: str) -> None:
        jsii.set(self, "baselineId", value)

    @builtins.property
    @jsii.member(jsii_name="patchGroup")
    def patch_group(self) -> str:
        return jsii.get(self, "patchGroup")

    @patch_group.setter
    def patch_group(self, value: str) -> None:
        jsii.set(self, "patchGroup", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmPatchGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "baseline_id": "baselineId",
        "patch_group": "patchGroup",
    },
)
class SsmPatchGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        baseline_id: str,
        patch_group: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param baseline_id: 
        :param patch_group: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "baseline_id": baseline_id,
            "patch_group": patch_group,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def baseline_id(self) -> str:
        return self._values.get("baseline_id")

    @builtins.property
    def patch_group(self) -> str:
        return self._values.get("patch_group")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmPatchGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SsmResourceDataSync(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SsmResourceDataSync",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        s3_destination: typing.List["SsmResourceDataSyncS3Destination"],
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param s3_destination: s3_destination block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SsmResourceDataSyncConfig(
            name=name,
            s3_destination=s3_destination,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SsmResourceDataSync, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="s3Destination")
    def s3_destination(self) -> typing.List["SsmResourceDataSyncS3Destination"]:
        return jsii.get(self, "s3Destination")

    @s3_destination.setter
    def s3_destination(
        self, value: typing.List["SsmResourceDataSyncS3Destination"]
    ) -> None:
        jsii.set(self, "s3Destination", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmResourceDataSyncConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "s3_destination": "s3Destination",
    },
)
class SsmResourceDataSyncConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        s3_destination: typing.List["SsmResourceDataSyncS3Destination"],
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param s3_destination: s3_destination block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "s3_destination": s3_destination,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def s3_destination(self) -> typing.List["SsmResourceDataSyncS3Destination"]:
        """s3_destination block."""
        return self._values.get("s3_destination")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmResourceDataSyncConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SsmResourceDataSyncS3Destination",
    jsii_struct_bases=[],
    name_mapping={
        "bucket_name": "bucketName",
        "region": "region",
        "kms_key_arn": "kmsKeyArn",
        "prefix": "prefix",
        "sync_format": "syncFormat",
    },
)
class SsmResourceDataSyncS3Destination:
    def __init__(
        self,
        *,
        bucket_name: str,
        region: str,
        kms_key_arn: typing.Optional[str] = None,
        prefix: typing.Optional[str] = None,
        sync_format: typing.Optional[str] = None,
    ) -> None:
        """
        :param bucket_name: 
        :param region: 
        :param kms_key_arn: 
        :param prefix: 
        :param sync_format: 
        """
        self._values = {
            "bucket_name": bucket_name,
            "region": region,
        }
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if prefix is not None:
            self._values["prefix"] = prefix
        if sync_format is not None:
            self._values["sync_format"] = sync_format

    @builtins.property
    def bucket_name(self) -> str:
        return self._values.get("bucket_name")

    @builtins.property
    def region(self) -> str:
        return self._values.get("region")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def prefix(self) -> typing.Optional[str]:
        return self._values.get("prefix")

    @builtins.property
    def sync_format(self) -> typing.Optional[str]:
        return self._values.get("sync_format")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SsmResourceDataSyncS3Destination(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StoragegatewayCache(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayCache",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        disk_id: str,
        gateway_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param disk_id: 
        :param gateway_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StoragegatewayCacheConfig(
            disk_id=disk_id,
            gateway_arn=gateway_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StoragegatewayCache, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> str:
        return jsii.get(self, "diskId")

    @disk_id.setter
    def disk_id(self, value: str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayArn")
    def gateway_arn(self) -> str:
        return jsii.get(self, "gatewayArn")

    @gateway_arn.setter
    def gateway_arn(self, value: str) -> None:
        jsii.set(self, "gatewayArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayCacheConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "disk_id": "diskId",
        "gateway_arn": "gatewayArn",
    },
)
class StoragegatewayCacheConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        disk_id: str,
        gateway_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param disk_id: 
        :param gateway_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "disk_id": disk_id,
            "gateway_arn": gateway_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def disk_id(self) -> str:
        return self._values.get("disk_id")

    @builtins.property
    def gateway_arn(self) -> str:
        return self._values.get("gateway_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayCacheConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StoragegatewayCachedIscsiVolume(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayCachedIscsiVolume",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        gateway_arn: str,
        network_interface_id: str,
        target_name: str,
        volume_size_in_bytes: jsii.Number,
        snapshot_id: typing.Optional[str] = None,
        source_volume_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gateway_arn: 
        :param network_interface_id: 
        :param target_name: 
        :param volume_size_in_bytes: 
        :param snapshot_id: 
        :param source_volume_arn: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StoragegatewayCachedIscsiVolumeConfig(
            gateway_arn=gateway_arn,
            network_interface_id=network_interface_id,
            target_name=target_name,
            volume_size_in_bytes=volume_size_in_bytes,
            snapshot_id=snapshot_id,
            source_volume_arn=source_volume_arn,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StoragegatewayCachedIscsiVolume, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="chapEnabled")
    def chap_enabled(self) -> bool:
        return jsii.get(self, "chapEnabled")

    @builtins.property
    @jsii.member(jsii_name="lunNumber")
    def lun_number(self) -> jsii.Number:
        return jsii.get(self, "lunNumber")

    @builtins.property
    @jsii.member(jsii_name="networkInterfacePort")
    def network_interface_port(self) -> jsii.Number:
        return jsii.get(self, "networkInterfacePort")

    @builtins.property
    @jsii.member(jsii_name="targetArn")
    def target_arn(self) -> str:
        return jsii.get(self, "targetArn")

    @builtins.property
    @jsii.member(jsii_name="volumeArn")
    def volume_arn(self) -> str:
        return jsii.get(self, "volumeArn")

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @builtins.property
    @jsii.member(jsii_name="gatewayArn")
    def gateway_arn(self) -> str:
        return jsii.get(self, "gatewayArn")

    @gateway_arn.setter
    def gateway_arn(self, value: str) -> None:
        jsii.set(self, "gatewayArn", value)

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceId")
    def network_interface_id(self) -> str:
        return jsii.get(self, "networkInterfaceId")

    @network_interface_id.setter
    def network_interface_id(self, value: str) -> None:
        jsii.set(self, "networkInterfaceId", value)

    @builtins.property
    @jsii.member(jsii_name="targetName")
    def target_name(self) -> str:
        return jsii.get(self, "targetName")

    @target_name.setter
    def target_name(self, value: str) -> None:
        jsii.set(self, "targetName", value)

    @builtins.property
    @jsii.member(jsii_name="volumeSizeInBytes")
    def volume_size_in_bytes(self) -> jsii.Number:
        return jsii.get(self, "volumeSizeInBytes")

    @volume_size_in_bytes.setter
    def volume_size_in_bytes(self, value: jsii.Number) -> None:
        jsii.set(self, "volumeSizeInBytes", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="snapshotId")
    def snapshot_id(self) -> typing.Optional[str]:
        return jsii.get(self, "snapshotId")

    @snapshot_id.setter
    def snapshot_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "snapshotId", value)

    @builtins.property
    @jsii.member(jsii_name="sourceVolumeArn")
    def source_volume_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "sourceVolumeArn")

    @source_volume_arn.setter
    def source_volume_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "sourceVolumeArn", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayCachedIscsiVolumeConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gateway_arn": "gatewayArn",
        "network_interface_id": "networkInterfaceId",
        "target_name": "targetName",
        "volume_size_in_bytes": "volumeSizeInBytes",
        "snapshot_id": "snapshotId",
        "source_volume_arn": "sourceVolumeArn",
        "tags": "tags",
    },
)
class StoragegatewayCachedIscsiVolumeConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gateway_arn: str,
        network_interface_id: str,
        target_name: str,
        volume_size_in_bytes: jsii.Number,
        snapshot_id: typing.Optional[str] = None,
        source_volume_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gateway_arn: 
        :param network_interface_id: 
        :param target_name: 
        :param volume_size_in_bytes: 
        :param snapshot_id: 
        :param source_volume_arn: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "gateway_arn": gateway_arn,
            "network_interface_id": network_interface_id,
            "target_name": target_name,
            "volume_size_in_bytes": volume_size_in_bytes,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if snapshot_id is not None:
            self._values["snapshot_id"] = snapshot_id
        if source_volume_arn is not None:
            self._values["source_volume_arn"] = source_volume_arn
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def gateway_arn(self) -> str:
        return self._values.get("gateway_arn")

    @builtins.property
    def network_interface_id(self) -> str:
        return self._values.get("network_interface_id")

    @builtins.property
    def target_name(self) -> str:
        return self._values.get("target_name")

    @builtins.property
    def volume_size_in_bytes(self) -> jsii.Number:
        return self._values.get("volume_size_in_bytes")

    @builtins.property
    def snapshot_id(self) -> typing.Optional[str]:
        return self._values.get("snapshot_id")

    @builtins.property
    def source_volume_arn(self) -> typing.Optional[str]:
        return self._values.get("source_volume_arn")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayCachedIscsiVolumeConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StoragegatewayGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        gateway_name: str,
        gateway_timezone: str,
        activation_key: typing.Optional[str] = None,
        cloudwatch_log_group_arn: typing.Optional[str] = None,
        gateway_ip_address: typing.Optional[str] = None,
        gateway_type: typing.Optional[str] = None,
        gateway_vpc_endpoint: typing.Optional[str] = None,
        medium_changer_type: typing.Optional[str] = None,
        smb_active_directory_settings: typing.Optional[
            typing.List["StoragegatewayGatewaySmbActiveDirectorySettings"]
        ] = None,
        smb_guest_password: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tape_drive_type: typing.Optional[str] = None,
        timeouts: typing.Optional["StoragegatewayGatewayTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gateway_name: 
        :param gateway_timezone: 
        :param activation_key: 
        :param cloudwatch_log_group_arn: 
        :param gateway_ip_address: 
        :param gateway_type: 
        :param gateway_vpc_endpoint: 
        :param medium_changer_type: 
        :param smb_active_directory_settings: smb_active_directory_settings block.
        :param smb_guest_password: 
        :param tags: 
        :param tape_drive_type: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StoragegatewayGatewayConfig(
            gateway_name=gateway_name,
            gateway_timezone=gateway_timezone,
            activation_key=activation_key,
            cloudwatch_log_group_arn=cloudwatch_log_group_arn,
            gateway_ip_address=gateway_ip_address,
            gateway_type=gateway_type,
            gateway_vpc_endpoint=gateway_vpc_endpoint,
            medium_changer_type=medium_changer_type,
            smb_active_directory_settings=smb_active_directory_settings,
            smb_guest_password=smb_guest_password,
            tags=tags,
            tape_drive_type=tape_drive_type,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StoragegatewayGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="gatewayId")
    def gateway_id(self) -> str:
        return jsii.get(self, "gatewayId")

    @builtins.property
    @jsii.member(jsii_name="gatewayName")
    def gateway_name(self) -> str:
        return jsii.get(self, "gatewayName")

    @gateway_name.setter
    def gateway_name(self, value: str) -> None:
        jsii.set(self, "gatewayName", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayTimezone")
    def gateway_timezone(self) -> str:
        return jsii.get(self, "gatewayTimezone")

    @gateway_timezone.setter
    def gateway_timezone(self, value: str) -> None:
        jsii.set(self, "gatewayTimezone", value)

    @builtins.property
    @jsii.member(jsii_name="activationKey")
    def activation_key(self) -> typing.Optional[str]:
        return jsii.get(self, "activationKey")

    @activation_key.setter
    def activation_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "activationKey", value)

    @builtins.property
    @jsii.member(jsii_name="cloudwatchLogGroupArn")
    def cloudwatch_log_group_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "cloudwatchLogGroupArn")

    @cloudwatch_log_group_arn.setter
    def cloudwatch_log_group_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "cloudwatchLogGroupArn", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayIpAddress")
    def gateway_ip_address(self) -> typing.Optional[str]:
        return jsii.get(self, "gatewayIpAddress")

    @gateway_ip_address.setter
    def gateway_ip_address(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "gatewayIpAddress", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayType")
    def gateway_type(self) -> typing.Optional[str]:
        return jsii.get(self, "gatewayType")

    @gateway_type.setter
    def gateway_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "gatewayType", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayVpcEndpoint")
    def gateway_vpc_endpoint(self) -> typing.Optional[str]:
        return jsii.get(self, "gatewayVpcEndpoint")

    @gateway_vpc_endpoint.setter
    def gateway_vpc_endpoint(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "gatewayVpcEndpoint", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="mediumChangerType")
    def medium_changer_type(self) -> typing.Optional[str]:
        return jsii.get(self, "mediumChangerType")

    @medium_changer_type.setter
    def medium_changer_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "mediumChangerType", value)

    @builtins.property
    @jsii.member(jsii_name="smbActiveDirectorySettings")
    def smb_active_directory_settings(
        self,
    ) -> typing.Optional[
        typing.List["StoragegatewayGatewaySmbActiveDirectorySettings"]
    ]:
        return jsii.get(self, "smbActiveDirectorySettings")

    @smb_active_directory_settings.setter
    def smb_active_directory_settings(
        self,
        value: typing.Optional[
            typing.List["StoragegatewayGatewaySmbActiveDirectorySettings"]
        ],
    ) -> None:
        jsii.set(self, "smbActiveDirectorySettings", value)

    @builtins.property
    @jsii.member(jsii_name="smbGuestPassword")
    def smb_guest_password(self) -> typing.Optional[str]:
        return jsii.get(self, "smbGuestPassword")

    @smb_guest_password.setter
    def smb_guest_password(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "smbGuestPassword", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="tapeDriveType")
    def tape_drive_type(self) -> typing.Optional[str]:
        return jsii.get(self, "tapeDriveType")

    @tape_drive_type.setter
    def tape_drive_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tapeDriveType", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StoragegatewayGatewayTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["StoragegatewayGatewayTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gateway_name": "gatewayName",
        "gateway_timezone": "gatewayTimezone",
        "activation_key": "activationKey",
        "cloudwatch_log_group_arn": "cloudwatchLogGroupArn",
        "gateway_ip_address": "gatewayIpAddress",
        "gateway_type": "gatewayType",
        "gateway_vpc_endpoint": "gatewayVpcEndpoint",
        "medium_changer_type": "mediumChangerType",
        "smb_active_directory_settings": "smbActiveDirectorySettings",
        "smb_guest_password": "smbGuestPassword",
        "tags": "tags",
        "tape_drive_type": "tapeDriveType",
        "timeouts": "timeouts",
    },
)
class StoragegatewayGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gateway_name: str,
        gateway_timezone: str,
        activation_key: typing.Optional[str] = None,
        cloudwatch_log_group_arn: typing.Optional[str] = None,
        gateway_ip_address: typing.Optional[str] = None,
        gateway_type: typing.Optional[str] = None,
        gateway_vpc_endpoint: typing.Optional[str] = None,
        medium_changer_type: typing.Optional[str] = None,
        smb_active_directory_settings: typing.Optional[
            typing.List["StoragegatewayGatewaySmbActiveDirectorySettings"]
        ] = None,
        smb_guest_password: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        tape_drive_type: typing.Optional[str] = None,
        timeouts: typing.Optional["StoragegatewayGatewayTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gateway_name: 
        :param gateway_timezone: 
        :param activation_key: 
        :param cloudwatch_log_group_arn: 
        :param gateway_ip_address: 
        :param gateway_type: 
        :param gateway_vpc_endpoint: 
        :param medium_changer_type: 
        :param smb_active_directory_settings: smb_active_directory_settings block.
        :param smb_guest_password: 
        :param tags: 
        :param tape_drive_type: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StoragegatewayGatewayTimeouts(**timeouts)
        self._values = {
            "gateway_name": gateway_name,
            "gateway_timezone": gateway_timezone,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if activation_key is not None:
            self._values["activation_key"] = activation_key
        if cloudwatch_log_group_arn is not None:
            self._values["cloudwatch_log_group_arn"] = cloudwatch_log_group_arn
        if gateway_ip_address is not None:
            self._values["gateway_ip_address"] = gateway_ip_address
        if gateway_type is not None:
            self._values["gateway_type"] = gateway_type
        if gateway_vpc_endpoint is not None:
            self._values["gateway_vpc_endpoint"] = gateway_vpc_endpoint
        if medium_changer_type is not None:
            self._values["medium_changer_type"] = medium_changer_type
        if smb_active_directory_settings is not None:
            self._values[
                "smb_active_directory_settings"
            ] = smb_active_directory_settings
        if smb_guest_password is not None:
            self._values["smb_guest_password"] = smb_guest_password
        if tags is not None:
            self._values["tags"] = tags
        if tape_drive_type is not None:
            self._values["tape_drive_type"] = tape_drive_type
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def gateway_name(self) -> str:
        return self._values.get("gateway_name")

    @builtins.property
    def gateway_timezone(self) -> str:
        return self._values.get("gateway_timezone")

    @builtins.property
    def activation_key(self) -> typing.Optional[str]:
        return self._values.get("activation_key")

    @builtins.property
    def cloudwatch_log_group_arn(self) -> typing.Optional[str]:
        return self._values.get("cloudwatch_log_group_arn")

    @builtins.property
    def gateway_ip_address(self) -> typing.Optional[str]:
        return self._values.get("gateway_ip_address")

    @builtins.property
    def gateway_type(self) -> typing.Optional[str]:
        return self._values.get("gateway_type")

    @builtins.property
    def gateway_vpc_endpoint(self) -> typing.Optional[str]:
        return self._values.get("gateway_vpc_endpoint")

    @builtins.property
    def medium_changer_type(self) -> typing.Optional[str]:
        return self._values.get("medium_changer_type")

    @builtins.property
    def smb_active_directory_settings(
        self,
    ) -> typing.Optional[
        typing.List["StoragegatewayGatewaySmbActiveDirectorySettings"]
    ]:
        """smb_active_directory_settings block."""
        return self._values.get("smb_active_directory_settings")

    @builtins.property
    def smb_guest_password(self) -> typing.Optional[str]:
        return self._values.get("smb_guest_password")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def tape_drive_type(self) -> typing.Optional[str]:
        return self._values.get("tape_drive_type")

    @builtins.property
    def timeouts(self) -> typing.Optional["StoragegatewayGatewayTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayGatewaySmbActiveDirectorySettings",
    jsii_struct_bases=[],
    name_mapping={
        "domain_name": "domainName",
        "password": "password",
        "username": "username",
    },
)
class StoragegatewayGatewaySmbActiveDirectorySettings:
    def __init__(self, *, domain_name: str, password: str, username: str) -> None:
        """
        :param domain_name: 
        :param password: 
        :param username: 
        """
        self._values = {
            "domain_name": domain_name,
            "password": password,
            "username": username,
        }

    @builtins.property
    def domain_name(self) -> str:
        return self._values.get("domain_name")

    @builtins.property
    def password(self) -> str:
        return self._values.get("password")

    @builtins.property
    def username(self) -> str:
        return self._values.get("username")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayGatewaySmbActiveDirectorySettings(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayGatewayTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create"},
)
class StoragegatewayGatewayTimeouts:
    def __init__(self, *, create: typing.Optional[str] = None) -> None:
        """
        :param create: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayGatewayTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StoragegatewayNfsFileShare(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayNfsFileShare",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        client_list: typing.List[str],
        gateway_arn: str,
        location_arn: str,
        role_arn: str,
        default_storage_class: typing.Optional[str] = None,
        guess_mime_type_enabled: typing.Optional[bool] = None,
        kms_encrypted: typing.Optional[bool] = None,
        kms_key_arn: typing.Optional[str] = None,
        nfs_file_share_defaults: typing.Optional[
            typing.List["StoragegatewayNfsFileShareNfsFileShareDefaults"]
        ] = None,
        object_acl: typing.Optional[str] = None,
        read_only: typing.Optional[bool] = None,
        requester_pays: typing.Optional[bool] = None,
        squash: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["StoragegatewayNfsFileShareTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param client_list: 
        :param gateway_arn: 
        :param location_arn: 
        :param role_arn: 
        :param default_storage_class: 
        :param guess_mime_type_enabled: 
        :param kms_encrypted: 
        :param kms_key_arn: 
        :param nfs_file_share_defaults: nfs_file_share_defaults block.
        :param object_acl: 
        :param read_only: 
        :param requester_pays: 
        :param squash: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StoragegatewayNfsFileShareConfig(
            client_list=client_list,
            gateway_arn=gateway_arn,
            location_arn=location_arn,
            role_arn=role_arn,
            default_storage_class=default_storage_class,
            guess_mime_type_enabled=guess_mime_type_enabled,
            kms_encrypted=kms_encrypted,
            kms_key_arn=kms_key_arn,
            nfs_file_share_defaults=nfs_file_share_defaults,
            object_acl=object_acl,
            read_only=read_only,
            requester_pays=requester_pays,
            squash=squash,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StoragegatewayNfsFileShare, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="fileshareId")
    def fileshare_id(self) -> str:
        return jsii.get(self, "fileshareId")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="clientList")
    def client_list(self) -> typing.List[str]:
        return jsii.get(self, "clientList")

    @client_list.setter
    def client_list(self, value: typing.List[str]) -> None:
        jsii.set(self, "clientList", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayArn")
    def gateway_arn(self) -> str:
        return jsii.get(self, "gatewayArn")

    @gateway_arn.setter
    def gateway_arn(self, value: str) -> None:
        jsii.set(self, "gatewayArn", value)

    @builtins.property
    @jsii.member(jsii_name="locationArn")
    def location_arn(self) -> str:
        return jsii.get(self, "locationArn")

    @location_arn.setter
    def location_arn(self, value: str) -> None:
        jsii.set(self, "locationArn", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="defaultStorageClass")
    def default_storage_class(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultStorageClass")

    @default_storage_class.setter
    def default_storage_class(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultStorageClass", value)

    @builtins.property
    @jsii.member(jsii_name="guessMimeTypeEnabled")
    def guess_mime_type_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "guessMimeTypeEnabled")

    @guess_mime_type_enabled.setter
    def guess_mime_type_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "guessMimeTypeEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="kmsEncrypted")
    def kms_encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "kmsEncrypted")

    @kms_encrypted.setter
    def kms_encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "kmsEncrypted", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="nfsFileShareDefaults")
    def nfs_file_share_defaults(
        self,
    ) -> typing.Optional[typing.List["StoragegatewayNfsFileShareNfsFileShareDefaults"]]:
        return jsii.get(self, "nfsFileShareDefaults")

    @nfs_file_share_defaults.setter
    def nfs_file_share_defaults(
        self,
        value: typing.Optional[
            typing.List["StoragegatewayNfsFileShareNfsFileShareDefaults"]
        ],
    ) -> None:
        jsii.set(self, "nfsFileShareDefaults", value)

    @builtins.property
    @jsii.member(jsii_name="objectAcl")
    def object_acl(self) -> typing.Optional[str]:
        return jsii.get(self, "objectAcl")

    @object_acl.setter
    def object_acl(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "objectAcl", value)

    @builtins.property
    @jsii.member(jsii_name="readOnly")
    def read_only(self) -> typing.Optional[bool]:
        return jsii.get(self, "readOnly")

    @read_only.setter
    def read_only(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "readOnly", value)

    @builtins.property
    @jsii.member(jsii_name="requesterPays")
    def requester_pays(self) -> typing.Optional[bool]:
        return jsii.get(self, "requesterPays")

    @requester_pays.setter
    def requester_pays(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "requesterPays", value)

    @builtins.property
    @jsii.member(jsii_name="squash")
    def squash(self) -> typing.Optional[str]:
        return jsii.get(self, "squash")

    @squash.setter
    def squash(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "squash", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StoragegatewayNfsFileShareTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["StoragegatewayNfsFileShareTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayNfsFileShareConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "client_list": "clientList",
        "gateway_arn": "gatewayArn",
        "location_arn": "locationArn",
        "role_arn": "roleArn",
        "default_storage_class": "defaultStorageClass",
        "guess_mime_type_enabled": "guessMimeTypeEnabled",
        "kms_encrypted": "kmsEncrypted",
        "kms_key_arn": "kmsKeyArn",
        "nfs_file_share_defaults": "nfsFileShareDefaults",
        "object_acl": "objectAcl",
        "read_only": "readOnly",
        "requester_pays": "requesterPays",
        "squash": "squash",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class StoragegatewayNfsFileShareConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        client_list: typing.List[str],
        gateway_arn: str,
        location_arn: str,
        role_arn: str,
        default_storage_class: typing.Optional[str] = None,
        guess_mime_type_enabled: typing.Optional[bool] = None,
        kms_encrypted: typing.Optional[bool] = None,
        kms_key_arn: typing.Optional[str] = None,
        nfs_file_share_defaults: typing.Optional[
            typing.List["StoragegatewayNfsFileShareNfsFileShareDefaults"]
        ] = None,
        object_acl: typing.Optional[str] = None,
        read_only: typing.Optional[bool] = None,
        requester_pays: typing.Optional[bool] = None,
        squash: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["StoragegatewayNfsFileShareTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param client_list: 
        :param gateway_arn: 
        :param location_arn: 
        :param role_arn: 
        :param default_storage_class: 
        :param guess_mime_type_enabled: 
        :param kms_encrypted: 
        :param kms_key_arn: 
        :param nfs_file_share_defaults: nfs_file_share_defaults block.
        :param object_acl: 
        :param read_only: 
        :param requester_pays: 
        :param squash: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StoragegatewayNfsFileShareTimeouts(**timeouts)
        self._values = {
            "client_list": client_list,
            "gateway_arn": gateway_arn,
            "location_arn": location_arn,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if default_storage_class is not None:
            self._values["default_storage_class"] = default_storage_class
        if guess_mime_type_enabled is not None:
            self._values["guess_mime_type_enabled"] = guess_mime_type_enabled
        if kms_encrypted is not None:
            self._values["kms_encrypted"] = kms_encrypted
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if nfs_file_share_defaults is not None:
            self._values["nfs_file_share_defaults"] = nfs_file_share_defaults
        if object_acl is not None:
            self._values["object_acl"] = object_acl
        if read_only is not None:
            self._values["read_only"] = read_only
        if requester_pays is not None:
            self._values["requester_pays"] = requester_pays
        if squash is not None:
            self._values["squash"] = squash
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def client_list(self) -> typing.List[str]:
        return self._values.get("client_list")

    @builtins.property
    def gateway_arn(self) -> str:
        return self._values.get("gateway_arn")

    @builtins.property
    def location_arn(self) -> str:
        return self._values.get("location_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def default_storage_class(self) -> typing.Optional[str]:
        return self._values.get("default_storage_class")

    @builtins.property
    def guess_mime_type_enabled(self) -> typing.Optional[bool]:
        return self._values.get("guess_mime_type_enabled")

    @builtins.property
    def kms_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("kms_encrypted")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def nfs_file_share_defaults(
        self,
    ) -> typing.Optional[typing.List["StoragegatewayNfsFileShareNfsFileShareDefaults"]]:
        """nfs_file_share_defaults block."""
        return self._values.get("nfs_file_share_defaults")

    @builtins.property
    def object_acl(self) -> typing.Optional[str]:
        return self._values.get("object_acl")

    @builtins.property
    def read_only(self) -> typing.Optional[bool]:
        return self._values.get("read_only")

    @builtins.property
    def requester_pays(self) -> typing.Optional[bool]:
        return self._values.get("requester_pays")

    @builtins.property
    def squash(self) -> typing.Optional[str]:
        return self._values.get("squash")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["StoragegatewayNfsFileShareTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayNfsFileShareConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayNfsFileShareNfsFileShareDefaults",
    jsii_struct_bases=[],
    name_mapping={
        "directory_mode": "directoryMode",
        "file_mode": "fileMode",
        "group_id": "groupId",
        "owner_id": "ownerId",
    },
)
class StoragegatewayNfsFileShareNfsFileShareDefaults:
    def __init__(
        self,
        *,
        directory_mode: typing.Optional[str] = None,
        file_mode: typing.Optional[str] = None,
        group_id: typing.Optional[jsii.Number] = None,
        owner_id: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param directory_mode: 
        :param file_mode: 
        :param group_id: 
        :param owner_id: 
        """
        self._values = {}
        if directory_mode is not None:
            self._values["directory_mode"] = directory_mode
        if file_mode is not None:
            self._values["file_mode"] = file_mode
        if group_id is not None:
            self._values["group_id"] = group_id
        if owner_id is not None:
            self._values["owner_id"] = owner_id

    @builtins.property
    def directory_mode(self) -> typing.Optional[str]:
        return self._values.get("directory_mode")

    @builtins.property
    def file_mode(self) -> typing.Optional[str]:
        return self._values.get("file_mode")

    @builtins.property
    def group_id(self) -> typing.Optional[jsii.Number]:
        return self._values.get("group_id")

    @builtins.property
    def owner_id(self) -> typing.Optional[jsii.Number]:
        return self._values.get("owner_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayNfsFileShareNfsFileShareDefaults(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayNfsFileShareTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class StoragegatewayNfsFileShareTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayNfsFileShareTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StoragegatewaySmbFileShare(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewaySmbFileShare",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        gateway_arn: str,
        location_arn: str,
        role_arn: str,
        authentication: typing.Optional[str] = None,
        default_storage_class: typing.Optional[str] = None,
        guess_mime_type_enabled: typing.Optional[bool] = None,
        invalid_user_list: typing.Optional[typing.List[str]] = None,
        kms_encrypted: typing.Optional[bool] = None,
        kms_key_arn: typing.Optional[str] = None,
        object_acl: typing.Optional[str] = None,
        read_only: typing.Optional[bool] = None,
        requester_pays: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["StoragegatewaySmbFileShareTimeouts"] = None,
        valid_user_list: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param gateway_arn: 
        :param location_arn: 
        :param role_arn: 
        :param authentication: 
        :param default_storage_class: 
        :param guess_mime_type_enabled: 
        :param invalid_user_list: 
        :param kms_encrypted: 
        :param kms_key_arn: 
        :param object_acl: 
        :param read_only: 
        :param requester_pays: 
        :param tags: 
        :param timeouts: timeouts block.
        :param valid_user_list: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StoragegatewaySmbFileShareConfig(
            gateway_arn=gateway_arn,
            location_arn=location_arn,
            role_arn=role_arn,
            authentication=authentication,
            default_storage_class=default_storage_class,
            guess_mime_type_enabled=guess_mime_type_enabled,
            invalid_user_list=invalid_user_list,
            kms_encrypted=kms_encrypted,
            kms_key_arn=kms_key_arn,
            object_acl=object_acl,
            read_only=read_only,
            requester_pays=requester_pays,
            tags=tags,
            timeouts=timeouts,
            valid_user_list=valid_user_list,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StoragegatewaySmbFileShare, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="fileshareId")
    def fileshare_id(self) -> str:
        return jsii.get(self, "fileshareId")

    @builtins.property
    @jsii.member(jsii_name="path")
    def path(self) -> str:
        return jsii.get(self, "path")

    @builtins.property
    @jsii.member(jsii_name="gatewayArn")
    def gateway_arn(self) -> str:
        return jsii.get(self, "gatewayArn")

    @gateway_arn.setter
    def gateway_arn(self, value: str) -> None:
        jsii.set(self, "gatewayArn", value)

    @builtins.property
    @jsii.member(jsii_name="locationArn")
    def location_arn(self) -> str:
        return jsii.get(self, "locationArn")

    @location_arn.setter
    def location_arn(self, value: str) -> None:
        jsii.set(self, "locationArn", value)

    @builtins.property
    @jsii.member(jsii_name="roleArn")
    def role_arn(self) -> str:
        return jsii.get(self, "roleArn")

    @role_arn.setter
    def role_arn(self, value: str) -> None:
        jsii.set(self, "roleArn", value)

    @builtins.property
    @jsii.member(jsii_name="authentication")
    def authentication(self) -> typing.Optional[str]:
        return jsii.get(self, "authentication")

    @authentication.setter
    def authentication(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "authentication", value)

    @builtins.property
    @jsii.member(jsii_name="defaultStorageClass")
    def default_storage_class(self) -> typing.Optional[str]:
        return jsii.get(self, "defaultStorageClass")

    @default_storage_class.setter
    def default_storage_class(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "defaultStorageClass", value)

    @builtins.property
    @jsii.member(jsii_name="guessMimeTypeEnabled")
    def guess_mime_type_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "guessMimeTypeEnabled")

    @guess_mime_type_enabled.setter
    def guess_mime_type_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "guessMimeTypeEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="invalidUserList")
    def invalid_user_list(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "invalidUserList")

    @invalid_user_list.setter
    def invalid_user_list(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "invalidUserList", value)

    @builtins.property
    @jsii.member(jsii_name="kmsEncrypted")
    def kms_encrypted(self) -> typing.Optional[bool]:
        return jsii.get(self, "kmsEncrypted")

    @kms_encrypted.setter
    def kms_encrypted(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "kmsEncrypted", value)

    @builtins.property
    @jsii.member(jsii_name="kmsKeyArn")
    def kms_key_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "kmsKeyArn")

    @kms_key_arn.setter
    def kms_key_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "kmsKeyArn", value)

    @builtins.property
    @jsii.member(jsii_name="objectAcl")
    def object_acl(self) -> typing.Optional[str]:
        return jsii.get(self, "objectAcl")

    @object_acl.setter
    def object_acl(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "objectAcl", value)

    @builtins.property
    @jsii.member(jsii_name="readOnly")
    def read_only(self) -> typing.Optional[bool]:
        return jsii.get(self, "readOnly")

    @read_only.setter
    def read_only(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "readOnly", value)

    @builtins.property
    @jsii.member(jsii_name="requesterPays")
    def requester_pays(self) -> typing.Optional[bool]:
        return jsii.get(self, "requesterPays")

    @requester_pays.setter
    def requester_pays(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "requesterPays", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["StoragegatewaySmbFileShareTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["StoragegatewaySmbFileShareTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="validUserList")
    def valid_user_list(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "validUserList")

    @valid_user_list.setter
    def valid_user_list(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "validUserList", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewaySmbFileShareConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "gateway_arn": "gatewayArn",
        "location_arn": "locationArn",
        "role_arn": "roleArn",
        "authentication": "authentication",
        "default_storage_class": "defaultStorageClass",
        "guess_mime_type_enabled": "guessMimeTypeEnabled",
        "invalid_user_list": "invalidUserList",
        "kms_encrypted": "kmsEncrypted",
        "kms_key_arn": "kmsKeyArn",
        "object_acl": "objectAcl",
        "read_only": "readOnly",
        "requester_pays": "requesterPays",
        "tags": "tags",
        "timeouts": "timeouts",
        "valid_user_list": "validUserList",
    },
)
class StoragegatewaySmbFileShareConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        gateway_arn: str,
        location_arn: str,
        role_arn: str,
        authentication: typing.Optional[str] = None,
        default_storage_class: typing.Optional[str] = None,
        guess_mime_type_enabled: typing.Optional[bool] = None,
        invalid_user_list: typing.Optional[typing.List[str]] = None,
        kms_encrypted: typing.Optional[bool] = None,
        kms_key_arn: typing.Optional[str] = None,
        object_acl: typing.Optional[str] = None,
        read_only: typing.Optional[bool] = None,
        requester_pays: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["StoragegatewaySmbFileShareTimeouts"] = None,
        valid_user_list: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param gateway_arn: 
        :param location_arn: 
        :param role_arn: 
        :param authentication: 
        :param default_storage_class: 
        :param guess_mime_type_enabled: 
        :param invalid_user_list: 
        :param kms_encrypted: 
        :param kms_key_arn: 
        :param object_acl: 
        :param read_only: 
        :param requester_pays: 
        :param tags: 
        :param timeouts: timeouts block.
        :param valid_user_list: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = StoragegatewaySmbFileShareTimeouts(**timeouts)
        self._values = {
            "gateway_arn": gateway_arn,
            "location_arn": location_arn,
            "role_arn": role_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if authentication is not None:
            self._values["authentication"] = authentication
        if default_storage_class is not None:
            self._values["default_storage_class"] = default_storage_class
        if guess_mime_type_enabled is not None:
            self._values["guess_mime_type_enabled"] = guess_mime_type_enabled
        if invalid_user_list is not None:
            self._values["invalid_user_list"] = invalid_user_list
        if kms_encrypted is not None:
            self._values["kms_encrypted"] = kms_encrypted
        if kms_key_arn is not None:
            self._values["kms_key_arn"] = kms_key_arn
        if object_acl is not None:
            self._values["object_acl"] = object_acl
        if read_only is not None:
            self._values["read_only"] = read_only
        if requester_pays is not None:
            self._values["requester_pays"] = requester_pays
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if valid_user_list is not None:
            self._values["valid_user_list"] = valid_user_list

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def gateway_arn(self) -> str:
        return self._values.get("gateway_arn")

    @builtins.property
    def location_arn(self) -> str:
        return self._values.get("location_arn")

    @builtins.property
    def role_arn(self) -> str:
        return self._values.get("role_arn")

    @builtins.property
    def authentication(self) -> typing.Optional[str]:
        return self._values.get("authentication")

    @builtins.property
    def default_storage_class(self) -> typing.Optional[str]:
        return self._values.get("default_storage_class")

    @builtins.property
    def guess_mime_type_enabled(self) -> typing.Optional[bool]:
        return self._values.get("guess_mime_type_enabled")

    @builtins.property
    def invalid_user_list(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("invalid_user_list")

    @builtins.property
    def kms_encrypted(self) -> typing.Optional[bool]:
        return self._values.get("kms_encrypted")

    @builtins.property
    def kms_key_arn(self) -> typing.Optional[str]:
        return self._values.get("kms_key_arn")

    @builtins.property
    def object_acl(self) -> typing.Optional[str]:
        return self._values.get("object_acl")

    @builtins.property
    def read_only(self) -> typing.Optional[bool]:
        return self._values.get("read_only")

    @builtins.property
    def requester_pays(self) -> typing.Optional[bool]:
        return self._values.get("requester_pays")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["StoragegatewaySmbFileShareTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def valid_user_list(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("valid_user_list")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewaySmbFileShareConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewaySmbFileShareTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class StoragegatewaySmbFileShareTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewaySmbFileShareTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StoragegatewayUploadBuffer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayUploadBuffer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        disk_id: str,
        gateway_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param disk_id: 
        :param gateway_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StoragegatewayUploadBufferConfig(
            disk_id=disk_id,
            gateway_arn=gateway_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StoragegatewayUploadBuffer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> str:
        return jsii.get(self, "diskId")

    @disk_id.setter
    def disk_id(self, value: str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayArn")
    def gateway_arn(self) -> str:
        return jsii.get(self, "gatewayArn")

    @gateway_arn.setter
    def gateway_arn(self, value: str) -> None:
        jsii.set(self, "gatewayArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayUploadBufferConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "disk_id": "diskId",
        "gateway_arn": "gatewayArn",
    },
)
class StoragegatewayUploadBufferConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        disk_id: str,
        gateway_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param disk_id: 
        :param gateway_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "disk_id": disk_id,
            "gateway_arn": gateway_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def disk_id(self) -> str:
        return self._values.get("disk_id")

    @builtins.property
    def gateway_arn(self) -> str:
        return self._values.get("gateway_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayUploadBufferConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class StoragegatewayWorkingStorage(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayWorkingStorage",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        disk_id: str,
        gateway_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param disk_id: 
        :param gateway_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = StoragegatewayWorkingStorageConfig(
            disk_id=disk_id,
            gateway_arn=gateway_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(StoragegatewayWorkingStorage, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="diskId")
    def disk_id(self) -> str:
        return jsii.get(self, "diskId")

    @disk_id.setter
    def disk_id(self, value: str) -> None:
        jsii.set(self, "diskId", value)

    @builtins.property
    @jsii.member(jsii_name="gatewayArn")
    def gateway_arn(self) -> str:
        return jsii.get(self, "gatewayArn")

    @gateway_arn.setter
    def gateway_arn(self, value: str) -> None:
        jsii.set(self, "gatewayArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.StoragegatewayWorkingStorageConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "disk_id": "diskId",
        "gateway_arn": "gatewayArn",
    },
)
class StoragegatewayWorkingStorageConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        disk_id: str,
        gateway_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param disk_id: 
        :param gateway_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "disk_id": disk_id,
            "gateway_arn": gateway_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def disk_id(self) -> str:
        return self._values.get("disk_id")

    @builtins.property
    def gateway_arn(self) -> str:
        return self._values.get("gateway_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "StoragegatewayWorkingStorageConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Subnet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Subnet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cidr_block: str,
        vpc_id: str,
        assign_ipv6_address_on_creation: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        availability_zone_id: typing.Optional[str] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        map_public_ip_on_launch: typing.Optional[bool] = None,
        outpost_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["SubnetTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cidr_block: 
        :param vpc_id: 
        :param assign_ipv6_address_on_creation: 
        :param availability_zone: 
        :param availability_zone_id: 
        :param ipv6_cidr_block: 
        :param map_public_ip_on_launch: 
        :param outpost_arn: 
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SubnetConfig(
            cidr_block=cidr_block,
            vpc_id=vpc_id,
            assign_ipv6_address_on_creation=assign_ipv6_address_on_creation,
            availability_zone=availability_zone,
            availability_zone_id=availability_zone_id,
            ipv6_cidr_block=ipv6_cidr_block,
            map_public_ip_on_launch=map_public_ip_on_launch,
            outpost_arn=outpost_arn,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Subnet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlockAssociationId")
    def ipv6_cidr_block_association_id(self) -> str:
        return jsii.get(self, "ipv6CidrBlockAssociationId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> str:
        return jsii.get(self, "cidrBlock")

    @cidr_block.setter
    def cidr_block(self, value: str) -> None:
        jsii.set(self, "cidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="assignIpv6AddressOnCreation")
    def assign_ipv6_address_on_creation(self) -> typing.Optional[bool]:
        return jsii.get(self, "assignIpv6AddressOnCreation")

    @assign_ipv6_address_on_creation.setter
    def assign_ipv6_address_on_creation(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "assignIpv6AddressOnCreation", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZoneId")
    def availability_zone_id(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZoneId")

    @availability_zone_id.setter
    def availability_zone_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZoneId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return jsii.get(self, "ipv6CidrBlock")

    @ipv6_cidr_block.setter
    def ipv6_cidr_block(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ipv6CidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="mapPublicIpOnLaunch")
    def map_public_ip_on_launch(self) -> typing.Optional[bool]:
        return jsii.get(self, "mapPublicIpOnLaunch")

    @map_public_ip_on_launch.setter
    def map_public_ip_on_launch(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "mapPublicIpOnLaunch", value)

    @builtins.property
    @jsii.member(jsii_name="outpostArn")
    def outpost_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "outpostArn")

    @outpost_arn.setter
    def outpost_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "outpostArn", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["SubnetTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["SubnetTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SubnetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cidr_block": "cidrBlock",
        "vpc_id": "vpcId",
        "assign_ipv6_address_on_creation": "assignIpv6AddressOnCreation",
        "availability_zone": "availabilityZone",
        "availability_zone_id": "availabilityZoneId",
        "ipv6_cidr_block": "ipv6CidrBlock",
        "map_public_ip_on_launch": "mapPublicIpOnLaunch",
        "outpost_arn": "outpostArn",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class SubnetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cidr_block: str,
        vpc_id: str,
        assign_ipv6_address_on_creation: typing.Optional[bool] = None,
        availability_zone: typing.Optional[str] = None,
        availability_zone_id: typing.Optional[str] = None,
        ipv6_cidr_block: typing.Optional[str] = None,
        map_public_ip_on_launch: typing.Optional[bool] = None,
        outpost_arn: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["SubnetTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cidr_block: 
        :param vpc_id: 
        :param assign_ipv6_address_on_creation: 
        :param availability_zone: 
        :param availability_zone_id: 
        :param ipv6_cidr_block: 
        :param map_public_ip_on_launch: 
        :param outpost_arn: 
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = SubnetTimeouts(**timeouts)
        self._values = {
            "cidr_block": cidr_block,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if assign_ipv6_address_on_creation is not None:
            self._values[
                "assign_ipv6_address_on_creation"
            ] = assign_ipv6_address_on_creation
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if availability_zone_id is not None:
            self._values["availability_zone_id"] = availability_zone_id
        if ipv6_cidr_block is not None:
            self._values["ipv6_cidr_block"] = ipv6_cidr_block
        if map_public_ip_on_launch is not None:
            self._values["map_public_ip_on_launch"] = map_public_ip_on_launch
        if outpost_arn is not None:
            self._values["outpost_arn"] = outpost_arn
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cidr_block(self) -> str:
        return self._values.get("cidr_block")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def assign_ipv6_address_on_creation(self) -> typing.Optional[bool]:
        return self._values.get("assign_ipv6_address_on_creation")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def availability_zone_id(self) -> typing.Optional[str]:
        return self._values.get("availability_zone_id")

    @builtins.property
    def ipv6_cidr_block(self) -> typing.Optional[str]:
        return self._values.get("ipv6_cidr_block")

    @builtins.property
    def map_public_ip_on_launch(self) -> typing.Optional[bool]:
        return self._values.get("map_public_ip_on_launch")

    @builtins.property
    def outpost_arn(self) -> typing.Optional[str]:
        return self._values.get("outpost_arn")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["SubnetTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SubnetTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class SubnetTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SubnetTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class SwfDomain(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.SwfDomain",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        workflow_execution_retention_period_in_days: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param workflow_execution_retention_period_in_days: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = SwfDomainConfig(
            workflow_execution_retention_period_in_days=workflow_execution_retention_period_in_days,
            description=description,
            name=name,
            name_prefix=name_prefix,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(SwfDomain, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="workflowExecutionRetentionPeriodInDays")
    def workflow_execution_retention_period_in_days(self) -> str:
        return jsii.get(self, "workflowExecutionRetentionPeriodInDays")

    @workflow_execution_retention_period_in_days.setter
    def workflow_execution_retention_period_in_days(self, value: str) -> None:
        jsii.set(self, "workflowExecutionRetentionPeriodInDays", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> typing.Optional[str]:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="namePrefix")
    def name_prefix(self) -> typing.Optional[str]:
        return jsii.get(self, "namePrefix")

    @name_prefix.setter
    def name_prefix(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "namePrefix", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.SwfDomainConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "workflow_execution_retention_period_in_days": "workflowExecutionRetentionPeriodInDays",
        "description": "description",
        "name": "name",
        "name_prefix": "namePrefix",
        "tags": "tags",
    },
)
class SwfDomainConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        workflow_execution_retention_period_in_days: str,
        description: typing.Optional[str] = None,
        name: typing.Optional[str] = None,
        name_prefix: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param workflow_execution_retention_period_in_days: 
        :param description: 
        :param name: 
        :param name_prefix: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "workflow_execution_retention_period_in_days": workflow_execution_retention_period_in_days,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if name is not None:
            self._values["name"] = name
        if name_prefix is not None:
            self._values["name_prefix"] = name_prefix
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def workflow_execution_retention_period_in_days(self) -> str:
        return self._values.get("workflow_execution_retention_period_in_days")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def name(self) -> typing.Optional[str]:
        return self._values.get("name")

    @builtins.property
    def name_prefix(self) -> typing.Optional[str]:
        return self._values.get("name_prefix")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "SwfDomainConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class TransferServer(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.TransferServer",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        endpoint_details: typing.Optional[
            typing.List["TransferServerEndpointDetails"]
        ] = None,
        endpoint_type: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        host_key: typing.Optional[str] = None,
        identity_provider_type: typing.Optional[str] = None,
        invocation_role: typing.Optional[str] = None,
        logging_role: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        url: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param endpoint_details: endpoint_details block.
        :param endpoint_type: 
        :param force_destroy: 
        :param host_key: 
        :param identity_provider_type: 
        :param invocation_role: 
        :param logging_role: 
        :param tags: 
        :param url: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = TransferServerConfig(
            endpoint_details=endpoint_details,
            endpoint_type=endpoint_type,
            force_destroy=force_destroy,
            host_key=host_key,
            identity_provider_type=identity_provider_type,
            invocation_role=invocation_role,
            logging_role=logging_role,
            tags=tags,
            url=url,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(TransferServer, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="endpoint")
    def endpoint(self) -> str:
        return jsii.get(self, "endpoint")

    @builtins.property
    @jsii.member(jsii_name="hostKeyFingerprint")
    def host_key_fingerprint(self) -> str:
        return jsii.get(self, "hostKeyFingerprint")

    @builtins.property
    @jsii.member(jsii_name="endpointDetails")
    def endpoint_details(
        self,
    ) -> typing.Optional[typing.List["TransferServerEndpointDetails"]]:
        return jsii.get(self, "endpointDetails")

    @endpoint_details.setter
    def endpoint_details(
        self, value: typing.Optional[typing.List["TransferServerEndpointDetails"]]
    ) -> None:
        jsii.set(self, "endpointDetails", value)

    @builtins.property
    @jsii.member(jsii_name="endpointType")
    def endpoint_type(self) -> typing.Optional[str]:
        return jsii.get(self, "endpointType")

    @endpoint_type.setter
    def endpoint_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "endpointType", value)

    @builtins.property
    @jsii.member(jsii_name="forceDestroy")
    def force_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDestroy")

    @force_destroy.setter
    def force_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDestroy", value)

    @builtins.property
    @jsii.member(jsii_name="hostKey")
    def host_key(self) -> typing.Optional[str]:
        return jsii.get(self, "hostKey")

    @host_key.setter
    def host_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "hostKey", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identityProviderType")
    def identity_provider_type(self) -> typing.Optional[str]:
        return jsii.get(self, "identityProviderType")

    @identity_provider_type.setter
    def identity_provider_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "identityProviderType", value)

    @builtins.property
    @jsii.member(jsii_name="invocationRole")
    def invocation_role(self) -> typing.Optional[str]:
        return jsii.get(self, "invocationRole")

    @invocation_role.setter
    def invocation_role(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "invocationRole", value)

    @builtins.property
    @jsii.member(jsii_name="loggingRole")
    def logging_role(self) -> typing.Optional[str]:
        return jsii.get(self, "loggingRole")

    @logging_role.setter
    def logging_role(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "loggingRole", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="url")
    def url(self) -> typing.Optional[str]:
        return jsii.get(self, "url")

    @url.setter
    def url(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "url", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.TransferServerConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "endpoint_details": "endpointDetails",
        "endpoint_type": "endpointType",
        "force_destroy": "forceDestroy",
        "host_key": "hostKey",
        "identity_provider_type": "identityProviderType",
        "invocation_role": "invocationRole",
        "logging_role": "loggingRole",
        "tags": "tags",
        "url": "url",
    },
)
class TransferServerConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        endpoint_details: typing.Optional[
            typing.List["TransferServerEndpointDetails"]
        ] = None,
        endpoint_type: typing.Optional[str] = None,
        force_destroy: typing.Optional[bool] = None,
        host_key: typing.Optional[str] = None,
        identity_provider_type: typing.Optional[str] = None,
        invocation_role: typing.Optional[str] = None,
        logging_role: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        url: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param endpoint_details: endpoint_details block.
        :param endpoint_type: 
        :param force_destroy: 
        :param host_key: 
        :param identity_provider_type: 
        :param invocation_role: 
        :param logging_role: 
        :param tags: 
        :param url: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if endpoint_details is not None:
            self._values["endpoint_details"] = endpoint_details
        if endpoint_type is not None:
            self._values["endpoint_type"] = endpoint_type
        if force_destroy is not None:
            self._values["force_destroy"] = force_destroy
        if host_key is not None:
            self._values["host_key"] = host_key
        if identity_provider_type is not None:
            self._values["identity_provider_type"] = identity_provider_type
        if invocation_role is not None:
            self._values["invocation_role"] = invocation_role
        if logging_role is not None:
            self._values["logging_role"] = logging_role
        if tags is not None:
            self._values["tags"] = tags
        if url is not None:
            self._values["url"] = url

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def endpoint_details(
        self,
    ) -> typing.Optional[typing.List["TransferServerEndpointDetails"]]:
        """endpoint_details block."""
        return self._values.get("endpoint_details")

    @builtins.property
    def endpoint_type(self) -> typing.Optional[str]:
        return self._values.get("endpoint_type")

    @builtins.property
    def force_destroy(self) -> typing.Optional[bool]:
        return self._values.get("force_destroy")

    @builtins.property
    def host_key(self) -> typing.Optional[str]:
        return self._values.get("host_key")

    @builtins.property
    def identity_provider_type(self) -> typing.Optional[str]:
        return self._values.get("identity_provider_type")

    @builtins.property
    def invocation_role(self) -> typing.Optional[str]:
        return self._values.get("invocation_role")

    @builtins.property
    def logging_role(self) -> typing.Optional[str]:
        return self._values.get("logging_role")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def url(self) -> typing.Optional[str]:
        return self._values.get("url")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TransferServerConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.TransferServerEndpointDetails",
    jsii_struct_bases=[],
    name_mapping={"vpc_endpoint_id": "vpcEndpointId"},
)
class TransferServerEndpointDetails:
    def __init__(self, *, vpc_endpoint_id: str) -> None:
        """
        :param vpc_endpoint_id: 
        """
        self._values = {
            "vpc_endpoint_id": vpc_endpoint_id,
        }

    @builtins.property
    def vpc_endpoint_id(self) -> str:
        return self._values.get("vpc_endpoint_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TransferServerEndpointDetails(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class TransferSshKey(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.TransferSshKey",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        body: str,
        server_id: str,
        user_name: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param body: 
        :param server_id: 
        :param user_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = TransferSshKeyConfig(
            body=body,
            server_id=server_id,
            user_name=user_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(TransferSshKey, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="body")
    def body(self) -> str:
        return jsii.get(self, "body")

    @body.setter
    def body(self, value: str) -> None:
        jsii.set(self, "body", value)

    @builtins.property
    @jsii.member(jsii_name="serverId")
    def server_id(self) -> str:
        return jsii.get(self, "serverId")

    @server_id.setter
    def server_id(self, value: str) -> None:
        jsii.set(self, "serverId", value)

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> str:
        return jsii.get(self, "userName")

    @user_name.setter
    def user_name(self, value: str) -> None:
        jsii.set(self, "userName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.TransferSshKeyConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "body": "body",
        "server_id": "serverId",
        "user_name": "userName",
    },
)
class TransferSshKeyConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        body: str,
        server_id: str,
        user_name: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param body: 
        :param server_id: 
        :param user_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "body": body,
            "server_id": server_id,
            "user_name": user_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def body(self) -> str:
        return self._values.get("body")

    @builtins.property
    def server_id(self) -> str:
        return self._values.get("server_id")

    @builtins.property
    def user_name(self) -> str:
        return self._values.get("user_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TransferSshKeyConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class TransferUser(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.TransferUser",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        role: str,
        server_id: str,
        user_name: str,
        home_directory: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param role: 
        :param server_id: 
        :param user_name: 
        :param home_directory: 
        :param policy: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = TransferUserConfig(
            role=role,
            server_id=server_id,
            user_name=user_name,
            home_directory=home_directory,
            policy=policy,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(TransferUser, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="role")
    def role(self) -> str:
        return jsii.get(self, "role")

    @role.setter
    def role(self, value: str) -> None:
        jsii.set(self, "role", value)

    @builtins.property
    @jsii.member(jsii_name="serverId")
    def server_id(self) -> str:
        return jsii.get(self, "serverId")

    @server_id.setter
    def server_id(self, value: str) -> None:
        jsii.set(self, "serverId", value)

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> str:
        return jsii.get(self, "userName")

    @user_name.setter
    def user_name(self, value: str) -> None:
        jsii.set(self, "userName", value)

    @builtins.property
    @jsii.member(jsii_name="homeDirectory")
    def home_directory(self) -> typing.Optional[str]:
        return jsii.get(self, "homeDirectory")

    @home_directory.setter
    def home_directory(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "homeDirectory", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.TransferUserConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "role": "role",
        "server_id": "serverId",
        "user_name": "userName",
        "home_directory": "homeDirectory",
        "policy": "policy",
        "tags": "tags",
    },
)
class TransferUserConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        role: str,
        server_id: str,
        user_name: str,
        home_directory: typing.Optional[str] = None,
        policy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param role: 
        :param server_id: 
        :param user_name: 
        :param home_directory: 
        :param policy: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "role": role,
            "server_id": server_id,
            "user_name": user_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if home_directory is not None:
            self._values["home_directory"] = home_directory
        if policy is not None:
            self._values["policy"] = policy
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def role(self) -> str:
        return self._values.get("role")

    @builtins.property
    def server_id(self) -> str:
        return self._values.get("server_id")

    @builtins.property
    def user_name(self) -> str:
        return self._values.get("user_name")

    @builtins.property
    def home_directory(self) -> typing.Optional[str]:
        return self._values.get("home_directory")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "TransferUserConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VolumeAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VolumeAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        device_name: str,
        instance_id: str,
        volume_id: str,
        force_detach: typing.Optional[bool] = None,
        skip_destroy: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param device_name: 
        :param instance_id: 
        :param volume_id: 
        :param force_detach: 
        :param skip_destroy: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VolumeAttachmentConfig(
            device_name=device_name,
            instance_id=instance_id,
            volume_id=volume_id,
            force_detach=force_detach,
            skip_destroy=skip_destroy,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VolumeAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="deviceName")
    def device_name(self) -> str:
        return jsii.get(self, "deviceName")

    @device_name.setter
    def device_name(self, value: str) -> None:
        jsii.set(self, "deviceName", value)

    @builtins.property
    @jsii.member(jsii_name="instanceId")
    def instance_id(self) -> str:
        return jsii.get(self, "instanceId")

    @instance_id.setter
    def instance_id(self, value: str) -> None:
        jsii.set(self, "instanceId", value)

    @builtins.property
    @jsii.member(jsii_name="volumeId")
    def volume_id(self) -> str:
        return jsii.get(self, "volumeId")

    @volume_id.setter
    def volume_id(self, value: str) -> None:
        jsii.set(self, "volumeId", value)

    @builtins.property
    @jsii.member(jsii_name="forceDetach")
    def force_detach(self) -> typing.Optional[bool]:
        return jsii.get(self, "forceDetach")

    @force_detach.setter
    def force_detach(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "forceDetach", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="skipDestroy")
    def skip_destroy(self) -> typing.Optional[bool]:
        return jsii.get(self, "skipDestroy")

    @skip_destroy.setter
    def skip_destroy(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "skipDestroy", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VolumeAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "device_name": "deviceName",
        "instance_id": "instanceId",
        "volume_id": "volumeId",
        "force_detach": "forceDetach",
        "skip_destroy": "skipDestroy",
    },
)
class VolumeAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        device_name: str,
        instance_id: str,
        volume_id: str,
        force_detach: typing.Optional[bool] = None,
        skip_destroy: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param device_name: 
        :param instance_id: 
        :param volume_id: 
        :param force_detach: 
        :param skip_destroy: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "device_name": device_name,
            "instance_id": instance_id,
            "volume_id": volume_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if force_detach is not None:
            self._values["force_detach"] = force_detach
        if skip_destroy is not None:
            self._values["skip_destroy"] = skip_destroy

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def device_name(self) -> str:
        return self._values.get("device_name")

    @builtins.property
    def instance_id(self) -> str:
        return self._values.get("instance_id")

    @builtins.property
    def volume_id(self) -> str:
        return self._values.get("volume_id")

    @builtins.property
    def force_detach(self) -> typing.Optional[bool]:
        return self._values.get("force_detach")

    @builtins.property
    def skip_destroy(self) -> typing.Optional[bool]:
        return self._values.get("skip_destroy")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VolumeAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Vpc(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Vpc",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cidr_block: str,
        assign_generated_ipv6_cidr_block: typing.Optional[bool] = None,
        enable_classiclink: typing.Optional[bool] = None,
        enable_classiclink_dns_support: typing.Optional[bool] = None,
        enable_dns_hostnames: typing.Optional[bool] = None,
        enable_dns_support: typing.Optional[bool] = None,
        instance_tenancy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cidr_block: 
        :param assign_generated_ipv6_cidr_block: 
        :param enable_classiclink: 
        :param enable_classiclink_dns_support: 
        :param enable_dns_hostnames: 
        :param enable_dns_support: 
        :param instance_tenancy: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcConfig(
            cidr_block=cidr_block,
            assign_generated_ipv6_cidr_block=assign_generated_ipv6_cidr_block,
            enable_classiclink=enable_classiclink,
            enable_classiclink_dns_support=enable_classiclink_dns_support,
            enable_dns_hostnames=enable_dns_hostnames,
            enable_dns_support=enable_dns_support,
            instance_tenancy=instance_tenancy,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Vpc, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultNetworkAclId")
    def default_network_acl_id(self) -> str:
        return jsii.get(self, "defaultNetworkAclId")

    @builtins.property
    @jsii.member(jsii_name="defaultRouteTableId")
    def default_route_table_id(self) -> str:
        return jsii.get(self, "defaultRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="defaultSecurityGroupId")
    def default_security_group_id(self) -> str:
        return jsii.get(self, "defaultSecurityGroupId")

    @builtins.property
    @jsii.member(jsii_name="dhcpOptionsId")
    def dhcp_options_id(self) -> str:
        return jsii.get(self, "dhcpOptionsId")

    @builtins.property
    @jsii.member(jsii_name="ipv6AssociationId")
    def ipv6_association_id(self) -> str:
        return jsii.get(self, "ipv6AssociationId")

    @builtins.property
    @jsii.member(jsii_name="ipv6CidrBlock")
    def ipv6_cidr_block(self) -> str:
        return jsii.get(self, "ipv6CidrBlock")

    @builtins.property
    @jsii.member(jsii_name="mainRouteTableId")
    def main_route_table_id(self) -> str:
        return jsii.get(self, "mainRouteTableId")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> str:
        return jsii.get(self, "cidrBlock")

    @cidr_block.setter
    def cidr_block(self, value: str) -> None:
        jsii.set(self, "cidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="assignGeneratedIpv6CidrBlock")
    def assign_generated_ipv6_cidr_block(self) -> typing.Optional[bool]:
        return jsii.get(self, "assignGeneratedIpv6CidrBlock")

    @assign_generated_ipv6_cidr_block.setter
    def assign_generated_ipv6_cidr_block(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "assignGeneratedIpv6CidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="enableClassiclink")
    def enable_classiclink(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableClassiclink")

    @enable_classiclink.setter
    def enable_classiclink(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableClassiclink", value)

    @builtins.property
    @jsii.member(jsii_name="enableClassiclinkDnsSupport")
    def enable_classiclink_dns_support(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableClassiclinkDnsSupport")

    @enable_classiclink_dns_support.setter
    def enable_classiclink_dns_support(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableClassiclinkDnsSupport", value)

    @builtins.property
    @jsii.member(jsii_name="enableDnsHostnames")
    def enable_dns_hostnames(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableDnsHostnames")

    @enable_dns_hostnames.setter
    def enable_dns_hostnames(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableDnsHostnames", value)

    @builtins.property
    @jsii.member(jsii_name="enableDnsSupport")
    def enable_dns_support(self) -> typing.Optional[bool]:
        return jsii.get(self, "enableDnsSupport")

    @enable_dns_support.setter
    def enable_dns_support(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "enableDnsSupport", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="instanceTenancy")
    def instance_tenancy(self) -> typing.Optional[str]:
        return jsii.get(self, "instanceTenancy")

    @instance_tenancy.setter
    def instance_tenancy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "instanceTenancy", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cidr_block": "cidrBlock",
        "assign_generated_ipv6_cidr_block": "assignGeneratedIpv6CidrBlock",
        "enable_classiclink": "enableClassiclink",
        "enable_classiclink_dns_support": "enableClassiclinkDnsSupport",
        "enable_dns_hostnames": "enableDnsHostnames",
        "enable_dns_support": "enableDnsSupport",
        "instance_tenancy": "instanceTenancy",
        "tags": "tags",
    },
)
class VpcConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cidr_block: str,
        assign_generated_ipv6_cidr_block: typing.Optional[bool] = None,
        enable_classiclink: typing.Optional[bool] = None,
        enable_classiclink_dns_support: typing.Optional[bool] = None,
        enable_dns_hostnames: typing.Optional[bool] = None,
        enable_dns_support: typing.Optional[bool] = None,
        instance_tenancy: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cidr_block: 
        :param assign_generated_ipv6_cidr_block: 
        :param enable_classiclink: 
        :param enable_classiclink_dns_support: 
        :param enable_dns_hostnames: 
        :param enable_dns_support: 
        :param instance_tenancy: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "cidr_block": cidr_block,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if assign_generated_ipv6_cidr_block is not None:
            self._values[
                "assign_generated_ipv6_cidr_block"
            ] = assign_generated_ipv6_cidr_block
        if enable_classiclink is not None:
            self._values["enable_classiclink"] = enable_classiclink
        if enable_classiclink_dns_support is not None:
            self._values[
                "enable_classiclink_dns_support"
            ] = enable_classiclink_dns_support
        if enable_dns_hostnames is not None:
            self._values["enable_dns_hostnames"] = enable_dns_hostnames
        if enable_dns_support is not None:
            self._values["enable_dns_support"] = enable_dns_support
        if instance_tenancy is not None:
            self._values["instance_tenancy"] = instance_tenancy
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cidr_block(self) -> str:
        return self._values.get("cidr_block")

    @builtins.property
    def assign_generated_ipv6_cidr_block(self) -> typing.Optional[bool]:
        return self._values.get("assign_generated_ipv6_cidr_block")

    @builtins.property
    def enable_classiclink(self) -> typing.Optional[bool]:
        return self._values.get("enable_classiclink")

    @builtins.property
    def enable_classiclink_dns_support(self) -> typing.Optional[bool]:
        return self._values.get("enable_classiclink_dns_support")

    @builtins.property
    def enable_dns_hostnames(self) -> typing.Optional[bool]:
        return self._values.get("enable_dns_hostnames")

    @builtins.property
    def enable_dns_support(self) -> typing.Optional[bool]:
        return self._values.get("enable_dns_support")

    @builtins.property
    def instance_tenancy(self) -> typing.Optional[str]:
        return self._values.get("instance_tenancy")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcDhcpOptions(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcDhcpOptions",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        domain_name: typing.Optional[str] = None,
        domain_name_servers: typing.Optional[typing.List[str]] = None,
        netbios_name_servers: typing.Optional[typing.List[str]] = None,
        netbios_node_type: typing.Optional[str] = None,
        ntp_servers: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param domain_name: 
        :param domain_name_servers: 
        :param netbios_name_servers: 
        :param netbios_node_type: 
        :param ntp_servers: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcDhcpOptionsConfig(
            domain_name=domain_name,
            domain_name_servers=domain_name_servers,
            netbios_name_servers=netbios_name_servers,
            netbios_node_type=netbios_node_type,
            ntp_servers=ntp_servers,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcDhcpOptions, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="domainName")
    def domain_name(self) -> typing.Optional[str]:
        return jsii.get(self, "domainName")

    @domain_name.setter
    def domain_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "domainName", value)

    @builtins.property
    @jsii.member(jsii_name="domainNameServers")
    def domain_name_servers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "domainNameServers")

    @domain_name_servers.setter
    def domain_name_servers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "domainNameServers", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="netbiosNameServers")
    def netbios_name_servers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "netbiosNameServers")

    @netbios_name_servers.setter
    def netbios_name_servers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "netbiosNameServers", value)

    @builtins.property
    @jsii.member(jsii_name="netbiosNodeType")
    def netbios_node_type(self) -> typing.Optional[str]:
        return jsii.get(self, "netbiosNodeType")

    @netbios_node_type.setter
    def netbios_node_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "netbiosNodeType", value)

    @builtins.property
    @jsii.member(jsii_name="ntpServers")
    def ntp_servers(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "ntpServers")

    @ntp_servers.setter
    def ntp_servers(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "ntpServers", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class VpcDhcpOptionsAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcDhcpOptionsAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        dhcp_options_id: str,
        vpc_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param dhcp_options_id: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcDhcpOptionsAssociationConfig(
            dhcp_options_id=dhcp_options_id,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcDhcpOptionsAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="dhcpOptionsId")
    def dhcp_options_id(self) -> str:
        return jsii.get(self, "dhcpOptionsId")

    @dhcp_options_id.setter
    def dhcp_options_id(self, value: str) -> None:
        jsii.set(self, "dhcpOptionsId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcDhcpOptionsAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "dhcp_options_id": "dhcpOptionsId",
        "vpc_id": "vpcId",
    },
)
class VpcDhcpOptionsAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        dhcp_options_id: str,
        vpc_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param dhcp_options_id: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "dhcp_options_id": dhcp_options_id,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def dhcp_options_id(self) -> str:
        return self._values.get("dhcp_options_id")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcDhcpOptionsAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcDhcpOptionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "domain_name": "domainName",
        "domain_name_servers": "domainNameServers",
        "netbios_name_servers": "netbiosNameServers",
        "netbios_node_type": "netbiosNodeType",
        "ntp_servers": "ntpServers",
        "tags": "tags",
    },
)
class VpcDhcpOptionsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        domain_name: typing.Optional[str] = None,
        domain_name_servers: typing.Optional[typing.List[str]] = None,
        netbios_name_servers: typing.Optional[typing.List[str]] = None,
        netbios_node_type: typing.Optional[str] = None,
        ntp_servers: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param domain_name: 
        :param domain_name_servers: 
        :param netbios_name_servers: 
        :param netbios_node_type: 
        :param ntp_servers: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if domain_name is not None:
            self._values["domain_name"] = domain_name
        if domain_name_servers is not None:
            self._values["domain_name_servers"] = domain_name_servers
        if netbios_name_servers is not None:
            self._values["netbios_name_servers"] = netbios_name_servers
        if netbios_node_type is not None:
            self._values["netbios_node_type"] = netbios_node_type
        if ntp_servers is not None:
            self._values["ntp_servers"] = ntp_servers
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def domain_name(self) -> typing.Optional[str]:
        return self._values.get("domain_name")

    @builtins.property
    def domain_name_servers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("domain_name_servers")

    @builtins.property
    def netbios_name_servers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("netbios_name_servers")

    @builtins.property
    def netbios_node_type(self) -> typing.Optional[str]:
        return self._values.get("netbios_node_type")

    @builtins.property
    def ntp_servers(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("ntp_servers")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcDhcpOptionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcEndpoint(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpoint",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        service_name: str,
        vpc_id: str,
        auto_accept: typing.Optional[bool] = None,
        policy: typing.Optional[str] = None,
        private_dns_enabled: typing.Optional[bool] = None,
        route_table_ids: typing.Optional[typing.List[str]] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["VpcEndpointTimeouts"] = None,
        vpc_endpoint_type: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param service_name: 
        :param vpc_id: 
        :param auto_accept: 
        :param policy: 
        :param private_dns_enabled: 
        :param route_table_ids: 
        :param security_group_ids: 
        :param subnet_ids: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_endpoint_type: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcEndpointConfig(
            service_name=service_name,
            vpc_id=vpc_id,
            auto_accept=auto_accept,
            policy=policy,
            private_dns_enabled=private_dns_enabled,
            route_table_ids=route_table_ids,
            security_group_ids=security_group_ids,
            subnet_ids=subnet_ids,
            tags=tags,
            timeouts=timeouts,
            vpc_endpoint_type=vpc_endpoint_type,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcEndpoint, self, [scope, id, config])

    @jsii.member(jsii_name="dnsEntry")
    def dns_entry(self, index: str) -> "VpcEndpointDnsEntry":
        """
        :param index: -
        """
        return jsii.invoke(self, "dnsEntry", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="cidrBlocks")
    def cidr_blocks(self) -> typing.List[str]:
        return jsii.get(self, "cidrBlocks")

    @builtins.property
    @jsii.member(jsii_name="networkInterfaceIds")
    def network_interface_ids(self) -> typing.List[str]:
        return jsii.get(self, "networkInterfaceIds")

    @builtins.property
    @jsii.member(jsii_name="ownerId")
    def owner_id(self) -> str:
        return jsii.get(self, "ownerId")

    @builtins.property
    @jsii.member(jsii_name="prefixListId")
    def prefix_list_id(self) -> str:
        return jsii.get(self, "prefixListId")

    @builtins.property
    @jsii.member(jsii_name="requesterManaged")
    def requester_managed(self) -> bool:
        return jsii.get(self, "requesterManaged")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> str:
        return jsii.get(self, "serviceName")

    @service_name.setter
    def service_name(self, value: str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="autoAccept")
    def auto_accept(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAccept")

    @auto_accept.setter
    def auto_accept(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAccept", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="policy")
    def policy(self) -> typing.Optional[str]:
        return jsii.get(self, "policy")

    @policy.setter
    def policy(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "policy", value)

    @builtins.property
    @jsii.member(jsii_name="privateDnsEnabled")
    def private_dns_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "privateDnsEnabled")

    @private_dns_enabled.setter
    def private_dns_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "privateDnsEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="routeTableIds")
    def route_table_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "routeTableIds")

    @route_table_ids.setter
    def route_table_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "routeTableIds", value)

    @builtins.property
    @jsii.member(jsii_name="securityGroupIds")
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "securityGroupIds")

    @security_group_ids.setter
    def security_group_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "securityGroupIds", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VpcEndpointTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["VpcEndpointTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointType")
    def vpc_endpoint_type(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcEndpointType")

    @vpc_endpoint_type.setter
    def vpc_endpoint_type(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcEndpointType", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "service_name": "serviceName",
        "vpc_id": "vpcId",
        "auto_accept": "autoAccept",
        "policy": "policy",
        "private_dns_enabled": "privateDnsEnabled",
        "route_table_ids": "routeTableIds",
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
        "tags": "tags",
        "timeouts": "timeouts",
        "vpc_endpoint_type": "vpcEndpointType",
    },
)
class VpcEndpointConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        service_name: str,
        vpc_id: str,
        auto_accept: typing.Optional[bool] = None,
        policy: typing.Optional[str] = None,
        private_dns_enabled: typing.Optional[bool] = None,
        route_table_ids: typing.Optional[typing.List[str]] = None,
        security_group_ids: typing.Optional[typing.List[str]] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["VpcEndpointTimeouts"] = None,
        vpc_endpoint_type: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param service_name: 
        :param vpc_id: 
        :param auto_accept: 
        :param policy: 
        :param private_dns_enabled: 
        :param route_table_ids: 
        :param security_group_ids: 
        :param subnet_ids: 
        :param tags: 
        :param timeouts: timeouts block.
        :param vpc_endpoint_type: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcEndpointTimeouts(**timeouts)
        self._values = {
            "service_name": service_name,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if auto_accept is not None:
            self._values["auto_accept"] = auto_accept
        if policy is not None:
            self._values["policy"] = policy
        if private_dns_enabled is not None:
            self._values["private_dns_enabled"] = private_dns_enabled
        if route_table_ids is not None:
            self._values["route_table_ids"] = route_table_ids
        if security_group_ids is not None:
            self._values["security_group_ids"] = security_group_ids
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts
        if vpc_endpoint_type is not None:
            self._values["vpc_endpoint_type"] = vpc_endpoint_type

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def service_name(self) -> str:
        return self._values.get("service_name")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def auto_accept(self) -> typing.Optional[bool]:
        return self._values.get("auto_accept")

    @builtins.property
    def policy(self) -> typing.Optional[str]:
        return self._values.get("policy")

    @builtins.property
    def private_dns_enabled(self) -> typing.Optional[bool]:
        return self._values.get("private_dns_enabled")

    @builtins.property
    def route_table_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("route_table_ids")

    @builtins.property
    def security_group_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcEndpointTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    @builtins.property
    def vpc_endpoint_type(self) -> typing.Optional[str]:
        return self._values.get("vpc_endpoint_type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcEndpointConnectionNotification(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointConnectionNotification",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        connection_events: typing.List[str],
        connection_notification_arn: str,
        vpc_endpoint_id: typing.Optional[str] = None,
        vpc_endpoint_service_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param connection_events: 
        :param connection_notification_arn: 
        :param vpc_endpoint_id: 
        :param vpc_endpoint_service_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcEndpointConnectionNotificationConfig(
            connection_events=connection_events,
            connection_notification_arn=connection_notification_arn,
            vpc_endpoint_id=vpc_endpoint_id,
            vpc_endpoint_service_id=vpc_endpoint_service_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcEndpointConnectionNotification, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="notificationType")
    def notification_type(self) -> str:
        return jsii.get(self, "notificationType")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="connectionEvents")
    def connection_events(self) -> typing.List[str]:
        return jsii.get(self, "connectionEvents")

    @connection_events.setter
    def connection_events(self, value: typing.List[str]) -> None:
        jsii.set(self, "connectionEvents", value)

    @builtins.property
    @jsii.member(jsii_name="connectionNotificationArn")
    def connection_notification_arn(self) -> str:
        return jsii.get(self, "connectionNotificationArn")

    @connection_notification_arn.setter
    def connection_notification_arn(self, value: str) -> None:
        jsii.set(self, "connectionNotificationArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointId")
    def vpc_endpoint_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcEndpointId")

    @vpc_endpoint_id.setter
    def vpc_endpoint_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointServiceId")
    def vpc_endpoint_service_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcEndpointServiceId")

    @vpc_endpoint_service_id.setter
    def vpc_endpoint_service_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcEndpointServiceId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointConnectionNotificationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "connection_events": "connectionEvents",
        "connection_notification_arn": "connectionNotificationArn",
        "vpc_endpoint_id": "vpcEndpointId",
        "vpc_endpoint_service_id": "vpcEndpointServiceId",
    },
)
class VpcEndpointConnectionNotificationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        connection_events: typing.List[str],
        connection_notification_arn: str,
        vpc_endpoint_id: typing.Optional[str] = None,
        vpc_endpoint_service_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param connection_events: 
        :param connection_notification_arn: 
        :param vpc_endpoint_id: 
        :param vpc_endpoint_service_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "connection_events": connection_events,
            "connection_notification_arn": connection_notification_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if vpc_endpoint_id is not None:
            self._values["vpc_endpoint_id"] = vpc_endpoint_id
        if vpc_endpoint_service_id is not None:
            self._values["vpc_endpoint_service_id"] = vpc_endpoint_service_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def connection_events(self) -> typing.List[str]:
        return self._values.get("connection_events")

    @builtins.property
    def connection_notification_arn(self) -> str:
        return self._values.get("connection_notification_arn")

    @builtins.property
    def vpc_endpoint_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_endpoint_id")

    @builtins.property
    def vpc_endpoint_service_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_endpoint_service_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointConnectionNotificationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcEndpointDnsEntry(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointDnsEntry",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            VpcEndpointDnsEntry, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="dnsName")
    def dns_name(self) -> str:
        return jsii.get(self, "dnsName")

    @builtins.property
    @jsii.member(jsii_name="hostedZoneId")
    def hosted_zone_id(self) -> str:
        return jsii.get(self, "hostedZoneId")


class VpcEndpointRouteTableAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointRouteTableAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        route_table_id: str,
        vpc_endpoint_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param route_table_id: 
        :param vpc_endpoint_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcEndpointRouteTableAssociationConfig(
            route_table_id=route_table_id,
            vpc_endpoint_id=vpc_endpoint_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcEndpointRouteTableAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> str:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter
    def route_table_id(self, value: str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointId")
    def vpc_endpoint_id(self) -> str:
        return jsii.get(self, "vpcEndpointId")

    @vpc_endpoint_id.setter
    def vpc_endpoint_id(self, value: str) -> None:
        jsii.set(self, "vpcEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointRouteTableAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "route_table_id": "routeTableId",
        "vpc_endpoint_id": "vpcEndpointId",
    },
)
class VpcEndpointRouteTableAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        route_table_id: str,
        vpc_endpoint_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param route_table_id: 
        :param vpc_endpoint_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "route_table_id": route_table_id,
            "vpc_endpoint_id": vpc_endpoint_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def route_table_id(self) -> str:
        return self._values.get("route_table_id")

    @builtins.property
    def vpc_endpoint_id(self) -> str:
        return self._values.get("vpc_endpoint_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointRouteTableAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcEndpointService(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointService",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        acceptance_required: bool,
        network_load_balancer_arns: typing.List[str],
        allowed_principals: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param acceptance_required: 
        :param network_load_balancer_arns: 
        :param allowed_principals: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcEndpointServiceConfig(
            acceptance_required=acceptance_required,
            network_load_balancer_arns=network_load_balancer_arns,
            allowed_principals=allowed_principals,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcEndpointService, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="availabilityZones")
    def availability_zones(self) -> typing.List[str]:
        return jsii.get(self, "availabilityZones")

    @builtins.property
    @jsii.member(jsii_name="baseEndpointDnsNames")
    def base_endpoint_dns_names(self) -> typing.List[str]:
        return jsii.get(self, "baseEndpointDnsNames")

    @builtins.property
    @jsii.member(jsii_name="managesVpcEndpoints")
    def manages_vpc_endpoints(self) -> bool:
        return jsii.get(self, "managesVpcEndpoints")

    @builtins.property
    @jsii.member(jsii_name="privateDnsName")
    def private_dns_name(self) -> str:
        return jsii.get(self, "privateDnsName")

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> str:
        return jsii.get(self, "serviceName")

    @builtins.property
    @jsii.member(jsii_name="serviceType")
    def service_type(self) -> str:
        return jsii.get(self, "serviceType")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="acceptanceRequired")
    def acceptance_required(self) -> bool:
        return jsii.get(self, "acceptanceRequired")

    @acceptance_required.setter
    def acceptance_required(self, value: bool) -> None:
        jsii.set(self, "acceptanceRequired", value)

    @builtins.property
    @jsii.member(jsii_name="networkLoadBalancerArns")
    def network_load_balancer_arns(self) -> typing.List[str]:
        return jsii.get(self, "networkLoadBalancerArns")

    @network_load_balancer_arns.setter
    def network_load_balancer_arns(self, value: typing.List[str]) -> None:
        jsii.set(self, "networkLoadBalancerArns", value)

    @builtins.property
    @jsii.member(jsii_name="allowedPrincipals")
    def allowed_principals(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "allowedPrincipals")

    @allowed_principals.setter
    def allowed_principals(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "allowedPrincipals", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class VpcEndpointServiceAllowedPrincipal(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointServiceAllowedPrincipal",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        principal_arn: str,
        vpc_endpoint_service_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param principal_arn: 
        :param vpc_endpoint_service_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcEndpointServiceAllowedPrincipalConfig(
            principal_arn=principal_arn,
            vpc_endpoint_service_id=vpc_endpoint_service_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcEndpointServiceAllowedPrincipal, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="principalArn")
    def principal_arn(self) -> str:
        return jsii.get(self, "principalArn")

    @principal_arn.setter
    def principal_arn(self, value: str) -> None:
        jsii.set(self, "principalArn", value)

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointServiceId")
    def vpc_endpoint_service_id(self) -> str:
        return jsii.get(self, "vpcEndpointServiceId")

    @vpc_endpoint_service_id.setter
    def vpc_endpoint_service_id(self, value: str) -> None:
        jsii.set(self, "vpcEndpointServiceId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointServiceAllowedPrincipalConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "principal_arn": "principalArn",
        "vpc_endpoint_service_id": "vpcEndpointServiceId",
    },
)
class VpcEndpointServiceAllowedPrincipalConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        principal_arn: str,
        vpc_endpoint_service_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param principal_arn: 
        :param vpc_endpoint_service_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "principal_arn": principal_arn,
            "vpc_endpoint_service_id": vpc_endpoint_service_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def principal_arn(self) -> str:
        return self._values.get("principal_arn")

    @builtins.property
    def vpc_endpoint_service_id(self) -> str:
        return self._values.get("vpc_endpoint_service_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointServiceAllowedPrincipalConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointServiceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "acceptance_required": "acceptanceRequired",
        "network_load_balancer_arns": "networkLoadBalancerArns",
        "allowed_principals": "allowedPrincipals",
        "tags": "tags",
    },
)
class VpcEndpointServiceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        acceptance_required: bool,
        network_load_balancer_arns: typing.List[str],
        allowed_principals: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param acceptance_required: 
        :param network_load_balancer_arns: 
        :param allowed_principals: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "acceptance_required": acceptance_required,
            "network_load_balancer_arns": network_load_balancer_arns,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if allowed_principals is not None:
            self._values["allowed_principals"] = allowed_principals
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def acceptance_required(self) -> bool:
        return self._values.get("acceptance_required")

    @builtins.property
    def network_load_balancer_arns(self) -> typing.List[str]:
        return self._values.get("network_load_balancer_arns")

    @builtins.property
    def allowed_principals(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("allowed_principals")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointServiceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcEndpointSubnetAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointSubnetAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        subnet_id: str,
        vpc_endpoint_id: str,
        timeouts: typing.Optional["VpcEndpointSubnetAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param subnet_id: 
        :param vpc_endpoint_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcEndpointSubnetAssociationConfig(
            subnet_id=subnet_id,
            vpc_endpoint_id=vpc_endpoint_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcEndpointSubnetAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="subnetId")
    def subnet_id(self) -> str:
        return jsii.get(self, "subnetId")

    @subnet_id.setter
    def subnet_id(self, value: str) -> None:
        jsii.set(self, "subnetId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcEndpointId")
    def vpc_endpoint_id(self) -> str:
        return jsii.get(self, "vpcEndpointId")

    @vpc_endpoint_id.setter
    def vpc_endpoint_id(self, value: str) -> None:
        jsii.set(self, "vpcEndpointId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VpcEndpointSubnetAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["VpcEndpointSubnetAssociationTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointSubnetAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "subnet_id": "subnetId",
        "vpc_endpoint_id": "vpcEndpointId",
        "timeouts": "timeouts",
    },
)
class VpcEndpointSubnetAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        subnet_id: str,
        vpc_endpoint_id: str,
        timeouts: typing.Optional["VpcEndpointSubnetAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param subnet_id: 
        :param vpc_endpoint_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcEndpointSubnetAssociationTimeouts(**timeouts)
        self._values = {
            "subnet_id": subnet_id,
            "vpc_endpoint_id": vpc_endpoint_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def subnet_id(self) -> str:
        return self._values.get("subnet_id")

    @builtins.property
    def vpc_endpoint_id(self) -> str:
        return self._values.get("vpc_endpoint_id")

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcEndpointSubnetAssociationTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointSubnetAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointSubnetAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class VpcEndpointSubnetAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointSubnetAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcEndpointTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class VpcEndpointTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcEndpointTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcIpv4CidrBlockAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcIpv4CidrBlockAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        cidr_block: str,
        vpc_id: str,
        timeouts: typing.Optional["VpcIpv4CidrBlockAssociationTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param cidr_block: 
        :param vpc_id: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcIpv4CidrBlockAssociationConfig(
            cidr_block=cidr_block,
            vpc_id=vpc_id,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcIpv4CidrBlockAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="cidrBlock")
    def cidr_block(self) -> str:
        return jsii.get(self, "cidrBlock")

    @cidr_block.setter
    def cidr_block(self, value: str) -> None:
        jsii.set(self, "cidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VpcIpv4CidrBlockAssociationTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(
        self, value: typing.Optional["VpcIpv4CidrBlockAssociationTimeouts"]
    ) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcIpv4CidrBlockAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "cidr_block": "cidrBlock",
        "vpc_id": "vpcId",
        "timeouts": "timeouts",
    },
)
class VpcIpv4CidrBlockAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        cidr_block: str,
        vpc_id: str,
        timeouts: typing.Optional["VpcIpv4CidrBlockAssociationTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param cidr_block: 
        :param vpc_id: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcIpv4CidrBlockAssociationTimeouts(**timeouts)
        self._values = {
            "cidr_block": cidr_block,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def cidr_block(self) -> str:
        return self._values.get("cidr_block")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcIpv4CidrBlockAssociationTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcIpv4CidrBlockAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcIpv4CidrBlockAssociationTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete"},
)
class VpcIpv4CidrBlockAssociationTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcIpv4CidrBlockAssociationTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcPeeringConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        peer_vpc_id: str,
        vpc_id: str,
        accepter: typing.Optional[typing.List["VpcPeeringConnectionAccepter"]] = None,
        auto_accept: typing.Optional[bool] = None,
        peer_owner_id: typing.Optional[str] = None,
        peer_region: typing.Optional[str] = None,
        requester: typing.Optional[typing.List["VpcPeeringConnectionRequester"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["VpcPeeringConnectionTimeouts"] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param peer_vpc_id: 
        :param vpc_id: 
        :param accepter: accepter block.
        :param auto_accept: 
        :param peer_owner_id: 
        :param peer_region: 
        :param requester: requester block.
        :param tags: 
        :param timeouts: timeouts block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcPeeringConnectionConfig(
            peer_vpc_id=peer_vpc_id,
            vpc_id=vpc_id,
            accepter=accepter,
            auto_accept=auto_accept,
            peer_owner_id=peer_owner_id,
            peer_region=peer_region,
            requester=requester,
            tags=tags,
            timeouts=timeouts,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcPeeringConnection, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="acceptStatus")
    def accept_status(self) -> str:
        return jsii.get(self, "acceptStatus")

    @builtins.property
    @jsii.member(jsii_name="peerVpcId")
    def peer_vpc_id(self) -> str:
        return jsii.get(self, "peerVpcId")

    @peer_vpc_id.setter
    def peer_vpc_id(self, value: str) -> None:
        jsii.set(self, "peerVpcId", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="accepter")
    def accepter(self) -> typing.Optional[typing.List["VpcPeeringConnectionAccepter"]]:
        return jsii.get(self, "accepter")

    @accepter.setter
    def accepter(
        self, value: typing.Optional[typing.List["VpcPeeringConnectionAccepter"]]
    ) -> None:
        jsii.set(self, "accepter", value)

    @builtins.property
    @jsii.member(jsii_name="autoAccept")
    def auto_accept(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAccept")

    @auto_accept.setter
    def auto_accept(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAccept", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="peerOwnerId")
    def peer_owner_id(self) -> typing.Optional[str]:
        return jsii.get(self, "peerOwnerId")

    @peer_owner_id.setter
    def peer_owner_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "peerOwnerId", value)

    @builtins.property
    @jsii.member(jsii_name="peerRegion")
    def peer_region(self) -> typing.Optional[str]:
        return jsii.get(self, "peerRegion")

    @peer_region.setter
    def peer_region(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "peerRegion", value)

    @builtins.property
    @jsii.member(jsii_name="requester")
    def requester(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionRequester"]]:
        return jsii.get(self, "requester")

    @requester.setter
    def requester(
        self, value: typing.Optional[typing.List["VpcPeeringConnectionRequester"]]
    ) -> None:
        jsii.set(self, "requester", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="timeouts")
    def timeouts(self) -> typing.Optional["VpcPeeringConnectionTimeouts"]:
        return jsii.get(self, "timeouts")

    @timeouts.setter
    def timeouts(self, value: typing.Optional["VpcPeeringConnectionTimeouts"]) -> None:
        jsii.set(self, "timeouts", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionAccepter",
    jsii_struct_bases=[],
    name_mapping={
        "allow_classic_link_to_remote_vpc": "allowClassicLinkToRemoteVpc",
        "allow_remote_vpc_dns_resolution": "allowRemoteVpcDnsResolution",
        "allow_vpc_to_remote_classic_link": "allowVpcToRemoteClassicLink",
    },
)
class VpcPeeringConnectionAccepter:
    def __init__(
        self,
        *,
        allow_classic_link_to_remote_vpc: typing.Optional[bool] = None,
        allow_remote_vpc_dns_resolution: typing.Optional[bool] = None,
        allow_vpc_to_remote_classic_link: typing.Optional[bool] = None,
    ) -> None:
        """
        :param allow_classic_link_to_remote_vpc: 
        :param allow_remote_vpc_dns_resolution: 
        :param allow_vpc_to_remote_classic_link: 
        """
        self._values = {}
        if allow_classic_link_to_remote_vpc is not None:
            self._values[
                "allow_classic_link_to_remote_vpc"
            ] = allow_classic_link_to_remote_vpc
        if allow_remote_vpc_dns_resolution is not None:
            self._values[
                "allow_remote_vpc_dns_resolution"
            ] = allow_remote_vpc_dns_resolution
        if allow_vpc_to_remote_classic_link is not None:
            self._values[
                "allow_vpc_to_remote_classic_link"
            ] = allow_vpc_to_remote_classic_link

    @builtins.property
    def allow_classic_link_to_remote_vpc(self) -> typing.Optional[bool]:
        return self._values.get("allow_classic_link_to_remote_vpc")

    @builtins.property
    def allow_remote_vpc_dns_resolution(self) -> typing.Optional[bool]:
        return self._values.get("allow_remote_vpc_dns_resolution")

    @builtins.property
    def allow_vpc_to_remote_classic_link(self) -> typing.Optional[bool]:
        return self._values.get("allow_vpc_to_remote_classic_link")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionAccepter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcPeeringConnectionAccepterA(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionAccepterA",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_peering_connection_id: str,
        accepter: typing.Optional[
            typing.List["VpcPeeringConnectionAccepterAccepter"]
        ] = None,
        auto_accept: typing.Optional[bool] = None,
        requester: typing.Optional[
            typing.List["VpcPeeringConnectionAccepterRequester"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_peering_connection_id: 
        :param accepter: accepter block.
        :param auto_accept: 
        :param requester: requester block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcPeeringConnectionAccepterAConfig(
            vpc_peering_connection_id=vpc_peering_connection_id,
            accepter=accepter,
            auto_accept=auto_accept,
            requester=requester,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcPeeringConnectionAccepterA, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="acceptStatus")
    def accept_status(self) -> str:
        return jsii.get(self, "acceptStatus")

    @builtins.property
    @jsii.member(jsii_name="peerOwnerId")
    def peer_owner_id(self) -> str:
        return jsii.get(self, "peerOwnerId")

    @builtins.property
    @jsii.member(jsii_name="peerRegion")
    def peer_region(self) -> str:
        return jsii.get(self, "peerRegion")

    @builtins.property
    @jsii.member(jsii_name="peerVpcId")
    def peer_vpc_id(self) -> str:
        return jsii.get(self, "peerVpcId")

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @builtins.property
    @jsii.member(jsii_name="vpcPeeringConnectionId")
    def vpc_peering_connection_id(self) -> str:
        return jsii.get(self, "vpcPeeringConnectionId")

    @vpc_peering_connection_id.setter
    def vpc_peering_connection_id(self, value: str) -> None:
        jsii.set(self, "vpcPeeringConnectionId", value)

    @builtins.property
    @jsii.member(jsii_name="accepter")
    def accepter(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionAccepterAccepter"]]:
        return jsii.get(self, "accepter")

    @accepter.setter
    def accepter(
        self,
        value: typing.Optional[typing.List["VpcPeeringConnectionAccepterAccepter"]],
    ) -> None:
        jsii.set(self, "accepter", value)

    @builtins.property
    @jsii.member(jsii_name="autoAccept")
    def auto_accept(self) -> typing.Optional[bool]:
        return jsii.get(self, "autoAccept")

    @auto_accept.setter
    def auto_accept(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "autoAccept", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="requester")
    def requester(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionAccepterRequester"]]:
        return jsii.get(self, "requester")

    @requester.setter
    def requester(
        self,
        value: typing.Optional[typing.List["VpcPeeringConnectionAccepterRequester"]],
    ) -> None:
        jsii.set(self, "requester", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionAccepterAConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_peering_connection_id": "vpcPeeringConnectionId",
        "accepter": "accepter",
        "auto_accept": "autoAccept",
        "requester": "requester",
        "tags": "tags",
    },
)
class VpcPeeringConnectionAccepterAConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_peering_connection_id: str,
        accepter: typing.Optional[
            typing.List["VpcPeeringConnectionAccepterAccepter"]
        ] = None,
        auto_accept: typing.Optional[bool] = None,
        requester: typing.Optional[
            typing.List["VpcPeeringConnectionAccepterRequester"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_peering_connection_id: 
        :param accepter: accepter block.
        :param auto_accept: 
        :param requester: requester block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_peering_connection_id": vpc_peering_connection_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if accepter is not None:
            self._values["accepter"] = accepter
        if auto_accept is not None:
            self._values["auto_accept"] = auto_accept
        if requester is not None:
            self._values["requester"] = requester
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_peering_connection_id(self) -> str:
        return self._values.get("vpc_peering_connection_id")

    @builtins.property
    def accepter(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionAccepterAccepter"]]:
        """accepter block."""
        return self._values.get("accepter")

    @builtins.property
    def auto_accept(self) -> typing.Optional[bool]:
        return self._values.get("auto_accept")

    @builtins.property
    def requester(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionAccepterRequester"]]:
        """requester block."""
        return self._values.get("requester")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionAccepterAConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionAccepterAccepter",
    jsii_struct_bases=[],
    name_mapping={
        "allow_classic_link_to_remote_vpc": "allowClassicLinkToRemoteVpc",
        "allow_remote_vpc_dns_resolution": "allowRemoteVpcDnsResolution",
        "allow_vpc_to_remote_classic_link": "allowVpcToRemoteClassicLink",
    },
)
class VpcPeeringConnectionAccepterAccepter:
    def __init__(
        self,
        *,
        allow_classic_link_to_remote_vpc: typing.Optional[bool] = None,
        allow_remote_vpc_dns_resolution: typing.Optional[bool] = None,
        allow_vpc_to_remote_classic_link: typing.Optional[bool] = None,
    ) -> None:
        """
        :param allow_classic_link_to_remote_vpc: 
        :param allow_remote_vpc_dns_resolution: 
        :param allow_vpc_to_remote_classic_link: 
        """
        self._values = {}
        if allow_classic_link_to_remote_vpc is not None:
            self._values[
                "allow_classic_link_to_remote_vpc"
            ] = allow_classic_link_to_remote_vpc
        if allow_remote_vpc_dns_resolution is not None:
            self._values[
                "allow_remote_vpc_dns_resolution"
            ] = allow_remote_vpc_dns_resolution
        if allow_vpc_to_remote_classic_link is not None:
            self._values[
                "allow_vpc_to_remote_classic_link"
            ] = allow_vpc_to_remote_classic_link

    @builtins.property
    def allow_classic_link_to_remote_vpc(self) -> typing.Optional[bool]:
        return self._values.get("allow_classic_link_to_remote_vpc")

    @builtins.property
    def allow_remote_vpc_dns_resolution(self) -> typing.Optional[bool]:
        return self._values.get("allow_remote_vpc_dns_resolution")

    @builtins.property
    def allow_vpc_to_remote_classic_link(self) -> typing.Optional[bool]:
        return self._values.get("allow_vpc_to_remote_classic_link")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionAccepterAccepter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionAccepterRequester",
    jsii_struct_bases=[],
    name_mapping={
        "allow_classic_link_to_remote_vpc": "allowClassicLinkToRemoteVpc",
        "allow_remote_vpc_dns_resolution": "allowRemoteVpcDnsResolution",
        "allow_vpc_to_remote_classic_link": "allowVpcToRemoteClassicLink",
    },
)
class VpcPeeringConnectionAccepterRequester:
    def __init__(
        self,
        *,
        allow_classic_link_to_remote_vpc: typing.Optional[bool] = None,
        allow_remote_vpc_dns_resolution: typing.Optional[bool] = None,
        allow_vpc_to_remote_classic_link: typing.Optional[bool] = None,
    ) -> None:
        """
        :param allow_classic_link_to_remote_vpc: 
        :param allow_remote_vpc_dns_resolution: 
        :param allow_vpc_to_remote_classic_link: 
        """
        self._values = {}
        if allow_classic_link_to_remote_vpc is not None:
            self._values[
                "allow_classic_link_to_remote_vpc"
            ] = allow_classic_link_to_remote_vpc
        if allow_remote_vpc_dns_resolution is not None:
            self._values[
                "allow_remote_vpc_dns_resolution"
            ] = allow_remote_vpc_dns_resolution
        if allow_vpc_to_remote_classic_link is not None:
            self._values[
                "allow_vpc_to_remote_classic_link"
            ] = allow_vpc_to_remote_classic_link

    @builtins.property
    def allow_classic_link_to_remote_vpc(self) -> typing.Optional[bool]:
        return self._values.get("allow_classic_link_to_remote_vpc")

    @builtins.property
    def allow_remote_vpc_dns_resolution(self) -> typing.Optional[bool]:
        return self._values.get("allow_remote_vpc_dns_resolution")

    @builtins.property
    def allow_vpc_to_remote_classic_link(self) -> typing.Optional[bool]:
        return self._values.get("allow_vpc_to_remote_classic_link")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionAccepterRequester(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "peer_vpc_id": "peerVpcId",
        "vpc_id": "vpcId",
        "accepter": "accepter",
        "auto_accept": "autoAccept",
        "peer_owner_id": "peerOwnerId",
        "peer_region": "peerRegion",
        "requester": "requester",
        "tags": "tags",
        "timeouts": "timeouts",
    },
)
class VpcPeeringConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        peer_vpc_id: str,
        vpc_id: str,
        accepter: typing.Optional[typing.List["VpcPeeringConnectionAccepter"]] = None,
        auto_accept: typing.Optional[bool] = None,
        peer_owner_id: typing.Optional[str] = None,
        peer_region: typing.Optional[str] = None,
        requester: typing.Optional[typing.List["VpcPeeringConnectionRequester"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        timeouts: typing.Optional["VpcPeeringConnectionTimeouts"] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param peer_vpc_id: 
        :param vpc_id: 
        :param accepter: accepter block.
        :param auto_accept: 
        :param peer_owner_id: 
        :param peer_region: 
        :param requester: requester block.
        :param tags: 
        :param timeouts: timeouts block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        if isinstance(timeouts, dict):
            timeouts = VpcPeeringConnectionTimeouts(**timeouts)
        self._values = {
            "peer_vpc_id": peer_vpc_id,
            "vpc_id": vpc_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if accepter is not None:
            self._values["accepter"] = accepter
        if auto_accept is not None:
            self._values["auto_accept"] = auto_accept
        if peer_owner_id is not None:
            self._values["peer_owner_id"] = peer_owner_id
        if peer_region is not None:
            self._values["peer_region"] = peer_region
        if requester is not None:
            self._values["requester"] = requester
        if tags is not None:
            self._values["tags"] = tags
        if timeouts is not None:
            self._values["timeouts"] = timeouts

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def peer_vpc_id(self) -> str:
        return self._values.get("peer_vpc_id")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def accepter(self) -> typing.Optional[typing.List["VpcPeeringConnectionAccepter"]]:
        """accepter block."""
        return self._values.get("accepter")

    @builtins.property
    def auto_accept(self) -> typing.Optional[bool]:
        return self._values.get("auto_accept")

    @builtins.property
    def peer_owner_id(self) -> typing.Optional[str]:
        return self._values.get("peer_owner_id")

    @builtins.property
    def peer_region(self) -> typing.Optional[str]:
        return self._values.get("peer_region")

    @builtins.property
    def requester(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionRequester"]]:
        """requester block."""
        return self._values.get("requester")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def timeouts(self) -> typing.Optional["VpcPeeringConnectionTimeouts"]:
        """timeouts block."""
        return self._values.get("timeouts")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpcPeeringConnectionOptions(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionOptions",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_peering_connection_id: str,
        accepter: typing.Optional[
            typing.List["VpcPeeringConnectionOptionsAccepter"]
        ] = None,
        requester: typing.Optional[
            typing.List["VpcPeeringConnectionOptionsRequester"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_peering_connection_id: 
        :param accepter: accepter block.
        :param requester: requester block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpcPeeringConnectionOptionsConfig(
            vpc_peering_connection_id=vpc_peering_connection_id,
            accepter=accepter,
            requester=requester,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpcPeeringConnectionOptions, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="vpcPeeringConnectionId")
    def vpc_peering_connection_id(self) -> str:
        return jsii.get(self, "vpcPeeringConnectionId")

    @vpc_peering_connection_id.setter
    def vpc_peering_connection_id(self, value: str) -> None:
        jsii.set(self, "vpcPeeringConnectionId", value)

    @builtins.property
    @jsii.member(jsii_name="accepter")
    def accepter(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionOptionsAccepter"]]:
        return jsii.get(self, "accepter")

    @accepter.setter
    def accepter(
        self, value: typing.Optional[typing.List["VpcPeeringConnectionOptionsAccepter"]]
    ) -> None:
        jsii.set(self, "accepter", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="requester")
    def requester(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionOptionsRequester"]]:
        return jsii.get(self, "requester")

    @requester.setter
    def requester(
        self,
        value: typing.Optional[typing.List["VpcPeeringConnectionOptionsRequester"]],
    ) -> None:
        jsii.set(self, "requester", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionOptionsAccepter",
    jsii_struct_bases=[],
    name_mapping={
        "allow_classic_link_to_remote_vpc": "allowClassicLinkToRemoteVpc",
        "allow_remote_vpc_dns_resolution": "allowRemoteVpcDnsResolution",
        "allow_vpc_to_remote_classic_link": "allowVpcToRemoteClassicLink",
    },
)
class VpcPeeringConnectionOptionsAccepter:
    def __init__(
        self,
        *,
        allow_classic_link_to_remote_vpc: typing.Optional[bool] = None,
        allow_remote_vpc_dns_resolution: typing.Optional[bool] = None,
        allow_vpc_to_remote_classic_link: typing.Optional[bool] = None,
    ) -> None:
        """
        :param allow_classic_link_to_remote_vpc: 
        :param allow_remote_vpc_dns_resolution: 
        :param allow_vpc_to_remote_classic_link: 
        """
        self._values = {}
        if allow_classic_link_to_remote_vpc is not None:
            self._values[
                "allow_classic_link_to_remote_vpc"
            ] = allow_classic_link_to_remote_vpc
        if allow_remote_vpc_dns_resolution is not None:
            self._values[
                "allow_remote_vpc_dns_resolution"
            ] = allow_remote_vpc_dns_resolution
        if allow_vpc_to_remote_classic_link is not None:
            self._values[
                "allow_vpc_to_remote_classic_link"
            ] = allow_vpc_to_remote_classic_link

    @builtins.property
    def allow_classic_link_to_remote_vpc(self) -> typing.Optional[bool]:
        return self._values.get("allow_classic_link_to_remote_vpc")

    @builtins.property
    def allow_remote_vpc_dns_resolution(self) -> typing.Optional[bool]:
        return self._values.get("allow_remote_vpc_dns_resolution")

    @builtins.property
    def allow_vpc_to_remote_classic_link(self) -> typing.Optional[bool]:
        return self._values.get("allow_vpc_to_remote_classic_link")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionOptionsAccepter(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionOptionsConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_peering_connection_id": "vpcPeeringConnectionId",
        "accepter": "accepter",
        "requester": "requester",
    },
)
class VpcPeeringConnectionOptionsConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_peering_connection_id: str,
        accepter: typing.Optional[
            typing.List["VpcPeeringConnectionOptionsAccepter"]
        ] = None,
        requester: typing.Optional[
            typing.List["VpcPeeringConnectionOptionsRequester"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_peering_connection_id: 
        :param accepter: accepter block.
        :param requester: requester block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_peering_connection_id": vpc_peering_connection_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if accepter is not None:
            self._values["accepter"] = accepter
        if requester is not None:
            self._values["requester"] = requester

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_peering_connection_id(self) -> str:
        return self._values.get("vpc_peering_connection_id")

    @builtins.property
    def accepter(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionOptionsAccepter"]]:
        """accepter block."""
        return self._values.get("accepter")

    @builtins.property
    def requester(
        self,
    ) -> typing.Optional[typing.List["VpcPeeringConnectionOptionsRequester"]]:
        """requester block."""
        return self._values.get("requester")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionOptionsConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionOptionsRequester",
    jsii_struct_bases=[],
    name_mapping={
        "allow_classic_link_to_remote_vpc": "allowClassicLinkToRemoteVpc",
        "allow_remote_vpc_dns_resolution": "allowRemoteVpcDnsResolution",
        "allow_vpc_to_remote_classic_link": "allowVpcToRemoteClassicLink",
    },
)
class VpcPeeringConnectionOptionsRequester:
    def __init__(
        self,
        *,
        allow_classic_link_to_remote_vpc: typing.Optional[bool] = None,
        allow_remote_vpc_dns_resolution: typing.Optional[bool] = None,
        allow_vpc_to_remote_classic_link: typing.Optional[bool] = None,
    ) -> None:
        """
        :param allow_classic_link_to_remote_vpc: 
        :param allow_remote_vpc_dns_resolution: 
        :param allow_vpc_to_remote_classic_link: 
        """
        self._values = {}
        if allow_classic_link_to_remote_vpc is not None:
            self._values[
                "allow_classic_link_to_remote_vpc"
            ] = allow_classic_link_to_remote_vpc
        if allow_remote_vpc_dns_resolution is not None:
            self._values[
                "allow_remote_vpc_dns_resolution"
            ] = allow_remote_vpc_dns_resolution
        if allow_vpc_to_remote_classic_link is not None:
            self._values[
                "allow_vpc_to_remote_classic_link"
            ] = allow_vpc_to_remote_classic_link

    @builtins.property
    def allow_classic_link_to_remote_vpc(self) -> typing.Optional[bool]:
        return self._values.get("allow_classic_link_to_remote_vpc")

    @builtins.property
    def allow_remote_vpc_dns_resolution(self) -> typing.Optional[bool]:
        return self._values.get("allow_remote_vpc_dns_resolution")

    @builtins.property
    def allow_vpc_to_remote_classic_link(self) -> typing.Optional[bool]:
        return self._values.get("allow_vpc_to_remote_classic_link")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionOptionsRequester(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionRequester",
    jsii_struct_bases=[],
    name_mapping={
        "allow_classic_link_to_remote_vpc": "allowClassicLinkToRemoteVpc",
        "allow_remote_vpc_dns_resolution": "allowRemoteVpcDnsResolution",
        "allow_vpc_to_remote_classic_link": "allowVpcToRemoteClassicLink",
    },
)
class VpcPeeringConnectionRequester:
    def __init__(
        self,
        *,
        allow_classic_link_to_remote_vpc: typing.Optional[bool] = None,
        allow_remote_vpc_dns_resolution: typing.Optional[bool] = None,
        allow_vpc_to_remote_classic_link: typing.Optional[bool] = None,
    ) -> None:
        """
        :param allow_classic_link_to_remote_vpc: 
        :param allow_remote_vpc_dns_resolution: 
        :param allow_vpc_to_remote_classic_link: 
        """
        self._values = {}
        if allow_classic_link_to_remote_vpc is not None:
            self._values[
                "allow_classic_link_to_remote_vpc"
            ] = allow_classic_link_to_remote_vpc
        if allow_remote_vpc_dns_resolution is not None:
            self._values[
                "allow_remote_vpc_dns_resolution"
            ] = allow_remote_vpc_dns_resolution
        if allow_vpc_to_remote_classic_link is not None:
            self._values[
                "allow_vpc_to_remote_classic_link"
            ] = allow_vpc_to_remote_classic_link

    @builtins.property
    def allow_classic_link_to_remote_vpc(self) -> typing.Optional[bool]:
        return self._values.get("allow_classic_link_to_remote_vpc")

    @builtins.property
    def allow_remote_vpc_dns_resolution(self) -> typing.Optional[bool]:
        return self._values.get("allow_remote_vpc_dns_resolution")

    @builtins.property
    def allow_vpc_to_remote_classic_link(self) -> typing.Optional[bool]:
        return self._values.get("allow_vpc_to_remote_classic_link")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionRequester(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpcPeeringConnectionTimeouts",
    jsii_struct_bases=[],
    name_mapping={"create": "create", "delete": "delete", "update": "update"},
)
class VpcPeeringConnectionTimeouts:
    def __init__(
        self,
        *,
        create: typing.Optional[str] = None,
        delete: typing.Optional[str] = None,
        update: typing.Optional[str] = None,
    ) -> None:
        """
        :param create: 
        :param delete: 
        :param update: 
        """
        self._values = {}
        if create is not None:
            self._values["create"] = create
        if delete is not None:
            self._values["delete"] = delete
        if update is not None:
            self._values["update"] = update

    @builtins.property
    def create(self) -> typing.Optional[str]:
        return self._values.get("create")

    @builtins.property
    def delete(self) -> typing.Optional[str]:
        return self._values.get("delete")

    @builtins.property
    def update(self) -> typing.Optional[str]:
        return self._values.get("update")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpcPeeringConnectionTimeouts(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpnConnection(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpnConnection",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        customer_gateway_id: str,
        type: str,
        static_routes_only: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_id: typing.Optional[str] = None,
        tunnel1_inside_cidr: typing.Optional[str] = None,
        tunnel1_preshared_key: typing.Optional[str] = None,
        tunnel2_inside_cidr: typing.Optional[str] = None,
        tunnel2_preshared_key: typing.Optional[str] = None,
        vpn_gateway_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param customer_gateway_id: 
        :param type: 
        :param static_routes_only: 
        :param tags: 
        :param transit_gateway_id: 
        :param tunnel1_inside_cidr: 
        :param tunnel1_preshared_key: 
        :param tunnel2_inside_cidr: 
        :param tunnel2_preshared_key: 
        :param vpn_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpnConnectionConfig(
            customer_gateway_id=customer_gateway_id,
            type=type,
            static_routes_only=static_routes_only,
            tags=tags,
            transit_gateway_id=transit_gateway_id,
            tunnel1_inside_cidr=tunnel1_inside_cidr,
            tunnel1_preshared_key=tunnel1_preshared_key,
            tunnel2_inside_cidr=tunnel2_inside_cidr,
            tunnel2_preshared_key=tunnel2_preshared_key,
            vpn_gateway_id=vpn_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpnConnection, self, [scope, id, config])

    @jsii.member(jsii_name="routes")
    def routes(self, index: str) -> "VpnConnectionRoutes":
        """
        :param index: -
        """
        return jsii.invoke(self, "routes", [index])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @jsii.member(jsii_name="vgwTelemetry")
    def vgw_telemetry(self, index: str) -> "VpnConnectionVgwTelemetry":
        """
        :param index: -
        """
        return jsii.invoke(self, "vgwTelemetry", [index])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="customerGatewayConfiguration")
    def customer_gateway_configuration(self) -> str:
        return jsii.get(self, "customerGatewayConfiguration")

    @builtins.property
    @jsii.member(jsii_name="transitGatewayAttachmentId")
    def transit_gateway_attachment_id(self) -> str:
        return jsii.get(self, "transitGatewayAttachmentId")

    @builtins.property
    @jsii.member(jsii_name="tunnel1Address")
    def tunnel1_address(self) -> str:
        return jsii.get(self, "tunnel1Address")

    @builtins.property
    @jsii.member(jsii_name="tunnel1BgpAsn")
    def tunnel1_bgp_asn(self) -> str:
        return jsii.get(self, "tunnel1BgpAsn")

    @builtins.property
    @jsii.member(jsii_name="tunnel1BgpHoldtime")
    def tunnel1_bgp_holdtime(self) -> jsii.Number:
        return jsii.get(self, "tunnel1BgpHoldtime")

    @builtins.property
    @jsii.member(jsii_name="tunnel1CgwInsideAddress")
    def tunnel1_cgw_inside_address(self) -> str:
        return jsii.get(self, "tunnel1CgwInsideAddress")

    @builtins.property
    @jsii.member(jsii_name="tunnel1VgwInsideAddress")
    def tunnel1_vgw_inside_address(self) -> str:
        return jsii.get(self, "tunnel1VgwInsideAddress")

    @builtins.property
    @jsii.member(jsii_name="tunnel2Address")
    def tunnel2_address(self) -> str:
        return jsii.get(self, "tunnel2Address")

    @builtins.property
    @jsii.member(jsii_name="tunnel2BgpAsn")
    def tunnel2_bgp_asn(self) -> str:
        return jsii.get(self, "tunnel2BgpAsn")

    @builtins.property
    @jsii.member(jsii_name="tunnel2BgpHoldtime")
    def tunnel2_bgp_holdtime(self) -> jsii.Number:
        return jsii.get(self, "tunnel2BgpHoldtime")

    @builtins.property
    @jsii.member(jsii_name="tunnel2CgwInsideAddress")
    def tunnel2_cgw_inside_address(self) -> str:
        return jsii.get(self, "tunnel2CgwInsideAddress")

    @builtins.property
    @jsii.member(jsii_name="tunnel2VgwInsideAddress")
    def tunnel2_vgw_inside_address(self) -> str:
        return jsii.get(self, "tunnel2VgwInsideAddress")

    @builtins.property
    @jsii.member(jsii_name="customerGatewayId")
    def customer_gateway_id(self) -> str:
        return jsii.get(self, "customerGatewayId")

    @customer_gateway_id.setter
    def customer_gateway_id(self, value: str) -> None:
        jsii.set(self, "customerGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="type")
    def type(self) -> str:
        return jsii.get(self, "type")

    @type.setter
    def type(self, value: str) -> None:
        jsii.set(self, "type", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="staticRoutesOnly")
    def static_routes_only(self) -> typing.Optional[bool]:
        return jsii.get(self, "staticRoutesOnly")

    @static_routes_only.setter
    def static_routes_only(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "staticRoutesOnly", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="transitGatewayId")
    def transit_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "transitGatewayId")

    @transit_gateway_id.setter
    def transit_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "transitGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="tunnel1InsideCidr")
    def tunnel1_inside_cidr(self) -> typing.Optional[str]:
        return jsii.get(self, "tunnel1InsideCidr")

    @tunnel1_inside_cidr.setter
    def tunnel1_inside_cidr(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tunnel1InsideCidr", value)

    @builtins.property
    @jsii.member(jsii_name="tunnel1PresharedKey")
    def tunnel1_preshared_key(self) -> typing.Optional[str]:
        return jsii.get(self, "tunnel1PresharedKey")

    @tunnel1_preshared_key.setter
    def tunnel1_preshared_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tunnel1PresharedKey", value)

    @builtins.property
    @jsii.member(jsii_name="tunnel2InsideCidr")
    def tunnel2_inside_cidr(self) -> typing.Optional[str]:
        return jsii.get(self, "tunnel2InsideCidr")

    @tunnel2_inside_cidr.setter
    def tunnel2_inside_cidr(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tunnel2InsideCidr", value)

    @builtins.property
    @jsii.member(jsii_name="tunnel2PresharedKey")
    def tunnel2_preshared_key(self) -> typing.Optional[str]:
        return jsii.get(self, "tunnel2PresharedKey")

    @tunnel2_preshared_key.setter
    def tunnel2_preshared_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "tunnel2PresharedKey", value)

    @builtins.property
    @jsii.member(jsii_name="vpnGatewayId")
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpnGatewayId")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpnGatewayId", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpnConnectionConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "customer_gateway_id": "customerGatewayId",
        "type": "type",
        "static_routes_only": "staticRoutesOnly",
        "tags": "tags",
        "transit_gateway_id": "transitGatewayId",
        "tunnel1_inside_cidr": "tunnel1InsideCidr",
        "tunnel1_preshared_key": "tunnel1PresharedKey",
        "tunnel2_inside_cidr": "tunnel2InsideCidr",
        "tunnel2_preshared_key": "tunnel2PresharedKey",
        "vpn_gateway_id": "vpnGatewayId",
    },
)
class VpnConnectionConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        customer_gateway_id: str,
        type: str,
        static_routes_only: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        transit_gateway_id: typing.Optional[str] = None,
        tunnel1_inside_cidr: typing.Optional[str] = None,
        tunnel1_preshared_key: typing.Optional[str] = None,
        tunnel2_inside_cidr: typing.Optional[str] = None,
        tunnel2_preshared_key: typing.Optional[str] = None,
        vpn_gateway_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param customer_gateway_id: 
        :param type: 
        :param static_routes_only: 
        :param tags: 
        :param transit_gateway_id: 
        :param tunnel1_inside_cidr: 
        :param tunnel1_preshared_key: 
        :param tunnel2_inside_cidr: 
        :param tunnel2_preshared_key: 
        :param vpn_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "customer_gateway_id": customer_gateway_id,
            "type": type,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if static_routes_only is not None:
            self._values["static_routes_only"] = static_routes_only
        if tags is not None:
            self._values["tags"] = tags
        if transit_gateway_id is not None:
            self._values["transit_gateway_id"] = transit_gateway_id
        if tunnel1_inside_cidr is not None:
            self._values["tunnel1_inside_cidr"] = tunnel1_inside_cidr
        if tunnel1_preshared_key is not None:
            self._values["tunnel1_preshared_key"] = tunnel1_preshared_key
        if tunnel2_inside_cidr is not None:
            self._values["tunnel2_inside_cidr"] = tunnel2_inside_cidr
        if tunnel2_preshared_key is not None:
            self._values["tunnel2_preshared_key"] = tunnel2_preshared_key
        if vpn_gateway_id is not None:
            self._values["vpn_gateway_id"] = vpn_gateway_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def customer_gateway_id(self) -> str:
        return self._values.get("customer_gateway_id")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def static_routes_only(self) -> typing.Optional[bool]:
        return self._values.get("static_routes_only")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def transit_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("transit_gateway_id")

    @builtins.property
    def tunnel1_inside_cidr(self) -> typing.Optional[str]:
        return self._values.get("tunnel1_inside_cidr")

    @builtins.property
    def tunnel1_preshared_key(self) -> typing.Optional[str]:
        return self._values.get("tunnel1_preshared_key")

    @builtins.property
    def tunnel2_inside_cidr(self) -> typing.Optional[str]:
        return self._values.get("tunnel2_inside_cidr")

    @builtins.property
    def tunnel2_preshared_key(self) -> typing.Optional[str]:
        return self._values.get("tunnel2_preshared_key")

    @builtins.property
    def vpn_gateway_id(self) -> typing.Optional[str]:
        return self._values.get("vpn_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnConnectionConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpnConnectionRoute(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpnConnectionRoute",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        destination_cidr_block: str,
        vpn_connection_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param destination_cidr_block: 
        :param vpn_connection_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpnConnectionRouteConfig(
            destination_cidr_block=destination_cidr_block,
            vpn_connection_id=vpn_connection_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpnConnectionRoute, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> str:
        return jsii.get(self, "destinationCidrBlock")

    @destination_cidr_block.setter
    def destination_cidr_block(self, value: str) -> None:
        jsii.set(self, "destinationCidrBlock", value)

    @builtins.property
    @jsii.member(jsii_name="vpnConnectionId")
    def vpn_connection_id(self) -> str:
        return jsii.get(self, "vpnConnectionId")

    @vpn_connection_id.setter
    def vpn_connection_id(self, value: str) -> None:
        jsii.set(self, "vpnConnectionId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpnConnectionRouteConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "destination_cidr_block": "destinationCidrBlock",
        "vpn_connection_id": "vpnConnectionId",
    },
)
class VpnConnectionRouteConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        destination_cidr_block: str,
        vpn_connection_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param destination_cidr_block: 
        :param vpn_connection_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "destination_cidr_block": destination_cidr_block,
            "vpn_connection_id": vpn_connection_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def destination_cidr_block(self) -> str:
        return self._values.get("destination_cidr_block")

    @builtins.property
    def vpn_connection_id(self) -> str:
        return self._values.get("vpn_connection_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnConnectionRouteConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpnConnectionRoutes(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpnConnectionRoutes",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            VpnConnectionRoutes, self, [terraform_resource, terraform_attribute, index]
        )

    @builtins.property
    @jsii.member(jsii_name="destinationCidrBlock")
    def destination_cidr_block(self) -> str:
        return jsii.get(self, "destinationCidrBlock")

    @builtins.property
    @jsii.member(jsii_name="source")
    def source(self) -> str:
        return jsii.get(self, "source")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")


class VpnConnectionVgwTelemetry(
    cdktf.ComplexComputedList,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpnConnectionVgwTelemetry",
):
    def __init__(
        self,
        terraform_resource: cdktf.ITerraformResource,
        terraform_attribute: str,
        index: str,
    ) -> None:
        """
        :param terraform_resource: -
        :param terraform_attribute: -
        :param index: -

        stability
        :stability: experimental
        """
        jsii.create(
            VpnConnectionVgwTelemetry,
            self,
            [terraform_resource, terraform_attribute, index],
        )

    @builtins.property
    @jsii.member(jsii_name="acceptedRouteCount")
    def accepted_route_count(self) -> jsii.Number:
        return jsii.get(self, "acceptedRouteCount")

    @builtins.property
    @jsii.member(jsii_name="lastStatusChange")
    def last_status_change(self) -> str:
        return jsii.get(self, "lastStatusChange")

    @builtins.property
    @jsii.member(jsii_name="outsideIpAddress")
    def outside_ip_address(self) -> str:
        return jsii.get(self, "outsideIpAddress")

    @builtins.property
    @jsii.member(jsii_name="status")
    def status(self) -> str:
        return jsii.get(self, "status")

    @builtins.property
    @jsii.member(jsii_name="statusMessage")
    def status_message(self) -> str:
        return jsii.get(self, "statusMessage")


class VpnGateway(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpnGateway",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        amazon_side_asn: typing.Optional[str] = None,
        availability_zone: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param amazon_side_asn: 
        :param availability_zone: 
        :param tags: 
        :param vpc_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpnGatewayConfig(
            amazon_side_asn=amazon_side_asn,
            availability_zone=availability_zone,
            tags=tags,
            vpc_id=vpc_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpnGateway, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="amazonSideAsn")
    def amazon_side_asn(self) -> typing.Optional[str]:
        return jsii.get(self, "amazonSideAsn")

    @amazon_side_asn.setter
    def amazon_side_asn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "amazonSideAsn", value)

    @builtins.property
    @jsii.member(jsii_name="availabilityZone")
    def availability_zone(self) -> typing.Optional[str]:
        return jsii.get(self, "availabilityZone")

    @availability_zone.setter
    def availability_zone(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "availabilityZone", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> typing.Optional[str]:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "vpcId", value)


class VpnGatewayAttachment(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpnGatewayAttachment",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        vpc_id: str,
        vpn_gateway_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param vpc_id: 
        :param vpn_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpnGatewayAttachmentConfig(
            vpc_id=vpc_id,
            vpn_gateway_id=vpn_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpnGatewayAttachment, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="vpcId")
    def vpc_id(self) -> str:
        return jsii.get(self, "vpcId")

    @vpc_id.setter
    def vpc_id(self, value: str) -> None:
        jsii.set(self, "vpcId", value)

    @builtins.property
    @jsii.member(jsii_name="vpnGatewayId")
    def vpn_gateway_id(self) -> str:
        return jsii.get(self, "vpnGatewayId")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: str) -> None:
        jsii.set(self, "vpnGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpnGatewayAttachmentConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "vpc_id": "vpcId",
        "vpn_gateway_id": "vpnGatewayId",
    },
)
class VpnGatewayAttachmentConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        vpc_id: str,
        vpn_gateway_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param vpc_id: 
        :param vpn_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "vpc_id": vpc_id,
            "vpn_gateway_id": vpn_gateway_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    @builtins.property
    def vpn_gateway_id(self) -> str:
        return self._values.get("vpn_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnGatewayAttachmentConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpnGatewayConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "amazon_side_asn": "amazonSideAsn",
        "availability_zone": "availabilityZone",
        "tags": "tags",
        "vpc_id": "vpcId",
    },
)
class VpnGatewayConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        amazon_side_asn: typing.Optional[str] = None,
        availability_zone: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        vpc_id: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param amazon_side_asn: 
        :param availability_zone: 
        :param tags: 
        :param vpc_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if amazon_side_asn is not None:
            self._values["amazon_side_asn"] = amazon_side_asn
        if availability_zone is not None:
            self._values["availability_zone"] = availability_zone
        if tags is not None:
            self._values["tags"] = tags
        if vpc_id is not None:
            self._values["vpc_id"] = vpc_id

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def amazon_side_asn(self) -> typing.Optional[str]:
        return self._values.get("amazon_side_asn")

    @builtins.property
    def availability_zone(self) -> typing.Optional[str]:
        return self._values.get("availability_zone")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def vpc_id(self) -> typing.Optional[str]:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnGatewayConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class VpnGatewayRoutePropagation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.VpnGatewayRoutePropagation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        route_table_id: str,
        vpn_gateway_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param route_table_id: 
        :param vpn_gateway_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = VpnGatewayRoutePropagationConfig(
            route_table_id=route_table_id,
            vpn_gateway_id=vpn_gateway_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(VpnGatewayRoutePropagation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="routeTableId")
    def route_table_id(self) -> str:
        return jsii.get(self, "routeTableId")

    @route_table_id.setter
    def route_table_id(self, value: str) -> None:
        jsii.set(self, "routeTableId", value)

    @builtins.property
    @jsii.member(jsii_name="vpnGatewayId")
    def vpn_gateway_id(self) -> str:
        return jsii.get(self, "vpnGatewayId")

    @vpn_gateway_id.setter
    def vpn_gateway_id(self, value: str) -> None:
        jsii.set(self, "vpnGatewayId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.VpnGatewayRoutePropagationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "route_table_id": "routeTableId",
        "vpn_gateway_id": "vpnGatewayId",
    },
)
class VpnGatewayRoutePropagationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        route_table_id: str,
        vpn_gateway_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param route_table_id: 
        :param vpn_gateway_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "route_table_id": route_table_id,
            "vpn_gateway_id": vpn_gateway_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def route_table_id(self) -> str:
        return self._values.get("route_table_id")

    @builtins.property
    def vpn_gateway_id(self) -> str:
        return self._values.get("vpn_gateway_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "VpnGatewayRoutePropagationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafByteMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafByteMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        byte_match_tuples: typing.Optional[
            typing.List["WafByteMatchSetByteMatchTuples"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param byte_match_tuples: byte_match_tuples block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafByteMatchSetConfig(
            name=name,
            byte_match_tuples=byte_match_tuples,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafByteMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="byteMatchTuples")
    def byte_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafByteMatchSetByteMatchTuples"]]:
        return jsii.get(self, "byteMatchTuples")

    @byte_match_tuples.setter
    def byte_match_tuples(
        self, value: typing.Optional[typing.List["WafByteMatchSetByteMatchTuples"]]
    ) -> None:
        jsii.set(self, "byteMatchTuples", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafByteMatchSetByteMatchTuples",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "positional_constraint": "positionalConstraint",
        "text_transformation": "textTransformation",
        "target_string": "targetString",
    },
)
class WafByteMatchSetByteMatchTuples:
    def __init__(
        self,
        *,
        field_to_match: typing.List["WafByteMatchSetByteMatchTuplesFieldToMatch"],
        positional_constraint: str,
        text_transformation: str,
        target_string: typing.Optional[str] = None,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param positional_constraint: 
        :param text_transformation: 
        :param target_string: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "positional_constraint": positional_constraint,
            "text_transformation": text_transformation,
        }
        if target_string is not None:
            self._values["target_string"] = target_string

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafByteMatchSetByteMatchTuplesFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    @builtins.property
    def target_string(self) -> typing.Optional[str]:
        return self._values.get("target_string")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafByteMatchSetByteMatchTuples(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafByteMatchSetByteMatchTuplesFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafByteMatchSetByteMatchTuplesFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafByteMatchSetByteMatchTuplesFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafByteMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "byte_match_tuples": "byteMatchTuples",
    },
)
class WafByteMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        byte_match_tuples: typing.Optional[
            typing.List["WafByteMatchSetByteMatchTuples"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param byte_match_tuples: byte_match_tuples block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if byte_match_tuples is not None:
            self._values["byte_match_tuples"] = byte_match_tuples

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def byte_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafByteMatchSetByteMatchTuples"]]:
        """byte_match_tuples block."""
        return self._values.get("byte_match_tuples")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafByteMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafGeoMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafGeoMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        geo_match_constraint: typing.Optional[
            typing.List["WafGeoMatchSetGeoMatchConstraint"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param geo_match_constraint: geo_match_constraint block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafGeoMatchSetConfig(
            name=name,
            geo_match_constraint=geo_match_constraint,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafGeoMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="geoMatchConstraint")
    def geo_match_constraint(
        self,
    ) -> typing.Optional[typing.List["WafGeoMatchSetGeoMatchConstraint"]]:
        return jsii.get(self, "geoMatchConstraint")

    @geo_match_constraint.setter
    def geo_match_constraint(
        self, value: typing.Optional[typing.List["WafGeoMatchSetGeoMatchConstraint"]]
    ) -> None:
        jsii.set(self, "geoMatchConstraint", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafGeoMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "geo_match_constraint": "geoMatchConstraint",
    },
)
class WafGeoMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        geo_match_constraint: typing.Optional[
            typing.List["WafGeoMatchSetGeoMatchConstraint"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param geo_match_constraint: geo_match_constraint block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if geo_match_constraint is not None:
            self._values["geo_match_constraint"] = geo_match_constraint

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def geo_match_constraint(
        self,
    ) -> typing.Optional[typing.List["WafGeoMatchSetGeoMatchConstraint"]]:
        """geo_match_constraint block."""
        return self._values.get("geo_match_constraint")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafGeoMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafGeoMatchSetGeoMatchConstraint",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "value": "value"},
)
class WafGeoMatchSetGeoMatchConstraint:
    def __init__(self, *, type: str, value: str) -> None:
        """
        :param type: 
        :param value: 
        """
        self._values = {
            "type": type,
            "value": value,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafGeoMatchSetGeoMatchConstraint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafIpset(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafIpset",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        ip_set_descriptors: typing.Optional[
            typing.List["WafIpsetIpSetDescriptors"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param ip_set_descriptors: ip_set_descriptors block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafIpsetConfig(
            name=name,
            ip_set_descriptors=ip_set_descriptors,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafIpset, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipSetDescriptors")
    def ip_set_descriptors(
        self,
    ) -> typing.Optional[typing.List["WafIpsetIpSetDescriptors"]]:
        return jsii.get(self, "ipSetDescriptors")

    @ip_set_descriptors.setter
    def ip_set_descriptors(
        self, value: typing.Optional[typing.List["WafIpsetIpSetDescriptors"]]
    ) -> None:
        jsii.set(self, "ipSetDescriptors", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafIpsetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "ip_set_descriptors": "ipSetDescriptors",
    },
)
class WafIpsetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        ip_set_descriptors: typing.Optional[
            typing.List["WafIpsetIpSetDescriptors"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param ip_set_descriptors: ip_set_descriptors block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ip_set_descriptors is not None:
            self._values["ip_set_descriptors"] = ip_set_descriptors

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def ip_set_descriptors(
        self,
    ) -> typing.Optional[typing.List["WafIpsetIpSetDescriptors"]]:
        """ip_set_descriptors block."""
        return self._values.get("ip_set_descriptors")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafIpsetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafIpsetIpSetDescriptors",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "value": "value"},
)
class WafIpsetIpSetDescriptors:
    def __init__(self, *, type: str, value: str) -> None:
        """
        :param type: 
        :param value: 
        """
        self._values = {
            "type": type,
            "value": value,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafIpsetIpSetDescriptors(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafRateBasedRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafRateBasedRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        metric_name: str,
        name: str,
        rate_key: str,
        rate_limit: jsii.Number,
        predicates: typing.Optional[typing.List["WafRateBasedRulePredicates"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param metric_name: 
        :param name: 
        :param rate_key: 
        :param rate_limit: 
        :param predicates: predicates block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafRateBasedRuleConfig(
            metric_name=metric_name,
            name=name,
            rate_key=rate_key,
            rate_limit=rate_limit,
            predicates=predicates,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafRateBasedRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="rateKey")
    def rate_key(self) -> str:
        return jsii.get(self, "rateKey")

    @rate_key.setter
    def rate_key(self, value: str) -> None:
        jsii.set(self, "rateKey", value)

    @builtins.property
    @jsii.member(jsii_name="rateLimit")
    def rate_limit(self) -> jsii.Number:
        return jsii.get(self, "rateLimit")

    @rate_limit.setter
    def rate_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "rateLimit", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="predicates")
    def predicates(self) -> typing.Optional[typing.List["WafRateBasedRulePredicates"]]:
        return jsii.get(self, "predicates")

    @predicates.setter
    def predicates(
        self, value: typing.Optional[typing.List["WafRateBasedRulePredicates"]]
    ) -> None:
        jsii.set(self, "predicates", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRateBasedRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "metric_name": "metricName",
        "name": "name",
        "rate_key": "rateKey",
        "rate_limit": "rateLimit",
        "predicates": "predicates",
        "tags": "tags",
    },
)
class WafRateBasedRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        metric_name: str,
        name: str,
        rate_key: str,
        rate_limit: jsii.Number,
        predicates: typing.Optional[typing.List["WafRateBasedRulePredicates"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param metric_name: 
        :param name: 
        :param rate_key: 
        :param rate_limit: 
        :param predicates: predicates block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "metric_name": metric_name,
            "name": name,
            "rate_key": rate_key,
            "rate_limit": rate_limit,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if predicates is not None:
            self._values["predicates"] = predicates
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rate_key(self) -> str:
        return self._values.get("rate_key")

    @builtins.property
    def rate_limit(self) -> jsii.Number:
        return self._values.get("rate_limit")

    @builtins.property
    def predicates(self) -> typing.Optional[typing.List["WafRateBasedRulePredicates"]]:
        """predicates block."""
        return self._values.get("predicates")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRateBasedRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRateBasedRulePredicates",
    jsii_struct_bases=[],
    name_mapping={"data_id": "dataId", "negated": "negated", "type": "type"},
)
class WafRateBasedRulePredicates:
    def __init__(self, *, data_id: str, negated: bool, type: str) -> None:
        """
        :param data_id: 
        :param negated: 
        :param type: 
        """
        self._values = {
            "data_id": data_id,
            "negated": negated,
            "type": type,
        }

    @builtins.property
    def data_id(self) -> str:
        return self._values.get("data_id")

    @builtins.property
    def negated(self) -> bool:
        return self._values.get("negated")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRateBasedRulePredicates(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafRegexMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafRegexMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        regex_match_tuple: typing.Optional[
            typing.List["WafRegexMatchSetRegexMatchTuple"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param regex_match_tuple: regex_match_tuple block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafRegexMatchSetConfig(
            name=name,
            regex_match_tuple=regex_match_tuple,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafRegexMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="regexMatchTuple")
    def regex_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafRegexMatchSetRegexMatchTuple"]]:
        return jsii.get(self, "regexMatchTuple")

    @regex_match_tuple.setter
    def regex_match_tuple(
        self, value: typing.Optional[typing.List["WafRegexMatchSetRegexMatchTuple"]]
    ) -> None:
        jsii.set(self, "regexMatchTuple", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRegexMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "regex_match_tuple": "regexMatchTuple",
    },
)
class WafRegexMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        regex_match_tuple: typing.Optional[
            typing.List["WafRegexMatchSetRegexMatchTuple"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param regex_match_tuple: regex_match_tuple block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if regex_match_tuple is not None:
            self._values["regex_match_tuple"] = regex_match_tuple

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def regex_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafRegexMatchSetRegexMatchTuple"]]:
        """regex_match_tuple block."""
        return self._values.get("regex_match_tuple")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRegexMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRegexMatchSetRegexMatchTuple",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "regex_pattern_set_id": "regexPatternSetId",
        "text_transformation": "textTransformation",
    },
)
class WafRegexMatchSetRegexMatchTuple:
    def __init__(
        self,
        *,
        field_to_match: typing.List["WafRegexMatchSetRegexMatchTupleFieldToMatch"],
        regex_pattern_set_id: str,
        text_transformation: str,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param regex_pattern_set_id: 
        :param text_transformation: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "regex_pattern_set_id": regex_pattern_set_id,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafRegexMatchSetRegexMatchTupleFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def regex_pattern_set_id(self) -> str:
        return self._values.get("regex_pattern_set_id")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRegexMatchSetRegexMatchTuple(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRegexMatchSetRegexMatchTupleFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafRegexMatchSetRegexMatchTupleFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRegexMatchSetRegexMatchTupleFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafRegexPatternSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafRegexPatternSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        regex_pattern_strings: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param regex_pattern_strings: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafRegexPatternSetConfig(
            name=name,
            regex_pattern_strings=regex_pattern_strings,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafRegexPatternSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="regexPatternStrings")
    def regex_pattern_strings(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "regexPatternStrings")

    @regex_pattern_strings.setter
    def regex_pattern_strings(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "regexPatternStrings", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRegexPatternSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "regex_pattern_strings": "regexPatternStrings",
    },
)
class WafRegexPatternSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        regex_pattern_strings: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param regex_pattern_strings: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if regex_pattern_strings is not None:
            self._values["regex_pattern_strings"] = regex_pattern_strings

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def regex_pattern_strings(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("regex_pattern_strings")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRegexPatternSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        metric_name: str,
        name: str,
        predicates: typing.Optional[typing.List["WafRulePredicates"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param metric_name: 
        :param name: 
        :param predicates: predicates block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafRuleConfig(
            metric_name=metric_name,
            name=name,
            predicates=predicates,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="predicates")
    def predicates(self) -> typing.Optional[typing.List["WafRulePredicates"]]:
        return jsii.get(self, "predicates")

    @predicates.setter
    def predicates(
        self, value: typing.Optional[typing.List["WafRulePredicates"]]
    ) -> None:
        jsii.set(self, "predicates", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "metric_name": "metricName",
        "name": "name",
        "predicates": "predicates",
        "tags": "tags",
    },
)
class WafRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        metric_name: str,
        name: str,
        predicates: typing.Optional[typing.List["WafRulePredicates"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param metric_name: 
        :param name: 
        :param predicates: predicates block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "metric_name": metric_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if predicates is not None:
            self._values["predicates"] = predicates
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def predicates(self) -> typing.Optional[typing.List["WafRulePredicates"]]:
        """predicates block."""
        return self._values.get("predicates")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafRuleGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafRuleGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        metric_name: str,
        name: str,
        activated_rule: typing.Optional[
            typing.List["WafRuleGroupActivatedRule"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param metric_name: 
        :param name: 
        :param activated_rule: activated_rule block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafRuleGroupConfig(
            metric_name=metric_name,
            name=name,
            activated_rule=activated_rule,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafRuleGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="activatedRule")
    def activated_rule(
        self,
    ) -> typing.Optional[typing.List["WafRuleGroupActivatedRule"]]:
        return jsii.get(self, "activatedRule")

    @activated_rule.setter
    def activated_rule(
        self, value: typing.Optional[typing.List["WafRuleGroupActivatedRule"]]
    ) -> None:
        jsii.set(self, "activatedRule", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRuleGroupActivatedRule",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "priority": "priority",
        "rule_id": "ruleId",
        "type": "type",
    },
)
class WafRuleGroupActivatedRule:
    def __init__(
        self,
        *,
        action: typing.List["WafRuleGroupActivatedRuleAction"],
        priority: jsii.Number,
        rule_id: str,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param action: action block.
        :param priority: 
        :param rule_id: 
        :param type: 
        """
        self._values = {
            "action": action,
            "priority": priority,
            "rule_id": rule_id,
        }
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def action(self) -> typing.List["WafRuleGroupActivatedRuleAction"]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def rule_id(self) -> str:
        return self._values.get("rule_id")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRuleGroupActivatedRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRuleGroupActivatedRuleAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafRuleGroupActivatedRuleAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRuleGroupActivatedRuleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRuleGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "metric_name": "metricName",
        "name": "name",
        "activated_rule": "activatedRule",
        "tags": "tags",
    },
)
class WafRuleGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        metric_name: str,
        name: str,
        activated_rule: typing.Optional[
            typing.List["WafRuleGroupActivatedRule"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param metric_name: 
        :param name: 
        :param activated_rule: activated_rule block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "metric_name": metric_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if activated_rule is not None:
            self._values["activated_rule"] = activated_rule
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def activated_rule(
        self,
    ) -> typing.Optional[typing.List["WafRuleGroupActivatedRule"]]:
        """activated_rule block."""
        return self._values.get("activated_rule")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRuleGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafRulePredicates",
    jsii_struct_bases=[],
    name_mapping={"data_id": "dataId", "negated": "negated", "type": "type"},
)
class WafRulePredicates:
    def __init__(self, *, data_id: str, negated: bool, type: str) -> None:
        """
        :param data_id: 
        :param negated: 
        :param type: 
        """
        self._values = {
            "data_id": data_id,
            "negated": negated,
            "type": type,
        }

    @builtins.property
    def data_id(self) -> str:
        return self._values.get("data_id")

    @builtins.property
    def negated(self) -> bool:
        return self._values.get("negated")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafRulePredicates(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafSizeConstraintSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafSizeConstraintSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        size_constraints: typing.Optional[
            typing.List["WafSizeConstraintSetSizeConstraints"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param size_constraints: size_constraints block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafSizeConstraintSetConfig(
            name=name,
            size_constraints=size_constraints,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafSizeConstraintSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sizeConstraints")
    def size_constraints(
        self,
    ) -> typing.Optional[typing.List["WafSizeConstraintSetSizeConstraints"]]:
        return jsii.get(self, "sizeConstraints")

    @size_constraints.setter
    def size_constraints(
        self, value: typing.Optional[typing.List["WafSizeConstraintSetSizeConstraints"]]
    ) -> None:
        jsii.set(self, "sizeConstraints", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafSizeConstraintSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "size_constraints": "sizeConstraints",
    },
)
class WafSizeConstraintSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        size_constraints: typing.Optional[
            typing.List["WafSizeConstraintSetSizeConstraints"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param size_constraints: size_constraints block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if size_constraints is not None:
            self._values["size_constraints"] = size_constraints

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def size_constraints(
        self,
    ) -> typing.Optional[typing.List["WafSizeConstraintSetSizeConstraints"]]:
        """size_constraints block."""
        return self._values.get("size_constraints")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafSizeConstraintSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafSizeConstraintSetSizeConstraints",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "field_to_match": "fieldToMatch",
        "size": "size",
        "text_transformation": "textTransformation",
    },
)
class WafSizeConstraintSetSizeConstraints:
    def __init__(
        self,
        *,
        comparison_operator: str,
        field_to_match: typing.List["WafSizeConstraintSetSizeConstraintsFieldToMatch"],
        size: jsii.Number,
        text_transformation: str,
    ) -> None:
        """
        :param comparison_operator: 
        :param field_to_match: field_to_match block.
        :param size: 
        :param text_transformation: 
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "field_to_match": field_to_match,
            "size": size,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafSizeConstraintSetSizeConstraintsFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafSizeConstraintSetSizeConstraints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafSizeConstraintSetSizeConstraintsFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafSizeConstraintSetSizeConstraintsFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafSizeConstraintSetSizeConstraintsFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafSqlInjectionMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafSqlInjectionMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        sql_injection_match_tuples: typing.Optional[
            typing.List["WafSqlInjectionMatchSetSqlInjectionMatchTuples"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param sql_injection_match_tuples: sql_injection_match_tuples block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafSqlInjectionMatchSetConfig(
            name=name,
            sql_injection_match_tuples=sql_injection_match_tuples,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafSqlInjectionMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sqlInjectionMatchTuples")
    def sql_injection_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafSqlInjectionMatchSetSqlInjectionMatchTuples"]]:
        return jsii.get(self, "sqlInjectionMatchTuples")

    @sql_injection_match_tuples.setter
    def sql_injection_match_tuples(
        self,
        value: typing.Optional[
            typing.List["WafSqlInjectionMatchSetSqlInjectionMatchTuples"]
        ],
    ) -> None:
        jsii.set(self, "sqlInjectionMatchTuples", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafSqlInjectionMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "sql_injection_match_tuples": "sqlInjectionMatchTuples",
    },
)
class WafSqlInjectionMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        sql_injection_match_tuples: typing.Optional[
            typing.List["WafSqlInjectionMatchSetSqlInjectionMatchTuples"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param sql_injection_match_tuples: sql_injection_match_tuples block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if sql_injection_match_tuples is not None:
            self._values["sql_injection_match_tuples"] = sql_injection_match_tuples

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def sql_injection_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafSqlInjectionMatchSetSqlInjectionMatchTuples"]]:
        """sql_injection_match_tuples block."""
        return self._values.get("sql_injection_match_tuples")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafSqlInjectionMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafSqlInjectionMatchSetSqlInjectionMatchTuples",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "text_transformation": "textTransformation",
    },
)
class WafSqlInjectionMatchSetSqlInjectionMatchTuples:
    def __init__(
        self,
        *,
        field_to_match: typing.List[
            "WafSqlInjectionMatchSetSqlInjectionMatchTuplesFieldToMatch"
        ],
        text_transformation: str,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param text_transformation: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafSqlInjectionMatchSetSqlInjectionMatchTuplesFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafSqlInjectionMatchSetSqlInjectionMatchTuples(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafSqlInjectionMatchSetSqlInjectionMatchTuplesFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafSqlInjectionMatchSetSqlInjectionMatchTuplesFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "WafSqlInjectionMatchSetSqlInjectionMatchTuplesFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class WafWebAcl(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAcl",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_action: typing.List["WafWebAclDefaultAction"],
        metric_name: str,
        name: str,
        logging_configuration: typing.Optional[
            typing.List["WafWebAclLoggingConfiguration"]
        ] = None,
        rules: typing.Optional[typing.List["WafWebAclRules"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_action: default_action block.
        :param metric_name: 
        :param name: 
        :param logging_configuration: logging_configuration block.
        :param rules: rules block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafWebAclConfig(
            default_action=default_action,
            metric_name=metric_name,
            name=name,
            logging_configuration=logging_configuration,
            rules=rules,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafWebAcl, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultAction")
    def default_action(self) -> typing.List["WafWebAclDefaultAction"]:
        return jsii.get(self, "defaultAction")

    @default_action.setter
    def default_action(self, value: typing.List["WafWebAclDefaultAction"]) -> None:
        jsii.set(self, "defaultAction", value)

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="loggingConfiguration")
    def logging_configuration(
        self,
    ) -> typing.Optional[typing.List["WafWebAclLoggingConfiguration"]]:
        return jsii.get(self, "loggingConfiguration")

    @logging_configuration.setter
    def logging_configuration(
        self, value: typing.Optional[typing.List["WafWebAclLoggingConfiguration"]]
    ) -> None:
        jsii.set(self, "loggingConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="rules")
    def rules(self) -> typing.Optional[typing.List["WafWebAclRules"]]:
        return jsii.get(self, "rules")

    @rules.setter
    def rules(self, value: typing.Optional[typing.List["WafWebAclRules"]]) -> None:
        jsii.set(self, "rules", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_action": "defaultAction",
        "metric_name": "metricName",
        "name": "name",
        "logging_configuration": "loggingConfiguration",
        "rules": "rules",
        "tags": "tags",
    },
)
class WafWebAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_action: typing.List["WafWebAclDefaultAction"],
        metric_name: str,
        name: str,
        logging_configuration: typing.Optional[
            typing.List["WafWebAclLoggingConfiguration"]
        ] = None,
        rules: typing.Optional[typing.List["WafWebAclRules"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_action: default_action block.
        :param metric_name: 
        :param name: 
        :param logging_configuration: logging_configuration block.
        :param rules: rules block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "default_action": default_action,
            "metric_name": metric_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if logging_configuration is not None:
            self._values["logging_configuration"] = logging_configuration
        if rules is not None:
            self._values["rules"] = rules
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_action(self) -> typing.List["WafWebAclDefaultAction"]:
        """default_action block."""
        return self._values.get("default_action")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def logging_configuration(
        self,
    ) -> typing.Optional[typing.List["WafWebAclLoggingConfiguration"]]:
        """logging_configuration block."""
        return self._values.get("logging_configuration")

    @builtins.property
    def rules(self) -> typing.Optional[typing.List["WafWebAclRules"]]:
        """rules block."""
        return self._values.get("rules")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafWebAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclDefaultAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafWebAclDefaultAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafWebAclDefaultAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclLoggingConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "log_destination": "logDestination",
        "redacted_fields": "redactedFields",
    },
)
class WafWebAclLoggingConfiguration:
    def __init__(
        self,
        *,
        log_destination: str,
        redacted_fields: typing.Optional[
            typing.List["WafWebAclLoggingConfigurationRedactedFields"]
        ] = None,
    ) -> None:
        """
        :param log_destination: 
        :param redacted_fields: redacted_fields block.
        """
        self._values = {
            "log_destination": log_destination,
        }
        if redacted_fields is not None:
            self._values["redacted_fields"] = redacted_fields

    @builtins.property
    def log_destination(self) -> str:
        return self._values.get("log_destination")

    @builtins.property
    def redacted_fields(
        self,
    ) -> typing.Optional[typing.List["WafWebAclLoggingConfigurationRedactedFields"]]:
        """redacted_fields block."""
        return self._values.get("redacted_fields")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafWebAclLoggingConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclLoggingConfigurationRedactedFields",
    jsii_struct_bases=[],
    name_mapping={"field_to_match": "fieldToMatch"},
)
class WafWebAclLoggingConfigurationRedactedFields:
    def __init__(
        self,
        *,
        field_to_match: typing.List[
            "WafWebAclLoggingConfigurationRedactedFieldsFieldToMatch"
        ],
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "field_to_match": field_to_match,
        }

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafWebAclLoggingConfigurationRedactedFieldsFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafWebAclLoggingConfigurationRedactedFields(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclLoggingConfigurationRedactedFieldsFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafWebAclLoggingConfigurationRedactedFieldsFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "WafWebAclLoggingConfigurationRedactedFieldsFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclRules",
    jsii_struct_bases=[],
    name_mapping={
        "priority": "priority",
        "rule_id": "ruleId",
        "action": "action",
        "override_action": "overrideAction",
        "type": "type",
    },
)
class WafWebAclRules:
    def __init__(
        self,
        *,
        priority: jsii.Number,
        rule_id: str,
        action: typing.Optional[typing.List["WafWebAclRulesAction"]] = None,
        override_action: typing.Optional[
            typing.List["WafWebAclRulesOverrideAction"]
        ] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param priority: 
        :param rule_id: 
        :param action: action block.
        :param override_action: override_action block.
        :param type: 
        """
        self._values = {
            "priority": priority,
            "rule_id": rule_id,
        }
        if action is not None:
            self._values["action"] = action
        if override_action is not None:
            self._values["override_action"] = override_action
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def rule_id(self) -> str:
        return self._values.get("rule_id")

    @builtins.property
    def action(self) -> typing.Optional[typing.List["WafWebAclRulesAction"]]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def override_action(
        self,
    ) -> typing.Optional[typing.List["WafWebAclRulesOverrideAction"]]:
        """override_action block."""
        return self._values.get("override_action")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafWebAclRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclRulesAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafWebAclRulesAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafWebAclRulesAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafWebAclRulesOverrideAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafWebAclRulesOverrideAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafWebAclRulesOverrideAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafXssMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafXssMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        xss_match_tuples: typing.Optional[
            typing.List["WafXssMatchSetXssMatchTuples"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param xss_match_tuples: xss_match_tuples block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafXssMatchSetConfig(
            name=name,
            xss_match_tuples=xss_match_tuples,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafXssMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="xssMatchTuples")
    def xss_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafXssMatchSetXssMatchTuples"]]:
        return jsii.get(self, "xssMatchTuples")

    @xss_match_tuples.setter
    def xss_match_tuples(
        self, value: typing.Optional[typing.List["WafXssMatchSetXssMatchTuples"]]
    ) -> None:
        jsii.set(self, "xssMatchTuples", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafXssMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "xss_match_tuples": "xssMatchTuples",
    },
)
class WafXssMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        xss_match_tuples: typing.Optional[
            typing.List["WafXssMatchSetXssMatchTuples"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param xss_match_tuples: xss_match_tuples block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if xss_match_tuples is not None:
            self._values["xss_match_tuples"] = xss_match_tuples

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def xss_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafXssMatchSetXssMatchTuples"]]:
        """xss_match_tuples block."""
        return self._values.get("xss_match_tuples")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafXssMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafXssMatchSetXssMatchTuples",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "text_transformation": "textTransformation",
    },
)
class WafXssMatchSetXssMatchTuples:
    def __init__(
        self,
        *,
        field_to_match: typing.List["WafXssMatchSetXssMatchTuplesFieldToMatch"],
        text_transformation: str,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param text_transformation: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def field_to_match(self) -> typing.List["WafXssMatchSetXssMatchTuplesFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafXssMatchSetXssMatchTuples(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafXssMatchSetXssMatchTuplesFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafXssMatchSetXssMatchTuplesFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafXssMatchSetXssMatchTuplesFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalByteMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalByteMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        byte_match_tuple: typing.Optional[
            typing.List["WafregionalByteMatchSetByteMatchTuple"]
        ] = None,
        byte_match_tuples: typing.Optional[
            typing.List["WafregionalByteMatchSetByteMatchTuples"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param byte_match_tuple: byte_match_tuple block.
        :param byte_match_tuples: byte_match_tuples block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalByteMatchSetConfig(
            name=name,
            byte_match_tuple=byte_match_tuple,
            byte_match_tuples=byte_match_tuples,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalByteMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="byteMatchTuple")
    def byte_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafregionalByteMatchSetByteMatchTuple"]]:
        return jsii.get(self, "byteMatchTuple")

    @byte_match_tuple.setter
    def byte_match_tuple(
        self,
        value: typing.Optional[typing.List["WafregionalByteMatchSetByteMatchTuple"]],
    ) -> None:
        jsii.set(self, "byteMatchTuple", value)

    @builtins.property
    @jsii.member(jsii_name="byteMatchTuples")
    def byte_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafregionalByteMatchSetByteMatchTuples"]]:
        return jsii.get(self, "byteMatchTuples")

    @byte_match_tuples.setter
    def byte_match_tuples(
        self,
        value: typing.Optional[typing.List["WafregionalByteMatchSetByteMatchTuples"]],
    ) -> None:
        jsii.set(self, "byteMatchTuples", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalByteMatchSetByteMatchTuple",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "positional_constraint": "positionalConstraint",
        "text_transformation": "textTransformation",
        "target_string": "targetString",
    },
)
class WafregionalByteMatchSetByteMatchTuple:
    def __init__(
        self,
        *,
        field_to_match: typing.List[
            "WafregionalByteMatchSetByteMatchTupleFieldToMatch"
        ],
        positional_constraint: str,
        text_transformation: str,
        target_string: typing.Optional[str] = None,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param positional_constraint: 
        :param text_transformation: 
        :param target_string: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "positional_constraint": positional_constraint,
            "text_transformation": text_transformation,
        }
        if target_string is not None:
            self._values["target_string"] = target_string

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafregionalByteMatchSetByteMatchTupleFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    @builtins.property
    def target_string(self) -> typing.Optional[str]:
        return self._values.get("target_string")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalByteMatchSetByteMatchTuple(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalByteMatchSetByteMatchTupleFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafregionalByteMatchSetByteMatchTupleFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalByteMatchSetByteMatchTupleFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalByteMatchSetByteMatchTuples",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "positional_constraint": "positionalConstraint",
        "text_transformation": "textTransformation",
        "target_string": "targetString",
    },
)
class WafregionalByteMatchSetByteMatchTuples:
    def __init__(
        self,
        *,
        field_to_match: typing.List[
            "WafregionalByteMatchSetByteMatchTuplesFieldToMatch"
        ],
        positional_constraint: str,
        text_transformation: str,
        target_string: typing.Optional[str] = None,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param positional_constraint: 
        :param text_transformation: 
        :param target_string: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "positional_constraint": positional_constraint,
            "text_transformation": text_transformation,
        }
        if target_string is not None:
            self._values["target_string"] = target_string

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafregionalByteMatchSetByteMatchTuplesFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    @builtins.property
    def target_string(self) -> typing.Optional[str]:
        return self._values.get("target_string")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalByteMatchSetByteMatchTuples(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalByteMatchSetByteMatchTuplesFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafregionalByteMatchSetByteMatchTuplesFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalByteMatchSetByteMatchTuplesFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalByteMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "byte_match_tuple": "byteMatchTuple",
        "byte_match_tuples": "byteMatchTuples",
    },
)
class WafregionalByteMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        byte_match_tuple: typing.Optional[
            typing.List["WafregionalByteMatchSetByteMatchTuple"]
        ] = None,
        byte_match_tuples: typing.Optional[
            typing.List["WafregionalByteMatchSetByteMatchTuples"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param byte_match_tuple: byte_match_tuple block.
        :param byte_match_tuples: byte_match_tuples block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if byte_match_tuple is not None:
            self._values["byte_match_tuple"] = byte_match_tuple
        if byte_match_tuples is not None:
            self._values["byte_match_tuples"] = byte_match_tuples

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def byte_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafregionalByteMatchSetByteMatchTuple"]]:
        """byte_match_tuple block."""
        return self._values.get("byte_match_tuple")

    @builtins.property
    def byte_match_tuples(
        self,
    ) -> typing.Optional[typing.List["WafregionalByteMatchSetByteMatchTuples"]]:
        """byte_match_tuples block."""
        return self._values.get("byte_match_tuples")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalByteMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalGeoMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalGeoMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        geo_match_constraint: typing.Optional[
            typing.List["WafregionalGeoMatchSetGeoMatchConstraint"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param geo_match_constraint: geo_match_constraint block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalGeoMatchSetConfig(
            name=name,
            geo_match_constraint=geo_match_constraint,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalGeoMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="geoMatchConstraint")
    def geo_match_constraint(
        self,
    ) -> typing.Optional[typing.List["WafregionalGeoMatchSetGeoMatchConstraint"]]:
        return jsii.get(self, "geoMatchConstraint")

    @geo_match_constraint.setter
    def geo_match_constraint(
        self,
        value: typing.Optional[typing.List["WafregionalGeoMatchSetGeoMatchConstraint"]],
    ) -> None:
        jsii.set(self, "geoMatchConstraint", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalGeoMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "geo_match_constraint": "geoMatchConstraint",
    },
)
class WafregionalGeoMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        geo_match_constraint: typing.Optional[
            typing.List["WafregionalGeoMatchSetGeoMatchConstraint"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param geo_match_constraint: geo_match_constraint block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if geo_match_constraint is not None:
            self._values["geo_match_constraint"] = geo_match_constraint

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def geo_match_constraint(
        self,
    ) -> typing.Optional[typing.List["WafregionalGeoMatchSetGeoMatchConstraint"]]:
        """geo_match_constraint block."""
        return self._values.get("geo_match_constraint")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalGeoMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalGeoMatchSetGeoMatchConstraint",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "value": "value"},
)
class WafregionalGeoMatchSetGeoMatchConstraint:
    def __init__(self, *, type: str, value: str) -> None:
        """
        :param type: 
        :param value: 
        """
        self._values = {
            "type": type,
            "value": value,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalGeoMatchSetGeoMatchConstraint(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalIpset(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalIpset",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        ip_set_descriptor: typing.Optional[
            typing.List["WafregionalIpsetIpSetDescriptor"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param ip_set_descriptor: ip_set_descriptor block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalIpsetConfig(
            name=name,
            ip_set_descriptor=ip_set_descriptor,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalIpset, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ipSetDescriptor")
    def ip_set_descriptor(
        self,
    ) -> typing.Optional[typing.List["WafregionalIpsetIpSetDescriptor"]]:
        return jsii.get(self, "ipSetDescriptor")

    @ip_set_descriptor.setter
    def ip_set_descriptor(
        self, value: typing.Optional[typing.List["WafregionalIpsetIpSetDescriptor"]]
    ) -> None:
        jsii.set(self, "ipSetDescriptor", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalIpsetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "ip_set_descriptor": "ipSetDescriptor",
    },
)
class WafregionalIpsetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        ip_set_descriptor: typing.Optional[
            typing.List["WafregionalIpsetIpSetDescriptor"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param ip_set_descriptor: ip_set_descriptor block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if ip_set_descriptor is not None:
            self._values["ip_set_descriptor"] = ip_set_descriptor

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def ip_set_descriptor(
        self,
    ) -> typing.Optional[typing.List["WafregionalIpsetIpSetDescriptor"]]:
        """ip_set_descriptor block."""
        return self._values.get("ip_set_descriptor")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalIpsetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalIpsetIpSetDescriptor",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "value": "value"},
)
class WafregionalIpsetIpSetDescriptor:
    def __init__(self, *, type: str, value: str) -> None:
        """
        :param type: 
        :param value: 
        """
        self._values = {
            "type": type,
            "value": value,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def value(self) -> str:
        return self._values.get("value")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalIpsetIpSetDescriptor(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalRateBasedRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRateBasedRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        metric_name: str,
        name: str,
        rate_key: str,
        rate_limit: jsii.Number,
        predicate: typing.Optional[
            typing.List["WafregionalRateBasedRulePredicate"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param metric_name: 
        :param name: 
        :param rate_key: 
        :param rate_limit: 
        :param predicate: predicate block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalRateBasedRuleConfig(
            metric_name=metric_name,
            name=name,
            rate_key=rate_key,
            rate_limit=rate_limit,
            predicate=predicate,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalRateBasedRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="rateKey")
    def rate_key(self) -> str:
        return jsii.get(self, "rateKey")

    @rate_key.setter
    def rate_key(self, value: str) -> None:
        jsii.set(self, "rateKey", value)

    @builtins.property
    @jsii.member(jsii_name="rateLimit")
    def rate_limit(self) -> jsii.Number:
        return jsii.get(self, "rateLimit")

    @rate_limit.setter
    def rate_limit(self, value: jsii.Number) -> None:
        jsii.set(self, "rateLimit", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="predicate")
    def predicate(
        self,
    ) -> typing.Optional[typing.List["WafregionalRateBasedRulePredicate"]]:
        return jsii.get(self, "predicate")

    @predicate.setter
    def predicate(
        self, value: typing.Optional[typing.List["WafregionalRateBasedRulePredicate"]]
    ) -> None:
        jsii.set(self, "predicate", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRateBasedRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "metric_name": "metricName",
        "name": "name",
        "rate_key": "rateKey",
        "rate_limit": "rateLimit",
        "predicate": "predicate",
        "tags": "tags",
    },
)
class WafregionalRateBasedRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        metric_name: str,
        name: str,
        rate_key: str,
        rate_limit: jsii.Number,
        predicate: typing.Optional[
            typing.List["WafregionalRateBasedRulePredicate"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param metric_name: 
        :param name: 
        :param rate_key: 
        :param rate_limit: 
        :param predicate: predicate block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "metric_name": metric_name,
            "name": name,
            "rate_key": rate_key,
            "rate_limit": rate_limit,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if predicate is not None:
            self._values["predicate"] = predicate
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def rate_key(self) -> str:
        return self._values.get("rate_key")

    @builtins.property
    def rate_limit(self) -> jsii.Number:
        return self._values.get("rate_limit")

    @builtins.property
    def predicate(
        self,
    ) -> typing.Optional[typing.List["WafregionalRateBasedRulePredicate"]]:
        """predicate block."""
        return self._values.get("predicate")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRateBasedRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRateBasedRulePredicate",
    jsii_struct_bases=[],
    name_mapping={"data_id": "dataId", "negated": "negated", "type": "type"},
)
class WafregionalRateBasedRulePredicate:
    def __init__(self, *, data_id: str, negated: bool, type: str) -> None:
        """
        :param data_id: 
        :param negated: 
        :param type: 
        """
        self._values = {
            "data_id": data_id,
            "negated": negated,
            "type": type,
        }

    @builtins.property
    def data_id(self) -> str:
        return self._values.get("data_id")

    @builtins.property
    def negated(self) -> bool:
        return self._values.get("negated")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRateBasedRulePredicate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalRegexMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRegexMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        regex_match_tuple: typing.Optional[
            typing.List["WafregionalRegexMatchSetRegexMatchTuple"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param regex_match_tuple: regex_match_tuple block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalRegexMatchSetConfig(
            name=name,
            regex_match_tuple=regex_match_tuple,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalRegexMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="regexMatchTuple")
    def regex_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafregionalRegexMatchSetRegexMatchTuple"]]:
        return jsii.get(self, "regexMatchTuple")

    @regex_match_tuple.setter
    def regex_match_tuple(
        self,
        value: typing.Optional[typing.List["WafregionalRegexMatchSetRegexMatchTuple"]],
    ) -> None:
        jsii.set(self, "regexMatchTuple", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRegexMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "regex_match_tuple": "regexMatchTuple",
    },
)
class WafregionalRegexMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        regex_match_tuple: typing.Optional[
            typing.List["WafregionalRegexMatchSetRegexMatchTuple"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param regex_match_tuple: regex_match_tuple block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if regex_match_tuple is not None:
            self._values["regex_match_tuple"] = regex_match_tuple

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def regex_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafregionalRegexMatchSetRegexMatchTuple"]]:
        """regex_match_tuple block."""
        return self._values.get("regex_match_tuple")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRegexMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRegexMatchSetRegexMatchTuple",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "regex_pattern_set_id": "regexPatternSetId",
        "text_transformation": "textTransformation",
    },
)
class WafregionalRegexMatchSetRegexMatchTuple:
    def __init__(
        self,
        *,
        field_to_match: typing.List[
            "WafregionalRegexMatchSetRegexMatchTupleFieldToMatch"
        ],
        regex_pattern_set_id: str,
        text_transformation: str,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param regex_pattern_set_id: 
        :param text_transformation: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "regex_pattern_set_id": regex_pattern_set_id,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafregionalRegexMatchSetRegexMatchTupleFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def regex_pattern_set_id(self) -> str:
        return self._values.get("regex_pattern_set_id")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRegexMatchSetRegexMatchTuple(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRegexMatchSetRegexMatchTupleFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafregionalRegexMatchSetRegexMatchTupleFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRegexMatchSetRegexMatchTupleFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalRegexPatternSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRegexPatternSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        regex_pattern_strings: typing.Optional[typing.List[str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param regex_pattern_strings: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalRegexPatternSetConfig(
            name=name,
            regex_pattern_strings=regex_pattern_strings,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalRegexPatternSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="regexPatternStrings")
    def regex_pattern_strings(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "regexPatternStrings")

    @regex_pattern_strings.setter
    def regex_pattern_strings(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "regexPatternStrings", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRegexPatternSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "regex_pattern_strings": "regexPatternStrings",
    },
)
class WafregionalRegexPatternSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        regex_pattern_strings: typing.Optional[typing.List[str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param regex_pattern_strings: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if regex_pattern_strings is not None:
            self._values["regex_pattern_strings"] = regex_pattern_strings

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def regex_pattern_strings(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("regex_pattern_strings")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRegexPatternSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        metric_name: str,
        name: str,
        predicate: typing.Optional[typing.List["WafregionalRulePredicate"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param metric_name: 
        :param name: 
        :param predicate: predicate block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalRuleConfig(
            metric_name=metric_name,
            name=name,
            predicate=predicate,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="predicate")
    def predicate(self) -> typing.Optional[typing.List["WafregionalRulePredicate"]]:
        return jsii.get(self, "predicate")

    @predicate.setter
    def predicate(
        self, value: typing.Optional[typing.List["WafregionalRulePredicate"]]
    ) -> None:
        jsii.set(self, "predicate", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "metric_name": "metricName",
        "name": "name",
        "predicate": "predicate",
        "tags": "tags",
    },
)
class WafregionalRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        metric_name: str,
        name: str,
        predicate: typing.Optional[typing.List["WafregionalRulePredicate"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param metric_name: 
        :param name: 
        :param predicate: predicate block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "metric_name": metric_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if predicate is not None:
            self._values["predicate"] = predicate
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def predicate(self) -> typing.Optional[typing.List["WafregionalRulePredicate"]]:
        """predicate block."""
        return self._values.get("predicate")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalRuleGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRuleGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        metric_name: str,
        name: str,
        activated_rule: typing.Optional[
            typing.List["WafregionalRuleGroupActivatedRule"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param metric_name: 
        :param name: 
        :param activated_rule: activated_rule block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalRuleGroupConfig(
            metric_name=metric_name,
            name=name,
            activated_rule=activated_rule,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalRuleGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="activatedRule")
    def activated_rule(
        self,
    ) -> typing.Optional[typing.List["WafregionalRuleGroupActivatedRule"]]:
        return jsii.get(self, "activatedRule")

    @activated_rule.setter
    def activated_rule(
        self, value: typing.Optional[typing.List["WafregionalRuleGroupActivatedRule"]]
    ) -> None:
        jsii.set(self, "activatedRule", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRuleGroupActivatedRule",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "priority": "priority",
        "rule_id": "ruleId",
        "type": "type",
    },
)
class WafregionalRuleGroupActivatedRule:
    def __init__(
        self,
        *,
        action: typing.List["WafregionalRuleGroupActivatedRuleAction"],
        priority: jsii.Number,
        rule_id: str,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param action: action block.
        :param priority: 
        :param rule_id: 
        :param type: 
        """
        self._values = {
            "action": action,
            "priority": priority,
            "rule_id": rule_id,
        }
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def action(self) -> typing.List["WafregionalRuleGroupActivatedRuleAction"]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def rule_id(self) -> str:
        return self._values.get("rule_id")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRuleGroupActivatedRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRuleGroupActivatedRuleAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafregionalRuleGroupActivatedRuleAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRuleGroupActivatedRuleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRuleGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "metric_name": "metricName",
        "name": "name",
        "activated_rule": "activatedRule",
        "tags": "tags",
    },
)
class WafregionalRuleGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        metric_name: str,
        name: str,
        activated_rule: typing.Optional[
            typing.List["WafregionalRuleGroupActivatedRule"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param metric_name: 
        :param name: 
        :param activated_rule: activated_rule block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "metric_name": metric_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if activated_rule is not None:
            self._values["activated_rule"] = activated_rule
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def activated_rule(
        self,
    ) -> typing.Optional[typing.List["WafregionalRuleGroupActivatedRule"]]:
        """activated_rule block."""
        return self._values.get("activated_rule")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRuleGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalRulePredicate",
    jsii_struct_bases=[],
    name_mapping={"data_id": "dataId", "negated": "negated", "type": "type"},
)
class WafregionalRulePredicate:
    def __init__(self, *, data_id: str, negated: bool, type: str) -> None:
        """
        :param data_id: 
        :param negated: 
        :param type: 
        """
        self._values = {
            "data_id": data_id,
            "negated": negated,
            "type": type,
        }

    @builtins.property
    def data_id(self) -> str:
        return self._values.get("data_id")

    @builtins.property
    def negated(self) -> bool:
        return self._values.get("negated")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalRulePredicate(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalSizeConstraintSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSizeConstraintSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        size_constraints: typing.Optional[
            typing.List["WafregionalSizeConstraintSetSizeConstraints"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param size_constraints: size_constraints block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalSizeConstraintSetConfig(
            name=name,
            size_constraints=size_constraints,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalSizeConstraintSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sizeConstraints")
    def size_constraints(
        self,
    ) -> typing.Optional[typing.List["WafregionalSizeConstraintSetSizeConstraints"]]:
        return jsii.get(self, "sizeConstraints")

    @size_constraints.setter
    def size_constraints(
        self,
        value: typing.Optional[
            typing.List["WafregionalSizeConstraintSetSizeConstraints"]
        ],
    ) -> None:
        jsii.set(self, "sizeConstraints", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSizeConstraintSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "size_constraints": "sizeConstraints",
    },
)
class WafregionalSizeConstraintSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        size_constraints: typing.Optional[
            typing.List["WafregionalSizeConstraintSetSizeConstraints"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param size_constraints: size_constraints block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if size_constraints is not None:
            self._values["size_constraints"] = size_constraints

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def size_constraints(
        self,
    ) -> typing.Optional[typing.List["WafregionalSizeConstraintSetSizeConstraints"]]:
        """size_constraints block."""
        return self._values.get("size_constraints")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalSizeConstraintSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSizeConstraintSetSizeConstraints",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "field_to_match": "fieldToMatch",
        "size": "size",
        "text_transformation": "textTransformation",
    },
)
class WafregionalSizeConstraintSetSizeConstraints:
    def __init__(
        self,
        *,
        comparison_operator: str,
        field_to_match: typing.List[
            "WafregionalSizeConstraintSetSizeConstraintsFieldToMatch"
        ],
        size: jsii.Number,
        text_transformation: str,
    ) -> None:
        """
        :param comparison_operator: 
        :param field_to_match: field_to_match block.
        :param size: 
        :param text_transformation: 
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "field_to_match": field_to_match,
            "size": size,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafregionalSizeConstraintSetSizeConstraintsFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalSizeConstraintSetSizeConstraints(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSizeConstraintSetSizeConstraintsFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafregionalSizeConstraintSetSizeConstraintsFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "WafregionalSizeConstraintSetSizeConstraintsFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class WafregionalSqlInjectionMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSqlInjectionMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        sql_injection_match_tuple: typing.Optional[
            typing.List["WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param sql_injection_match_tuple: sql_injection_match_tuple block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalSqlInjectionMatchSetConfig(
            name=name,
            sql_injection_match_tuple=sql_injection_match_tuple,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalSqlInjectionMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="sqlInjectionMatchTuple")
    def sql_injection_match_tuple(
        self,
    ) -> typing.Optional[
        typing.List["WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple"]
    ]:
        return jsii.get(self, "sqlInjectionMatchTuple")

    @sql_injection_match_tuple.setter
    def sql_injection_match_tuple(
        self,
        value: typing.Optional[
            typing.List["WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple"]
        ],
    ) -> None:
        jsii.set(self, "sqlInjectionMatchTuple", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSqlInjectionMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "sql_injection_match_tuple": "sqlInjectionMatchTuple",
    },
)
class WafregionalSqlInjectionMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        sql_injection_match_tuple: typing.Optional[
            typing.List["WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param sql_injection_match_tuple: sql_injection_match_tuple block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if sql_injection_match_tuple is not None:
            self._values["sql_injection_match_tuple"] = sql_injection_match_tuple

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def sql_injection_match_tuple(
        self,
    ) -> typing.Optional[
        typing.List["WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple"]
    ]:
        """sql_injection_match_tuple block."""
        return self._values.get("sql_injection_match_tuple")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalSqlInjectionMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "text_transformation": "textTransformation",
    },
)
class WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple:
    def __init__(
        self,
        *,
        field_to_match: typing.List[
            "WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch"
        ],
        text_transformation: str,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param text_transformation: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List[
        "WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch"
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


class WafregionalWebAcl(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAcl",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        default_action: typing.List["WafregionalWebAclDefaultAction"],
        metric_name: str,
        name: str,
        logging_configuration: typing.Optional[
            typing.List["WafregionalWebAclLoggingConfiguration"]
        ] = None,
        rule: typing.Optional[typing.List["WafregionalWebAclRule"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param default_action: default_action block.
        :param metric_name: 
        :param name: 
        :param logging_configuration: logging_configuration block.
        :param rule: rule block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalWebAclConfig(
            default_action=default_action,
            metric_name=metric_name,
            name=name,
            logging_configuration=logging_configuration,
            rule=rule,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalWebAcl, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="defaultAction")
    def default_action(self) -> typing.List["WafregionalWebAclDefaultAction"]:
        return jsii.get(self, "defaultAction")

    @default_action.setter
    def default_action(
        self, value: typing.List["WafregionalWebAclDefaultAction"]
    ) -> None:
        jsii.set(self, "defaultAction", value)

    @builtins.property
    @jsii.member(jsii_name="metricName")
    def metric_name(self) -> str:
        return jsii.get(self, "metricName")

    @metric_name.setter
    def metric_name(self, value: str) -> None:
        jsii.set(self, "metricName", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="loggingConfiguration")
    def logging_configuration(
        self,
    ) -> typing.Optional[typing.List["WafregionalWebAclLoggingConfiguration"]]:
        return jsii.get(self, "loggingConfiguration")

    @logging_configuration.setter
    def logging_configuration(
        self,
        value: typing.Optional[typing.List["WafregionalWebAclLoggingConfiguration"]],
    ) -> None:
        jsii.set(self, "loggingConfiguration", value)

    @builtins.property
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.Optional[typing.List["WafregionalWebAclRule"]]:
        return jsii.get(self, "rule")

    @rule.setter
    def rule(
        self, value: typing.Optional[typing.List["WafregionalWebAclRule"]]
    ) -> None:
        jsii.set(self, "rule", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class WafregionalWebAclAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        resource_arn: str,
        web_acl_id: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_arn: 
        :param web_acl_id: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalWebAclAssociationConfig(
            resource_arn=resource_arn,
            web_acl_id=web_acl_id,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalWebAclAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resourceArn")
    def resource_arn(self) -> str:
        return jsii.get(self, "resourceArn")

    @resource_arn.setter
    def resource_arn(self, value: str) -> None:
        jsii.set(self, "resourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="webAclId")
    def web_acl_id(self) -> str:
        return jsii.get(self, "webAclId")

    @web_acl_id.setter
    def web_acl_id(self, value: str) -> None:
        jsii.set(self, "webAclId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_arn": "resourceArn",
        "web_acl_id": "webAclId",
    },
)
class WafregionalWebAclAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_arn: str,
        web_acl_id: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_arn: 
        :param web_acl_id: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "resource_arn": resource_arn,
            "web_acl_id": web_acl_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def web_acl_id(self) -> str:
        return self._values.get("web_acl_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_action": "defaultAction",
        "metric_name": "metricName",
        "name": "name",
        "logging_configuration": "loggingConfiguration",
        "rule": "rule",
        "tags": "tags",
    },
)
class WafregionalWebAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_action: typing.List["WafregionalWebAclDefaultAction"],
        metric_name: str,
        name: str,
        logging_configuration: typing.Optional[
            typing.List["WafregionalWebAclLoggingConfiguration"]
        ] = None,
        rule: typing.Optional[typing.List["WafregionalWebAclRule"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_action: default_action block.
        :param metric_name: 
        :param name: 
        :param logging_configuration: logging_configuration block.
        :param rule: rule block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "default_action": default_action,
            "metric_name": metric_name,
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if logging_configuration is not None:
            self._values["logging_configuration"] = logging_configuration
        if rule is not None:
            self._values["rule"] = rule
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_action(self) -> typing.List["WafregionalWebAclDefaultAction"]:
        """default_action block."""
        return self._values.get("default_action")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def logging_configuration(
        self,
    ) -> typing.Optional[typing.List["WafregionalWebAclLoggingConfiguration"]]:
        """logging_configuration block."""
        return self._values.get("logging_configuration")

    @builtins.property
    def rule(self) -> typing.Optional[typing.List["WafregionalWebAclRule"]]:
        """rule block."""
        return self._values.get("rule")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclDefaultAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafregionalWebAclDefaultAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclDefaultAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclLoggingConfiguration",
    jsii_struct_bases=[],
    name_mapping={
        "log_destination": "logDestination",
        "redacted_fields": "redactedFields",
    },
)
class WafregionalWebAclLoggingConfiguration:
    def __init__(
        self,
        *,
        log_destination: str,
        redacted_fields: typing.Optional[
            typing.List["WafregionalWebAclLoggingConfigurationRedactedFields"]
        ] = None,
    ) -> None:
        """
        :param log_destination: 
        :param redacted_fields: redacted_fields block.
        """
        self._values = {
            "log_destination": log_destination,
        }
        if redacted_fields is not None:
            self._values["redacted_fields"] = redacted_fields

    @builtins.property
    def log_destination(self) -> str:
        return self._values.get("log_destination")

    @builtins.property
    def redacted_fields(
        self,
    ) -> typing.Optional[
        typing.List["WafregionalWebAclLoggingConfigurationRedactedFields"]
    ]:
        """redacted_fields block."""
        return self._values.get("redacted_fields")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclLoggingConfiguration(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclLoggingConfigurationRedactedFields",
    jsii_struct_bases=[],
    name_mapping={"field_to_match": "fieldToMatch"},
)
class WafregionalWebAclLoggingConfigurationRedactedFields:
    def __init__(
        self,
        *,
        field_to_match: typing.List[
            "WafregionalWebAclLoggingConfigurationRedactedFieldsFieldToMatch"
        ],
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "field_to_match": field_to_match,
        }

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafregionalWebAclLoggingConfigurationRedactedFieldsFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclLoggingConfigurationRedactedFields(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclLoggingConfigurationRedactedFieldsFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafregionalWebAclLoggingConfigurationRedactedFieldsFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "WafregionalWebAclLoggingConfigurationRedactedFieldsFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclRule",
    jsii_struct_bases=[],
    name_mapping={
        "priority": "priority",
        "rule_id": "ruleId",
        "action": "action",
        "override_action": "overrideAction",
        "type": "type",
    },
)
class WafregionalWebAclRule:
    def __init__(
        self,
        *,
        priority: jsii.Number,
        rule_id: str,
        action: typing.Optional[typing.List["WafregionalWebAclRuleAction"]] = None,
        override_action: typing.Optional[
            typing.List["WafregionalWebAclRuleOverrideAction"]
        ] = None,
        type: typing.Optional[str] = None,
    ) -> None:
        """
        :param priority: 
        :param rule_id: 
        :param action: action block.
        :param override_action: override_action block.
        :param type: 
        """
        self._values = {
            "priority": priority,
            "rule_id": rule_id,
        }
        if action is not None:
            self._values["action"] = action
        if override_action is not None:
            self._values["override_action"] = override_action
        if type is not None:
            self._values["type"] = type

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def rule_id(self) -> str:
        return self._values.get("rule_id")

    @builtins.property
    def action(self) -> typing.Optional[typing.List["WafregionalWebAclRuleAction"]]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def override_action(
        self,
    ) -> typing.Optional[typing.List["WafregionalWebAclRuleOverrideAction"]]:
        """override_action block."""
        return self._values.get("override_action")

    @builtins.property
    def type(self) -> typing.Optional[str]:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclRuleAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafregionalWebAclRuleAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclRuleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalWebAclRuleOverrideAction",
    jsii_struct_bases=[],
    name_mapping={"type": "type"},
)
class WafregionalWebAclRuleOverrideAction:
    def __init__(self, *, type: str) -> None:
        """
        :param type: 
        """
        self._values = {
            "type": type,
        }

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalWebAclRuleOverrideAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WafregionalXssMatchSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalXssMatchSet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        xss_match_tuple: typing.Optional[
            typing.List["WafregionalXssMatchSetXssMatchTuple"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param xss_match_tuple: xss_match_tuple block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WafregionalXssMatchSetConfig(
            name=name,
            xss_match_tuple=xss_match_tuple,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WafregionalXssMatchSet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="xssMatchTuple")
    def xss_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafregionalXssMatchSetXssMatchTuple"]]:
        return jsii.get(self, "xssMatchTuple")

    @xss_match_tuple.setter
    def xss_match_tuple(
        self, value: typing.Optional[typing.List["WafregionalXssMatchSetXssMatchTuple"]]
    ) -> None:
        jsii.set(self, "xssMatchTuple", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalXssMatchSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "xss_match_tuple": "xssMatchTuple",
    },
)
class WafregionalXssMatchSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        xss_match_tuple: typing.Optional[
            typing.List["WafregionalXssMatchSetXssMatchTuple"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param xss_match_tuple: xss_match_tuple block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if xss_match_tuple is not None:
            self._values["xss_match_tuple"] = xss_match_tuple

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def xss_match_tuple(
        self,
    ) -> typing.Optional[typing.List["WafregionalXssMatchSetXssMatchTuple"]]:
        """xss_match_tuple block."""
        return self._values.get("xss_match_tuple")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalXssMatchSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalXssMatchSetXssMatchTuple",
    jsii_struct_bases=[],
    name_mapping={
        "field_to_match": "fieldToMatch",
        "text_transformation": "textTransformation",
    },
)
class WafregionalXssMatchSetXssMatchTuple:
    def __init__(
        self,
        *,
        field_to_match: typing.List["WafregionalXssMatchSetXssMatchTupleFieldToMatch"],
        text_transformation: str,
    ) -> None:
        """
        :param field_to_match: field_to_match block.
        :param text_transformation: 
        """
        self._values = {
            "field_to_match": field_to_match,
            "text_transformation": text_transformation,
        }

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.List["WafregionalXssMatchSetXssMatchTupleFieldToMatch"]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    @builtins.property
    def text_transformation(self) -> str:
        return self._values.get("text_transformation")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalXssMatchSetXssMatchTuple(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WafregionalXssMatchSetXssMatchTupleFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={"type": "type", "data": "data"},
)
class WafregionalXssMatchSetXssMatchTupleFieldToMatch:
    def __init__(self, *, type: str, data: typing.Optional[str] = None) -> None:
        """
        :param type: 
        :param data: 
        """
        self._values = {
            "type": type,
        }
        if data is not None:
            self._values["data"] = data

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    @builtins.property
    def data(self) -> typing.Optional[str]:
        return self._values.get("data")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WafregionalXssMatchSetXssMatchTupleFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Wafv2IpSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2IpSet",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        ip_address_version: str,
        name: str,
        scope: str,
        addresses: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param ip_address_version: 
        :param name: 
        :param scope: 
        :param addresses: 
        :param description: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Wafv2IpSetConfig(
            ip_address_version=ip_address_version,
            name=name,
            scope=scope,
            addresses=addresses,
            description=description,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Wafv2IpSet, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="lockToken")
    def lock_token(self) -> str:
        return jsii.get(self, "lockToken")

    @builtins.property
    @jsii.member(jsii_name="ipAddressVersion")
    def ip_address_version(self) -> str:
        return jsii.get(self, "ipAddressVersion")

    @ip_address_version.setter
    def ip_address_version(self, value: str) -> None:
        jsii.set(self, "ipAddressVersion", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="addresses")
    def addresses(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "addresses")

    @addresses.setter
    def addresses(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "addresses", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2IpSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "ip_address_version": "ipAddressVersion",
        "name": "name",
        "scope": "scope",
        "addresses": "addresses",
        "description": "description",
        "tags": "tags",
    },
)
class Wafv2IpSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        ip_address_version: str,
        name: str,
        scope: str,
        addresses: typing.Optional[typing.List[str]] = None,
        description: typing.Optional[str] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param ip_address_version: 
        :param name: 
        :param scope: 
        :param addresses: 
        :param description: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "ip_address_version": ip_address_version,
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if addresses is not None:
            self._values["addresses"] = addresses
        if description is not None:
            self._values["description"] = description
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def ip_address_version(self) -> str:
        return self._values.get("ip_address_version")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    @builtins.property
    def addresses(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("addresses")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2IpSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Wafv2RegexPatternSet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RegexPatternSet",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        name: str,
        scope: str,
        description: typing.Optional[str] = None,
        regular_expression: typing.Optional[
            typing.List["Wafv2RegexPatternSetRegularExpression"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param name: 
        :param scope: 
        :param description: 
        :param regular_expression: regular_expression block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Wafv2RegexPatternSetConfig(
            name=name,
            scope=scope,
            description=description,
            regular_expression=regular_expression,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Wafv2RegexPatternSet, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="lockToken")
    def lock_token(self) -> str:
        return jsii.get(self, "lockToken")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="regularExpression")
    def regular_expression(
        self,
    ) -> typing.Optional[typing.List["Wafv2RegexPatternSetRegularExpression"]]:
        return jsii.get(self, "regularExpression")

    @regular_expression.setter
    def regular_expression(
        self,
        value: typing.Optional[typing.List["Wafv2RegexPatternSetRegularExpression"]],
    ) -> None:
        jsii.set(self, "regularExpression", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RegexPatternSetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "scope": "scope",
        "description": "description",
        "regular_expression": "regularExpression",
        "tags": "tags",
    },
)
class Wafv2RegexPatternSetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        scope: str,
        description: typing.Optional[str] = None,
        regular_expression: typing.Optional[
            typing.List["Wafv2RegexPatternSetRegularExpression"]
        ] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param scope: 
        :param description: 
        :param regular_expression: regular_expression block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
            "scope": scope,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if regular_expression is not None:
            self._values["regular_expression"] = regular_expression
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def regular_expression(
        self,
    ) -> typing.Optional[typing.List["Wafv2RegexPatternSetRegularExpression"]]:
        """regular_expression block."""
        return self._values.get("regular_expression")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RegexPatternSetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RegexPatternSetRegularExpression",
    jsii_struct_bases=[],
    name_mapping={"regex_string": "regexString"},
)
class Wafv2RegexPatternSetRegularExpression:
    def __init__(self, *, regex_string: str) -> None:
        """
        :param regex_string: 
        """
        self._values = {
            "regex_string": regex_string,
        }

    @builtins.property
    def regex_string(self) -> str:
        return self._values.get("regex_string")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RegexPatternSetRegularExpression(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Wafv2RuleGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroup",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        capacity: jsii.Number,
        name: str,
        scope: str,
        visibility_config: typing.List["Wafv2RuleGroupVisibilityConfig"],
        description: typing.Optional[str] = None,
        rule: typing.Optional[typing.List["Wafv2RuleGroupRule"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param capacity: 
        :param name: 
        :param scope: 
        :param visibility_config: visibility_config block.
        :param description: 
        :param rule: rule block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Wafv2RuleGroupConfig(
            capacity=capacity,
            name=name,
            scope=scope,
            visibility_config=visibility_config,
            description=description,
            rule=rule,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Wafv2RuleGroup, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="lockToken")
    def lock_token(self) -> str:
        return jsii.get(self, "lockToken")

    @builtins.property
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> jsii.Number:
        return jsii.get(self, "capacity")

    @capacity.setter
    def capacity(self, value: jsii.Number) -> None:
        jsii.set(self, "capacity", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="visibilityConfig")
    def visibility_config(self) -> typing.List["Wafv2RuleGroupVisibilityConfig"]:
        return jsii.get(self, "visibilityConfig")

    @visibility_config.setter
    def visibility_config(
        self, value: typing.List["Wafv2RuleGroupVisibilityConfig"]
    ) -> None:
        jsii.set(self, "visibilityConfig", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.Optional[typing.List["Wafv2RuleGroupRule"]]:
        return jsii.get(self, "rule")

    @rule.setter
    def rule(self, value: typing.Optional[typing.List["Wafv2RuleGroupRule"]]) -> None:
        jsii.set(self, "rule", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "capacity": "capacity",
        "name": "name",
        "scope": "scope",
        "visibility_config": "visibilityConfig",
        "description": "description",
        "rule": "rule",
        "tags": "tags",
    },
)
class Wafv2RuleGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        capacity: jsii.Number,
        name: str,
        scope: str,
        visibility_config: typing.List["Wafv2RuleGroupVisibilityConfig"],
        description: typing.Optional[str] = None,
        rule: typing.Optional[typing.List["Wafv2RuleGroupRule"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param capacity: 
        :param name: 
        :param scope: 
        :param visibility_config: visibility_config block.
        :param description: 
        :param rule: rule block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "capacity": capacity,
            "name": name,
            "scope": scope,
            "visibility_config": visibility_config,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if rule is not None:
            self._values["rule"] = rule
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def capacity(self) -> jsii.Number:
        return self._values.get("capacity")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    @builtins.property
    def visibility_config(self) -> typing.List["Wafv2RuleGroupVisibilityConfig"]:
        """visibility_config block."""
        return self._values.get("visibility_config")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def rule(self) -> typing.Optional[typing.List["Wafv2RuleGroupRule"]]:
        """rule block."""
        return self._values.get("rule")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRule",
    jsii_struct_bases=[],
    name_mapping={
        "action": "action",
        "name": "name",
        "priority": "priority",
        "statement": "statement",
        "visibility_config": "visibilityConfig",
    },
)
class Wafv2RuleGroupRule:
    def __init__(
        self,
        *,
        action: typing.List["Wafv2RuleGroupRuleAction"],
        name: str,
        priority: jsii.Number,
        statement: typing.List["Wafv2RuleGroupRuleStatement"],
        visibility_config: typing.List["Wafv2RuleGroupRuleVisibilityConfig"],
    ) -> None:
        """
        :param action: action block.
        :param name: 
        :param priority: 
        :param statement: statement block.
        :param visibility_config: visibility_config block.
        """
        self._values = {
            "action": action,
            "name": name,
            "priority": priority,
            "statement": statement,
            "visibility_config": visibility_config,
        }

    @builtins.property
    def action(self) -> typing.List["Wafv2RuleGroupRuleAction"]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def statement(self) -> typing.List["Wafv2RuleGroupRuleStatement"]:
        """statement block."""
        return self._values.get("statement")

    @builtins.property
    def visibility_config(self) -> typing.List["Wafv2RuleGroupRuleVisibilityConfig"]:
        """visibility_config block."""
        return self._values.get("visibility_config")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleAction",
    jsii_struct_bases=[],
    name_mapping={"allow": "allow", "block": "block", "count": "count"},
)
class Wafv2RuleGroupRuleAction:
    def __init__(
        self,
        *,
        allow: typing.Optional[typing.List["Wafv2RuleGroupRuleActionAllow"]] = None,
        block: typing.Optional[typing.List["Wafv2RuleGroupRuleActionBlock"]] = None,
        count: typing.Optional[typing.List["Wafv2RuleGroupRuleActionCount"]] = None,
    ) -> None:
        """
        :param allow: allow block.
        :param block: block block.
        :param count: count block.
        """
        self._values = {}
        if allow is not None:
            self._values["allow"] = allow
        if block is not None:
            self._values["block"] = block
        if count is not None:
            self._values["count"] = count

    @builtins.property
    def allow(self) -> typing.Optional[typing.List["Wafv2RuleGroupRuleActionAllow"]]:
        """allow block."""
        return self._values.get("allow")

    @builtins.property
    def block(self) -> typing.Optional[typing.List["Wafv2RuleGroupRuleActionBlock"]]:
        """block block."""
        return self._values.get("block")

    @builtins.property
    def count(self) -> typing.Optional[typing.List["Wafv2RuleGroupRuleActionCount"]]:
        """count block."""
        return self._values.get("count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleActionAllow",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleActionAllow:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleActionAllow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleActionBlock",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleActionBlock:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleActionBlock(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleActionCount",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleActionCount:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleActionCount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementByteMatchStatement"]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementGeoMatchStatement"]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementIpSetReferenceStatement"]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementOrStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatement"]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementSizeConstraintStatement"]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatement"]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementXssMatchStatement"]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2RuleGroupRuleStatementAndStatement"]]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2RuleGroupRuleStatementByteMatchStatement"]]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2RuleGroupRuleStatementGeoMatchStatement"]]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementIpSetReferenceStatement"]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2RuleGroupRuleStatementNotStatement"]]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2RuleGroupRuleStatementOrStatement"]]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatement"]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementSizeConstraintStatement"]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatement"]]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2RuleGroupRuleStatementXssMatchStatement"]]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List["Wafv2RuleGroupRuleStatementAndStatementStatement"],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List["Wafv2RuleGroupRuleStatementAndStatementStatement"]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementAndStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementOrStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementAndStatement"]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementGeoMatchStatement"]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementNotStatement"]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementOrStatement"]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatement"]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementAndStatementStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatch"]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List["Wafv2RuleGroupRuleStatementByteMatchStatementTextTransformation"]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementByteMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchBody"]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchUriPath"]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementGeoMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementIpSetReferenceStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List["Wafv2RuleGroupRuleStatementNotStatementStatement"],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List["Wafv2RuleGroupRuleStatementNotStatementStatement"]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementNotStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementOrStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementAndStatement"]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementGeoMatchStatement"]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementNotStatement"]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementOrStatement"]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatement"]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementNotStatementStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List["Wafv2RuleGroupRuleStatementOrStatementStatement"],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List["Wafv2RuleGroupRuleStatementOrStatementStatement"]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementOrStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementOrStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementAndStatement"]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatement"]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementGeoMatchStatement"]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementNotStatement"]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementOrStatement"]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatement"]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatement"]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementOrStatementStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2RuleGroupRuleStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementSizeConstraintStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatch"]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatementTextTransformation"]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementSqliMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchBody"]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchUriPath"]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2RuleGroupRuleStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2RuleGroupRuleStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatch"]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List["Wafv2RuleGroupRuleStatementXssMatchStatementTextTransformation"]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleStatementXssMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List["Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchBody"]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchUriPath"]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2RuleGroupRuleStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2RuleGroupRuleStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupRuleVisibilityConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_metrics_enabled": "cloudwatchMetricsEnabled",
        "metric_name": "metricName",
        "sampled_requests_enabled": "sampledRequestsEnabled",
    },
)
class Wafv2RuleGroupRuleVisibilityConfig:
    def __init__(
        self,
        *,
        cloudwatch_metrics_enabled: bool,
        metric_name: str,
        sampled_requests_enabled: bool,
    ) -> None:
        """
        :param cloudwatch_metrics_enabled: 
        :param metric_name: 
        :param sampled_requests_enabled: 
        """
        self._values = {
            "cloudwatch_metrics_enabled": cloudwatch_metrics_enabled,
            "metric_name": metric_name,
            "sampled_requests_enabled": sampled_requests_enabled,
        }

    @builtins.property
    def cloudwatch_metrics_enabled(self) -> bool:
        return self._values.get("cloudwatch_metrics_enabled")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def sampled_requests_enabled(self) -> bool:
        return self._values.get("sampled_requests_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupRuleVisibilityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2RuleGroupVisibilityConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_metrics_enabled": "cloudwatchMetricsEnabled",
        "metric_name": "metricName",
        "sampled_requests_enabled": "sampledRequestsEnabled",
    },
)
class Wafv2RuleGroupVisibilityConfig:
    def __init__(
        self,
        *,
        cloudwatch_metrics_enabled: bool,
        metric_name: str,
        sampled_requests_enabled: bool,
    ) -> None:
        """
        :param cloudwatch_metrics_enabled: 
        :param metric_name: 
        :param sampled_requests_enabled: 
        """
        self._values = {
            "cloudwatch_metrics_enabled": cloudwatch_metrics_enabled,
            "metric_name": metric_name,
            "sampled_requests_enabled": sampled_requests_enabled,
        }

    @builtins.property
    def cloudwatch_metrics_enabled(self) -> bool:
        return self._values.get("cloudwatch_metrics_enabled")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def sampled_requests_enabled(self) -> bool:
        return self._values.get("sampled_requests_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2RuleGroupVisibilityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Wafv2WebAcl(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAcl",
):
    def __init__(
        self,
        scope_: constructs.Construct,
        id: str,
        *,
        default_action: typing.List["Wafv2WebAclDefaultAction"],
        name: str,
        scope: str,
        visibility_config: typing.List["Wafv2WebAclVisibilityConfig"],
        description: typing.Optional[str] = None,
        rule: typing.Optional[typing.List["Wafv2WebAclRule"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope_: -
        :param id: -
        :param default_action: default_action block.
        :param name: 
        :param scope: 
        :param visibility_config: visibility_config block.
        :param description: 
        :param rule: rule block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Wafv2WebAclConfig(
            default_action=default_action,
            name=name,
            scope=scope,
            visibility_config=visibility_config,
            description=description,
            rule=rule,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Wafv2WebAcl, self, [scope_, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="capacity")
    def capacity(self) -> jsii.Number:
        return jsii.get(self, "capacity")

    @builtins.property
    @jsii.member(jsii_name="lockToken")
    def lock_token(self) -> str:
        return jsii.get(self, "lockToken")

    @builtins.property
    @jsii.member(jsii_name="defaultAction")
    def default_action(self) -> typing.List["Wafv2WebAclDefaultAction"]:
        return jsii.get(self, "defaultAction")

    @default_action.setter
    def default_action(self, value: typing.List["Wafv2WebAclDefaultAction"]) -> None:
        jsii.set(self, "defaultAction", value)

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="scope")
    def scope(self) -> str:
        return jsii.get(self, "scope")

    @scope.setter
    def scope(self, value: str) -> None:
        jsii.set(self, "scope", value)

    @builtins.property
    @jsii.member(jsii_name="visibilityConfig")
    def visibility_config(self) -> typing.List["Wafv2WebAclVisibilityConfig"]:
        return jsii.get(self, "visibilityConfig")

    @visibility_config.setter
    def visibility_config(
        self, value: typing.List["Wafv2WebAclVisibilityConfig"]
    ) -> None:
        jsii.set(self, "visibilityConfig", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="rule")
    def rule(self) -> typing.Optional[typing.List["Wafv2WebAclRule"]]:
        return jsii.get(self, "rule")

    @rule.setter
    def rule(self, value: typing.Optional[typing.List["Wafv2WebAclRule"]]) -> None:
        jsii.set(self, "rule", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


class Wafv2WebAclAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        resource_arn: str,
        web_acl_arn: str,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param resource_arn: 
        :param web_acl_arn: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Wafv2WebAclAssociationConfig(
            resource_arn=resource_arn,
            web_acl_arn=web_acl_arn,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Wafv2WebAclAssociation, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="resourceArn")
    def resource_arn(self) -> str:
        return jsii.get(self, "resourceArn")

    @resource_arn.setter
    def resource_arn(self, value: str) -> None:
        jsii.set(self, "resourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="webAclArn")
    def web_acl_arn(self) -> str:
        return jsii.get(self, "webAclArn")

    @web_acl_arn.setter
    def web_acl_arn(self, value: str) -> None:
        jsii.set(self, "webAclArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "resource_arn": "resourceArn",
        "web_acl_arn": "webAclArn",
    },
)
class Wafv2WebAclAssociationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        resource_arn: str,
        web_acl_arn: str,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param resource_arn: 
        :param web_acl_arn: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "resource_arn": resource_arn,
            "web_acl_arn": web_acl_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def web_acl_arn(self) -> str:
        return self._values.get("web_acl_arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "default_action": "defaultAction",
        "name": "name",
        "scope": "scope",
        "visibility_config": "visibilityConfig",
        "description": "description",
        "rule": "rule",
        "tags": "tags",
    },
)
class Wafv2WebAclConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        default_action: typing.List["Wafv2WebAclDefaultAction"],
        name: str,
        scope: str,
        visibility_config: typing.List["Wafv2WebAclVisibilityConfig"],
        description: typing.Optional[str] = None,
        rule: typing.Optional[typing.List["Wafv2WebAclRule"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param default_action: default_action block.
        :param name: 
        :param scope: 
        :param visibility_config: visibility_config block.
        :param description: 
        :param rule: rule block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "default_action": default_action,
            "name": name,
            "scope": scope,
            "visibility_config": visibility_config,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if rule is not None:
            self._values["rule"] = rule
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def default_action(self) -> typing.List["Wafv2WebAclDefaultAction"]:
        """default_action block."""
        return self._values.get("default_action")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def scope(self) -> str:
        return self._values.get("scope")

    @builtins.property
    def visibility_config(self) -> typing.List["Wafv2WebAclVisibilityConfig"]:
        """visibility_config block."""
        return self._values.get("visibility_config")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def rule(self) -> typing.Optional[typing.List["Wafv2WebAclRule"]]:
        """rule block."""
        return self._values.get("rule")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclDefaultAction",
    jsii_struct_bases=[],
    name_mapping={"allow": "allow", "block": "block"},
)
class Wafv2WebAclDefaultAction:
    def __init__(
        self,
        *,
        allow: typing.Optional[typing.List["Wafv2WebAclDefaultActionAllow"]] = None,
        block: typing.Optional[typing.List["Wafv2WebAclDefaultActionBlock"]] = None,
    ) -> None:
        """
        :param allow: allow block.
        :param block: block block.
        """
        self._values = {}
        if allow is not None:
            self._values["allow"] = allow
        if block is not None:
            self._values["block"] = block

    @builtins.property
    def allow(self) -> typing.Optional[typing.List["Wafv2WebAclDefaultActionAllow"]]:
        """allow block."""
        return self._values.get("allow")

    @builtins.property
    def block(self) -> typing.Optional[typing.List["Wafv2WebAclDefaultActionBlock"]]:
        """block block."""
        return self._values.get("block")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclDefaultAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclDefaultActionAllow",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclDefaultActionAllow:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclDefaultActionAllow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclDefaultActionBlock",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclDefaultActionBlock:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclDefaultActionBlock(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class Wafv2WebAclLoggingConfiguration(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfiguration",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        log_destination_configs: typing.List[str],
        resource_arn: str,
        redacted_fields: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFields"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param log_destination_configs: AWS Kinesis Firehose Delivery Stream ARNs.
        :param resource_arn: AWS WebACL ARN.
        :param redacted_fields: redacted_fields block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = Wafv2WebAclLoggingConfigurationConfig(
            log_destination_configs=log_destination_configs,
            resource_arn=resource_arn,
            redacted_fields=redacted_fields,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(Wafv2WebAclLoggingConfiguration, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="logDestinationConfigs")
    def log_destination_configs(self) -> typing.List[str]:
        return jsii.get(self, "logDestinationConfigs")

    @log_destination_configs.setter
    def log_destination_configs(self, value: typing.List[str]) -> None:
        jsii.set(self, "logDestinationConfigs", value)

    @builtins.property
    @jsii.member(jsii_name="resourceArn")
    def resource_arn(self) -> str:
        return jsii.get(self, "resourceArn")

    @resource_arn.setter
    def resource_arn(self, value: str) -> None:
        jsii.set(self, "resourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="redactedFields")
    def redacted_fields(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclLoggingConfigurationRedactedFields"]]:
        return jsii.get(self, "redactedFields")

    @redacted_fields.setter
    def redacted_fields(
        self,
        value: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFields"]
        ],
    ) -> None:
        jsii.set(self, "redactedFields", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "log_destination_configs": "logDestinationConfigs",
        "resource_arn": "resourceArn",
        "redacted_fields": "redactedFields",
    },
)
class Wafv2WebAclLoggingConfigurationConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        log_destination_configs: typing.List[str],
        resource_arn: str,
        redacted_fields: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFields"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param log_destination_configs: AWS Kinesis Firehose Delivery Stream ARNs.
        :param resource_arn: AWS WebACL ARN.
        :param redacted_fields: redacted_fields block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "log_destination_configs": log_destination_configs,
            "resource_arn": resource_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if redacted_fields is not None:
            self._values["redacted_fields"] = redacted_fields

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def log_destination_configs(self) -> typing.List[str]:
        """AWS Kinesis Firehose Delivery Stream ARNs."""
        return self._values.get("log_destination_configs")

    @builtins.property
    def resource_arn(self) -> str:
        """AWS WebACL ARN."""
        return self._values.get("resource_arn")

    @builtins.property
    def redacted_fields(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclLoggingConfigurationRedactedFields"]]:
        """redacted_fields block."""
        return self._values.get("redacted_fields")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclLoggingConfigurationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFields",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclLoggingConfigurationRedactedFields:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclLoggingConfigurationRedactedFieldsAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsBody"]
        ] = None,
        method: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsMethod"]
        ] = None,
        query_string: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsQueryString"]
        ] = None,
        single_header: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsSingleHeader"]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclLoggingConfigurationRedactedFieldsSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsUriPath"]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsAllQueryArguments"]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsQueryString"]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsSingleHeader"]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsSingleQueryArgument"]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclLoggingConfigurationRedactedFieldsUriPath"]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclLoggingConfigurationRedactedFields(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFieldsAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclLoggingConfigurationRedactedFieldsAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclLoggingConfigurationRedactedFieldsAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFieldsBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclLoggingConfigurationRedactedFieldsBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclLoggingConfigurationRedactedFieldsBody(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFieldsMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclLoggingConfigurationRedactedFieldsMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclLoggingConfigurationRedactedFieldsMethod(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFieldsQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclLoggingConfigurationRedactedFieldsQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclLoggingConfigurationRedactedFieldsQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFieldsSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclLoggingConfigurationRedactedFieldsSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclLoggingConfigurationRedactedFieldsSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFieldsSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclLoggingConfigurationRedactedFieldsSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclLoggingConfigurationRedactedFieldsSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclLoggingConfigurationRedactedFieldsUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclLoggingConfigurationRedactedFieldsUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclLoggingConfigurationRedactedFieldsUriPath(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRule",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "priority": "priority",
        "statement": "statement",
        "visibility_config": "visibilityConfig",
        "action": "action",
        "override_action": "overrideAction",
    },
)
class Wafv2WebAclRule:
    def __init__(
        self,
        *,
        name: str,
        priority: jsii.Number,
        statement: typing.List["Wafv2WebAclRuleStatement"],
        visibility_config: typing.List["Wafv2WebAclRuleVisibilityConfig"],
        action: typing.Optional[typing.List["Wafv2WebAclRuleAction"]] = None,
        override_action: typing.Optional[
            typing.List["Wafv2WebAclRuleOverrideAction"]
        ] = None,
    ) -> None:
        """
        :param name: 
        :param priority: 
        :param statement: statement block.
        :param visibility_config: visibility_config block.
        :param action: action block.
        :param override_action: override_action block.
        """
        self._values = {
            "name": name,
            "priority": priority,
            "statement": statement,
            "visibility_config": visibility_config,
        }
        if action is not None:
            self._values["action"] = action
        if override_action is not None:
            self._values["override_action"] = override_action

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def statement(self) -> typing.List["Wafv2WebAclRuleStatement"]:
        """statement block."""
        return self._values.get("statement")

    @builtins.property
    def visibility_config(self) -> typing.List["Wafv2WebAclRuleVisibilityConfig"]:
        """visibility_config block."""
        return self._values.get("visibility_config")

    @builtins.property
    def action(self) -> typing.Optional[typing.List["Wafv2WebAclRuleAction"]]:
        """action block."""
        return self._values.get("action")

    @builtins.property
    def override_action(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleOverrideAction"]]:
        """override_action block."""
        return self._values.get("override_action")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRule(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleAction",
    jsii_struct_bases=[],
    name_mapping={"allow": "allow", "block": "block", "count": "count"},
)
class Wafv2WebAclRuleAction:
    def __init__(
        self,
        *,
        allow: typing.Optional[typing.List["Wafv2WebAclRuleActionAllow"]] = None,
        block: typing.Optional[typing.List["Wafv2WebAclRuleActionBlock"]] = None,
        count: typing.Optional[typing.List["Wafv2WebAclRuleActionCount"]] = None,
    ) -> None:
        """
        :param allow: allow block.
        :param block: block block.
        :param count: count block.
        """
        self._values = {}
        if allow is not None:
            self._values["allow"] = allow
        if block is not None:
            self._values["block"] = block
        if count is not None:
            self._values["count"] = count

    @builtins.property
    def allow(self) -> typing.Optional[typing.List["Wafv2WebAclRuleActionAllow"]]:
        """allow block."""
        return self._values.get("allow")

    @builtins.property
    def block(self) -> typing.Optional[typing.List["Wafv2WebAclRuleActionBlock"]]:
        """block block."""
        return self._values.get("block")

    @builtins.property
    def count(self) -> typing.Optional[typing.List["Wafv2WebAclRuleActionCount"]]:
        """count block."""
        return self._values.get("count")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleActionAllow",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleActionAllow:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleActionAllow(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleActionBlock",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleActionBlock:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleActionBlock(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleActionCount",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleActionCount:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleActionCount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleOverrideAction",
    jsii_struct_bases=[],
    name_mapping={"count": "count", "none": "none"},
)
class Wafv2WebAclRuleOverrideAction:
    def __init__(
        self,
        *,
        count: typing.Optional[
            typing.List["Wafv2WebAclRuleOverrideActionCount"]
        ] = None,
        none: typing.Optional[typing.List["Wafv2WebAclRuleOverrideActionNone"]] = None,
    ) -> None:
        """
        :param count: count block.
        :param none: none block.
        """
        self._values = {}
        if count is not None:
            self._values["count"] = count
        if none is not None:
            self._values["none"] = none

    @builtins.property
    def count(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleOverrideActionCount"]]:
        """count block."""
        return self._values.get("count")

    @builtins.property
    def none(self) -> typing.Optional[typing.List["Wafv2WebAclRuleOverrideActionNone"]]:
        """none block."""
        return self._values.get("none")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleOverrideAction(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleOverrideActionCount",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleOverrideActionCount:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleOverrideActionCount(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleOverrideActionNone",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleOverrideActionNone:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleOverrideActionNone(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "managed_rule_group_statement": "managedRuleGroupStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "rate_based_statement": "rateBasedStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "rule_group_reference_statement": "ruleGroupReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementByteMatchStatement"]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementGeoMatchStatement"]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementIpSetReferenceStatement"]
        ] = None,
        managed_rule_group_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementManagedRuleGroupStatement"]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementOrStatement"]
        ] = None,
        rate_based_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementRateBasedStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementRegexPatternSetReferenceStatement"]
        ] = None,
        rule_group_reference_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementRuleGroupReferenceStatement"]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementSizeConstraintStatement"]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementSqliMatchStatement"]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementXssMatchStatement"]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param managed_rule_group_statement: managed_rule_group_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param rate_based_statement: rate_based_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param rule_group_reference_statement: rule_group_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if managed_rule_group_statement is not None:
            self._values["managed_rule_group_statement"] = managed_rule_group_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if rate_based_statement is not None:
            self._values["rate_based_statement"] = rate_based_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if rule_group_reference_statement is not None:
            self._values[
                "rule_group_reference_statement"
            ] = rule_group_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementAndStatement"]]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementByteMatchStatement"]]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementGeoMatchStatement"]]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementIpSetReferenceStatement"]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def managed_rule_group_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementManagedRuleGroupStatement"]
    ]:
        """managed_rule_group_statement block."""
        return self._values.get("managed_rule_group_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementNotStatement"]]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementOrStatement"]]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def rate_based_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementRateBasedStatement"]]:
        """rate_based_statement block."""
        return self._values.get("rate_based_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementRegexPatternSetReferenceStatement"]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def rule_group_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementRuleGroupReferenceStatement"]
    ]:
        """rule_group_reference_statement block."""
        return self._values.get("rule_group_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSizeConstraintStatement"]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementSqliMatchStatement"]]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[typing.List["Wafv2WebAclRuleStatementXssMatchStatement"]]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatement:
    def __init__(
        self, *, statement: typing.List["Wafv2WebAclRuleStatementAndStatementStatement"]
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(self) -> typing.List["Wafv2WebAclRuleStatementAndStatementStatement"]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementAndStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementAndStatementStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementAndStatementStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementAndStatementStatementOrStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementAndStatementStatementAndStatement"]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatement"]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementAndStatementStatementGeoMatchStatement"]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementAndStatementStatementNotStatement"]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementAndStatementStatementOrStatement"]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatement"]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatement"]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementAndStatementStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatch"]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List["Wafv2WebAclRuleStatementByteMatchStatementTextTransformation"]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementByteMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchBody"]
        ] = None,
        method: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchMethod"]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchUriPath"]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchQueryString"]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchUriPath"]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementGeoMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementIpSetReferenceStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementManagedRuleGroupStatement",
    jsii_struct_bases=[],
    name_mapping={
        "name": "name",
        "vendor_name": "vendorName",
        "excluded_rule": "excludedRule",
    },
)
class Wafv2WebAclRuleStatementManagedRuleGroupStatement:
    def __init__(
        self,
        *,
        name: str,
        vendor_name: str,
        excluded_rule: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementManagedRuleGroupStatementExcludedRule"]
        ] = None,
    ) -> None:
        """
        :param name: 
        :param vendor_name: 
        :param excluded_rule: excluded_rule block.
        """
        self._values = {
            "name": name,
            "vendor_name": vendor_name,
        }
        if excluded_rule is not None:
            self._values["excluded_rule"] = excluded_rule

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def vendor_name(self) -> str:
        return self._values.get("vendor_name")

    @builtins.property
    def excluded_rule(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementManagedRuleGroupStatementExcludedRule"]
    ]:
        """excluded_rule block."""
        return self._values.get("excluded_rule")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementManagedRuleGroupStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementManagedRuleGroupStatementExcludedRule",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementManagedRuleGroupStatementExcludedRule:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementManagedRuleGroupStatementExcludedRule(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatement:
    def __init__(
        self, *, statement: typing.List["Wafv2WebAclRuleStatementNotStatementStatement"]
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(self) -> typing.List["Wafv2WebAclRuleStatementNotStatementStatement"]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementNotStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementNotStatementStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementNotStatementStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementNotStatementStatementOrStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementNotStatementStatementAndStatement"]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatement"]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementNotStatementStatementGeoMatchStatement"]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementNotStatementStatementNotStatement"]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementNotStatementStatementOrStatement"]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatement"]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatement"]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementNotStatementStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatement:
    def __init__(
        self, *, statement: typing.List["Wafv2WebAclRuleStatementOrStatementStatement"]
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(self) -> typing.List["Wafv2WebAclRuleStatementOrStatementStatement"]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementOrStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementOrStatementStatementAndStatement"]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementOrStatementStatementGeoMatchStatement"]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementOrStatementStatementNotStatement"]
        ] = None,
        or_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementOrStatementStatementOrStatement"]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatement"]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementOrStatementStatementAndStatement"]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatement"]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementOrStatementStatementGeoMatchStatement"]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementOrStatementStatementNotStatement"]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementOrStatementStatementOrStatement"]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatement"]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatement"]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementOrStatementStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatement",
    jsii_struct_bases=[],
    name_mapping={
        "limit": "limit",
        "aggregate_key_type": "aggregateKeyType",
        "scope_down_statement": "scopeDownStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatement:
    def __init__(
        self,
        *,
        limit: jsii.Number,
        aggregate_key_type: typing.Optional[str] = None,
        scope_down_statement: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatement"]
        ] = None,
    ) -> None:
        """
        :param limit: 
        :param aggregate_key_type: 
        :param scope_down_statement: scope_down_statement block.
        """
        self._values = {
            "limit": limit,
        }
        if aggregate_key_type is not None:
            self._values["aggregate_key_type"] = aggregate_key_type
        if scope_down_statement is not None:
            self._values["scope_down_statement"] = scope_down_statement

    @builtins.property
    def limit(self) -> jsii.Number:
        return self._values.get("limit")

    @builtins.property
    def aggregate_key_type(self) -> typing.Optional[str]:
        return self._values.get("aggregate_key_type")

    @builtins.property
    def scope_down_statement(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatement"]
    ]:
        """scope_down_statement block."""
        return self._values.get("scope_down_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementRateBasedStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "and_statement": "andStatement",
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "not_statement": "notStatement",
        "or_statement": "orStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatement:
    def __init__(
        self,
        *,
        and_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatement"
            ]
        ] = None,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        not_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatement"
            ]
        ] = None,
        or_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param and_statement: and_statement block.
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param not_statement: not_statement block.
        :param or_statement: or_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if and_statement is not None:
            self._values["and_statement"] = and_statement
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if not_statement is not None:
            self._values["not_statement"] = not_statement
        if or_statement is not None:
            self._values["or_statement"] = or_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def and_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatement"
        ]
    ]:
        """and_statement block."""
        return self._values.get("and_statement")

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def not_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatement"
        ]
    ]:
        """not_statement block."""
        return self._values.get("not_statement")

    @builtins.property
    def or_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatement"
        ]
    ]:
        """or_statement block."""
        return self._values.get("or_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatement",
    jsii_struct_bases=[],
    name_mapping={"statement": "statement"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatement:
    def __init__(
        self,
        *,
        statement: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatement"
        ],
    ) -> None:
        """
        :param statement: statement block.
        """
        self._values = {
            "statement": statement,
        }

    @builtins.property
    def statement(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatement"
    ]:
        """statement block."""
        return self._values.get("statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatement",
    jsii_struct_bases=[],
    name_mapping={
        "byte_match_statement": "byteMatchStatement",
        "geo_match_statement": "geoMatchStatement",
        "ip_set_reference_statement": "ipSetReferenceStatement",
        "regex_pattern_set_reference_statement": "regexPatternSetReferenceStatement",
        "size_constraint_statement": "sizeConstraintStatement",
        "sqli_match_statement": "sqliMatchStatement",
        "xss_match_statement": "xssMatchStatement",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatement:
    def __init__(
        self,
        *,
        byte_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatement"
            ]
        ] = None,
        geo_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
            ]
        ] = None,
        ip_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
            ]
        ] = None,
        regex_pattern_set_reference_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
            ]
        ] = None,
        size_constraint_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
            ]
        ] = None,
        sqli_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
            ]
        ] = None,
        xss_match_statement: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatement"
            ]
        ] = None,
    ) -> None:
        """
        :param byte_match_statement: byte_match_statement block.
        :param geo_match_statement: geo_match_statement block.
        :param ip_set_reference_statement: ip_set_reference_statement block.
        :param regex_pattern_set_reference_statement: regex_pattern_set_reference_statement block.
        :param size_constraint_statement: size_constraint_statement block.
        :param sqli_match_statement: sqli_match_statement block.
        :param xss_match_statement: xss_match_statement block.
        """
        self._values = {}
        if byte_match_statement is not None:
            self._values["byte_match_statement"] = byte_match_statement
        if geo_match_statement is not None:
            self._values["geo_match_statement"] = geo_match_statement
        if ip_set_reference_statement is not None:
            self._values["ip_set_reference_statement"] = ip_set_reference_statement
        if regex_pattern_set_reference_statement is not None:
            self._values[
                "regex_pattern_set_reference_statement"
            ] = regex_pattern_set_reference_statement
        if size_constraint_statement is not None:
            self._values["size_constraint_statement"] = size_constraint_statement
        if sqli_match_statement is not None:
            self._values["sqli_match_statement"] = sqli_match_statement
        if xss_match_statement is not None:
            self._values["xss_match_statement"] = xss_match_statement

    @builtins.property
    def byte_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatement"
        ]
    ]:
        """byte_match_statement block."""
        return self._values.get("byte_match_statement")

    @builtins.property
    def geo_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementGeoMatchStatement"
        ]
    ]:
        """geo_match_statement block."""
        return self._values.get("geo_match_statement")

    @builtins.property
    def ip_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement"
        ]
    ]:
        """ip_set_reference_statement block."""
        return self._values.get("ip_set_reference_statement")

    @builtins.property
    def regex_pattern_set_reference_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement"
        ]
    ]:
        """regex_pattern_set_reference_statement block."""
        return self._values.get("regex_pattern_set_reference_statement")

    @builtins.property
    def size_constraint_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatement"
        ]
    ]:
        """size_constraint_statement block."""
        return self._values.get("size_constraint_statement")

    @builtins.property
    def sqli_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatement"
        ]
    ]:
        """sqli_match_statement block."""
        return self._values.get("sqli_match_statement")

    @builtins.property
    def xss_match_statement(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatement"
        ]
    ]:
        """xss_match_statement block."""
        return self._values.get("xss_match_statement")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "positional_constraint": "positionalConstraint",
        "search_string": "searchString",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatement:
    def __init__(
        self,
        *,
        positional_constraint: str,
        search_string: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param positional_constraint: 
        :param search_string: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "positional_constraint": positional_constraint,
            "search_string": search_string,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def positional_constraint(self) -> str:
        return self._values.get("positional_constraint")

    @builtins.property
    def search_string(self) -> str:
        return self._values.get("search_string")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    jsii_struct_bases=[],
    name_mapping={"country_codes": "countryCodes"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementGeoMatchStatement:
    def __init__(self, *, country_codes: typing.List[str]) -> None:
        """
        :param country_codes: 
        """
        self._values = {
            "country_codes": country_codes,
        }

    @builtins.property
    def country_codes(self) -> typing.List[str]:
        return self._values.get("country_codes")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementGeoMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement:
    def __init__(self, *, arn: str) -> None:
        """
        :param arn: 
        """
        self._values = {
            "arn": arn,
        }

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={
        "arn": "arn",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatch"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "arn": arn,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatch"
        ]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatement(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody"
        ]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod"
        ]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRuleGroupReferenceStatement",
    jsii_struct_bases=[],
    name_mapping={"arn": "arn", "excluded_rule": "excludedRule"},
)
class Wafv2WebAclRuleStatementRuleGroupReferenceStatement:
    def __init__(
        self,
        *,
        arn: str,
        excluded_rule: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementRuleGroupReferenceStatementExcludedRule"
            ]
        ] = None,
    ) -> None:
        """
        :param arn: 
        :param excluded_rule: excluded_rule block.
        """
        self._values = {
            "arn": arn,
        }
        if excluded_rule is not None:
            self._values["excluded_rule"] = excluded_rule

    @builtins.property
    def arn(self) -> str:
        return self._values.get("arn")

    @builtins.property
    def excluded_rule(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementRuleGroupReferenceStatementExcludedRule"]
    ]:
        """excluded_rule block."""
        return self._values.get("excluded_rule")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementRuleGroupReferenceStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementRuleGroupReferenceStatementExcludedRule",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementRuleGroupReferenceStatementExcludedRule:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementRuleGroupReferenceStatementExcludedRule(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatement",
    jsii_struct_bases=[],
    name_mapping={
        "comparison_operator": "comparisonOperator",
        "size": "size",
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementSizeConstraintStatement:
    def __init__(
        self,
        *,
        comparison_operator: str,
        size: jsii.Number,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementSizeConstraintStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatch"]
        ] = None,
    ) -> None:
        """
        :param comparison_operator: 
        :param size: 
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "comparison_operator": comparison_operator,
            "size": size,
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def comparison_operator(self) -> str:
        return self._values.get("comparison_operator")

    @builtins.property
    def size(self) -> jsii.Number:
        return self._values.get("size")

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List[
        "Wafv2WebAclRuleStatementSizeConstraintStatementTextTransformation"
    ]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementSizeConstraintStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchBody"
            ]
        ] = None,
        method: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchMethod"
            ]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchUriPath"
            ]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchQueryString"
        ]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchUriPath"
        ]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatch(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSizeConstraintStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementSizeConstraintStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSizeConstraintStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementSqliMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementSqliMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatch"]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List["Wafv2WebAclRuleStatementSqliMatchStatementTextTransformation"]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementSqliMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchBody"]
        ] = None,
        method: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchMethod"]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchUriPath"]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchQueryString"]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleHeader"
        ]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchUriPath"]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementSqliMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementSqliMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementSqliMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatement",
    jsii_struct_bases=[],
    name_mapping={
        "text_transformation": "textTransformation",
        "field_to_match": "fieldToMatch",
    },
)
class Wafv2WebAclRuleStatementXssMatchStatement:
    def __init__(
        self,
        *,
        text_transformation: typing.List[
            "Wafv2WebAclRuleStatementXssMatchStatementTextTransformation"
        ],
        field_to_match: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatch"]
        ] = None,
    ) -> None:
        """
        :param text_transformation: text_transformation block.
        :param field_to_match: field_to_match block.
        """
        self._values = {
            "text_transformation": text_transformation,
        }
        if field_to_match is not None:
            self._values["field_to_match"] = field_to_match

    @builtins.property
    def text_transformation(
        self,
    ) -> typing.List["Wafv2WebAclRuleStatementXssMatchStatementTextTransformation"]:
        """text_transformation block."""
        return self._values.get("text_transformation")

    @builtins.property
    def field_to_match(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatch"]
    ]:
        """field_to_match block."""
        return self._values.get("field_to_match")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementXssMatchStatement(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatch",
    jsii_struct_bases=[],
    name_mapping={
        "all_query_arguments": "allQueryArguments",
        "body": "body",
        "method": "method",
        "query_string": "queryString",
        "single_header": "singleHeader",
        "single_query_argument": "singleQueryArgument",
        "uri_path": "uriPath",
    },
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatch:
    def __init__(
        self,
        *,
        all_query_arguments: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchAllQueryArguments"
            ]
        ] = None,
        body: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchBody"]
        ] = None,
        method: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchMethod"]
        ] = None,
        query_string: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchQueryString"
            ]
        ] = None,
        single_header: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleHeader"
            ]
        ] = None,
        single_query_argument: typing.Optional[
            typing.List[
                "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument"
            ]
        ] = None,
        uri_path: typing.Optional[
            typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchUriPath"]
        ] = None,
    ) -> None:
        """
        :param all_query_arguments: all_query_arguments block.
        :param body: body block.
        :param method: method block.
        :param query_string: query_string block.
        :param single_header: single_header block.
        :param single_query_argument: single_query_argument block.
        :param uri_path: uri_path block.
        """
        self._values = {}
        if all_query_arguments is not None:
            self._values["all_query_arguments"] = all_query_arguments
        if body is not None:
            self._values["body"] = body
        if method is not None:
            self._values["method"] = method
        if query_string is not None:
            self._values["query_string"] = query_string
        if single_header is not None:
            self._values["single_header"] = single_header
        if single_query_argument is not None:
            self._values["single_query_argument"] = single_query_argument
        if uri_path is not None:
            self._values["uri_path"] = uri_path

    @builtins.property
    def all_query_arguments(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchAllQueryArguments"
        ]
    ]:
        """all_query_arguments block."""
        return self._values.get("all_query_arguments")

    @builtins.property
    def body(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchBody"]
    ]:
        """body block."""
        return self._values.get("body")

    @builtins.property
    def method(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchMethod"]
    ]:
        """method block."""
        return self._values.get("method")

    @builtins.property
    def query_string(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchQueryString"]
    ]:
        """query_string block."""
        return self._values.get("query_string")

    @builtins.property
    def single_header(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleHeader"]
    ]:
        """single_header block."""
        return self._values.get("single_header")

    @builtins.property
    def single_query_argument(
        self,
    ) -> typing.Optional[
        typing.List[
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument"
        ]
    ]:
        """single_query_argument block."""
        return self._values.get("single_query_argument")

    @builtins.property
    def uri_path(
        self,
    ) -> typing.Optional[
        typing.List["Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchUriPath"]
    ]:
        """uri_path block."""
        return self._values.get("uri_path")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatch(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchAllQueryArguments",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchAllQueryArguments:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchAllQueryArguments(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchBody",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchBody:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchBody(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchMethod",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchMethod:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchMethod(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchQueryString",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchQueryString:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchQueryString(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleHeader",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleHeader:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleHeader(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    jsii_struct_bases=[],
    name_mapping={"name": "name"},
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument:
    def __init__(self, *, name: str) -> None:
        """
        :param name: 
        """
        self._values = {
            "name": name,
        }

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchUriPath",
    jsii_struct_bases=[],
    name_mapping={},
)
class Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchUriPath:
    def __init__(self) -> None:
        self._values = {}

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchUriPath(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleStatementXssMatchStatementTextTransformation",
    jsii_struct_bases=[],
    name_mapping={"priority": "priority", "type": "type"},
)
class Wafv2WebAclRuleStatementXssMatchStatementTextTransformation:
    def __init__(self, *, priority: jsii.Number, type: str) -> None:
        """
        :param priority: 
        :param type: 
        """
        self._values = {
            "priority": priority,
            "type": type,
        }

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return (
            "Wafv2WebAclRuleStatementXssMatchStatementTextTransformation(%s)"
            % ", ".join(k + "=" + repr(v) for k, v in self._values.items())
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclRuleVisibilityConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_metrics_enabled": "cloudwatchMetricsEnabled",
        "metric_name": "metricName",
        "sampled_requests_enabled": "sampledRequestsEnabled",
    },
)
class Wafv2WebAclRuleVisibilityConfig:
    def __init__(
        self,
        *,
        cloudwatch_metrics_enabled: bool,
        metric_name: str,
        sampled_requests_enabled: bool,
    ) -> None:
        """
        :param cloudwatch_metrics_enabled: 
        :param metric_name: 
        :param sampled_requests_enabled: 
        """
        self._values = {
            "cloudwatch_metrics_enabled": cloudwatch_metrics_enabled,
            "metric_name": metric_name,
            "sampled_requests_enabled": sampled_requests_enabled,
        }

    @builtins.property
    def cloudwatch_metrics_enabled(self) -> bool:
        return self._values.get("cloudwatch_metrics_enabled")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def sampled_requests_enabled(self) -> bool:
        return self._values.get("sampled_requests_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclRuleVisibilityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.Wafv2WebAclVisibilityConfig",
    jsii_struct_bases=[],
    name_mapping={
        "cloudwatch_metrics_enabled": "cloudwatchMetricsEnabled",
        "metric_name": "metricName",
        "sampled_requests_enabled": "sampledRequestsEnabled",
    },
)
class Wafv2WebAclVisibilityConfig:
    def __init__(
        self,
        *,
        cloudwatch_metrics_enabled: bool,
        metric_name: str,
        sampled_requests_enabled: bool,
    ) -> None:
        """
        :param cloudwatch_metrics_enabled: 
        :param metric_name: 
        :param sampled_requests_enabled: 
        """
        self._values = {
            "cloudwatch_metrics_enabled": cloudwatch_metrics_enabled,
            "metric_name": metric_name,
            "sampled_requests_enabled": sampled_requests_enabled,
        }

    @builtins.property
    def cloudwatch_metrics_enabled(self) -> bool:
        return self._values.get("cloudwatch_metrics_enabled")

    @builtins.property
    def metric_name(self) -> str:
        return self._values.get("metric_name")

    @builtins.property
    def sampled_requests_enabled(self) -> bool:
        return self._values.get("sampled_requests_enabled")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "Wafv2WebAclVisibilityConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WorklinkFleet(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WorklinkFleet",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        audit_stream_arn: typing.Optional[str] = None,
        device_ca_certificate: typing.Optional[str] = None,
        display_name: typing.Optional[str] = None,
        identity_provider: typing.Optional[
            typing.List["WorklinkFleetIdentityProvider"]
        ] = None,
        network: typing.Optional[typing.List["WorklinkFleetNetwork"]] = None,
        optimize_for_end_user_location: typing.Optional[bool] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param audit_stream_arn: 
        :param device_ca_certificate: 
        :param display_name: 
        :param identity_provider: identity_provider block.
        :param network: network block.
        :param optimize_for_end_user_location: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WorklinkFleetConfig(
            name=name,
            audit_stream_arn=audit_stream_arn,
            device_ca_certificate=device_ca_certificate,
            display_name=display_name,
            identity_provider=identity_provider,
            network=network,
            optimize_for_end_user_location=optimize_for_end_user_location,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WorklinkFleet, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="companyCode")
    def company_code(self) -> str:
        return jsii.get(self, "companyCode")

    @builtins.property
    @jsii.member(jsii_name="createdTime")
    def created_time(self) -> str:
        return jsii.get(self, "createdTime")

    @builtins.property
    @jsii.member(jsii_name="lastUpdatedTime")
    def last_updated_time(self) -> str:
        return jsii.get(self, "lastUpdatedTime")

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="auditStreamArn")
    def audit_stream_arn(self) -> typing.Optional[str]:
        return jsii.get(self, "auditStreamArn")

    @audit_stream_arn.setter
    def audit_stream_arn(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "auditStreamArn", value)

    @builtins.property
    @jsii.member(jsii_name="deviceCaCertificate")
    def device_ca_certificate(self) -> typing.Optional[str]:
        return jsii.get(self, "deviceCaCertificate")

    @device_ca_certificate.setter
    def device_ca_certificate(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "deviceCaCertificate", value)

    @builtins.property
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[str]:
        return jsii.get(self, "displayName")

    @display_name.setter
    def display_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="identityProvider")
    def identity_provider(
        self,
    ) -> typing.Optional[typing.List["WorklinkFleetIdentityProvider"]]:
        return jsii.get(self, "identityProvider")

    @identity_provider.setter
    def identity_provider(
        self, value: typing.Optional[typing.List["WorklinkFleetIdentityProvider"]]
    ) -> None:
        jsii.set(self, "identityProvider", value)

    @builtins.property
    @jsii.member(jsii_name="network")
    def network(self) -> typing.Optional[typing.List["WorklinkFleetNetwork"]]:
        return jsii.get(self, "network")

    @network.setter
    def network(
        self, value: typing.Optional[typing.List["WorklinkFleetNetwork"]]
    ) -> None:
        jsii.set(self, "network", value)

    @builtins.property
    @jsii.member(jsii_name="optimizeForEndUserLocation")
    def optimize_for_end_user_location(self) -> typing.Optional[bool]:
        return jsii.get(self, "optimizeForEndUserLocation")

    @optimize_for_end_user_location.setter
    def optimize_for_end_user_location(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "optimizeForEndUserLocation", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorklinkFleetConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "audit_stream_arn": "auditStreamArn",
        "device_ca_certificate": "deviceCaCertificate",
        "display_name": "displayName",
        "identity_provider": "identityProvider",
        "network": "network",
        "optimize_for_end_user_location": "optimizeForEndUserLocation",
    },
)
class WorklinkFleetConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        audit_stream_arn: typing.Optional[str] = None,
        device_ca_certificate: typing.Optional[str] = None,
        display_name: typing.Optional[str] = None,
        identity_provider: typing.Optional[
            typing.List["WorklinkFleetIdentityProvider"]
        ] = None,
        network: typing.Optional[typing.List["WorklinkFleetNetwork"]] = None,
        optimize_for_end_user_location: typing.Optional[bool] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param audit_stream_arn: 
        :param device_ca_certificate: 
        :param display_name: 
        :param identity_provider: identity_provider block.
        :param network: network block.
        :param optimize_for_end_user_location: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if audit_stream_arn is not None:
            self._values["audit_stream_arn"] = audit_stream_arn
        if device_ca_certificate is not None:
            self._values["device_ca_certificate"] = device_ca_certificate
        if display_name is not None:
            self._values["display_name"] = display_name
        if identity_provider is not None:
            self._values["identity_provider"] = identity_provider
        if network is not None:
            self._values["network"] = network
        if optimize_for_end_user_location is not None:
            self._values[
                "optimize_for_end_user_location"
            ] = optimize_for_end_user_location

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def audit_stream_arn(self) -> typing.Optional[str]:
        return self._values.get("audit_stream_arn")

    @builtins.property
    def device_ca_certificate(self) -> typing.Optional[str]:
        return self._values.get("device_ca_certificate")

    @builtins.property
    def display_name(self) -> typing.Optional[str]:
        return self._values.get("display_name")

    @builtins.property
    def identity_provider(
        self,
    ) -> typing.Optional[typing.List["WorklinkFleetIdentityProvider"]]:
        """identity_provider block."""
        return self._values.get("identity_provider")

    @builtins.property
    def network(self) -> typing.Optional[typing.List["WorklinkFleetNetwork"]]:
        """network block."""
        return self._values.get("network")

    @builtins.property
    def optimize_for_end_user_location(self) -> typing.Optional[bool]:
        return self._values.get("optimize_for_end_user_location")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorklinkFleetConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorklinkFleetIdentityProvider",
    jsii_struct_bases=[],
    name_mapping={"saml_metadata": "samlMetadata", "type": "type"},
)
class WorklinkFleetIdentityProvider:
    def __init__(self, *, saml_metadata: str, type: str) -> None:
        """
        :param saml_metadata: 
        :param type: 
        """
        self._values = {
            "saml_metadata": saml_metadata,
            "type": type,
        }

    @builtins.property
    def saml_metadata(self) -> str:
        return self._values.get("saml_metadata")

    @builtins.property
    def type(self) -> str:
        return self._values.get("type")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorklinkFleetIdentityProvider(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorklinkFleetNetwork",
    jsii_struct_bases=[],
    name_mapping={
        "security_group_ids": "securityGroupIds",
        "subnet_ids": "subnetIds",
        "vpc_id": "vpcId",
    },
)
class WorklinkFleetNetwork:
    def __init__(
        self,
        *,
        security_group_ids: typing.List[str],
        subnet_ids: typing.List[str],
        vpc_id: str,
    ) -> None:
        """
        :param security_group_ids: 
        :param subnet_ids: 
        :param vpc_id: 
        """
        self._values = {
            "security_group_ids": security_group_ids,
            "subnet_ids": subnet_ids,
            "vpc_id": vpc_id,
        }

    @builtins.property
    def security_group_ids(self) -> typing.List[str]:
        return self._values.get("security_group_ids")

    @builtins.property
    def subnet_ids(self) -> typing.List[str]:
        return self._values.get("subnet_ids")

    @builtins.property
    def vpc_id(self) -> str:
        return self._values.get("vpc_id")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorklinkFleetNetwork(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WorklinkWebsiteCertificateAuthorityAssociation(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WorklinkWebsiteCertificateAuthorityAssociation",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        certificate: str,
        fleet_arn: str,
        display_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param certificate: 
        :param fleet_arn: 
        :param display_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WorklinkWebsiteCertificateAuthorityAssociationConfig(
            certificate=certificate,
            fleet_arn=fleet_arn,
            display_name=display_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(
            WorklinkWebsiteCertificateAuthorityAssociation, self, [scope, id, config]
        )

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="websiteCaId")
    def website_ca_id(self) -> str:
        return jsii.get(self, "websiteCaId")

    @builtins.property
    @jsii.member(jsii_name="certificate")
    def certificate(self) -> str:
        return jsii.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: str) -> None:
        jsii.set(self, "certificate", value)

    @builtins.property
    @jsii.member(jsii_name="fleetArn")
    def fleet_arn(self) -> str:
        return jsii.get(self, "fleetArn")

    @fleet_arn.setter
    def fleet_arn(self, value: str) -> None:
        jsii.set(self, "fleetArn", value)

    @builtins.property
    @jsii.member(jsii_name="displayName")
    def display_name(self) -> typing.Optional[str]:
        return jsii.get(self, "displayName")

    @display_name.setter
    def display_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "displayName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorklinkWebsiteCertificateAuthorityAssociationConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "certificate": "certificate",
        "fleet_arn": "fleetArn",
        "display_name": "displayName",
    },
)
class WorklinkWebsiteCertificateAuthorityAssociationConfig(
    cdktf.TerraformMetaArguments
):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        certificate: str,
        fleet_arn: str,
        display_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param certificate: 
        :param fleet_arn: 
        :param display_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "certificate": certificate,
            "fleet_arn": fleet_arn,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if display_name is not None:
            self._values["display_name"] = display_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def certificate(self) -> str:
        return self._values.get("certificate")

    @builtins.property
    def fleet_arn(self) -> str:
        return self._values.get("fleet_arn")

    @builtins.property
    def display_name(self) -> typing.Optional[str]:
        return self._values.get("display_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorklinkWebsiteCertificateAuthorityAssociationConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WorkspacesDirectory(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesDirectory",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        directory_id: str,
        self_service_permissions: typing.Optional[
            typing.List["WorkspacesDirectorySelfServicePermissions"]
        ] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param directory_id: 
        :param self_service_permissions: self_service_permissions block.
        :param subnet_ids: 
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WorkspacesDirectoryConfig(
            directory_id=directory_id,
            self_service_permissions=self_service_permissions,
            subnet_ids=subnet_ids,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WorkspacesDirectory, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="alias")
    def alias(self) -> str:
        return jsii.get(self, "alias")

    @builtins.property
    @jsii.member(jsii_name="customerUserName")
    def customer_user_name(self) -> str:
        return jsii.get(self, "customerUserName")

    @builtins.property
    @jsii.member(jsii_name="directoryName")
    def directory_name(self) -> str:
        return jsii.get(self, "directoryName")

    @builtins.property
    @jsii.member(jsii_name="directoryType")
    def directory_type(self) -> str:
        return jsii.get(self, "directoryType")

    @builtins.property
    @jsii.member(jsii_name="dnsIpAddresses")
    def dns_ip_addresses(self) -> typing.List[str]:
        return jsii.get(self, "dnsIpAddresses")

    @builtins.property
    @jsii.member(jsii_name="iamRoleId")
    def iam_role_id(self) -> str:
        return jsii.get(self, "iamRoleId")

    @builtins.property
    @jsii.member(jsii_name="ipGroupIds")
    def ip_group_ids(self) -> typing.List[str]:
        return jsii.get(self, "ipGroupIds")

    @builtins.property
    @jsii.member(jsii_name="registrationCode")
    def registration_code(self) -> str:
        return jsii.get(self, "registrationCode")

    @builtins.property
    @jsii.member(jsii_name="workspaceSecurityGroupId")
    def workspace_security_group_id(self) -> str:
        return jsii.get(self, "workspaceSecurityGroupId")

    @builtins.property
    @jsii.member(jsii_name="directoryId")
    def directory_id(self) -> str:
        return jsii.get(self, "directoryId")

    @directory_id.setter
    def directory_id(self, value: str) -> None:
        jsii.set(self, "directoryId", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="selfServicePermissions")
    def self_service_permissions(
        self,
    ) -> typing.Optional[typing.List["WorkspacesDirectorySelfServicePermissions"]]:
        return jsii.get(self, "selfServicePermissions")

    @self_service_permissions.setter
    def self_service_permissions(
        self,
        value: typing.Optional[
            typing.List["WorkspacesDirectorySelfServicePermissions"]
        ],
    ) -> None:
        jsii.set(self, "selfServicePermissions", value)

    @builtins.property
    @jsii.member(jsii_name="subnetIds")
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return jsii.get(self, "subnetIds")

    @subnet_ids.setter
    def subnet_ids(self, value: typing.Optional[typing.List[str]]) -> None:
        jsii.set(self, "subnetIds", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesDirectoryConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "directory_id": "directoryId",
        "self_service_permissions": "selfServicePermissions",
        "subnet_ids": "subnetIds",
        "tags": "tags",
    },
)
class WorkspacesDirectoryConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        directory_id: str,
        self_service_permissions: typing.Optional[
            typing.List["WorkspacesDirectorySelfServicePermissions"]
        ] = None,
        subnet_ids: typing.Optional[typing.List[str]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param directory_id: 
        :param self_service_permissions: self_service_permissions block.
        :param subnet_ids: 
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "directory_id": directory_id,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if self_service_permissions is not None:
            self._values["self_service_permissions"] = self_service_permissions
        if subnet_ids is not None:
            self._values["subnet_ids"] = subnet_ids
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def directory_id(self) -> str:
        return self._values.get("directory_id")

    @builtins.property
    def self_service_permissions(
        self,
    ) -> typing.Optional[typing.List["WorkspacesDirectorySelfServicePermissions"]]:
        """self_service_permissions block."""
        return self._values.get("self_service_permissions")

    @builtins.property
    def subnet_ids(self) -> typing.Optional[typing.List[str]]:
        return self._values.get("subnet_ids")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkspacesDirectoryConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesDirectorySelfServicePermissions",
    jsii_struct_bases=[],
    name_mapping={
        "change_compute_type": "changeComputeType",
        "increase_volume_size": "increaseVolumeSize",
        "rebuild_workspace": "rebuildWorkspace",
        "restart_workspace": "restartWorkspace",
        "switch_running_mode": "switchRunningMode",
    },
)
class WorkspacesDirectorySelfServicePermissions:
    def __init__(
        self,
        *,
        change_compute_type: typing.Optional[bool] = None,
        increase_volume_size: typing.Optional[bool] = None,
        rebuild_workspace: typing.Optional[bool] = None,
        restart_workspace: typing.Optional[bool] = None,
        switch_running_mode: typing.Optional[bool] = None,
    ) -> None:
        """
        :param change_compute_type: 
        :param increase_volume_size: 
        :param rebuild_workspace: 
        :param restart_workspace: 
        :param switch_running_mode: 
        """
        self._values = {}
        if change_compute_type is not None:
            self._values["change_compute_type"] = change_compute_type
        if increase_volume_size is not None:
            self._values["increase_volume_size"] = increase_volume_size
        if rebuild_workspace is not None:
            self._values["rebuild_workspace"] = rebuild_workspace
        if restart_workspace is not None:
            self._values["restart_workspace"] = restart_workspace
        if switch_running_mode is not None:
            self._values["switch_running_mode"] = switch_running_mode

    @builtins.property
    def change_compute_type(self) -> typing.Optional[bool]:
        return self._values.get("change_compute_type")

    @builtins.property
    def increase_volume_size(self) -> typing.Optional[bool]:
        return self._values.get("increase_volume_size")

    @builtins.property
    def rebuild_workspace(self) -> typing.Optional[bool]:
        return self._values.get("rebuild_workspace")

    @builtins.property
    def restart_workspace(self) -> typing.Optional[bool]:
        return self._values.get("restart_workspace")

    @builtins.property
    def switch_running_mode(self) -> typing.Optional[bool]:
        return self._values.get("switch_running_mode")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkspacesDirectorySelfServicePermissions(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WorkspacesIpGroup(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesIpGroup",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        name: str,
        description: typing.Optional[str] = None,
        rules: typing.Optional[typing.List["WorkspacesIpGroupRules"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param name: 
        :param description: 
        :param rules: rules block.
        :param tags: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WorkspacesIpGroupConfig(
            name=name,
            description=description,
            rules=rules,
            tags=tags,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WorkspacesIpGroup, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="name")
    def name(self) -> str:
        return jsii.get(self, "name")

    @name.setter
    def name(self, value: str) -> None:
        jsii.set(self, "name", value)

    @builtins.property
    @jsii.member(jsii_name="description")
    def description(self) -> typing.Optional[str]:
        return jsii.get(self, "description")

    @description.setter
    def description(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "description", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="rules")
    def rules(self) -> typing.Optional[typing.List["WorkspacesIpGroupRules"]]:
        return jsii.get(self, "rules")

    @rules.setter
    def rules(
        self, value: typing.Optional[typing.List["WorkspacesIpGroupRules"]]
    ) -> None:
        jsii.set(self, "rules", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesIpGroupConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "name": "name",
        "description": "description",
        "rules": "rules",
        "tags": "tags",
    },
)
class WorkspacesIpGroupConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        name: str,
        description: typing.Optional[str] = None,
        rules: typing.Optional[typing.List["WorkspacesIpGroupRules"]] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param name: 
        :param description: 
        :param rules: rules block.
        :param tags: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "name": name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if description is not None:
            self._values["description"] = description
        if rules is not None:
            self._values["rules"] = rules
        if tags is not None:
            self._values["tags"] = tags

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def name(self) -> str:
        return self._values.get("name")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    @builtins.property
    def rules(self) -> typing.Optional[typing.List["WorkspacesIpGroupRules"]]:
        """rules block."""
        return self._values.get("rules")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkspacesIpGroupConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesIpGroupRules",
    jsii_struct_bases=[],
    name_mapping={"source": "source", "description": "description"},
)
class WorkspacesIpGroupRules:
    def __init__(
        self, *, source: str, description: typing.Optional[str] = None
    ) -> None:
        """
        :param source: 
        :param description: 
        """
        self._values = {
            "source": source,
        }
        if description is not None:
            self._values["description"] = description

    @builtins.property
    def source(self) -> str:
        return self._values.get("source")

    @builtins.property
    def description(self) -> typing.Optional[str]:
        return self._values.get("description")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkspacesIpGroupRules(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class WorkspacesWorkspace(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesWorkspace",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        bundle_id: str,
        directory_id: str,
        user_name: str,
        root_volume_encryption_enabled: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        user_volume_encryption_enabled: typing.Optional[bool] = None,
        volume_encryption_key: typing.Optional[str] = None,
        workspace_properties: typing.Optional[
            typing.List["WorkspacesWorkspaceWorkspaceProperties"]
        ] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param bundle_id: 
        :param directory_id: 
        :param user_name: 
        :param root_volume_encryption_enabled: 
        :param tags: 
        :param user_volume_encryption_enabled: 
        :param volume_encryption_key: 
        :param workspace_properties: workspace_properties block.
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = WorkspacesWorkspaceConfig(
            bundle_id=bundle_id,
            directory_id=directory_id,
            user_name=user_name,
            root_volume_encryption_enabled=root_volume_encryption_enabled,
            tags=tags,
            user_volume_encryption_enabled=user_volume_encryption_enabled,
            volume_encryption_key=volume_encryption_key,
            workspace_properties=workspace_properties,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(WorkspacesWorkspace, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="computerName")
    def computer_name(self) -> str:
        return jsii.get(self, "computerName")

    @builtins.property
    @jsii.member(jsii_name="ipAddress")
    def ip_address(self) -> str:
        return jsii.get(self, "ipAddress")

    @builtins.property
    @jsii.member(jsii_name="state")
    def state(self) -> str:
        return jsii.get(self, "state")

    @builtins.property
    @jsii.member(jsii_name="bundleId")
    def bundle_id(self) -> str:
        return jsii.get(self, "bundleId")

    @bundle_id.setter
    def bundle_id(self, value: str) -> None:
        jsii.set(self, "bundleId", value)

    @builtins.property
    @jsii.member(jsii_name="directoryId")
    def directory_id(self) -> str:
        return jsii.get(self, "directoryId")

    @directory_id.setter
    def directory_id(self, value: str) -> None:
        jsii.set(self, "directoryId", value)

    @builtins.property
    @jsii.member(jsii_name="userName")
    def user_name(self) -> str:
        return jsii.get(self, "userName")

    @user_name.setter
    def user_name(self, value: str) -> None:
        jsii.set(self, "userName", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="rootVolumeEncryptionEnabled")
    def root_volume_encryption_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "rootVolumeEncryptionEnabled")

    @root_volume_encryption_enabled.setter
    def root_volume_encryption_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "rootVolumeEncryptionEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="tags")
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "tags")

    @tags.setter
    def tags(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "tags", value)

    @builtins.property
    @jsii.member(jsii_name="userVolumeEncryptionEnabled")
    def user_volume_encryption_enabled(self) -> typing.Optional[bool]:
        return jsii.get(self, "userVolumeEncryptionEnabled")

    @user_volume_encryption_enabled.setter
    def user_volume_encryption_enabled(self, value: typing.Optional[bool]) -> None:
        jsii.set(self, "userVolumeEncryptionEnabled", value)

    @builtins.property
    @jsii.member(jsii_name="volumeEncryptionKey")
    def volume_encryption_key(self) -> typing.Optional[str]:
        return jsii.get(self, "volumeEncryptionKey")

    @volume_encryption_key.setter
    def volume_encryption_key(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "volumeEncryptionKey", value)

    @builtins.property
    @jsii.member(jsii_name="workspaceProperties")
    def workspace_properties(
        self,
    ) -> typing.Optional[typing.List["WorkspacesWorkspaceWorkspaceProperties"]]:
        return jsii.get(self, "workspaceProperties")

    @workspace_properties.setter
    def workspace_properties(
        self,
        value: typing.Optional[typing.List["WorkspacesWorkspaceWorkspaceProperties"]],
    ) -> None:
        jsii.set(self, "workspaceProperties", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesWorkspaceConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "bundle_id": "bundleId",
        "directory_id": "directoryId",
        "user_name": "userName",
        "root_volume_encryption_enabled": "rootVolumeEncryptionEnabled",
        "tags": "tags",
        "user_volume_encryption_enabled": "userVolumeEncryptionEnabled",
        "volume_encryption_key": "volumeEncryptionKey",
        "workspace_properties": "workspaceProperties",
    },
)
class WorkspacesWorkspaceConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        bundle_id: str,
        directory_id: str,
        user_name: str,
        root_volume_encryption_enabled: typing.Optional[bool] = None,
        tags: typing.Optional[typing.Mapping[str, str]] = None,
        user_volume_encryption_enabled: typing.Optional[bool] = None,
        volume_encryption_key: typing.Optional[str] = None,
        workspace_properties: typing.Optional[
            typing.List["WorkspacesWorkspaceWorkspaceProperties"]
        ] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param bundle_id: 
        :param directory_id: 
        :param user_name: 
        :param root_volume_encryption_enabled: 
        :param tags: 
        :param user_volume_encryption_enabled: 
        :param volume_encryption_key: 
        :param workspace_properties: workspace_properties block.
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "bundle_id": bundle_id,
            "directory_id": directory_id,
            "user_name": user_name,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if root_volume_encryption_enabled is not None:
            self._values[
                "root_volume_encryption_enabled"
            ] = root_volume_encryption_enabled
        if tags is not None:
            self._values["tags"] = tags
        if user_volume_encryption_enabled is not None:
            self._values[
                "user_volume_encryption_enabled"
            ] = user_volume_encryption_enabled
        if volume_encryption_key is not None:
            self._values["volume_encryption_key"] = volume_encryption_key
        if workspace_properties is not None:
            self._values["workspace_properties"] = workspace_properties

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def bundle_id(self) -> str:
        return self._values.get("bundle_id")

    @builtins.property
    def directory_id(self) -> str:
        return self._values.get("directory_id")

    @builtins.property
    def user_name(self) -> str:
        return self._values.get("user_name")

    @builtins.property
    def root_volume_encryption_enabled(self) -> typing.Optional[bool]:
        return self._values.get("root_volume_encryption_enabled")

    @builtins.property
    def tags(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("tags")

    @builtins.property
    def user_volume_encryption_enabled(self) -> typing.Optional[bool]:
        return self._values.get("user_volume_encryption_enabled")

    @builtins.property
    def volume_encryption_key(self) -> typing.Optional[str]:
        return self._values.get("volume_encryption_key")

    @builtins.property
    def workspace_properties(
        self,
    ) -> typing.Optional[typing.List["WorkspacesWorkspaceWorkspaceProperties"]]:
        """workspace_properties block."""
        return self._values.get("workspace_properties")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkspacesWorkspaceConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.WorkspacesWorkspaceWorkspaceProperties",
    jsii_struct_bases=[],
    name_mapping={
        "compute_type_name": "computeTypeName",
        "root_volume_size_gib": "rootVolumeSizeGib",
        "running_mode": "runningMode",
        "running_mode_auto_stop_timeout_in_minutes": "runningModeAutoStopTimeoutInMinutes",
        "user_volume_size_gib": "userVolumeSizeGib",
    },
)
class WorkspacesWorkspaceWorkspaceProperties:
    def __init__(
        self,
        *,
        compute_type_name: typing.Optional[str] = None,
        root_volume_size_gib: typing.Optional[jsii.Number] = None,
        running_mode: typing.Optional[str] = None,
        running_mode_auto_stop_timeout_in_minutes: typing.Optional[jsii.Number] = None,
        user_volume_size_gib: typing.Optional[jsii.Number] = None,
    ) -> None:
        """
        :param compute_type_name: 
        :param root_volume_size_gib: 
        :param running_mode: 
        :param running_mode_auto_stop_timeout_in_minutes: 
        :param user_volume_size_gib: 
        """
        self._values = {}
        if compute_type_name is not None:
            self._values["compute_type_name"] = compute_type_name
        if root_volume_size_gib is not None:
            self._values["root_volume_size_gib"] = root_volume_size_gib
        if running_mode is not None:
            self._values["running_mode"] = running_mode
        if running_mode_auto_stop_timeout_in_minutes is not None:
            self._values[
                "running_mode_auto_stop_timeout_in_minutes"
            ] = running_mode_auto_stop_timeout_in_minutes
        if user_volume_size_gib is not None:
            self._values["user_volume_size_gib"] = user_volume_size_gib

    @builtins.property
    def compute_type_name(self) -> typing.Optional[str]:
        return self._values.get("compute_type_name")

    @builtins.property
    def root_volume_size_gib(self) -> typing.Optional[jsii.Number]:
        return self._values.get("root_volume_size_gib")

    @builtins.property
    def running_mode(self) -> typing.Optional[str]:
        return self._values.get("running_mode")

    @builtins.property
    def running_mode_auto_stop_timeout_in_minutes(self) -> typing.Optional[jsii.Number]:
        return self._values.get("running_mode_auto_stop_timeout_in_minutes")

    @builtins.property
    def user_volume_size_gib(self) -> typing.Optional[jsii.Number]:
        return self._values.get("user_volume_size_gib")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "WorkspacesWorkspaceWorkspaceProperties(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


class XraySamplingRule(
    cdktf.TerraformResource,
    metaclass=jsii.JSIIMeta,
    jsii_type="@skorfmann/cdktf-provider-aws.XraySamplingRule",
):
    def __init__(
        self,
        scope: constructs.Construct,
        id: str,
        *,
        fixed_rate: jsii.Number,
        host: str,
        http_method: str,
        priority: jsii.Number,
        reservoir_size: jsii.Number,
        resource_arn: str,
        service_name: str,
        service_type: str,
        url_path: str,
        version: jsii.Number,
        attributes: typing.Optional[typing.Mapping[str, str]] = None,
        rule_name: typing.Optional[str] = None,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
    ) -> None:
        """
        :param scope: -
        :param id: -
        :param fixed_rate: 
        :param host: 
        :param http_method: 
        :param priority: 
        :param reservoir_size: 
        :param resource_arn: 
        :param service_name: 
        :param service_type: 
        :param url_path: 
        :param version: 
        :param attributes: 
        :param rule_name: 
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        """
        config = XraySamplingRuleConfig(
            fixed_rate=fixed_rate,
            host=host,
            http_method=http_method,
            priority=priority,
            reservoir_size=reservoir_size,
            resource_arn=resource_arn,
            service_name=service_name,
            service_type=service_type,
            url_path=url_path,
            version=version,
            attributes=attributes,
            rule_name=rule_name,
            count=count,
            depends_on=depends_on,
            lifecycle=lifecycle,
            provider=provider,
        )

        jsii.create(XraySamplingRule, self, [scope, id, config])

    @jsii.member(jsii_name="synthesizeAttributes")
    def synthesize_attributes(self) -> typing.Mapping[str, typing.Any]:
        return jsii.invoke(self, "synthesizeAttributes", [])

    @builtins.property
    @jsii.member(jsii_name="arn")
    def arn(self) -> str:
        return jsii.get(self, "arn")

    @builtins.property
    @jsii.member(jsii_name="fixedRate")
    def fixed_rate(self) -> jsii.Number:
        return jsii.get(self, "fixedRate")

    @fixed_rate.setter
    def fixed_rate(self, value: jsii.Number) -> None:
        jsii.set(self, "fixedRate", value)

    @builtins.property
    @jsii.member(jsii_name="host")
    def host(self) -> str:
        return jsii.get(self, "host")

    @host.setter
    def host(self, value: str) -> None:
        jsii.set(self, "host", value)

    @builtins.property
    @jsii.member(jsii_name="httpMethod")
    def http_method(self) -> str:
        return jsii.get(self, "httpMethod")

    @http_method.setter
    def http_method(self, value: str) -> None:
        jsii.set(self, "httpMethod", value)

    @builtins.property
    @jsii.member(jsii_name="priority")
    def priority(self) -> jsii.Number:
        return jsii.get(self, "priority")

    @priority.setter
    def priority(self, value: jsii.Number) -> None:
        jsii.set(self, "priority", value)

    @builtins.property
    @jsii.member(jsii_name="reservoirSize")
    def reservoir_size(self) -> jsii.Number:
        return jsii.get(self, "reservoirSize")

    @reservoir_size.setter
    def reservoir_size(self, value: jsii.Number) -> None:
        jsii.set(self, "reservoirSize", value)

    @builtins.property
    @jsii.member(jsii_name="resourceArn")
    def resource_arn(self) -> str:
        return jsii.get(self, "resourceArn")

    @resource_arn.setter
    def resource_arn(self, value: str) -> None:
        jsii.set(self, "resourceArn", value)

    @builtins.property
    @jsii.member(jsii_name="serviceName")
    def service_name(self) -> str:
        return jsii.get(self, "serviceName")

    @service_name.setter
    def service_name(self, value: str) -> None:
        jsii.set(self, "serviceName", value)

    @builtins.property
    @jsii.member(jsii_name="serviceType")
    def service_type(self) -> str:
        return jsii.get(self, "serviceType")

    @service_type.setter
    def service_type(self, value: str) -> None:
        jsii.set(self, "serviceType", value)

    @builtins.property
    @jsii.member(jsii_name="urlPath")
    def url_path(self) -> str:
        return jsii.get(self, "urlPath")

    @url_path.setter
    def url_path(self, value: str) -> None:
        jsii.set(self, "urlPath", value)

    @builtins.property
    @jsii.member(jsii_name="version")
    def version(self) -> jsii.Number:
        return jsii.get(self, "version")

    @version.setter
    def version(self, value: jsii.Number) -> None:
        jsii.set(self, "version", value)

    @builtins.property
    @jsii.member(jsii_name="attributes")
    def attributes(self) -> typing.Optional[typing.Mapping[str, str]]:
        return jsii.get(self, "attributes")

    @attributes.setter
    def attributes(self, value: typing.Optional[typing.Mapping[str, str]]) -> None:
        jsii.set(self, "attributes", value)

    @builtins.property
    @jsii.member(jsii_name="id")
    def id(self) -> typing.Optional[str]:
        return jsii.get(self, "id")

    @id.setter
    def id(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "id", value)

    @builtins.property
    @jsii.member(jsii_name="ruleName")
    def rule_name(self) -> typing.Optional[str]:
        return jsii.get(self, "ruleName")

    @rule_name.setter
    def rule_name(self, value: typing.Optional[str]) -> None:
        jsii.set(self, "ruleName", value)


@jsii.data_type(
    jsii_type="@skorfmann/cdktf-provider-aws.XraySamplingRuleConfig",
    jsii_struct_bases=[cdktf.TerraformMetaArguments],
    name_mapping={
        "count": "count",
        "depends_on": "dependsOn",
        "lifecycle": "lifecycle",
        "provider": "provider",
        "fixed_rate": "fixedRate",
        "host": "host",
        "http_method": "httpMethod",
        "priority": "priority",
        "reservoir_size": "reservoirSize",
        "resource_arn": "resourceArn",
        "service_name": "serviceName",
        "service_type": "serviceType",
        "url_path": "urlPath",
        "version": "version",
        "attributes": "attributes",
        "rule_name": "ruleName",
    },
)
class XraySamplingRuleConfig(cdktf.TerraformMetaArguments):
    def __init__(
        self,
        *,
        count: typing.Optional[jsii.Number] = None,
        depends_on: typing.Optional[typing.List[cdktf.TerraformResource]] = None,
        lifecycle: typing.Optional[cdktf.TerraformResourceLifecycle] = None,
        provider: typing.Optional[cdktf.TerraformProvider] = None,
        fixed_rate: jsii.Number,
        host: str,
        http_method: str,
        priority: jsii.Number,
        reservoir_size: jsii.Number,
        resource_arn: str,
        service_name: str,
        service_type: str,
        url_path: str,
        version: jsii.Number,
        attributes: typing.Optional[typing.Mapping[str, str]] = None,
        rule_name: typing.Optional[str] = None,
    ) -> None:
        """
        :param count: 
        :param depends_on: 
        :param lifecycle: 
        :param provider: 
        :param fixed_rate: 
        :param host: 
        :param http_method: 
        :param priority: 
        :param reservoir_size: 
        :param resource_arn: 
        :param service_name: 
        :param service_type: 
        :param url_path: 
        :param version: 
        :param attributes: 
        :param rule_name: 
        """
        if isinstance(lifecycle, dict):
            lifecycle = cdktf.TerraformResourceLifecycle(**lifecycle)
        self._values = {
            "fixed_rate": fixed_rate,
            "host": host,
            "http_method": http_method,
            "priority": priority,
            "reservoir_size": reservoir_size,
            "resource_arn": resource_arn,
            "service_name": service_name,
            "service_type": service_type,
            "url_path": url_path,
            "version": version,
        }
        if count is not None:
            self._values["count"] = count
        if depends_on is not None:
            self._values["depends_on"] = depends_on
        if lifecycle is not None:
            self._values["lifecycle"] = lifecycle
        if provider is not None:
            self._values["provider"] = provider
        if attributes is not None:
            self._values["attributes"] = attributes
        if rule_name is not None:
            self._values["rule_name"] = rule_name

    @builtins.property
    def count(self) -> typing.Optional[jsii.Number]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("count")

    @builtins.property
    def depends_on(self) -> typing.Optional[typing.List[cdktf.TerraformResource]]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("depends_on")

    @builtins.property
    def lifecycle(self) -> typing.Optional[cdktf.TerraformResourceLifecycle]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("lifecycle")

    @builtins.property
    def provider(self) -> typing.Optional[cdktf.TerraformProvider]:
        """
        stability
        :stability: experimental
        """
        return self._values.get("provider")

    @builtins.property
    def fixed_rate(self) -> jsii.Number:
        return self._values.get("fixed_rate")

    @builtins.property
    def host(self) -> str:
        return self._values.get("host")

    @builtins.property
    def http_method(self) -> str:
        return self._values.get("http_method")

    @builtins.property
    def priority(self) -> jsii.Number:
        return self._values.get("priority")

    @builtins.property
    def reservoir_size(self) -> jsii.Number:
        return self._values.get("reservoir_size")

    @builtins.property
    def resource_arn(self) -> str:
        return self._values.get("resource_arn")

    @builtins.property
    def service_name(self) -> str:
        return self._values.get("service_name")

    @builtins.property
    def service_type(self) -> str:
        return self._values.get("service_type")

    @builtins.property
    def url_path(self) -> str:
        return self._values.get("url_path")

    @builtins.property
    def version(self) -> jsii.Number:
        return self._values.get("version")

    @builtins.property
    def attributes(self) -> typing.Optional[typing.Mapping[str, str]]:
        return self._values.get("attributes")

    @builtins.property
    def rule_name(self) -> typing.Optional[str]:
        return self._values.get("rule_name")

    def __eq__(self, rhs) -> bool:
        return isinstance(rhs, self.__class__) and rhs._values == self._values

    def __ne__(self, rhs) -> bool:
        return not (rhs == self)

    def __repr__(self) -> str:
        return "XraySamplingRuleConfig(%s)" % ", ".join(
            k + "=" + repr(v) for k, v in self._values.items()
        )


__all__ = [
    "AccessanalyzerAnalyzer",
    "AccessanalyzerAnalyzerConfig",
    "AcmCertificate",
    "AcmCertificateConfig",
    "AcmCertificateDomainValidationOptions",
    "AcmCertificateOptions",
    "AcmCertificateValidation",
    "AcmCertificateValidationConfig",
    "AcmCertificateValidationTimeouts",
    "AcmpcaCertificateAuthority",
    "AcmpcaCertificateAuthorityCertificateAuthorityConfiguration",
    "AcmpcaCertificateAuthorityCertificateAuthorityConfigurationSubject",
    "AcmpcaCertificateAuthorityConfig",
    "AcmpcaCertificateAuthorityRevocationConfiguration",
    "AcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration",
    "AcmpcaCertificateAuthorityTimeouts",
    "Alb",
    "AlbAccessLogs",
    "AlbConfig",
    "AlbListener",
    "AlbListenerCertificate",
    "AlbListenerCertificateConfig",
    "AlbListenerConfig",
    "AlbListenerDefaultAction",
    "AlbListenerDefaultActionAuthenticateCognito",
    "AlbListenerDefaultActionAuthenticateOidc",
    "AlbListenerDefaultActionFixedResponse",
    "AlbListenerDefaultActionForward",
    "AlbListenerDefaultActionForwardStickiness",
    "AlbListenerDefaultActionForwardTargetGroup",
    "AlbListenerDefaultActionRedirect",
    "AlbListenerRule",
    "AlbListenerRuleAction",
    "AlbListenerRuleActionAuthenticateCognito",
    "AlbListenerRuleActionAuthenticateOidc",
    "AlbListenerRuleActionFixedResponse",
    "AlbListenerRuleActionForward",
    "AlbListenerRuleActionForwardStickiness",
    "AlbListenerRuleActionForwardTargetGroup",
    "AlbListenerRuleActionRedirect",
    "AlbListenerRuleCondition",
    "AlbListenerRuleConditionHostHeader",
    "AlbListenerRuleConditionHttpHeader",
    "AlbListenerRuleConditionHttpRequestMethod",
    "AlbListenerRuleConditionPathPattern",
    "AlbListenerRuleConditionQueryString",
    "AlbListenerRuleConditionSourceIp",
    "AlbListenerRuleConfig",
    "AlbListenerTimeouts",
    "AlbSubnetMapping",
    "AlbTargetGroup",
    "AlbTargetGroupAttachment",
    "AlbTargetGroupAttachmentConfig",
    "AlbTargetGroupConfig",
    "AlbTargetGroupHealthCheck",
    "AlbTargetGroupStickiness",
    "AlbTimeouts",
    "Ami",
    "AmiConfig",
    "AmiCopy",
    "AmiCopyConfig",
    "AmiCopyEbsBlockDevice",
    "AmiCopyEphemeralBlockDevice",
    "AmiCopyTimeouts",
    "AmiEbsBlockDevice",
    "AmiEphemeralBlockDevice",
    "AmiFromInstance",
    "AmiFromInstanceConfig",
    "AmiFromInstanceEbsBlockDevice",
    "AmiFromInstanceEphemeralBlockDevice",
    "AmiFromInstanceTimeouts",
    "AmiLaunchPermission",
    "AmiLaunchPermissionConfig",
    "AmiTimeouts",
    "ApiGatewayAccount",
    "ApiGatewayAccountConfig",
    "ApiGatewayAccountThrottleSettings",
    "ApiGatewayApiKey",
    "ApiGatewayApiKeyConfig",
    "ApiGatewayApiKeyStageKey",
    "ApiGatewayAuthorizer",
    "ApiGatewayAuthorizerConfig",
    "ApiGatewayBasePathMapping",
    "ApiGatewayBasePathMappingConfig",
    "ApiGatewayClientCertificate",
    "ApiGatewayClientCertificateConfig",
    "ApiGatewayDeployment",
    "ApiGatewayDeploymentConfig",
    "ApiGatewayDocumentationPart",
    "ApiGatewayDocumentationPartConfig",
    "ApiGatewayDocumentationPartLocation",
    "ApiGatewayDocumentationVersion",
    "ApiGatewayDocumentationVersionConfig",
    "ApiGatewayDomainName",
    "ApiGatewayDomainNameConfig",
    "ApiGatewayDomainNameEndpointConfiguration",
    "ApiGatewayGatewayResponse",
    "ApiGatewayGatewayResponseConfig",
    "ApiGatewayIntegration",
    "ApiGatewayIntegrationConfig",
    "ApiGatewayIntegrationResponse",
    "ApiGatewayIntegrationResponseConfig",
    "ApiGatewayMethod",
    "ApiGatewayMethodConfig",
    "ApiGatewayMethodResponse",
    "ApiGatewayMethodResponseConfig",
    "ApiGatewayMethodSettings",
    "ApiGatewayMethodSettingsConfig",
    "ApiGatewayMethodSettingsSettings",
    "ApiGatewayModel",
    "ApiGatewayModelConfig",
    "ApiGatewayRequestValidator",
    "ApiGatewayRequestValidatorConfig",
    "ApiGatewayResource",
    "ApiGatewayResourceConfig",
    "ApiGatewayRestApi",
    "ApiGatewayRestApiConfig",
    "ApiGatewayRestApiEndpointConfiguration",
    "ApiGatewayStage",
    "ApiGatewayStageAccessLogSettings",
    "ApiGatewayStageConfig",
    "ApiGatewayUsagePlan",
    "ApiGatewayUsagePlanApiStages",
    "ApiGatewayUsagePlanConfig",
    "ApiGatewayUsagePlanKey",
    "ApiGatewayUsagePlanKeyConfig",
    "ApiGatewayUsagePlanQuotaSettings",
    "ApiGatewayUsagePlanThrottleSettings",
    "ApiGatewayVpcLink",
    "ApiGatewayVpcLinkConfig",
    "Apigatewayv2Api",
    "Apigatewayv2ApiConfig",
    "Apigatewayv2ApiCorsConfiguration",
    "Apigatewayv2ApiMapping",
    "Apigatewayv2ApiMappingConfig",
    "Apigatewayv2Authorizer",
    "Apigatewayv2AuthorizerConfig",
    "Apigatewayv2AuthorizerJwtConfiguration",
    "Apigatewayv2Deployment",
    "Apigatewayv2DeploymentConfig",
    "Apigatewayv2DomainName",
    "Apigatewayv2DomainNameConfig",
    "Apigatewayv2DomainNameDomainNameConfiguration",
    "Apigatewayv2DomainNameTimeouts",
    "Apigatewayv2Integration",
    "Apigatewayv2IntegrationConfig",
    "Apigatewayv2IntegrationResponse",
    "Apigatewayv2IntegrationResponseConfig",
    "Apigatewayv2Model",
    "Apigatewayv2ModelConfig",
    "Apigatewayv2Route",
    "Apigatewayv2RouteConfig",
    "Apigatewayv2RouteResponse",
    "Apigatewayv2RouteResponseConfig",
    "Apigatewayv2Stage",
    "Apigatewayv2StageAccessLogSettings",
    "Apigatewayv2StageConfig",
    "Apigatewayv2StageDefaultRouteSettings",
    "Apigatewayv2StageRouteSettings",
    "Apigatewayv2VpcLink",
    "Apigatewayv2VpcLinkConfig",
    "AppCookieStickinessPolicy",
    "AppCookieStickinessPolicyConfig",
    "AppautoscalingPolicy",
    "AppautoscalingPolicyConfig",
    "AppautoscalingPolicyStepAdjustment",
    "AppautoscalingPolicyStepScalingPolicyConfiguration",
    "AppautoscalingPolicyStepScalingPolicyConfigurationStepAdjustment",
    "AppautoscalingPolicyTargetTrackingScalingPolicyConfiguration",
    "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecification",
    "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationCustomizedMetricSpecificationDimensions",
    "AppautoscalingPolicyTargetTrackingScalingPolicyConfigurationPredefinedMetricSpecification",
    "AppautoscalingScheduledAction",
    "AppautoscalingScheduledActionConfig",
    "AppautoscalingScheduledActionScalableTargetAction",
    "AppautoscalingTarget",
    "AppautoscalingTargetConfig",
    "AppmeshMesh",
    "AppmeshMeshConfig",
    "AppmeshMeshSpec",
    "AppmeshMeshSpecEgressFilter",
    "AppmeshRoute",
    "AppmeshRouteConfig",
    "AppmeshRouteSpec",
    "AppmeshRouteSpecHttpRoute",
    "AppmeshRouteSpecHttpRouteAction",
    "AppmeshRouteSpecHttpRouteActionWeightedTarget",
    "AppmeshRouteSpecHttpRouteMatch",
    "AppmeshRouteSpecHttpRouteMatchHeader",
    "AppmeshRouteSpecHttpRouteMatchHeaderMatch",
    "AppmeshRouteSpecHttpRouteMatchHeaderMatchRange",
    "AppmeshRouteSpecTcpRoute",
    "AppmeshRouteSpecTcpRouteAction",
    "AppmeshRouteSpecTcpRouteActionWeightedTarget",
    "AppmeshVirtualNode",
    "AppmeshVirtualNodeConfig",
    "AppmeshVirtualNodeSpec",
    "AppmeshVirtualNodeSpecBackend",
    "AppmeshVirtualNodeSpecBackendVirtualService",
    "AppmeshVirtualNodeSpecListener",
    "AppmeshVirtualNodeSpecListenerHealthCheck",
    "AppmeshVirtualNodeSpecListenerPortMapping",
    "AppmeshVirtualNodeSpecLogging",
    "AppmeshVirtualNodeSpecLoggingAccessLog",
    "AppmeshVirtualNodeSpecLoggingAccessLogFile",
    "AppmeshVirtualNodeSpecServiceDiscovery",
    "AppmeshVirtualNodeSpecServiceDiscoveryAwsCloudMap",
    "AppmeshVirtualNodeSpecServiceDiscoveryDns",
    "AppmeshVirtualRouter",
    "AppmeshVirtualRouterConfig",
    "AppmeshVirtualRouterSpec",
    "AppmeshVirtualRouterSpecListener",
    "AppmeshVirtualRouterSpecListenerPortMapping",
    "AppmeshVirtualService",
    "AppmeshVirtualServiceConfig",
    "AppmeshVirtualServiceSpec",
    "AppmeshVirtualServiceSpecProvider",
    "AppmeshVirtualServiceSpecProviderVirtualNode",
    "AppmeshVirtualServiceSpecProviderVirtualRouter",
    "AppsyncApiKey",
    "AppsyncApiKeyConfig",
    "AppsyncDatasource",
    "AppsyncDatasourceConfig",
    "AppsyncDatasourceDynamodbConfig",
    "AppsyncDatasourceElasticsearchConfig",
    "AppsyncDatasourceHttpConfig",
    "AppsyncDatasourceLambdaConfig",
    "AppsyncFunction",
    "AppsyncFunctionConfig",
    "AppsyncGraphqlApi",
    "AppsyncGraphqlApiAdditionalAuthenticationProvider",
    "AppsyncGraphqlApiAdditionalAuthenticationProviderOpenidConnectConfig",
    "AppsyncGraphqlApiAdditionalAuthenticationProviderUserPoolConfig",
    "AppsyncGraphqlApiConfig",
    "AppsyncGraphqlApiLogConfig",
    "AppsyncGraphqlApiOpenidConnectConfig",
    "AppsyncGraphqlApiUserPoolConfig",
    "AppsyncResolver",
    "AppsyncResolverCachingConfig",
    "AppsyncResolverConfig",
    "AppsyncResolverPipelineConfig",
    "AthenaDatabase",
    "AthenaDatabaseConfig",
    "AthenaDatabaseEncryptionConfiguration",
    "AthenaNamedQuery",
    "AthenaNamedQueryConfig",
    "AthenaWorkgroup",
    "AthenaWorkgroupConfig",
    "AthenaWorkgroupConfiguration",
    "AthenaWorkgroupConfigurationResultConfiguration",
    "AthenaWorkgroupConfigurationResultConfigurationEncryptionConfiguration",
    "AutoscalingAttachment",
    "AutoscalingAttachmentConfig",
    "AutoscalingGroup",
    "AutoscalingGroupConfig",
    "AutoscalingGroupInitialLifecycleHook",
    "AutoscalingGroupLaunchTemplate",
    "AutoscalingGroupMixedInstancesPolicy",
    "AutoscalingGroupMixedInstancesPolicyInstancesDistribution",
    "AutoscalingGroupMixedInstancesPolicyLaunchTemplate",
    "AutoscalingGroupMixedInstancesPolicyLaunchTemplateLaunchTemplateSpecification",
    "AutoscalingGroupMixedInstancesPolicyLaunchTemplateOverride",
    "AutoscalingGroupTag",
    "AutoscalingGroupTimeouts",
    "AutoscalingLifecycleHook",
    "AutoscalingLifecycleHookConfig",
    "AutoscalingNotification",
    "AutoscalingNotificationConfig",
    "AutoscalingPolicy",
    "AutoscalingPolicyConfig",
    "AutoscalingPolicyStepAdjustment",
    "AutoscalingPolicyTargetTrackingConfiguration",
    "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecification",
    "AutoscalingPolicyTargetTrackingConfigurationCustomizedMetricSpecificationMetricDimension",
    "AutoscalingPolicyTargetTrackingConfigurationPredefinedMetricSpecification",
    "AutoscalingSchedule",
    "AutoscalingScheduleConfig",
    "AwsProvider",
    "AwsProviderAssumeRole",
    "AwsProviderConfig",
    "AwsProviderEndpoints",
    "AwsProviderIgnoreTags",
    "BackupPlan",
    "BackupPlanConfig",
    "BackupPlanRule",
    "BackupPlanRuleCopyAction",
    "BackupPlanRuleCopyActionLifecycle",
    "BackupPlanRuleLifecycle",
    "BackupSelection",
    "BackupSelectionConfig",
    "BackupSelectionSelectionTag",
    "BackupVault",
    "BackupVaultConfig",
    "BatchComputeEnvironment",
    "BatchComputeEnvironmentComputeResources",
    "BatchComputeEnvironmentComputeResourcesLaunchTemplate",
    "BatchComputeEnvironmentConfig",
    "BatchJobDefinition",
    "BatchJobDefinitionConfig",
    "BatchJobDefinitionRetryStrategy",
    "BatchJobDefinitionTimeout",
    "BatchJobQueue",
    "BatchJobQueueConfig",
    "BudgetsBudget",
    "BudgetsBudgetConfig",
    "BudgetsBudgetCostTypes",
    "BudgetsBudgetNotification",
    "Cloud9EnvironmentEc2",
    "Cloud9EnvironmentEc2Config",
    "CloudformationStack",
    "CloudformationStackConfig",
    "CloudformationStackSet",
    "CloudformationStackSetConfig",
    "CloudformationStackSetInstance",
    "CloudformationStackSetInstanceConfig",
    "CloudformationStackSetInstanceTimeouts",
    "CloudformationStackSetTimeouts",
    "CloudformationStackTimeouts",
    "CloudfrontDistribution",
    "CloudfrontDistributionCacheBehavior",
    "CloudfrontDistributionCacheBehaviorForwardedValues",
    "CloudfrontDistributionCacheBehaviorForwardedValuesCookies",
    "CloudfrontDistributionCacheBehaviorLambdaFunctionAssociation",
    "CloudfrontDistributionConfig",
    "CloudfrontDistributionCustomErrorResponse",
    "CloudfrontDistributionDefaultCacheBehavior",
    "CloudfrontDistributionDefaultCacheBehaviorForwardedValues",
    "CloudfrontDistributionDefaultCacheBehaviorForwardedValuesCookies",
    "CloudfrontDistributionDefaultCacheBehaviorLambdaFunctionAssociation",
    "CloudfrontDistributionLoggingConfig",
    "CloudfrontDistributionOrderedCacheBehavior",
    "CloudfrontDistributionOrderedCacheBehaviorForwardedValues",
    "CloudfrontDistributionOrderedCacheBehaviorForwardedValuesCookies",
    "CloudfrontDistributionOrderedCacheBehaviorLambdaFunctionAssociation",
    "CloudfrontDistributionOrigin",
    "CloudfrontDistributionOriginCustomHeader",
    "CloudfrontDistributionOriginCustomOriginConfig",
    "CloudfrontDistributionOriginGroup",
    "CloudfrontDistributionOriginGroupFailoverCriteria",
    "CloudfrontDistributionOriginGroupMember",
    "CloudfrontDistributionOriginS3OriginConfig",
    "CloudfrontDistributionRestrictions",
    "CloudfrontDistributionRestrictionsGeoRestriction",
    "CloudfrontDistributionViewerCertificate",
    "CloudfrontOriginAccessIdentity",
    "CloudfrontOriginAccessIdentityConfig",
    "CloudfrontPublicKey",
    "CloudfrontPublicKeyConfig",
    "CloudhsmV2Cluster",
    "CloudhsmV2ClusterClusterCertificates",
    "CloudhsmV2ClusterConfig",
    "CloudhsmV2ClusterTimeouts",
    "CloudhsmV2Hsm",
    "CloudhsmV2HsmConfig",
    "CloudhsmV2HsmTimeouts",
    "Cloudtrail",
    "CloudtrailConfig",
    "CloudtrailEventSelector",
    "CloudtrailEventSelectorDataResource",
    "CloudwatchDashboard",
    "CloudwatchDashboardConfig",
    "CloudwatchEventPermission",
    "CloudwatchEventPermissionCondition",
    "CloudwatchEventPermissionConfig",
    "CloudwatchEventRule",
    "CloudwatchEventRuleConfig",
    "CloudwatchEventTarget",
    "CloudwatchEventTargetBatchTarget",
    "CloudwatchEventTargetConfig",
    "CloudwatchEventTargetEcsTarget",
    "CloudwatchEventTargetEcsTargetNetworkConfiguration",
    "CloudwatchEventTargetInputTransformer",
    "CloudwatchEventTargetKinesisTarget",
    "CloudwatchEventTargetRunCommandTargets",
    "CloudwatchEventTargetSqsTarget",
    "CloudwatchLogDestination",
    "CloudwatchLogDestinationConfig",
    "CloudwatchLogDestinationPolicy",
    "CloudwatchLogDestinationPolicyConfig",
    "CloudwatchLogGroup",
    "CloudwatchLogGroupConfig",
    "CloudwatchLogMetricFilter",
    "CloudwatchLogMetricFilterConfig",
    "CloudwatchLogMetricFilterMetricTransformation",
    "CloudwatchLogResourcePolicy",
    "CloudwatchLogResourcePolicyConfig",
    "CloudwatchLogStream",
    "CloudwatchLogStreamConfig",
    "CloudwatchLogSubscriptionFilter",
    "CloudwatchLogSubscriptionFilterConfig",
    "CloudwatchMetricAlarm",
    "CloudwatchMetricAlarmConfig",
    "CloudwatchMetricAlarmMetricQuery",
    "CloudwatchMetricAlarmMetricQueryMetric",
    "CodebuildProject",
    "CodebuildProjectArtifacts",
    "CodebuildProjectCache",
    "CodebuildProjectConfig",
    "CodebuildProjectEnvironment",
    "CodebuildProjectEnvironmentEnvironmentVariable",
    "CodebuildProjectEnvironmentRegistryCredential",
    "CodebuildProjectLogsConfig",
    "CodebuildProjectLogsConfigCloudwatchLogs",
    "CodebuildProjectLogsConfigS3Logs",
    "CodebuildProjectSecondaryArtifacts",
    "CodebuildProjectSecondarySources",
    "CodebuildProjectSecondarySourcesAuth",
    "CodebuildProjectSecondarySourcesGitSubmodulesConfig",
    "CodebuildProjectSource",
    "CodebuildProjectSourceAuth",
    "CodebuildProjectSourceGitSubmodulesConfig",
    "CodebuildProjectVpcConfig",
    "CodebuildSourceCredential",
    "CodebuildSourceCredentialConfig",
    "CodebuildWebhook",
    "CodebuildWebhookConfig",
    "CodebuildWebhookFilterGroup",
    "CodebuildWebhookFilterGroupFilter",
    "CodecommitRepository",
    "CodecommitRepositoryConfig",
    "CodecommitTrigger",
    "CodecommitTriggerConfig",
    "CodecommitTriggerTrigger",
    "CodedeployApp",
    "CodedeployAppConfig",
    "CodedeployDeploymentConfig",
    "CodedeployDeploymentConfigConfig",
    "CodedeployDeploymentConfigMinimumHealthyHosts",
    "CodedeployDeploymentConfigTrafficRoutingConfig",
    "CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedCanary",
    "CodedeployDeploymentConfigTrafficRoutingConfigTimeBasedLinear",
    "CodedeployDeploymentGroup",
    "CodedeployDeploymentGroupAlarmConfiguration",
    "CodedeployDeploymentGroupAutoRollbackConfiguration",
    "CodedeployDeploymentGroupBlueGreenDeploymentConfig",
    "CodedeployDeploymentGroupBlueGreenDeploymentConfigDeploymentReadyOption",
    "CodedeployDeploymentGroupBlueGreenDeploymentConfigGreenFleetProvisioningOption",
    "CodedeployDeploymentGroupBlueGreenDeploymentConfigTerminateBlueInstancesOnDeploymentSuccess",
    "CodedeployDeploymentGroupConfig",
    "CodedeployDeploymentGroupDeploymentStyle",
    "CodedeployDeploymentGroupEc2TagFilter",
    "CodedeployDeploymentGroupEc2TagSet",
    "CodedeployDeploymentGroupEc2TagSetEc2TagFilter",
    "CodedeployDeploymentGroupEcsService",
    "CodedeployDeploymentGroupLoadBalancerInfo",
    "CodedeployDeploymentGroupLoadBalancerInfoElbInfo",
    "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupInfo",
    "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfo",
    "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoProdTrafficRoute",
    "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTargetGroup",
    "CodedeployDeploymentGroupLoadBalancerInfoTargetGroupPairInfoTestTrafficRoute",
    "CodedeployDeploymentGroupOnPremisesInstanceTagFilter",
    "CodedeployDeploymentGroupTriggerConfiguration",
    "Codepipeline",
    "CodepipelineArtifactStore",
    "CodepipelineArtifactStoreEncryptionKey",
    "CodepipelineConfig",
    "CodepipelineStage",
    "CodepipelineStageAction",
    "CodepipelineWebhook",
    "CodepipelineWebhookAuthenticationConfiguration",
    "CodepipelineWebhookConfig",
    "CodepipelineWebhookFilter",
    "CodestarnotificationsNotificationRule",
    "CodestarnotificationsNotificationRuleConfig",
    "CodestarnotificationsNotificationRuleTarget",
    "CognitoIdentityPool",
    "CognitoIdentityPoolCognitoIdentityProviders",
    "CognitoIdentityPoolConfig",
    "CognitoIdentityPoolRolesAttachment",
    "CognitoIdentityPoolRolesAttachmentConfig",
    "CognitoIdentityPoolRolesAttachmentRoleMapping",
    "CognitoIdentityPoolRolesAttachmentRoleMappingMappingRule",
    "CognitoIdentityProvider",
    "CognitoIdentityProviderConfig",
    "CognitoResourceServer",
    "CognitoResourceServerConfig",
    "CognitoResourceServerScope",
    "CognitoUserGroup",
    "CognitoUserGroupConfig",
    "CognitoUserPool",
    "CognitoUserPoolAdminCreateUserConfig",
    "CognitoUserPoolAdminCreateUserConfigInviteMessageTemplate",
    "CognitoUserPoolClient",
    "CognitoUserPoolClientAnalyticsConfiguration",
    "CognitoUserPoolClientConfig",
    "CognitoUserPoolConfig",
    "CognitoUserPoolDeviceConfiguration",
    "CognitoUserPoolDomain",
    "CognitoUserPoolDomainConfig",
    "CognitoUserPoolEmailConfiguration",
    "CognitoUserPoolLambdaConfig",
    "CognitoUserPoolPasswordPolicy",
    "CognitoUserPoolSchema",
    "CognitoUserPoolSchemaNumberAttributeConstraints",
    "CognitoUserPoolSchemaStringAttributeConstraints",
    "CognitoUserPoolSmsConfiguration",
    "CognitoUserPoolSoftwareTokenMfaConfiguration",
    "CognitoUserPoolUserPoolAddOns",
    "CognitoUserPoolUsernameConfiguration",
    "CognitoUserPoolVerificationMessageTemplate",
    "ConfigAggregateAuthorization",
    "ConfigAggregateAuthorizationConfig",
    "ConfigConfigRule",
    "ConfigConfigRuleConfig",
    "ConfigConfigRuleScope",
    "ConfigConfigRuleSource",
    "ConfigConfigRuleSourceSourceDetail",
    "ConfigConfigurationAggregator",
    "ConfigConfigurationAggregatorAccountAggregationSource",
    "ConfigConfigurationAggregatorConfig",
    "ConfigConfigurationAggregatorOrganizationAggregationSource",
    "ConfigConfigurationRecorder",
    "ConfigConfigurationRecorderConfig",
    "ConfigConfigurationRecorderRecordingGroup",
    "ConfigConfigurationRecorderStatus",
    "ConfigConfigurationRecorderStatusConfig",
    "ConfigDeliveryChannel",
    "ConfigDeliveryChannelConfig",
    "ConfigDeliveryChannelSnapshotDeliveryProperties",
    "ConfigOrganizationCustomRule",
    "ConfigOrganizationCustomRuleConfig",
    "ConfigOrganizationCustomRuleTimeouts",
    "ConfigOrganizationManagedRule",
    "ConfigOrganizationManagedRuleConfig",
    "ConfigOrganizationManagedRuleTimeouts",
    "CurReportDefinition",
    "CurReportDefinitionConfig",
    "CustomerGateway",
    "CustomerGatewayConfig",
    "DataAwsAcmCertificate",
    "DataAwsAcmCertificateConfig",
    "DataAwsAcmpcaCertificateAuthority",
    "DataAwsAcmpcaCertificateAuthorityConfig",
    "DataAwsAcmpcaCertificateAuthorityRevocationConfiguration",
    "DataAwsAcmpcaCertificateAuthorityRevocationConfigurationCrlConfiguration",
    "DataAwsAlb",
    "DataAwsAlbAccessLogs",
    "DataAwsAlbConfig",
    "DataAwsAlbListener",
    "DataAwsAlbListenerConfig",
    "DataAwsAlbListenerDefaultAction",
    "DataAwsAlbListenerDefaultActionAuthenticateCognito",
    "DataAwsAlbListenerDefaultActionAuthenticateOidc",
    "DataAwsAlbListenerDefaultActionFixedResponse",
    "DataAwsAlbListenerDefaultActionRedirect",
    "DataAwsAlbSubnetMapping",
    "DataAwsAlbTargetGroup",
    "DataAwsAlbTargetGroupConfig",
    "DataAwsAlbTargetGroupHealthCheck",
    "DataAwsAlbTargetGroupStickiness",
    "DataAwsAmi",
    "DataAwsAmiBlockDeviceMappings",
    "DataAwsAmiConfig",
    "DataAwsAmiFilter",
    "DataAwsAmiIds",
    "DataAwsAmiIdsConfig",
    "DataAwsAmiIdsFilter",
    "DataAwsAmiProductCodes",
    "DataAwsApiGatewayApiKey",
    "DataAwsApiGatewayApiKeyConfig",
    "DataAwsApiGatewayResource",
    "DataAwsApiGatewayResourceConfig",
    "DataAwsApiGatewayRestApi",
    "DataAwsApiGatewayRestApiConfig",
    "DataAwsApiGatewayRestApiEndpointConfiguration",
    "DataAwsApiGatewayVpcLink",
    "DataAwsApiGatewayVpcLinkConfig",
    "DataAwsArn",
    "DataAwsArnConfig",
    "DataAwsAutoscalingGroup",
    "DataAwsAutoscalingGroupConfig",
    "DataAwsAutoscalingGroups",
    "DataAwsAutoscalingGroupsConfig",
    "DataAwsAutoscalingGroupsFilter",
    "DataAwsAvailabilityZone",
    "DataAwsAvailabilityZoneConfig",
    "DataAwsAvailabilityZoneFilter",
    "DataAwsAvailabilityZones",
    "DataAwsAvailabilityZonesConfig",
    "DataAwsAvailabilityZonesFilter",
    "DataAwsBackupPlan",
    "DataAwsBackupPlanConfig",
    "DataAwsBackupSelection",
    "DataAwsBackupSelectionConfig",
    "DataAwsBackupVault",
    "DataAwsBackupVaultConfig",
    "DataAwsBatchComputeEnvironment",
    "DataAwsBatchComputeEnvironmentConfig",
    "DataAwsBatchJobQueue",
    "DataAwsBatchJobQueueComputeEnvironmentOrder",
    "DataAwsBatchJobQueueConfig",
    "DataAwsBillingServiceAccount",
    "DataAwsBillingServiceAccountConfig",
    "DataAwsCallerIdentity",
    "DataAwsCallerIdentityConfig",
    "DataAwsCanonicalUserId",
    "DataAwsCanonicalUserIdConfig",
    "DataAwsCloudformationExport",
    "DataAwsCloudformationExportConfig",
    "DataAwsCloudformationStack",
    "DataAwsCloudformationStackConfig",
    "DataAwsCloudfrontDistribution",
    "DataAwsCloudfrontDistributionConfig",
    "DataAwsCloudhsmV2Cluster",
    "DataAwsCloudhsmV2ClusterClusterCertificates",
    "DataAwsCloudhsmV2ClusterConfig",
    "DataAwsCloudtrailServiceAccount",
    "DataAwsCloudtrailServiceAccountConfig",
    "DataAwsCloudwatchLogGroup",
    "DataAwsCloudwatchLogGroupConfig",
    "DataAwsCodecommitRepository",
    "DataAwsCodecommitRepositoryConfig",
    "DataAwsCognitoUserPools",
    "DataAwsCognitoUserPoolsConfig",
    "DataAwsCurReportDefinition",
    "DataAwsCurReportDefinitionConfig",
    "DataAwsCustomerGateway",
    "DataAwsCustomerGatewayConfig",
    "DataAwsCustomerGatewayFilter",
    "DataAwsDbClusterSnapshot",
    "DataAwsDbClusterSnapshotConfig",
    "DataAwsDbEventCategories",
    "DataAwsDbEventCategoriesConfig",
    "DataAwsDbInstance",
    "DataAwsDbInstanceConfig",
    "DataAwsDbSnapshot",
    "DataAwsDbSnapshotConfig",
    "DataAwsDirectoryServiceDirectory",
    "DataAwsDirectoryServiceDirectoryConfig",
    "DataAwsDirectoryServiceDirectoryConnectSettings",
    "DataAwsDirectoryServiceDirectoryVpcSettings",
    "DataAwsDxGateway",
    "DataAwsDxGatewayConfig",
    "DataAwsDynamodbTable",
    "DataAwsDynamodbTableAttribute",
    "DataAwsDynamodbTableConfig",
    "DataAwsDynamodbTableGlobalSecondaryIndex",
    "DataAwsDynamodbTableLocalSecondaryIndex",
    "DataAwsDynamodbTablePointInTimeRecovery",
    "DataAwsDynamodbTableReplica",
    "DataAwsDynamodbTableServerSideEncryption",
    "DataAwsDynamodbTableTtl",
    "DataAwsEbsDefaultKmsKey",
    "DataAwsEbsDefaultKmsKeyConfig",
    "DataAwsEbsEncryptionByDefault",
    "DataAwsEbsEncryptionByDefaultConfig",
    "DataAwsEbsSnapshot",
    "DataAwsEbsSnapshotConfig",
    "DataAwsEbsSnapshotFilter",
    "DataAwsEbsSnapshotIds",
    "DataAwsEbsSnapshotIdsConfig",
    "DataAwsEbsSnapshotIdsFilter",
    "DataAwsEbsVolume",
    "DataAwsEbsVolumeConfig",
    "DataAwsEbsVolumeFilter",
    "DataAwsEbsVolumes",
    "DataAwsEbsVolumesConfig",
    "DataAwsEbsVolumesFilter",
    "DataAwsEc2CoipPool",
    "DataAwsEc2CoipPoolConfig",
    "DataAwsEc2CoipPoolFilter",
    "DataAwsEc2CoipPools",
    "DataAwsEc2CoipPoolsConfig",
    "DataAwsEc2CoipPoolsFilter",
    "DataAwsEc2InstanceTypeOffering",
    "DataAwsEc2InstanceTypeOfferingConfig",
    "DataAwsEc2InstanceTypeOfferingFilter",
    "DataAwsEc2InstanceTypeOfferings",
    "DataAwsEc2InstanceTypeOfferingsConfig",
    "DataAwsEc2InstanceTypeOfferingsFilter",
    "DataAwsEc2LocalGateway",
    "DataAwsEc2LocalGatewayConfig",
    "DataAwsEc2LocalGatewayFilter",
    "DataAwsEc2LocalGatewayRouteTable",
    "DataAwsEc2LocalGatewayRouteTableConfig",
    "DataAwsEc2LocalGatewayRouteTableFilter",
    "DataAwsEc2LocalGatewayRouteTables",
    "DataAwsEc2LocalGatewayRouteTablesConfig",
    "DataAwsEc2LocalGatewayRouteTablesFilter",
    "DataAwsEc2LocalGatewayVirtualInterface",
    "DataAwsEc2LocalGatewayVirtualInterfaceConfig",
    "DataAwsEc2LocalGatewayVirtualInterfaceFilter",
    "DataAwsEc2LocalGatewayVirtualInterfaceGroup",
    "DataAwsEc2LocalGatewayVirtualInterfaceGroupConfig",
    "DataAwsEc2LocalGatewayVirtualInterfaceGroupFilter",
    "DataAwsEc2LocalGatewayVirtualInterfaceGroups",
    "DataAwsEc2LocalGatewayVirtualInterfaceGroupsConfig",
    "DataAwsEc2LocalGatewayVirtualInterfaceGroupsFilter",
    "DataAwsEc2LocalGateways",
    "DataAwsEc2LocalGatewaysConfig",
    "DataAwsEc2LocalGatewaysFilter",
    "DataAwsEc2TransitGateway",
    "DataAwsEc2TransitGatewayConfig",
    "DataAwsEc2TransitGatewayDxGatewayAttachment",
    "DataAwsEc2TransitGatewayDxGatewayAttachmentConfig",
    "DataAwsEc2TransitGatewayDxGatewayAttachmentFilter",
    "DataAwsEc2TransitGatewayFilter",
    "DataAwsEc2TransitGatewayPeeringAttachment",
    "DataAwsEc2TransitGatewayPeeringAttachmentConfig",
    "DataAwsEc2TransitGatewayPeeringAttachmentFilter",
    "DataAwsEc2TransitGatewayRouteTable",
    "DataAwsEc2TransitGatewayRouteTableConfig",
    "DataAwsEc2TransitGatewayRouteTableFilter",
    "DataAwsEc2TransitGatewayVpcAttachment",
    "DataAwsEc2TransitGatewayVpcAttachmentConfig",
    "DataAwsEc2TransitGatewayVpcAttachmentFilter",
    "DataAwsEc2TransitGatewayVpnAttachment",
    "DataAwsEc2TransitGatewayVpnAttachmentConfig",
    "DataAwsEc2TransitGatewayVpnAttachmentFilter",
    "DataAwsEcrAuthorizationToken",
    "DataAwsEcrAuthorizationTokenConfig",
    "DataAwsEcrImage",
    "DataAwsEcrImageConfig",
    "DataAwsEcrRepository",
    "DataAwsEcrRepositoryConfig",
    "DataAwsEcsCluster",
    "DataAwsEcsClusterConfig",
    "DataAwsEcsClusterSetting",
    "DataAwsEcsContainerDefinition",
    "DataAwsEcsContainerDefinitionConfig",
    "DataAwsEcsService",
    "DataAwsEcsServiceConfig",
    "DataAwsEcsTaskDefinition",
    "DataAwsEcsTaskDefinitionConfig",
    "DataAwsEfsAccessPoint",
    "DataAwsEfsAccessPointConfig",
    "DataAwsEfsAccessPointPosixUser",
    "DataAwsEfsAccessPointRootDirectory",
    "DataAwsEfsAccessPointRootDirectoryCreationInfo",
    "DataAwsEfsAccessPoints",
    "DataAwsEfsAccessPointsConfig",
    "DataAwsEfsFileSystem",
    "DataAwsEfsFileSystemConfig",
    "DataAwsEfsFileSystemLifecyclePolicy",
    "DataAwsEfsMountTarget",
    "DataAwsEfsMountTargetConfig",
    "DataAwsEip",
    "DataAwsEipConfig",
    "DataAwsEipFilter",
    "DataAwsEksCluster",
    "DataAwsEksClusterAuth",
    "DataAwsEksClusterAuthConfig",
    "DataAwsEksClusterCertificateAuthority",
    "DataAwsEksClusterConfig",
    "DataAwsEksClusterIdentity",
    "DataAwsEksClusterIdentityOidc",
    "DataAwsEksClusterVpcConfig",
    "DataAwsElasticBeanstalkApplication",
    "DataAwsElasticBeanstalkApplicationAppversionLifecycle",
    "DataAwsElasticBeanstalkApplicationConfig",
    "DataAwsElasticBeanstalkHostedZone",
    "DataAwsElasticBeanstalkHostedZoneConfig",
    "DataAwsElasticBeanstalkSolutionStack",
    "DataAwsElasticBeanstalkSolutionStackConfig",
    "DataAwsElasticacheCluster",
    "DataAwsElasticacheClusterCacheNodes",
    "DataAwsElasticacheClusterConfig",
    "DataAwsElasticacheReplicationGroup",
    "DataAwsElasticacheReplicationGroupConfig",
    "DataAwsElasticsearchDomain",
    "DataAwsElasticsearchDomainAdvancedSecurityOptions",
    "DataAwsElasticsearchDomainClusterConfig",
    "DataAwsElasticsearchDomainClusterConfigZoneAwarenessConfig",
    "DataAwsElasticsearchDomainCognitoOptions",
    "DataAwsElasticsearchDomainConfig",
    "DataAwsElasticsearchDomainEbsOptions",
    "DataAwsElasticsearchDomainEncryptionAtRest",
    "DataAwsElasticsearchDomainLogPublishingOptions",
    "DataAwsElasticsearchDomainNodeToNodeEncryption",
    "DataAwsElasticsearchDomainSnapshotOptions",
    "DataAwsElasticsearchDomainVpcOptions",
    "DataAwsElb",
    "DataAwsElbAccessLogs",
    "DataAwsElbConfig",
    "DataAwsElbHealthCheck",
    "DataAwsElbHostedZoneId",
    "DataAwsElbHostedZoneIdConfig",
    "DataAwsElbListener",
    "DataAwsElbServiceAccount",
    "DataAwsElbServiceAccountConfig",
    "DataAwsGlueScript",
    "DataAwsGlueScriptConfig",
    "DataAwsGlueScriptDagEdge",
    "DataAwsGlueScriptDagNode",
    "DataAwsGlueScriptDagNodeArgs",
    "DataAwsGuarddutyDetector",
    "DataAwsGuarddutyDetectorConfig",
    "DataAwsIamAccountAlias",
    "DataAwsIamAccountAliasConfig",
    "DataAwsIamGroup",
    "DataAwsIamGroupConfig",
    "DataAwsIamGroupUsers",
    "DataAwsIamInstanceProfile",
    "DataAwsIamInstanceProfileConfig",
    "DataAwsIamPolicy",
    "DataAwsIamPolicyConfig",
    "DataAwsIamPolicyDocument",
    "DataAwsIamPolicyDocumentConfig",
    "DataAwsIamPolicyDocumentStatement",
    "DataAwsIamPolicyDocumentStatementCondition",
    "DataAwsIamPolicyDocumentStatementNotPrincipals",
    "DataAwsIamPolicyDocumentStatementPrincipals",
    "DataAwsIamRole",
    "DataAwsIamRoleConfig",
    "DataAwsIamServerCertificate",
    "DataAwsIamServerCertificateConfig",
    "DataAwsIamUser",
    "DataAwsIamUserConfig",
    "DataAwsInspectorRulesPackages",
    "DataAwsInspectorRulesPackagesConfig",
    "DataAwsInstance",
    "DataAwsInstanceConfig",
    "DataAwsInstanceCreditSpecification",
    "DataAwsInstanceEbsBlockDevice",
    "DataAwsInstanceEphemeralBlockDevice",
    "DataAwsInstanceFilter",
    "DataAwsInstanceMetadataOptions",
    "DataAwsInstanceRootBlockDevice",
    "DataAwsInstances",
    "DataAwsInstancesConfig",
    "DataAwsInstancesFilter",
    "DataAwsInternetGateway",
    "DataAwsInternetGatewayAttachments",
    "DataAwsInternetGatewayConfig",
    "DataAwsInternetGatewayFilter",
    "DataAwsIotEndpoint",
    "DataAwsIotEndpointConfig",
    "DataAwsIpRanges",
    "DataAwsIpRangesConfig",
    "DataAwsKinesisStream",
    "DataAwsKinesisStreamConfig",
    "DataAwsKmsAlias",
    "DataAwsKmsAliasConfig",
    "DataAwsKmsCiphertext",
    "DataAwsKmsCiphertextConfig",
    "DataAwsKmsKey",
    "DataAwsKmsKeyConfig",
    "DataAwsKmsSecret",
    "DataAwsKmsSecretConfig",
    "DataAwsKmsSecretSecret",
    "DataAwsKmsSecrets",
    "DataAwsKmsSecretsConfig",
    "DataAwsKmsSecretsSecret",
    "DataAwsLambdaAlias",
    "DataAwsLambdaAliasConfig",
    "DataAwsLambdaFunction",
    "DataAwsLambdaFunctionConfig",
    "DataAwsLambdaFunctionDeadLetterConfig",
    "DataAwsLambdaFunctionEnvironment",
    "DataAwsLambdaFunctionFileSystemConfig",
    "DataAwsLambdaFunctionTracingConfig",
    "DataAwsLambdaFunctionVpcConfig",
    "DataAwsLambdaInvocation",
    "DataAwsLambdaInvocationConfig",
    "DataAwsLambdaLayerVersion",
    "DataAwsLambdaLayerVersionConfig",
    "DataAwsLaunchConfiguration",
    "DataAwsLaunchConfigurationConfig",
    "DataAwsLaunchConfigurationEbsBlockDevice",
    "DataAwsLaunchConfigurationEphemeralBlockDevice",
    "DataAwsLaunchConfigurationRootBlockDevice",
    "DataAwsLaunchTemplate",
    "DataAwsLaunchTemplateBlockDeviceMappings",
    "DataAwsLaunchTemplateBlockDeviceMappingsEbs",
    "DataAwsLaunchTemplateConfig",
    "DataAwsLaunchTemplateCreditSpecification",
    "DataAwsLaunchTemplateElasticGpuSpecifications",
    "DataAwsLaunchTemplateFilter",
    "DataAwsLaunchTemplateHibernationOptions",
    "DataAwsLaunchTemplateIamInstanceProfile",
    "DataAwsLaunchTemplateInstanceMarketOptions",
    "DataAwsLaunchTemplateInstanceMarketOptionsSpotOptions",
    "DataAwsLaunchTemplateMetadataOptions",
    "DataAwsLaunchTemplateMonitoring",
    "DataAwsLaunchTemplateNetworkInterfaces",
    "DataAwsLaunchTemplatePlacement",
    "DataAwsLaunchTemplateTagSpecifications",
    "DataAwsLb",
    "DataAwsLbAccessLogs",
    "DataAwsLbConfig",
    "DataAwsLbListener",
    "DataAwsLbListenerConfig",
    "DataAwsLbListenerDefaultAction",
    "DataAwsLbListenerDefaultActionAuthenticateCognito",
    "DataAwsLbListenerDefaultActionAuthenticateOidc",
    "DataAwsLbListenerDefaultActionFixedResponse",
    "DataAwsLbListenerDefaultActionRedirect",
    "DataAwsLbSubnetMapping",
    "DataAwsLbTargetGroup",
    "DataAwsLbTargetGroupConfig",
    "DataAwsLbTargetGroupHealthCheck",
    "DataAwsLbTargetGroupStickiness",
    "DataAwsMqBroker",
    "DataAwsMqBrokerConfig",
    "DataAwsMqBrokerConfiguration",
    "DataAwsMqBrokerEncryptionOptions",
    "DataAwsMqBrokerInstances",
    "DataAwsMqBrokerLogs",
    "DataAwsMqBrokerMaintenanceWindowStartTime",
    "DataAwsMqBrokerUser",
    "DataAwsMskCluster",
    "DataAwsMskClusterConfig",
    "DataAwsMskConfiguration",
    "DataAwsMskConfigurationConfig",
    "DataAwsNatGateway",
    "DataAwsNatGatewayConfig",
    "DataAwsNatGatewayFilter",
    "DataAwsNetworkAcls",
    "DataAwsNetworkAclsConfig",
    "DataAwsNetworkAclsFilter",
    "DataAwsNetworkInterface",
    "DataAwsNetworkInterfaceAssociation",
    "DataAwsNetworkInterfaceAttachment",
    "DataAwsNetworkInterfaceConfig",
    "DataAwsNetworkInterfaceFilter",
    "DataAwsNetworkInterfaces",
    "DataAwsNetworkInterfacesConfig",
    "DataAwsNetworkInterfacesFilter",
    "DataAwsOrganizationsOrganization",
    "DataAwsOrganizationsOrganizationAccounts",
    "DataAwsOrganizationsOrganizationConfig",
    "DataAwsOrganizationsOrganizationNonMasterAccounts",
    "DataAwsOrganizationsOrganizationRoots",
    "DataAwsOrganizationsOrganizationRootsPolicyTypes",
    "DataAwsOrganizationsOrganizationalUnits",
    "DataAwsOrganizationsOrganizationalUnitsChildren",
    "DataAwsOrganizationsOrganizationalUnitsConfig",
    "DataAwsOutpostsOutpost",
    "DataAwsOutpostsOutpostConfig",
    "DataAwsOutpostsOutpostInstanceType",
    "DataAwsOutpostsOutpostInstanceTypeConfig",
    "DataAwsOutpostsOutpostInstanceTypes",
    "DataAwsOutpostsOutpostInstanceTypesConfig",
    "DataAwsOutpostsOutposts",
    "DataAwsOutpostsOutpostsConfig",
    "DataAwsOutpostsSite",
    "DataAwsOutpostsSiteConfig",
    "DataAwsOutpostsSites",
    "DataAwsOutpostsSitesConfig",
    "DataAwsPartition",
    "DataAwsPartitionConfig",
    "DataAwsPrefixList",
    "DataAwsPrefixListConfig",
    "DataAwsPrefixListFilter",
    "DataAwsPricingProduct",
    "DataAwsPricingProductConfig",
    "DataAwsPricingProductFilters",
    "DataAwsQldbLedger",
    "DataAwsQldbLedgerConfig",
    "DataAwsRamResourceShare",
    "DataAwsRamResourceShareConfig",
    "DataAwsRamResourceShareFilter",
    "DataAwsRdsCluster",
    "DataAwsRdsClusterConfig",
    "DataAwsRedshiftCluster",
    "DataAwsRedshiftClusterConfig",
    "DataAwsRedshiftServiceAccount",
    "DataAwsRedshiftServiceAccountConfig",
    "DataAwsRegion",
    "DataAwsRegionConfig",
    "DataAwsRegions",
    "DataAwsRegionsConfig",
    "DataAwsRegionsFilter",
    "DataAwsRoute",
    "DataAwsRoute53DelegationSet",
    "DataAwsRoute53DelegationSetConfig",
    "DataAwsRoute53ResolverRule",
    "DataAwsRoute53ResolverRuleConfig",
    "DataAwsRoute53ResolverRules",
    "DataAwsRoute53ResolverRulesConfig",
    "DataAwsRoute53Zone",
    "DataAwsRoute53ZoneConfig",
    "DataAwsRouteConfig",
    "DataAwsRouteTable",
    "DataAwsRouteTableAssociations",
    "DataAwsRouteTableConfig",
    "DataAwsRouteTableFilter",
    "DataAwsRouteTableRoutes",
    "DataAwsRouteTables",
    "DataAwsRouteTablesConfig",
    "DataAwsRouteTablesFilter",
    "DataAwsS3Bucket",
    "DataAwsS3BucketConfig",
    "DataAwsS3BucketObject",
    "DataAwsS3BucketObjectConfig",
    "DataAwsS3BucketObjects",
    "DataAwsS3BucketObjectsConfig",
    "DataAwsSecretsmanagerSecret",
    "DataAwsSecretsmanagerSecretConfig",
    "DataAwsSecretsmanagerSecretRotation",
    "DataAwsSecretsmanagerSecretRotationConfig",
    "DataAwsSecretsmanagerSecretRotationRotationRules",
    "DataAwsSecretsmanagerSecretRotationRules",
    "DataAwsSecretsmanagerSecretVersion",
    "DataAwsSecretsmanagerSecretVersionConfig",
    "DataAwsSecurityGroup",
    "DataAwsSecurityGroupConfig",
    "DataAwsSecurityGroupFilter",
    "DataAwsSecurityGroups",
    "DataAwsSecurityGroupsConfig",
    "DataAwsSecurityGroupsFilter",
    "DataAwsServicequotasService",
    "DataAwsServicequotasServiceConfig",
    "DataAwsServicequotasServiceQuota",
    "DataAwsServicequotasServiceQuotaConfig",
    "DataAwsSfnActivity",
    "DataAwsSfnActivityConfig",
    "DataAwsSfnStateMachine",
    "DataAwsSfnStateMachineConfig",
    "DataAwsSnsTopic",
    "DataAwsSnsTopicConfig",
    "DataAwsSqsQueue",
    "DataAwsSqsQueueConfig",
    "DataAwsSsmDocument",
    "DataAwsSsmDocumentConfig",
    "DataAwsSsmParameter",
    "DataAwsSsmParameterConfig",
    "DataAwsSsmPatchBaseline",
    "DataAwsSsmPatchBaselineConfig",
    "DataAwsStoragegatewayLocalDisk",
    "DataAwsStoragegatewayLocalDiskConfig",
    "DataAwsSubnet",
    "DataAwsSubnetConfig",
    "DataAwsSubnetFilter",
    "DataAwsSubnetIds",
    "DataAwsSubnetIdsConfig",
    "DataAwsSubnetIdsFilter",
    "DataAwsTransferServer",
    "DataAwsTransferServerConfig",
    "DataAwsVpc",
    "DataAwsVpcCidrBlockAssociations",
    "DataAwsVpcConfig",
    "DataAwsVpcDhcpOptions",
    "DataAwsVpcDhcpOptionsConfig",
    "DataAwsVpcDhcpOptionsFilter",
    "DataAwsVpcEndpoint",
    "DataAwsVpcEndpointConfig",
    "DataAwsVpcEndpointDnsEntry",
    "DataAwsVpcEndpointFilter",
    "DataAwsVpcEndpointService",
    "DataAwsVpcEndpointServiceConfig",
    "DataAwsVpcEndpointServiceFilter",
    "DataAwsVpcFilter",
    "DataAwsVpcPeeringConnection",
    "DataAwsVpcPeeringConnectionConfig",
    "DataAwsVpcPeeringConnectionFilter",
    "DataAwsVpcs",
    "DataAwsVpcsConfig",
    "DataAwsVpcsFilter",
    "DataAwsVpnGateway",
    "DataAwsVpnGatewayConfig",
    "DataAwsVpnGatewayFilter",
    "DataAwsWafIpset",
    "DataAwsWafIpsetConfig",
    "DataAwsWafRateBasedRule",
    "DataAwsWafRateBasedRuleConfig",
    "DataAwsWafRule",
    "DataAwsWafRuleConfig",
    "DataAwsWafWebAcl",
    "DataAwsWafWebAclConfig",
    "DataAwsWafregionalIpset",
    "DataAwsWafregionalIpsetConfig",
    "DataAwsWafregionalRateBasedRule",
    "DataAwsWafregionalRateBasedRuleConfig",
    "DataAwsWafregionalRule",
    "DataAwsWafregionalRuleConfig",
    "DataAwsWafregionalWebAcl",
    "DataAwsWafregionalWebAclConfig",
    "DataAwsWafv2IpSet",
    "DataAwsWafv2IpSetConfig",
    "DataAwsWafv2RegexPatternSet",
    "DataAwsWafv2RegexPatternSetConfig",
    "DataAwsWafv2RegexPatternSetRegularExpression",
    "DataAwsWafv2RuleGroup",
    "DataAwsWafv2RuleGroupConfig",
    "DataAwsWafv2WebAcl",
    "DataAwsWafv2WebAclConfig",
    "DataAwsWorkspacesBundle",
    "DataAwsWorkspacesBundleComputeType",
    "DataAwsWorkspacesBundleConfig",
    "DataAwsWorkspacesBundleRootStorage",
    "DataAwsWorkspacesBundleUserStorage",
    "DatapipelinePipeline",
    "DatapipelinePipelineConfig",
    "DatasyncAgent",
    "DatasyncAgentConfig",
    "DatasyncAgentTimeouts",
    "DatasyncLocationEfs",
    "DatasyncLocationEfsConfig",
    "DatasyncLocationEfsEc2Config",
    "DatasyncLocationNfs",
    "DatasyncLocationNfsConfig",
    "DatasyncLocationNfsOnPremConfig",
    "DatasyncLocationS3",
    "DatasyncLocationS3Config",
    "DatasyncLocationS3S3Config",
    "DatasyncLocationSmb",
    "DatasyncLocationSmbConfig",
    "DatasyncLocationSmbMountOptions",
    "DatasyncTask",
    "DatasyncTaskConfig",
    "DatasyncTaskOptions",
    "DatasyncTaskTimeouts",
    "DaxCluster",
    "DaxClusterConfig",
    "DaxClusterNodes",
    "DaxClusterServerSideEncryption",
    "DaxClusterTimeouts",
    "DaxParameterGroup",
    "DaxParameterGroupConfig",
    "DaxParameterGroupParameters",
    "DaxSubnetGroup",
    "DaxSubnetGroupConfig",
    "DbClusterSnapshot",
    "DbClusterSnapshotConfig",
    "DbClusterSnapshotTimeouts",
    "DbEventSubscription",
    "DbEventSubscriptionConfig",
    "DbEventSubscriptionTimeouts",
    "DbInstance",
    "DbInstanceConfig",
    "DbInstanceRoleAssociation",
    "DbInstanceRoleAssociationConfig",
    "DbInstanceS3Import",
    "DbInstanceTimeouts",
    "DbOptionGroup",
    "DbOptionGroupConfig",
    "DbOptionGroupOption",
    "DbOptionGroupOptionOptionSettings",
    "DbOptionGroupTimeouts",
    "DbParameterGroup",
    "DbParameterGroupConfig",
    "DbParameterGroupParameter",
    "DbSecurityGroup",
    "DbSecurityGroupConfig",
    "DbSecurityGroupIngress",
    "DbSnapshot",
    "DbSnapshotConfig",
    "DbSnapshotTimeouts",
    "DbSubnetGroup",
    "DbSubnetGroupConfig",
    "DefaultNetworkAcl",
    "DefaultNetworkAclConfig",
    "DefaultNetworkAclEgress",
    "DefaultNetworkAclIngress",
    "DefaultRouteTable",
    "DefaultRouteTableConfig",
    "DefaultRouteTableRoute",
    "DefaultSecurityGroup",
    "DefaultSecurityGroupConfig",
    "DefaultSecurityGroupEgress",
    "DefaultSecurityGroupIngress",
    "DefaultSecurityGroupTimeouts",
    "DefaultSubnet",
    "DefaultSubnetConfig",
    "DefaultSubnetTimeouts",
    "DefaultVpc",
    "DefaultVpcConfig",
    "DefaultVpcDhcpOptions",
    "DefaultVpcDhcpOptionsConfig",
    "DevicefarmProject",
    "DevicefarmProjectConfig",
    "DirectoryServiceConditionalForwarder",
    "DirectoryServiceConditionalForwarderConfig",
    "DirectoryServiceDirectory",
    "DirectoryServiceDirectoryConfig",
    "DirectoryServiceDirectoryConnectSettings",
    "DirectoryServiceDirectoryVpcSettings",
    "DirectoryServiceLogSubscription",
    "DirectoryServiceLogSubscriptionConfig",
    "DlmLifecyclePolicy",
    "DlmLifecyclePolicyConfig",
    "DlmLifecyclePolicyPolicyDetails",
    "DlmLifecyclePolicyPolicyDetailsSchedule",
    "DlmLifecyclePolicyPolicyDetailsScheduleCreateRule",
    "DlmLifecyclePolicyPolicyDetailsScheduleRetainRule",
    "DmsCertificate",
    "DmsCertificateConfig",
    "DmsEndpoint",
    "DmsEndpointConfig",
    "DmsEndpointElasticsearchSettings",
    "DmsEndpointKafkaSettings",
    "DmsEndpointKinesisSettings",
    "DmsEndpointMongodbSettings",
    "DmsEndpointS3Settings",
    "DmsEventSubscription",
    "DmsEventSubscriptionConfig",
    "DmsEventSubscriptionTimeouts",
    "DmsReplicationInstance",
    "DmsReplicationInstanceConfig",
    "DmsReplicationInstanceTimeouts",
    "DmsReplicationSubnetGroup",
    "DmsReplicationSubnetGroupConfig",
    "DmsReplicationTask",
    "DmsReplicationTaskConfig",
    "DocdbCluster",
    "DocdbClusterConfig",
    "DocdbClusterInstance",
    "DocdbClusterInstanceConfig",
    "DocdbClusterInstanceTimeouts",
    "DocdbClusterParameterGroup",
    "DocdbClusterParameterGroupConfig",
    "DocdbClusterParameterGroupParameter",
    "DocdbClusterSnapshot",
    "DocdbClusterSnapshotConfig",
    "DocdbClusterSnapshotTimeouts",
    "DocdbClusterTimeouts",
    "DocdbSubnetGroup",
    "DocdbSubnetGroupConfig",
    "DxBgpPeer",
    "DxBgpPeerConfig",
    "DxBgpPeerTimeouts",
    "DxConnection",
    "DxConnectionAssociation",
    "DxConnectionAssociationConfig",
    "DxConnectionConfig",
    "DxGateway",
    "DxGatewayAssociation",
    "DxGatewayAssociationConfig",
    "DxGatewayAssociationProposal",
    "DxGatewayAssociationProposalConfig",
    "DxGatewayAssociationTimeouts",
    "DxGatewayConfig",
    "DxGatewayTimeouts",
    "DxHostedPrivateVirtualInterface",
    "DxHostedPrivateVirtualInterfaceAccepter",
    "DxHostedPrivateVirtualInterfaceAccepterConfig",
    "DxHostedPrivateVirtualInterfaceAccepterTimeouts",
    "DxHostedPrivateVirtualInterfaceConfig",
    "DxHostedPrivateVirtualInterfaceTimeouts",
    "DxHostedPublicVirtualInterface",
    "DxHostedPublicVirtualInterfaceAccepter",
    "DxHostedPublicVirtualInterfaceAccepterConfig",
    "DxHostedPublicVirtualInterfaceAccepterTimeouts",
    "DxHostedPublicVirtualInterfaceConfig",
    "DxHostedPublicVirtualInterfaceTimeouts",
    "DxHostedTransitVirtualInterface",
    "DxHostedTransitVirtualInterfaceAccepter",
    "DxHostedTransitVirtualInterfaceAccepterConfig",
    "DxHostedTransitVirtualInterfaceAccepterTimeouts",
    "DxHostedTransitVirtualInterfaceConfig",
    "DxHostedTransitVirtualInterfaceTimeouts",
    "DxLag",
    "DxLagConfig",
    "DxPrivateVirtualInterface",
    "DxPrivateVirtualInterfaceConfig",
    "DxPrivateVirtualInterfaceTimeouts",
    "DxPublicVirtualInterface",
    "DxPublicVirtualInterfaceConfig",
    "DxPublicVirtualInterfaceTimeouts",
    "DxTransitVirtualInterface",
    "DxTransitVirtualInterfaceConfig",
    "DxTransitVirtualInterfaceTimeouts",
    "DynamodbGlobalTable",
    "DynamodbGlobalTableConfig",
    "DynamodbGlobalTableReplica",
    "DynamodbGlobalTableTimeouts",
    "DynamodbTable",
    "DynamodbTableAttribute",
    "DynamodbTableConfig",
    "DynamodbTableGlobalSecondaryIndex",
    "DynamodbTableItem",
    "DynamodbTableItemConfig",
    "DynamodbTableLocalSecondaryIndex",
    "DynamodbTablePointInTimeRecovery",
    "DynamodbTableReplica",
    "DynamodbTableServerSideEncryption",
    "DynamodbTableTimeouts",
    "DynamodbTableTtl",
    "EbsDefaultKmsKey",
    "EbsDefaultKmsKeyConfig",
    "EbsEncryptionByDefault",
    "EbsEncryptionByDefaultConfig",
    "EbsSnapshot",
    "EbsSnapshotConfig",
    "EbsSnapshotCopy",
    "EbsSnapshotCopyConfig",
    "EbsSnapshotTimeouts",
    "EbsVolume",
    "EbsVolumeConfig",
    "Ec2AvailabilityZoneGroup",
    "Ec2AvailabilityZoneGroupConfig",
    "Ec2CapacityReservation",
    "Ec2CapacityReservationConfig",
    "Ec2ClientVpnAuthorizationRule",
    "Ec2ClientVpnAuthorizationRuleConfig",
    "Ec2ClientVpnEndpoint",
    "Ec2ClientVpnEndpointAuthenticationOptions",
    "Ec2ClientVpnEndpointConfig",
    "Ec2ClientVpnEndpointConnectionLogOptions",
    "Ec2ClientVpnNetworkAssociation",
    "Ec2ClientVpnNetworkAssociationConfig",
    "Ec2ClientVpnRoute",
    "Ec2ClientVpnRouteConfig",
    "Ec2Fleet",
    "Ec2FleetConfig",
    "Ec2FleetLaunchTemplateConfig",
    "Ec2FleetLaunchTemplateConfigLaunchTemplateSpecification",
    "Ec2FleetLaunchTemplateConfigOverride",
    "Ec2FleetOnDemandOptions",
    "Ec2FleetSpotOptions",
    "Ec2FleetTargetCapacitySpecification",
    "Ec2FleetTimeouts",
    "Ec2LocalGatewayRoute",
    "Ec2LocalGatewayRouteConfig",
    "Ec2LocalGatewayRouteTableVpcAssociation",
    "Ec2LocalGatewayRouteTableVpcAssociationConfig",
    "Ec2Tag",
    "Ec2TagConfig",
    "Ec2TrafficMirrorFilter",
    "Ec2TrafficMirrorFilterConfig",
    "Ec2TrafficMirrorFilterRule",
    "Ec2TrafficMirrorFilterRuleConfig",
    "Ec2TrafficMirrorFilterRuleDestinationPortRange",
    "Ec2TrafficMirrorFilterRuleSourcePortRange",
    "Ec2TrafficMirrorSession",
    "Ec2TrafficMirrorSessionConfig",
    "Ec2TrafficMirrorTarget",
    "Ec2TrafficMirrorTargetConfig",
    "Ec2TransitGateway",
    "Ec2TransitGatewayConfig",
    "Ec2TransitGatewayPeeringAttachment",
    "Ec2TransitGatewayPeeringAttachmentAccepter",
    "Ec2TransitGatewayPeeringAttachmentAccepterConfig",
    "Ec2TransitGatewayPeeringAttachmentConfig",
    "Ec2TransitGatewayRoute",
    "Ec2TransitGatewayRouteConfig",
    "Ec2TransitGatewayRouteTable",
    "Ec2TransitGatewayRouteTableAssociation",
    "Ec2TransitGatewayRouteTableAssociationConfig",
    "Ec2TransitGatewayRouteTableConfig",
    "Ec2TransitGatewayRouteTablePropagation",
    "Ec2TransitGatewayRouteTablePropagationConfig",
    "Ec2TransitGatewayVpcAttachment",
    "Ec2TransitGatewayVpcAttachmentAccepter",
    "Ec2TransitGatewayVpcAttachmentAccepterConfig",
    "Ec2TransitGatewayVpcAttachmentConfig",
    "EcrLifecyclePolicy",
    "EcrLifecyclePolicyConfig",
    "EcrRepository",
    "EcrRepositoryConfig",
    "EcrRepositoryImageScanningConfiguration",
    "EcrRepositoryPolicy",
    "EcrRepositoryPolicyConfig",
    "EcrRepositoryTimeouts",
    "EcsCapacityProvider",
    "EcsCapacityProviderAutoScalingGroupProvider",
    "EcsCapacityProviderAutoScalingGroupProviderManagedScaling",
    "EcsCapacityProviderConfig",
    "EcsCluster",
    "EcsClusterConfig",
    "EcsClusterDefaultCapacityProviderStrategy",
    "EcsClusterSetting",
    "EcsService",
    "EcsServiceCapacityProviderStrategy",
    "EcsServiceConfig",
    "EcsServiceDeploymentController",
    "EcsServiceLoadBalancer",
    "EcsServiceNetworkConfiguration",
    "EcsServiceOrderedPlacementStrategy",
    "EcsServicePlacementConstraints",
    "EcsServicePlacementStrategy",
    "EcsServiceServiceRegistries",
    "EcsServiceTimeouts",
    "EcsTaskDefinition",
    "EcsTaskDefinitionConfig",
    "EcsTaskDefinitionInferenceAccelerator",
    "EcsTaskDefinitionPlacementConstraints",
    "EcsTaskDefinitionProxyConfiguration",
    "EcsTaskDefinitionVolume",
    "EcsTaskDefinitionVolumeDockerVolumeConfiguration",
    "EcsTaskDefinitionVolumeEfsVolumeConfiguration",
    "EcsTaskDefinitionVolumeEfsVolumeConfigurationAuthorizationConfig",
    "EfsAccessPoint",
    "EfsAccessPointConfig",
    "EfsAccessPointPosixUser",
    "EfsAccessPointRootDirectory",
    "EfsAccessPointRootDirectoryCreationInfo",
    "EfsFileSystem",
    "EfsFileSystemConfig",
    "EfsFileSystemLifecyclePolicy",
    "EfsFileSystemPolicy",
    "EfsFileSystemPolicyConfig",
    "EfsMountTarget",
    "EfsMountTargetConfig",
    "EgressOnlyInternetGateway",
    "EgressOnlyInternetGatewayConfig",
    "Eip",
    "EipAssociation",
    "EipAssociationConfig",
    "EipConfig",
    "EipTimeouts",
    "EksCluster",
    "EksClusterCertificateAuthority",
    "EksClusterConfig",
    "EksClusterEncryptionConfig",
    "EksClusterEncryptionConfigProvider",
    "EksClusterIdentity",
    "EksClusterIdentityOidc",
    "EksClusterTimeouts",
    "EksClusterVpcConfig",
    "EksFargateProfile",
    "EksFargateProfileConfig",
    "EksFargateProfileSelector",
    "EksFargateProfileTimeouts",
    "EksNodeGroup",
    "EksNodeGroupConfig",
    "EksNodeGroupRemoteAccess",
    "EksNodeGroupResources",
    "EksNodeGroupResourcesAutoscalingGroups",
    "EksNodeGroupScalingConfig",
    "EksNodeGroupTimeouts",
    "ElasticBeanstalkApplication",
    "ElasticBeanstalkApplicationAppversionLifecycle",
    "ElasticBeanstalkApplicationConfig",
    "ElasticBeanstalkApplicationVersion",
    "ElasticBeanstalkApplicationVersionConfig",
    "ElasticBeanstalkConfigurationTemplate",
    "ElasticBeanstalkConfigurationTemplateConfig",
    "ElasticBeanstalkConfigurationTemplateSetting",
    "ElasticBeanstalkEnvironment",
    "ElasticBeanstalkEnvironmentAllSettings",
    "ElasticBeanstalkEnvironmentConfig",
    "ElasticBeanstalkEnvironmentSetting",
    "ElasticacheCluster",
    "ElasticacheClusterCacheNodes",
    "ElasticacheClusterConfig",
    "ElasticacheParameterGroup",
    "ElasticacheParameterGroupConfig",
    "ElasticacheParameterGroupParameter",
    "ElasticacheReplicationGroup",
    "ElasticacheReplicationGroupClusterMode",
    "ElasticacheReplicationGroupConfig",
    "ElasticacheReplicationGroupTimeouts",
    "ElasticacheSecurityGroup",
    "ElasticacheSecurityGroupConfig",
    "ElasticacheSubnetGroup",
    "ElasticacheSubnetGroupConfig",
    "ElasticsearchDomain",
    "ElasticsearchDomainAdvancedSecurityOptions",
    "ElasticsearchDomainAdvancedSecurityOptionsMasterUserOptions",
    "ElasticsearchDomainClusterConfig",
    "ElasticsearchDomainClusterConfigZoneAwarenessConfig",
    "ElasticsearchDomainCognitoOptions",
    "ElasticsearchDomainConfig",
    "ElasticsearchDomainDomainEndpointOptions",
    "ElasticsearchDomainEbsOptions",
    "ElasticsearchDomainEncryptAtRest",
    "ElasticsearchDomainLogPublishingOptions",
    "ElasticsearchDomainNodeToNodeEncryption",
    "ElasticsearchDomainPolicy",
    "ElasticsearchDomainPolicyConfig",
    "ElasticsearchDomainSnapshotOptions",
    "ElasticsearchDomainTimeouts",
    "ElasticsearchDomainVpcOptions",
    "ElastictranscoderPipeline",
    "ElastictranscoderPipelineConfig",
    "ElastictranscoderPipelineContentConfig",
    "ElastictranscoderPipelineContentConfigPermissions",
    "ElastictranscoderPipelineNotifications",
    "ElastictranscoderPipelineThumbnailConfig",
    "ElastictranscoderPipelineThumbnailConfigPermissions",
    "ElastictranscoderPreset",
    "ElastictranscoderPresetAudio",
    "ElastictranscoderPresetAudioCodecOptions",
    "ElastictranscoderPresetConfig",
    "ElastictranscoderPresetThumbnails",
    "ElastictranscoderPresetVideo",
    "ElastictranscoderPresetVideoWatermarks",
    "Elb",
    "ElbAccessLogs",
    "ElbAttachment",
    "ElbAttachmentConfig",
    "ElbConfig",
    "ElbHealthCheck",
    "ElbListener",
    "EmrCluster",
    "EmrClusterBootstrapAction",
    "EmrClusterConfig",
    "EmrClusterCoreInstanceGroup",
    "EmrClusterCoreInstanceGroupEbsConfig",
    "EmrClusterEc2Attributes",
    "EmrClusterInstanceGroup",
    "EmrClusterInstanceGroupEbsConfig",
    "EmrClusterKerberosAttributes",
    "EmrClusterMasterInstanceGroup",
    "EmrClusterMasterInstanceGroupEbsConfig",
    "EmrClusterStep",
    "EmrClusterStepHadoopJarStep",
    "EmrInstanceGroup",
    "EmrInstanceGroupConfig",
    "EmrInstanceGroupEbsConfig",
    "EmrSecurityConfiguration",
    "EmrSecurityConfigurationConfig",
    "FlowLog",
    "FlowLogConfig",
    "FmsAdminAccount",
    "FmsAdminAccountConfig",
    "FsxLustreFileSystem",
    "FsxLustreFileSystemConfig",
    "FsxLustreFileSystemTimeouts",
    "FsxWindowsFileSystem",
    "FsxWindowsFileSystemConfig",
    "FsxWindowsFileSystemSelfManagedActiveDirectory",
    "FsxWindowsFileSystemTimeouts",
    "GameliftAlias",
    "GameliftAliasConfig",
    "GameliftAliasRoutingStrategy",
    "GameliftBuild",
    "GameliftBuildConfig",
    "GameliftBuildStorageLocation",
    "GameliftFleet",
    "GameliftFleetConfig",
    "GameliftFleetEc2InboundPermission",
    "GameliftFleetResourceCreationLimitPolicy",
    "GameliftFleetRuntimeConfiguration",
    "GameliftFleetRuntimeConfigurationServerProcess",
    "GameliftFleetTimeouts",
    "GameliftGameSessionQueue",
    "GameliftGameSessionQueueConfig",
    "GameliftGameSessionQueuePlayerLatencyPolicy",
    "GlacierVault",
    "GlacierVaultConfig",
    "GlacierVaultLock",
    "GlacierVaultLockConfig",
    "GlacierVaultNotification",
    "GlobalacceleratorAccelerator",
    "GlobalacceleratorAcceleratorAttributes",
    "GlobalacceleratorAcceleratorConfig",
    "GlobalacceleratorAcceleratorIpSets",
    "GlobalacceleratorEndpointGroup",
    "GlobalacceleratorEndpointGroupConfig",
    "GlobalacceleratorEndpointGroupEndpointConfiguration",
    "GlobalacceleratorListener",
    "GlobalacceleratorListenerConfig",
    "GlobalacceleratorListenerPortRange",
    "GlueCatalogDatabase",
    "GlueCatalogDatabaseConfig",
    "GlueCatalogTable",
    "GlueCatalogTableConfig",
    "GlueCatalogTablePartitionKeys",
    "GlueCatalogTableStorageDescriptor",
    "GlueCatalogTableStorageDescriptorColumns",
    "GlueCatalogTableStorageDescriptorSerDeInfo",
    "GlueCatalogTableStorageDescriptorSkewedInfo",
    "GlueCatalogTableStorageDescriptorSortColumns",
    "GlueClassifier",
    "GlueClassifierConfig",
    "GlueClassifierCsvClassifier",
    "GlueClassifierGrokClassifier",
    "GlueClassifierJsonClassifier",
    "GlueClassifierXmlClassifier",
    "GlueConnection",
    "GlueConnectionConfig",
    "GlueConnectionPhysicalConnectionRequirements",
    "GlueCrawler",
    "GlueCrawlerCatalogTarget",
    "GlueCrawlerConfig",
    "GlueCrawlerDynamodbTarget",
    "GlueCrawlerJdbcTarget",
    "GlueCrawlerS3Target",
    "GlueCrawlerSchemaChangePolicy",
    "GlueJob",
    "GlueJobCommand",
    "GlueJobConfig",
    "GlueJobExecutionProperty",
    "GlueJobNotificationProperty",
    "GlueSecurityConfiguration",
    "GlueSecurityConfigurationConfig",
    "GlueSecurityConfigurationEncryptionConfiguration",
    "GlueSecurityConfigurationEncryptionConfigurationCloudwatchEncryption",
    "GlueSecurityConfigurationEncryptionConfigurationJobBookmarksEncryption",
    "GlueSecurityConfigurationEncryptionConfigurationS3Encryption",
    "GlueTrigger",
    "GlueTriggerActions",
    "GlueTriggerConfig",
    "GlueTriggerPredicate",
    "GlueTriggerPredicateConditions",
    "GlueTriggerTimeouts",
    "GlueWorkflow",
    "GlueWorkflowConfig",
    "GuarddutyDetector",
    "GuarddutyDetectorConfig",
    "GuarddutyInviteAccepter",
    "GuarddutyInviteAccepterConfig",
    "GuarddutyInviteAccepterTimeouts",
    "GuarddutyIpset",
    "GuarddutyIpsetConfig",
    "GuarddutyMember",
    "GuarddutyMemberConfig",
    "GuarddutyMemberTimeouts",
    "GuarddutyOrganizationAdminAccount",
    "GuarddutyOrganizationAdminAccountConfig",
    "GuarddutyOrganizationConfiguration",
    "GuarddutyOrganizationConfigurationConfig",
    "GuarddutyThreatintelset",
    "GuarddutyThreatintelsetConfig",
    "IamAccessKey",
    "IamAccessKeyConfig",
    "IamAccountAlias",
    "IamAccountAliasConfig",
    "IamAccountPasswordPolicy",
    "IamAccountPasswordPolicyConfig",
    "IamGroup",
    "IamGroupConfig",
    "IamGroupMembership",
    "IamGroupMembershipConfig",
    "IamGroupPolicy",
    "IamGroupPolicyAttachment",
    "IamGroupPolicyAttachmentConfig",
    "IamGroupPolicyConfig",
    "IamInstanceProfile",
    "IamInstanceProfileConfig",
    "IamOpenidConnectProvider",
    "IamOpenidConnectProviderConfig",
    "IamPolicy",
    "IamPolicyAttachment",
    "IamPolicyAttachmentConfig",
    "IamPolicyConfig",
    "IamRole",
    "IamRoleConfig",
    "IamRolePolicy",
    "IamRolePolicyAttachment",
    "IamRolePolicyAttachmentConfig",
    "IamRolePolicyConfig",
    "IamSamlProvider",
    "IamSamlProviderConfig",
    "IamServerCertificate",
    "IamServerCertificateConfig",
    "IamServiceLinkedRole",
    "IamServiceLinkedRoleConfig",
    "IamUser",
    "IamUserConfig",
    "IamUserGroupMembership",
    "IamUserGroupMembershipConfig",
    "IamUserLoginProfile",
    "IamUserLoginProfileConfig",
    "IamUserPolicy",
    "IamUserPolicyAttachment",
    "IamUserPolicyAttachmentConfig",
    "IamUserPolicyConfig",
    "IamUserSshKey",
    "IamUserSshKeyConfig",
    "InspectorAssessmentTarget",
    "InspectorAssessmentTargetConfig",
    "InspectorAssessmentTemplate",
    "InspectorAssessmentTemplateConfig",
    "InspectorResourceGroup",
    "InspectorResourceGroupConfig",
    "Instance",
    "InstanceConfig",
    "InstanceCreditSpecification",
    "InstanceEbsBlockDevice",
    "InstanceEphemeralBlockDevice",
    "InstanceMetadataOptions",
    "InstanceNetworkInterface",
    "InstanceRootBlockDevice",
    "InstanceTimeouts",
    "InternetGateway",
    "InternetGatewayConfig",
    "IotCertificate",
    "IotCertificateConfig",
    "IotPolicy",
    "IotPolicyAttachment",
    "IotPolicyAttachmentConfig",
    "IotPolicyConfig",
    "IotRoleAlias",
    "IotRoleAliasConfig",
    "IotThing",
    "IotThingConfig",
    "IotThingPrincipalAttachment",
    "IotThingPrincipalAttachmentConfig",
    "IotThingType",
    "IotThingTypeConfig",
    "IotThingTypeProperties",
    "IotTopicRule",
    "IotTopicRuleCloudwatchAlarm",
    "IotTopicRuleCloudwatchMetric",
    "IotTopicRuleConfig",
    "IotTopicRuleDynamodb",
    "IotTopicRuleDynamodbv2",
    "IotTopicRuleDynamodbv2PutItem",
    "IotTopicRuleElasticsearch",
    "IotTopicRuleErrorAction",
    "IotTopicRuleErrorActionCloudwatchAlarm",
    "IotTopicRuleErrorActionCloudwatchMetric",
    "IotTopicRuleErrorActionDynamodb",
    "IotTopicRuleErrorActionDynamodbv2",
    "IotTopicRuleErrorActionDynamodbv2PutItem",
    "IotTopicRuleErrorActionElasticsearch",
    "IotTopicRuleErrorActionFirehose",
    "IotTopicRuleErrorActionIotAnalytics",
    "IotTopicRuleErrorActionIotEvents",
    "IotTopicRuleErrorActionKinesis",
    "IotTopicRuleErrorActionLambda",
    "IotTopicRuleErrorActionRepublish",
    "IotTopicRuleErrorActionS3",
    "IotTopicRuleErrorActionSns",
    "IotTopicRuleErrorActionSqs",
    "IotTopicRuleErrorActionStepFunctions",
    "IotTopicRuleFirehose",
    "IotTopicRuleIotAnalytics",
    "IotTopicRuleIotEvents",
    "IotTopicRuleKinesis",
    "IotTopicRuleLambda",
    "IotTopicRuleRepublish",
    "IotTopicRuleS3",
    "IotTopicRuleSns",
    "IotTopicRuleSqs",
    "IotTopicRuleStepFunctions",
    "KeyPair",
    "KeyPairConfig",
    "KinesisAnalyticsApplication",
    "KinesisAnalyticsApplicationCloudwatchLoggingOptions",
    "KinesisAnalyticsApplicationConfig",
    "KinesisAnalyticsApplicationInputs",
    "KinesisAnalyticsApplicationInputsKinesisFirehose",
    "KinesisAnalyticsApplicationInputsKinesisStream",
    "KinesisAnalyticsApplicationInputsParallelism",
    "KinesisAnalyticsApplicationInputsProcessingConfiguration",
    "KinesisAnalyticsApplicationInputsProcessingConfigurationLambda",
    "KinesisAnalyticsApplicationInputsSchema",
    "KinesisAnalyticsApplicationInputsSchemaRecordColumns",
    "KinesisAnalyticsApplicationInputsSchemaRecordFormat",
    "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParameters",
    "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersCsv",
    "KinesisAnalyticsApplicationInputsSchemaRecordFormatMappingParametersJson",
    "KinesisAnalyticsApplicationOutputs",
    "KinesisAnalyticsApplicationOutputsKinesisFirehose",
    "KinesisAnalyticsApplicationOutputsKinesisStream",
    "KinesisAnalyticsApplicationOutputsLambda",
    "KinesisAnalyticsApplicationOutputsSchema",
    "KinesisAnalyticsApplicationReferenceDataSources",
    "KinesisAnalyticsApplicationReferenceDataSourcesS3",
    "KinesisAnalyticsApplicationReferenceDataSourcesSchema",
    "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordColumns",
    "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormat",
    "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParameters",
    "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersCsv",
    "KinesisAnalyticsApplicationReferenceDataSourcesSchemaRecordFormatMappingParametersJson",
    "KinesisFirehoseDeliveryStream",
    "KinesisFirehoseDeliveryStreamConfig",
    "KinesisFirehoseDeliveryStreamElasticsearchConfiguration",
    "KinesisFirehoseDeliveryStreamElasticsearchConfigurationCloudwatchLoggingOptions",
    "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfiguration",
    "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessors",
    "KinesisFirehoseDeliveryStreamElasticsearchConfigurationProcessingConfigurationProcessorsParameters",
    "KinesisFirehoseDeliveryStreamExtendedS3Configuration",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationCloudwatchLoggingOptions",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfiguration",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfiguration",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializer",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerHiveJsonSerDe",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationInputFormatConfigurationDeserializerOpenXJsonSerDe",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfiguration",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializer",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerOrcSerDe",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationOutputFormatConfigurationSerializerParquetSerDe",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationDataFormatConversionConfigurationSchemaConfiguration",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfiguration",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessors",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationProcessingConfigurationProcessorsParameters",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfiguration",
    "KinesisFirehoseDeliveryStreamExtendedS3ConfigurationS3BackupConfigurationCloudwatchLoggingOptions",
    "KinesisFirehoseDeliveryStreamKinesisSourceConfiguration",
    "KinesisFirehoseDeliveryStreamRedshiftConfiguration",
    "KinesisFirehoseDeliveryStreamRedshiftConfigurationCloudwatchLoggingOptions",
    "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfiguration",
    "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessors",
    "KinesisFirehoseDeliveryStreamRedshiftConfigurationProcessingConfigurationProcessorsParameters",
    "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfiguration",
    "KinesisFirehoseDeliveryStreamRedshiftConfigurationS3BackupConfigurationCloudwatchLoggingOptions",
    "KinesisFirehoseDeliveryStreamS3Configuration",
    "KinesisFirehoseDeliveryStreamS3ConfigurationCloudwatchLoggingOptions",
    "KinesisFirehoseDeliveryStreamServerSideEncryption",
    "KinesisFirehoseDeliveryStreamSplunkConfiguration",
    "KinesisFirehoseDeliveryStreamSplunkConfigurationCloudwatchLoggingOptions",
    "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfiguration",
    "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessors",
    "KinesisFirehoseDeliveryStreamSplunkConfigurationProcessingConfigurationProcessorsParameters",
    "KinesisStream",
    "KinesisStreamConfig",
    "KinesisStreamTimeouts",
    "KinesisVideoStream",
    "KinesisVideoStreamConfig",
    "KinesisVideoStreamTimeouts",
    "KmsAlias",
    "KmsAliasConfig",
    "KmsCiphertext",
    "KmsCiphertextConfig",
    "KmsExternalKey",
    "KmsExternalKeyConfig",
    "KmsGrant",
    "KmsGrantConfig",
    "KmsGrantConstraints",
    "KmsKey",
    "KmsKeyConfig",
    "LambdaAlias",
    "LambdaAliasConfig",
    "LambdaAliasRoutingConfig",
    "LambdaEventSourceMapping",
    "LambdaEventSourceMappingConfig",
    "LambdaEventSourceMappingDestinationConfig",
    "LambdaEventSourceMappingDestinationConfigOnFailure",
    "LambdaFunction",
    "LambdaFunctionConfig",
    "LambdaFunctionDeadLetterConfig",
    "LambdaFunctionEnvironment",
    "LambdaFunctionEventInvokeConfig",
    "LambdaFunctionEventInvokeConfigConfig",
    "LambdaFunctionEventInvokeConfigDestinationConfig",
    "LambdaFunctionEventInvokeConfigDestinationConfigOnFailure",
    "LambdaFunctionEventInvokeConfigDestinationConfigOnSuccess",
    "LambdaFunctionFileSystemConfig",
    "LambdaFunctionTimeouts",
    "LambdaFunctionTracingConfig",
    "LambdaFunctionVpcConfig",
    "LambdaLayerVersion",
    "LambdaLayerVersionConfig",
    "LambdaPermission",
    "LambdaPermissionConfig",
    "LambdaProvisionedConcurrencyConfig",
    "LambdaProvisionedConcurrencyConfigConfig",
    "LambdaProvisionedConcurrencyConfigTimeouts",
    "LaunchConfiguration",
    "LaunchConfigurationConfig",
    "LaunchConfigurationEbsBlockDevice",
    "LaunchConfigurationEphemeralBlockDevice",
    "LaunchConfigurationRootBlockDevice",
    "LaunchTemplate",
    "LaunchTemplateBlockDeviceMappings",
    "LaunchTemplateBlockDeviceMappingsEbs",
    "LaunchTemplateCapacityReservationSpecification",
    "LaunchTemplateCapacityReservationSpecificationCapacityReservationTarget",
    "LaunchTemplateConfig",
    "LaunchTemplateCpuOptions",
    "LaunchTemplateCreditSpecification",
    "LaunchTemplateElasticGpuSpecifications",
    "LaunchTemplateElasticInferenceAccelerator",
    "LaunchTemplateHibernationOptions",
    "LaunchTemplateIamInstanceProfile",
    "LaunchTemplateInstanceMarketOptions",
    "LaunchTemplateInstanceMarketOptionsSpotOptions",
    "LaunchTemplateLicenseSpecification",
    "LaunchTemplateMetadataOptions",
    "LaunchTemplateMonitoring",
    "LaunchTemplateNetworkInterfaces",
    "LaunchTemplatePlacement",
    "LaunchTemplateTagSpecifications",
    "Lb",
    "LbAccessLogs",
    "LbConfig",
    "LbCookieStickinessPolicy",
    "LbCookieStickinessPolicyConfig",
    "LbListener",
    "LbListenerCertificate",
    "LbListenerCertificateConfig",
    "LbListenerConfig",
    "LbListenerDefaultAction",
    "LbListenerDefaultActionAuthenticateCognito",
    "LbListenerDefaultActionAuthenticateOidc",
    "LbListenerDefaultActionFixedResponse",
    "LbListenerDefaultActionForward",
    "LbListenerDefaultActionForwardStickiness",
    "LbListenerDefaultActionForwardTargetGroup",
    "LbListenerDefaultActionRedirect",
    "LbListenerRule",
    "LbListenerRuleAction",
    "LbListenerRuleActionAuthenticateCognito",
    "LbListenerRuleActionAuthenticateOidc",
    "LbListenerRuleActionFixedResponse",
    "LbListenerRuleActionForward",
    "LbListenerRuleActionForwardStickiness",
    "LbListenerRuleActionForwardTargetGroup",
    "LbListenerRuleActionRedirect",
    "LbListenerRuleCondition",
    "LbListenerRuleConditionHostHeader",
    "LbListenerRuleConditionHttpHeader",
    "LbListenerRuleConditionHttpRequestMethod",
    "LbListenerRuleConditionPathPattern",
    "LbListenerRuleConditionQueryString",
    "LbListenerRuleConditionSourceIp",
    "LbListenerRuleConfig",
    "LbListenerTimeouts",
    "LbSslNegotiationPolicy",
    "LbSslNegotiationPolicyAttribute",
    "LbSslNegotiationPolicyConfig",
    "LbSubnetMapping",
    "LbTargetGroup",
    "LbTargetGroupAttachment",
    "LbTargetGroupAttachmentConfig",
    "LbTargetGroupConfig",
    "LbTargetGroupHealthCheck",
    "LbTargetGroupStickiness",
    "LbTimeouts",
    "LicensemanagerAssociation",
    "LicensemanagerAssociationConfig",
    "LicensemanagerLicenseConfiguration",
    "LicensemanagerLicenseConfigurationConfig",
    "LightsailDomain",
    "LightsailDomainConfig",
    "LightsailInstance",
    "LightsailInstanceConfig",
    "LightsailKeyPair",
    "LightsailKeyPairConfig",
    "LightsailStaticIp",
    "LightsailStaticIpAttachment",
    "LightsailStaticIpAttachmentConfig",
    "LightsailStaticIpConfig",
    "LoadBalancerBackendServerPolicy",
    "LoadBalancerBackendServerPolicyConfig",
    "LoadBalancerListenerPolicy",
    "LoadBalancerListenerPolicyConfig",
    "LoadBalancerPolicy",
    "LoadBalancerPolicyConfig",
    "LoadBalancerPolicyPolicyAttribute",
    "MacieMemberAccountAssociation",
    "MacieMemberAccountAssociationConfig",
    "MacieS3BucketAssociation",
    "MacieS3BucketAssociationClassificationType",
    "MacieS3BucketAssociationConfig",
    "MainRouteTableAssociation",
    "MainRouteTableAssociationConfig",
    "MediaConvertQueue",
    "MediaConvertQueueConfig",
    "MediaConvertQueueReservationPlanSettings",
    "MediaPackageChannel",
    "MediaPackageChannelConfig",
    "MediaPackageChannelHlsIngest",
    "MediaPackageChannelHlsIngestIngestEndpoints",
    "MediaStoreContainer",
    "MediaStoreContainerConfig",
    "MediaStoreContainerPolicy",
    "MediaStoreContainerPolicyConfig",
    "MqBroker",
    "MqBrokerConfig",
    "MqBrokerConfiguration",
    "MqBrokerEncryptionOptions",
    "MqBrokerInstances",
    "MqBrokerLogs",
    "MqBrokerMaintenanceWindowStartTime",
    "MqBrokerUser",
    "MqConfiguration",
    "MqConfigurationConfig",
    "MskCluster",
    "MskClusterBrokerNodeGroupInfo",
    "MskClusterClientAuthentication",
    "MskClusterClientAuthenticationTls",
    "MskClusterConfig",
    "MskClusterConfigurationInfo",
    "MskClusterEncryptionInfo",
    "MskClusterEncryptionInfoEncryptionInTransit",
    "MskClusterLoggingInfo",
    "MskClusterLoggingInfoBrokerLogs",
    "MskClusterLoggingInfoBrokerLogsCloudwatchLogs",
    "MskClusterLoggingInfoBrokerLogsFirehose",
    "MskClusterLoggingInfoBrokerLogsS3",
    "MskClusterOpenMonitoring",
    "MskClusterOpenMonitoringPrometheus",
    "MskClusterOpenMonitoringPrometheusJmxExporter",
    "MskClusterOpenMonitoringPrometheusNodeExporter",
    "MskConfiguration",
    "MskConfigurationConfig",
    "NatGateway",
    "NatGatewayConfig",
    "NeptuneCluster",
    "NeptuneClusterConfig",
    "NeptuneClusterInstance",
    "NeptuneClusterInstanceConfig",
    "NeptuneClusterInstanceTimeouts",
    "NeptuneClusterParameterGroup",
    "NeptuneClusterParameterGroupConfig",
    "NeptuneClusterParameterGroupParameter",
    "NeptuneClusterSnapshot",
    "NeptuneClusterSnapshotConfig",
    "NeptuneClusterSnapshotTimeouts",
    "NeptuneClusterTimeouts",
    "NeptuneEventSubscription",
    "NeptuneEventSubscriptionConfig",
    "NeptuneEventSubscriptionTimeouts",
    "NeptuneParameterGroup",
    "NeptuneParameterGroupConfig",
    "NeptuneParameterGroupParameter",
    "NeptuneSubnetGroup",
    "NeptuneSubnetGroupConfig",
    "NetworkAcl",
    "NetworkAclConfig",
    "NetworkAclEgress",
    "NetworkAclIngress",
    "NetworkAclRule",
    "NetworkAclRuleConfig",
    "NetworkInterface",
    "NetworkInterfaceAttachment",
    "NetworkInterfaceAttachmentA",
    "NetworkInterfaceAttachmentAConfig",
    "NetworkInterfaceConfig",
    "NetworkInterfaceSgAttachment",
    "NetworkInterfaceSgAttachmentConfig",
    "OpsworksApplication",
    "OpsworksApplicationAppSource",
    "OpsworksApplicationConfig",
    "OpsworksApplicationEnvironment",
    "OpsworksApplicationSslConfiguration",
    "OpsworksCustomLayer",
    "OpsworksCustomLayerConfig",
    "OpsworksCustomLayerEbsVolume",
    "OpsworksGangliaLayer",
    "OpsworksGangliaLayerConfig",
    "OpsworksGangliaLayerEbsVolume",
    "OpsworksHaproxyLayer",
    "OpsworksHaproxyLayerConfig",
    "OpsworksHaproxyLayerEbsVolume",
    "OpsworksInstance",
    "OpsworksInstanceConfig",
    "OpsworksInstanceEbsBlockDevice",
    "OpsworksInstanceEphemeralBlockDevice",
    "OpsworksInstanceRootBlockDevice",
    "OpsworksInstanceTimeouts",
    "OpsworksJavaAppLayer",
    "OpsworksJavaAppLayerConfig",
    "OpsworksJavaAppLayerEbsVolume",
    "OpsworksMemcachedLayer",
    "OpsworksMemcachedLayerConfig",
    "OpsworksMemcachedLayerEbsVolume",
    "OpsworksMysqlLayer",
    "OpsworksMysqlLayerConfig",
    "OpsworksMysqlLayerEbsVolume",
    "OpsworksNodejsAppLayer",
    "OpsworksNodejsAppLayerConfig",
    "OpsworksNodejsAppLayerEbsVolume",
    "OpsworksPermission",
    "OpsworksPermissionConfig",
    "OpsworksPhpAppLayer",
    "OpsworksPhpAppLayerConfig",
    "OpsworksPhpAppLayerEbsVolume",
    "OpsworksRailsAppLayer",
    "OpsworksRailsAppLayerConfig",
    "OpsworksRailsAppLayerEbsVolume",
    "OpsworksRdsDbInstance",
    "OpsworksRdsDbInstanceConfig",
    "OpsworksStack",
    "OpsworksStackConfig",
    "OpsworksStackCustomCookbooksSource",
    "OpsworksStaticWebLayer",
    "OpsworksStaticWebLayerConfig",
    "OpsworksStaticWebLayerEbsVolume",
    "OpsworksUserProfile",
    "OpsworksUserProfileConfig",
    "OrganizationsAccount",
    "OrganizationsAccountConfig",
    "OrganizationsOrganization",
    "OrganizationsOrganizationAccounts",
    "OrganizationsOrganizationConfig",
    "OrganizationsOrganizationNonMasterAccounts",
    "OrganizationsOrganizationRoots",
    "OrganizationsOrganizationRootsPolicyTypes",
    "OrganizationsOrganizationalUnit",
    "OrganizationsOrganizationalUnitAccounts",
    "OrganizationsOrganizationalUnitConfig",
    "OrganizationsPolicy",
    "OrganizationsPolicyAttachment",
    "OrganizationsPolicyAttachmentConfig",
    "OrganizationsPolicyConfig",
    "PinpointAdmChannel",
    "PinpointAdmChannelConfig",
    "PinpointApnsChannel",
    "PinpointApnsChannelConfig",
    "PinpointApnsSandboxChannel",
    "PinpointApnsSandboxChannelConfig",
    "PinpointApnsVoipChannel",
    "PinpointApnsVoipChannelConfig",
    "PinpointApnsVoipSandboxChannel",
    "PinpointApnsVoipSandboxChannelConfig",
    "PinpointApp",
    "PinpointAppCampaignHook",
    "PinpointAppConfig",
    "PinpointAppLimits",
    "PinpointAppQuietTime",
    "PinpointBaiduChannel",
    "PinpointBaiduChannelConfig",
    "PinpointEmailChannel",
    "PinpointEmailChannelConfig",
    "PinpointEventStream",
    "PinpointEventStreamConfig",
    "PinpointGcmChannel",
    "PinpointGcmChannelConfig",
    "PinpointSmsChannel",
    "PinpointSmsChannelConfig",
    "PlacementGroup",
    "PlacementGroupConfig",
    "ProxyProtocolPolicy",
    "ProxyProtocolPolicyConfig",
    "QldbLedger",
    "QldbLedgerConfig",
    "QuicksightGroup",
    "QuicksightGroupConfig",
    "QuicksightUser",
    "QuicksightUserConfig",
    "RamPrincipalAssociation",
    "RamPrincipalAssociationConfig",
    "RamResourceAssociation",
    "RamResourceAssociationConfig",
    "RamResourceShare",
    "RamResourceShareAccepter",
    "RamResourceShareAccepterConfig",
    "RamResourceShareAccepterTimeouts",
    "RamResourceShareConfig",
    "RamResourceShareTimeouts",
    "RdsCluster",
    "RdsClusterConfig",
    "RdsClusterEndpoint",
    "RdsClusterEndpointConfig",
    "RdsClusterInstance",
    "RdsClusterInstanceConfig",
    "RdsClusterInstanceTimeouts",
    "RdsClusterParameterGroup",
    "RdsClusterParameterGroupConfig",
    "RdsClusterParameterGroupParameter",
    "RdsClusterS3Import",
    "RdsClusterScalingConfiguration",
    "RdsClusterTimeouts",
    "RdsGlobalCluster",
    "RdsGlobalClusterConfig",
    "RedshiftCluster",
    "RedshiftClusterConfig",
    "RedshiftClusterLogging",
    "RedshiftClusterSnapshotCopy",
    "RedshiftClusterTimeouts",
    "RedshiftEventSubscription",
    "RedshiftEventSubscriptionConfig",
    "RedshiftEventSubscriptionTimeouts",
    "RedshiftParameterGroup",
    "RedshiftParameterGroupConfig",
    "RedshiftParameterGroupParameter",
    "RedshiftSecurityGroup",
    "RedshiftSecurityGroupConfig",
    "RedshiftSecurityGroupIngress",
    "RedshiftSnapshotCopyGrant",
    "RedshiftSnapshotCopyGrantConfig",
    "RedshiftSnapshotSchedule",
    "RedshiftSnapshotScheduleAssociation",
    "RedshiftSnapshotScheduleAssociationConfig",
    "RedshiftSnapshotScheduleConfig",
    "RedshiftSubnetGroup",
    "RedshiftSubnetGroupConfig",
    "ResourcegroupsGroup",
    "ResourcegroupsGroupConfig",
    "ResourcegroupsGroupResourceQuery",
    "Route",
    "Route53DelegationSet",
    "Route53DelegationSetConfig",
    "Route53HealthCheck",
    "Route53HealthCheckConfig",
    "Route53QueryLog",
    "Route53QueryLogConfig",
    "Route53Record",
    "Route53RecordAlias",
    "Route53RecordConfig",
    "Route53RecordFailoverRoutingPolicy",
    "Route53RecordGeolocationRoutingPolicy",
    "Route53RecordLatencyRoutingPolicy",
    "Route53RecordWeightedRoutingPolicy",
    "Route53ResolverEndpoint",
    "Route53ResolverEndpointConfig",
    "Route53ResolverEndpointIpAddress",
    "Route53ResolverEndpointTimeouts",
    "Route53ResolverRule",
    "Route53ResolverRuleAssociation",
    "Route53ResolverRuleAssociationConfig",
    "Route53ResolverRuleAssociationTimeouts",
    "Route53ResolverRuleConfig",
    "Route53ResolverRuleTargetIp",
    "Route53ResolverRuleTimeouts",
    "Route53Zone",
    "Route53ZoneAssociation",
    "Route53ZoneAssociationConfig",
    "Route53ZoneConfig",
    "Route53ZoneVpc",
    "RouteConfig",
    "RouteTable",
    "RouteTableAssociation",
    "RouteTableAssociationConfig",
    "RouteTableConfig",
    "RouteTableRoute",
    "RouteTimeouts",
    "S3AccessPoint",
    "S3AccessPointConfig",
    "S3AccessPointPublicAccessBlockConfiguration",
    "S3AccessPointVpcConfiguration",
    "S3AccountPublicAccessBlock",
    "S3AccountPublicAccessBlockConfig",
    "S3Bucket",
    "S3BucketAnalyticsConfiguration",
    "S3BucketAnalyticsConfigurationConfig",
    "S3BucketAnalyticsConfigurationFilter",
    "S3BucketAnalyticsConfigurationStorageClassAnalysis",
    "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExport",
    "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestination",
    "S3BucketAnalyticsConfigurationStorageClassAnalysisDataExportDestinationS3BucketDestination",
    "S3BucketConfig",
    "S3BucketCorsRule",
    "S3BucketGrant",
    "S3BucketInventory",
    "S3BucketInventoryConfig",
    "S3BucketInventoryDestination",
    "S3BucketInventoryDestinationBucket",
    "S3BucketInventoryDestinationBucketEncryption",
    "S3BucketInventoryDestinationBucketEncryptionSseKms",
    "S3BucketInventoryDestinationBucketEncryptionSseS3",
    "S3BucketInventoryFilter",
    "S3BucketInventorySchedule",
    "S3BucketLifecycleRule",
    "S3BucketLifecycleRuleExpiration",
    "S3BucketLifecycleRuleNoncurrentVersionExpiration",
    "S3BucketLifecycleRuleNoncurrentVersionTransition",
    "S3BucketLifecycleRuleTransition",
    "S3BucketLogging",
    "S3BucketMetric",
    "S3BucketMetricConfig",
    "S3BucketMetricFilter",
    "S3BucketNotification",
    "S3BucketNotificationConfig",
    "S3BucketNotificationLambdaFunction",
    "S3BucketNotificationQueue",
    "S3BucketNotificationTopic",
    "S3BucketObject",
    "S3BucketObjectConfig",
    "S3BucketObjectLockConfiguration",
    "S3BucketObjectLockConfigurationRule",
    "S3BucketObjectLockConfigurationRuleDefaultRetention",
    "S3BucketPolicy",
    "S3BucketPolicyConfig",
    "S3BucketPublicAccessBlock",
    "S3BucketPublicAccessBlockConfig",
    "S3BucketReplicationConfiguration",
    "S3BucketReplicationConfigurationRules",
    "S3BucketReplicationConfigurationRulesDestination",
    "S3BucketReplicationConfigurationRulesDestinationAccessControlTranslation",
    "S3BucketReplicationConfigurationRulesFilter",
    "S3BucketReplicationConfigurationRulesSourceSelectionCriteria",
    "S3BucketReplicationConfigurationRulesSourceSelectionCriteriaSseKmsEncryptedObjects",
    "S3BucketServerSideEncryptionConfiguration",
    "S3BucketServerSideEncryptionConfigurationRule",
    "S3BucketServerSideEncryptionConfigurationRuleApplyServerSideEncryptionByDefault",
    "S3BucketVersioning",
    "S3BucketWebsite",
    "SagemakerEndpoint",
    "SagemakerEndpointConfig",
    "SagemakerEndpointConfiguration",
    "SagemakerEndpointConfigurationConfig",
    "SagemakerEndpointConfigurationProductionVariants",
    "SagemakerModel",
    "SagemakerModelConfig",
    "SagemakerModelContainer",
    "SagemakerModelPrimaryContainer",
    "SagemakerModelVpcConfig",
    "SagemakerNotebookInstance",
    "SagemakerNotebookInstanceConfig",
    "SagemakerNotebookInstanceLifecycleConfiguration",
    "SagemakerNotebookInstanceLifecycleConfigurationConfig",
    "SecretsmanagerSecret",
    "SecretsmanagerSecretConfig",
    "SecretsmanagerSecretRotation",
    "SecretsmanagerSecretRotationConfig",
    "SecretsmanagerSecretRotationRotationRules",
    "SecretsmanagerSecretRotationRules",
    "SecretsmanagerSecretVersion",
    "SecretsmanagerSecretVersionConfig",
    "SecurityGroup",
    "SecurityGroupConfig",
    "SecurityGroupEgress",
    "SecurityGroupIngress",
    "SecurityGroupRule",
    "SecurityGroupRuleConfig",
    "SecurityGroupTimeouts",
    "SecurityhubAccount",
    "SecurityhubAccountConfig",
    "SecurityhubMember",
    "SecurityhubMemberConfig",
    "SecurityhubProductSubscription",
    "SecurityhubProductSubscriptionConfig",
    "SecurityhubStandardsSubscription",
    "SecurityhubStandardsSubscriptionConfig",
    "ServiceDiscoveryHttpNamespace",
    "ServiceDiscoveryHttpNamespaceConfig",
    "ServiceDiscoveryPrivateDnsNamespace",
    "ServiceDiscoveryPrivateDnsNamespaceConfig",
    "ServiceDiscoveryPublicDnsNamespace",
    "ServiceDiscoveryPublicDnsNamespaceConfig",
    "ServiceDiscoveryService",
    "ServiceDiscoveryServiceConfig",
    "ServiceDiscoveryServiceDnsConfig",
    "ServiceDiscoveryServiceDnsConfigDnsRecords",
    "ServiceDiscoveryServiceHealthCheckConfig",
    "ServiceDiscoveryServiceHealthCheckCustomConfig",
    "ServicecatalogPortfolio",
    "ServicecatalogPortfolioConfig",
    "ServicecatalogPortfolioTimeouts",
    "ServicequotasServiceQuota",
    "ServicequotasServiceQuotaConfig",
    "SesActiveReceiptRuleSet",
    "SesActiveReceiptRuleSetConfig",
    "SesConfigurationSet",
    "SesConfigurationSetConfig",
    "SesDomainDkim",
    "SesDomainDkimConfig",
    "SesDomainIdentity",
    "SesDomainIdentityConfig",
    "SesDomainIdentityVerification",
    "SesDomainIdentityVerificationConfig",
    "SesDomainIdentityVerificationTimeouts",
    "SesDomainMailFrom",
    "SesDomainMailFromConfig",
    "SesEmailIdentity",
    "SesEmailIdentityConfig",
    "SesEventDestination",
    "SesEventDestinationCloudwatchDestination",
    "SesEventDestinationConfig",
    "SesEventDestinationKinesisDestination",
    "SesEventDestinationSnsDestination",
    "SesIdentityNotificationTopic",
    "SesIdentityNotificationTopicConfig",
    "SesIdentityPolicy",
    "SesIdentityPolicyConfig",
    "SesReceiptFilter",
    "SesReceiptFilterConfig",
    "SesReceiptRule",
    "SesReceiptRuleAddHeaderAction",
    "SesReceiptRuleBounceAction",
    "SesReceiptRuleConfig",
    "SesReceiptRuleLambdaAction",
    "SesReceiptRuleS3Action",
    "SesReceiptRuleSet",
    "SesReceiptRuleSetConfig",
    "SesReceiptRuleSnsAction",
    "SesReceiptRuleStopAction",
    "SesReceiptRuleWorkmailAction",
    "SesTemplate",
    "SesTemplateConfig",
    "SfnActivity",
    "SfnActivityConfig",
    "SfnStateMachine",
    "SfnStateMachineConfig",
    "ShieldProtection",
    "ShieldProtectionConfig",
    "SimpledbDomain",
    "SimpledbDomainConfig",
    "SnapshotCreateVolumePermission",
    "SnapshotCreateVolumePermissionConfig",
    "SnsPlatformApplication",
    "SnsPlatformApplicationConfig",
    "SnsSmsPreferences",
    "SnsSmsPreferencesConfig",
    "SnsTopic",
    "SnsTopicConfig",
    "SnsTopicPolicy",
    "SnsTopicPolicyConfig",
    "SnsTopicSubscription",
    "SnsTopicSubscriptionConfig",
    "SpotDatafeedSubscription",
    "SpotDatafeedSubscriptionConfig",
    "SpotFleetRequest",
    "SpotFleetRequestConfig",
    "SpotFleetRequestLaunchSpecification",
    "SpotFleetRequestLaunchSpecificationEbsBlockDevice",
    "SpotFleetRequestLaunchSpecificationEphemeralBlockDevice",
    "SpotFleetRequestLaunchSpecificationRootBlockDevice",
    "SpotFleetRequestLaunchTemplateConfig",
    "SpotFleetRequestLaunchTemplateConfigLaunchTemplateSpecification",
    "SpotFleetRequestLaunchTemplateConfigOverrides",
    "SpotFleetRequestTimeouts",
    "SpotInstanceRequest",
    "SpotInstanceRequestConfig",
    "SpotInstanceRequestCreditSpecification",
    "SpotInstanceRequestEbsBlockDevice",
    "SpotInstanceRequestEphemeralBlockDevice",
    "SpotInstanceRequestMetadataOptions",
    "SpotInstanceRequestNetworkInterface",
    "SpotInstanceRequestRootBlockDevice",
    "SpotInstanceRequestTimeouts",
    "SqsQueue",
    "SqsQueueConfig",
    "SqsQueuePolicy",
    "SqsQueuePolicyConfig",
    "SsmActivation",
    "SsmActivationConfig",
    "SsmAssociation",
    "SsmAssociationConfig",
    "SsmAssociationOutputLocation",
    "SsmAssociationTargets",
    "SsmDocument",
    "SsmDocumentAttachmentsSource",
    "SsmDocumentConfig",
    "SsmDocumentParameter",
    "SsmMaintenanceWindow",
    "SsmMaintenanceWindowConfig",
    "SsmMaintenanceWindowTarget",
    "SsmMaintenanceWindowTargetConfig",
    "SsmMaintenanceWindowTargetTargets",
    "SsmMaintenanceWindowTask",
    "SsmMaintenanceWindowTaskConfig",
    "SsmMaintenanceWindowTaskLoggingInfo",
    "SsmMaintenanceWindowTaskTargets",
    "SsmMaintenanceWindowTaskTaskInvocationParameters",
    "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParameters",
    "SsmMaintenanceWindowTaskTaskInvocationParametersAutomationParametersParameter",
    "SsmMaintenanceWindowTaskTaskInvocationParametersLambdaParameters",
    "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParameters",
    "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersNotificationConfig",
    "SsmMaintenanceWindowTaskTaskInvocationParametersRunCommandParametersParameter",
    "SsmMaintenanceWindowTaskTaskInvocationParametersStepFunctionsParameters",
    "SsmMaintenanceWindowTaskTaskParameters",
    "SsmParameter",
    "SsmParameterConfig",
    "SsmPatchBaseline",
    "SsmPatchBaselineApprovalRule",
    "SsmPatchBaselineApprovalRulePatchFilter",
    "SsmPatchBaselineConfig",
    "SsmPatchBaselineGlobalFilter",
    "SsmPatchGroup",
    "SsmPatchGroupConfig",
    "SsmResourceDataSync",
    "SsmResourceDataSyncConfig",
    "SsmResourceDataSyncS3Destination",
    "StoragegatewayCache",
    "StoragegatewayCacheConfig",
    "StoragegatewayCachedIscsiVolume",
    "StoragegatewayCachedIscsiVolumeConfig",
    "StoragegatewayGateway",
    "StoragegatewayGatewayConfig",
    "StoragegatewayGatewaySmbActiveDirectorySettings",
    "StoragegatewayGatewayTimeouts",
    "StoragegatewayNfsFileShare",
    "StoragegatewayNfsFileShareConfig",
    "StoragegatewayNfsFileShareNfsFileShareDefaults",
    "StoragegatewayNfsFileShareTimeouts",
    "StoragegatewaySmbFileShare",
    "StoragegatewaySmbFileShareConfig",
    "StoragegatewaySmbFileShareTimeouts",
    "StoragegatewayUploadBuffer",
    "StoragegatewayUploadBufferConfig",
    "StoragegatewayWorkingStorage",
    "StoragegatewayWorkingStorageConfig",
    "Subnet",
    "SubnetConfig",
    "SubnetTimeouts",
    "SwfDomain",
    "SwfDomainConfig",
    "TransferServer",
    "TransferServerConfig",
    "TransferServerEndpointDetails",
    "TransferSshKey",
    "TransferSshKeyConfig",
    "TransferUser",
    "TransferUserConfig",
    "VolumeAttachment",
    "VolumeAttachmentConfig",
    "Vpc",
    "VpcConfig",
    "VpcDhcpOptions",
    "VpcDhcpOptionsAssociation",
    "VpcDhcpOptionsAssociationConfig",
    "VpcDhcpOptionsConfig",
    "VpcEndpoint",
    "VpcEndpointConfig",
    "VpcEndpointConnectionNotification",
    "VpcEndpointConnectionNotificationConfig",
    "VpcEndpointDnsEntry",
    "VpcEndpointRouteTableAssociation",
    "VpcEndpointRouteTableAssociationConfig",
    "VpcEndpointService",
    "VpcEndpointServiceAllowedPrincipal",
    "VpcEndpointServiceAllowedPrincipalConfig",
    "VpcEndpointServiceConfig",
    "VpcEndpointSubnetAssociation",
    "VpcEndpointSubnetAssociationConfig",
    "VpcEndpointSubnetAssociationTimeouts",
    "VpcEndpointTimeouts",
    "VpcIpv4CidrBlockAssociation",
    "VpcIpv4CidrBlockAssociationConfig",
    "VpcIpv4CidrBlockAssociationTimeouts",
    "VpcPeeringConnection",
    "VpcPeeringConnectionAccepter",
    "VpcPeeringConnectionAccepterA",
    "VpcPeeringConnectionAccepterAConfig",
    "VpcPeeringConnectionAccepterAccepter",
    "VpcPeeringConnectionAccepterRequester",
    "VpcPeeringConnectionConfig",
    "VpcPeeringConnectionOptions",
    "VpcPeeringConnectionOptionsAccepter",
    "VpcPeeringConnectionOptionsConfig",
    "VpcPeeringConnectionOptionsRequester",
    "VpcPeeringConnectionRequester",
    "VpcPeeringConnectionTimeouts",
    "VpnConnection",
    "VpnConnectionConfig",
    "VpnConnectionRoute",
    "VpnConnectionRouteConfig",
    "VpnConnectionRoutes",
    "VpnConnectionVgwTelemetry",
    "VpnGateway",
    "VpnGatewayAttachment",
    "VpnGatewayAttachmentConfig",
    "VpnGatewayConfig",
    "VpnGatewayRoutePropagation",
    "VpnGatewayRoutePropagationConfig",
    "WafByteMatchSet",
    "WafByteMatchSetByteMatchTuples",
    "WafByteMatchSetByteMatchTuplesFieldToMatch",
    "WafByteMatchSetConfig",
    "WafGeoMatchSet",
    "WafGeoMatchSetConfig",
    "WafGeoMatchSetGeoMatchConstraint",
    "WafIpset",
    "WafIpsetConfig",
    "WafIpsetIpSetDescriptors",
    "WafRateBasedRule",
    "WafRateBasedRuleConfig",
    "WafRateBasedRulePredicates",
    "WafRegexMatchSet",
    "WafRegexMatchSetConfig",
    "WafRegexMatchSetRegexMatchTuple",
    "WafRegexMatchSetRegexMatchTupleFieldToMatch",
    "WafRegexPatternSet",
    "WafRegexPatternSetConfig",
    "WafRule",
    "WafRuleConfig",
    "WafRuleGroup",
    "WafRuleGroupActivatedRule",
    "WafRuleGroupActivatedRuleAction",
    "WafRuleGroupConfig",
    "WafRulePredicates",
    "WafSizeConstraintSet",
    "WafSizeConstraintSetConfig",
    "WafSizeConstraintSetSizeConstraints",
    "WafSizeConstraintSetSizeConstraintsFieldToMatch",
    "WafSqlInjectionMatchSet",
    "WafSqlInjectionMatchSetConfig",
    "WafSqlInjectionMatchSetSqlInjectionMatchTuples",
    "WafSqlInjectionMatchSetSqlInjectionMatchTuplesFieldToMatch",
    "WafWebAcl",
    "WafWebAclConfig",
    "WafWebAclDefaultAction",
    "WafWebAclLoggingConfiguration",
    "WafWebAclLoggingConfigurationRedactedFields",
    "WafWebAclLoggingConfigurationRedactedFieldsFieldToMatch",
    "WafWebAclRules",
    "WafWebAclRulesAction",
    "WafWebAclRulesOverrideAction",
    "WafXssMatchSet",
    "WafXssMatchSetConfig",
    "WafXssMatchSetXssMatchTuples",
    "WafXssMatchSetXssMatchTuplesFieldToMatch",
    "WafregionalByteMatchSet",
    "WafregionalByteMatchSetByteMatchTuple",
    "WafregionalByteMatchSetByteMatchTupleFieldToMatch",
    "WafregionalByteMatchSetByteMatchTuples",
    "WafregionalByteMatchSetByteMatchTuplesFieldToMatch",
    "WafregionalByteMatchSetConfig",
    "WafregionalGeoMatchSet",
    "WafregionalGeoMatchSetConfig",
    "WafregionalGeoMatchSetGeoMatchConstraint",
    "WafregionalIpset",
    "WafregionalIpsetConfig",
    "WafregionalIpsetIpSetDescriptor",
    "WafregionalRateBasedRule",
    "WafregionalRateBasedRuleConfig",
    "WafregionalRateBasedRulePredicate",
    "WafregionalRegexMatchSet",
    "WafregionalRegexMatchSetConfig",
    "WafregionalRegexMatchSetRegexMatchTuple",
    "WafregionalRegexMatchSetRegexMatchTupleFieldToMatch",
    "WafregionalRegexPatternSet",
    "WafregionalRegexPatternSetConfig",
    "WafregionalRule",
    "WafregionalRuleConfig",
    "WafregionalRuleGroup",
    "WafregionalRuleGroupActivatedRule",
    "WafregionalRuleGroupActivatedRuleAction",
    "WafregionalRuleGroupConfig",
    "WafregionalRulePredicate",
    "WafregionalSizeConstraintSet",
    "WafregionalSizeConstraintSetConfig",
    "WafregionalSizeConstraintSetSizeConstraints",
    "WafregionalSizeConstraintSetSizeConstraintsFieldToMatch",
    "WafregionalSqlInjectionMatchSet",
    "WafregionalSqlInjectionMatchSetConfig",
    "WafregionalSqlInjectionMatchSetSqlInjectionMatchTuple",
    "WafregionalSqlInjectionMatchSetSqlInjectionMatchTupleFieldToMatch",
    "WafregionalWebAcl",
    "WafregionalWebAclAssociation",
    "WafregionalWebAclAssociationConfig",
    "WafregionalWebAclConfig",
    "WafregionalWebAclDefaultAction",
    "WafregionalWebAclLoggingConfiguration",
    "WafregionalWebAclLoggingConfigurationRedactedFields",
    "WafregionalWebAclLoggingConfigurationRedactedFieldsFieldToMatch",
    "WafregionalWebAclRule",
    "WafregionalWebAclRuleAction",
    "WafregionalWebAclRuleOverrideAction",
    "WafregionalXssMatchSet",
    "WafregionalXssMatchSetConfig",
    "WafregionalXssMatchSetXssMatchTuple",
    "WafregionalXssMatchSetXssMatchTupleFieldToMatch",
    "Wafv2IpSet",
    "Wafv2IpSetConfig",
    "Wafv2RegexPatternSet",
    "Wafv2RegexPatternSetConfig",
    "Wafv2RegexPatternSetRegularExpression",
    "Wafv2RuleGroup",
    "Wafv2RuleGroupConfig",
    "Wafv2RuleGroupRule",
    "Wafv2RuleGroupRuleAction",
    "Wafv2RuleGroupRuleActionAllow",
    "Wafv2RuleGroupRuleActionBlock",
    "Wafv2RuleGroupRuleActionCount",
    "Wafv2RuleGroupRuleStatement",
    "Wafv2RuleGroupRuleStatementAndStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatement",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatement",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementSizeConstraintStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementSqliMatchStatement",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementSqliMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleStatementXssMatchStatement",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatch",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchBody",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2RuleGroupRuleStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2RuleGroupRuleStatementXssMatchStatementTextTransformation",
    "Wafv2RuleGroupRuleVisibilityConfig",
    "Wafv2RuleGroupVisibilityConfig",
    "Wafv2WebAcl",
    "Wafv2WebAclAssociation",
    "Wafv2WebAclAssociationConfig",
    "Wafv2WebAclConfig",
    "Wafv2WebAclDefaultAction",
    "Wafv2WebAclDefaultActionAllow",
    "Wafv2WebAclDefaultActionBlock",
    "Wafv2WebAclLoggingConfiguration",
    "Wafv2WebAclLoggingConfigurationConfig",
    "Wafv2WebAclLoggingConfigurationRedactedFields",
    "Wafv2WebAclLoggingConfigurationRedactedFieldsAllQueryArguments",
    "Wafv2WebAclLoggingConfigurationRedactedFieldsBody",
    "Wafv2WebAclLoggingConfigurationRedactedFieldsMethod",
    "Wafv2WebAclLoggingConfigurationRedactedFieldsQueryString",
    "Wafv2WebAclLoggingConfigurationRedactedFieldsSingleHeader",
    "Wafv2WebAclLoggingConfigurationRedactedFieldsSingleQueryArgument",
    "Wafv2WebAclLoggingConfigurationRedactedFieldsUriPath",
    "Wafv2WebAclRule",
    "Wafv2WebAclRuleAction",
    "Wafv2WebAclRuleActionAllow",
    "Wafv2WebAclRuleActionBlock",
    "Wafv2WebAclRuleActionCount",
    "Wafv2WebAclRuleOverrideAction",
    "Wafv2WebAclRuleOverrideActionCount",
    "Wafv2WebAclRuleOverrideActionNone",
    "Wafv2WebAclRuleStatement",
    "Wafv2WebAclRuleStatementAndStatement",
    "Wafv2WebAclRuleStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementManagedRuleGroupStatement",
    "Wafv2WebAclRuleStatementManagedRuleGroupStatementExcludedRule",
    "Wafv2WebAclRuleStatementNotStatement",
    "Wafv2WebAclRuleStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatement",
    "Wafv2WebAclRuleStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementAndStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementNotStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementByteMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementGeoMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementIpSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementOrStatementStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRateBasedStatementScopeDownStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatement",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatch",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementRegexPatternSetReferenceStatementTextTransformation",
    "Wafv2WebAclRuleStatementRuleGroupReferenceStatement",
    "Wafv2WebAclRuleStatementRuleGroupReferenceStatementExcludedRule",
    "Wafv2WebAclRuleStatementSizeConstraintStatement",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatch",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementSizeConstraintStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementSizeConstraintStatementTextTransformation",
    "Wafv2WebAclRuleStatementSqliMatchStatement",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementSqliMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementSqliMatchStatementTextTransformation",
    "Wafv2WebAclRuleStatementXssMatchStatement",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatch",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchAllQueryArguments",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchBody",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchMethod",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchQueryString",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleHeader",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchSingleQueryArgument",
    "Wafv2WebAclRuleStatementXssMatchStatementFieldToMatchUriPath",
    "Wafv2WebAclRuleStatementXssMatchStatementTextTransformation",
    "Wafv2WebAclRuleVisibilityConfig",
    "Wafv2WebAclVisibilityConfig",
    "WorklinkFleet",
    "WorklinkFleetConfig",
    "WorklinkFleetIdentityProvider",
    "WorklinkFleetNetwork",
    "WorklinkWebsiteCertificateAuthorityAssociation",
    "WorklinkWebsiteCertificateAuthorityAssociationConfig",
    "WorkspacesDirectory",
    "WorkspacesDirectoryConfig",
    "WorkspacesDirectorySelfServicePermissions",
    "WorkspacesIpGroup",
    "WorkspacesIpGroupConfig",
    "WorkspacesIpGroupRules",
    "WorkspacesWorkspace",
    "WorkspacesWorkspaceConfig",
    "WorkspacesWorkspaceWorkspaceProperties",
    "XraySamplingRule",
    "XraySamplingRuleConfig",
]

publication.publish()
